@@ -23,23 +23,19 @@
 ##
 
 import os
-import sys
 
 from kiwi.environ import environ
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.migration import PluginSchemaMigration
 from stoqlib.lib.interfaces import IPlugin
 from stoqlib.lib.pluginmanager import register_plugin
 
-plugin_root = os.path.dirname(__file__)
-sys.path.append(plugin_root)
-
-from booksui import BooksUI
+from books.booksui import BooksUI
 
 
+@implementer(IPlugin)
 class BooksPlugin(object):
-    implements(IPlugin)
     name = u'books'
     has_product_slave = True
 
@@ -51,14 +47,16 @@ class BooksPlugin(object):
     #
 
     def get_migration(self):
-        environ.add_resource('booksql', os.path.join(plugin_root, 'sql'))
+        environ.add_resource('booksql',
+                             os.path.join(os.path.dirname(__file__), 'sql'))
         return PluginSchemaMigration(self.name, 'booksql', ['*.sql'])
 
     def get_tables(self):
-        return [('bookdomain', ['BookPublisher', 'Book'])]
+        return [('booksdomain', ['BookPublisher', 'Book'])]
 
     def activate(self):
-        environ.add_resource('glade', os.path.join(plugin_root, 'glade'))
+        environ.add_resource('glade',
+                             os.path.join(os.path.dirname(__file__), 'glade'))
         self.ui = BooksUI()
 
     def get_dbadmin_commands(self):
