@@ -26,21 +26,19 @@
 from decimal import Decimal
 
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import SearchColumn
 
-from stoqlib.domain.sellable import Sellable
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.search.productsearch import ProductSearch
+from stoqlib.gui.search.searchcolumns import SearchColumn
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.lib.formatters import format_quantity, get_formatted_cost
 
-from booksdomain import ProductBookFullStockView
+from books.booksdomain import ProductBookFullStockView
 
 
 class ProductBookSearch(ProductSearch):
     title = _('Book Search')
-    search_table = ProductBookFullStockView
+    search_spec = ProductBookFullStockView
 
     def _setup_widgets(self):
         if not self.hide_cost_column:
@@ -59,7 +57,7 @@ class ProductBookSearch(ProductSearch):
         self.set_text_field_columns(['description', 'barcode',
                                      'category_description', 'author',
                                      'publisher', 'isbn'])
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
 
         # Branch
         branch_filter = self.create_branch_filter(_('In branch:'))
@@ -68,10 +66,7 @@ class ProductBookSearch(ProductSearch):
         self.branch_filter = branch_filter
 
         # Status
-        statuses = [(desc, id) for id, desc in Sellable.statuses.items()]
-        statuses.insert(0, (_('Any'), None))
-        status_filter = ComboSearchFilter(_('with status:'), statuses)
-        status_filter.select(None)
+        status_filter = self.create_sellable_filter()
         self.add_filter(status_filter, columns=['status'],
                         position=SearchFilterPosition.TOP)
 
@@ -81,26 +76,26 @@ class ProductBookSearch(ProductSearch):
 
     def get_columns(self):
         cols = [SearchColumn('barcode', title=_('Barcode'), data_type=str,
-                              sorted=True, width=130),
+                             sorted=True, width=130),
                 SearchColumn('code', title=_('Code'), data_type=str,
-                              visible=False),
+                             visible=False),
                 SearchColumn('category_description', title=_(u'Category'),
-                              data_type=str, width=100),
+                             data_type=str, width=100),
                 SearchColumn('subject', title=_(u'Subject'), data_type=str),
                 SearchColumn('description', title=_(u'Title'),
-                              expand=True, data_type=str),
+                             expand=True, data_type=str),
                 SearchColumn('author', title=_(u'Author'),
-                              expand=True, data_type=str),
+                             expand=True, data_type=str),
                 SearchColumn('publisher', title=_(u'Publisher'),
-                              expand=True, data_type=str),
+                             expand=True, data_type=str),
                 SearchColumn('isbn', title=_(u'ISBN'), data_type=str),
                 SearchColumn('volume', title=_(u'Volume'), data_type=str,
-                              visible=False),
+                             visible=False),
                 SearchColumn('series', title=_(u'Series'), data_type=str,
-                              visible=False),
+                             visible=False),
                 SearchColumn('language', title=_(u'Language'), data_type=str,
-                              visible=False),
-        ]
+                             visible=False),
+                ]
         # The price/cost columns must be controlled by hide_cost_column and
         # hide_price_column. Since the product search will be available across
         # the applications, it's important to restrict such columns depending
