@@ -30,9 +30,9 @@ from kiwi.datatypes import number
 from stoqdrivers.enum import TaxType
 from stoqlib.lib import latscii
 
-latscii.register_codec()
+from ecf.ecfdomain import ECFDocumentHistory
 
-from ecfdomain import ECFDocumentHistory
+latscii.register_codec()
 
 
 def _argtype_name(argtype):
@@ -41,7 +41,8 @@ def _argtype_name(argtype):
     else:
         return argtype.__name__
 
-# See http://www.fazenda.sp.gov.br/publicacao/noticia.aspx?id=571
+# See
+# http://www.fazenda.gov.br/confaz/confaz/atos/atos_cotepe/2004/ac017_04.htm
 # for a complete list of this:
 
 BRAND_CODES = {
@@ -52,7 +53,6 @@ BRAND_CODES = {
 MODEL_CODES = {
     ('daruma', 'FS345'): 4,
     ('bematech', 'MP25'): 1,
-    ('bematech', 'MP2100'): 'E',
 }
 
 BRAND_FULL_NAME = {
@@ -63,7 +63,6 @@ BRAND_FULL_NAME = {
 MODEL_FULL_NAME = {
     ('daruma', 'FS345'): 'FS-345',
     ('bematech', 'MP25'): 'MP-20 FI',
-    ('bematech', 'MP2100'): 'MP-2100 TH FI',
 }
 
 DOCUMENT_TYPES = {
@@ -174,7 +173,7 @@ class CATFile(object):
                                 register_date=self.printer.register_date.date(),
                                 register_hour=self.printer.register_date.time(),
                                 cro=self.printer.register_cro,
-                                total=int(total * 100), # 2 decimal positions
+                                total=int(total * 100),  # 2 decimal positions
                                 user_number=self.printer.user_number,
                                 ))
 
@@ -250,7 +249,7 @@ class CATFile(object):
         cpf_cnpj = 0
         if fiscal_data.document:
             cpf_cnpj = int(''.join([c for c in fiscal_data.document
-                                          if c.isdigit()]))
+                                    if c.isdigit()]))
 
         self.add(CATRegisterE14(serial_number=self.printer.device_serial,
                                 additional_mf='',
@@ -267,11 +266,11 @@ class CATFile(object):
                                 total=sale.total_amount,
                                 canceled=False,                     # !!!
                                 surcharge_canceled=0,
-                                #stoqlib/domain/sale.py:489
+                                # stoqlib/domain/sale.py:489
                                 discount_surcharge_order='A',
                                 client_name=client_name,
                                 client_cpf_cnpj=cpf_cnpj,
-        ))
+                                ))
 
     # E15
     def add_fiscal_coupon_details(self, sale, client, fiscal_data,
@@ -303,7 +302,7 @@ class CATFile(object):
             item_description=item.get_description(),
             # precision = 2
             item_amount=item.quantity * 100,
-            item_unit=(item.sellable.get_unit_description() or 'un'),
+            item_unit=(item.sellable.unit_description or 'un'),
             item_unitary_value=item.price * 100,
             # We don't offer discount,
             item_discount=0,
@@ -351,7 +350,7 @@ class CATFile(object):
             value=payment.value * 100,
             returned=returned,                      # S/N/P
             returned_value=returned_value * 100,    # Only if P
-            ))
+        ))
 
     # E16
     def add_other_document(self, document):
@@ -407,22 +406,21 @@ class CATRegister(object):
         if len(kwargs) != len(self.register_fields):
             raise TypeError('%s expected %d parameters but got %d' % (
                 self.__class__.__name__, len(self.register_fields),
-                                             len(kwargs)))
+                            len(kwargs)))
 
         sent_args = dict([(field[0], field[1:2])
                           for field in zip(self.register_fields,
                                            kwargs.values())])
         for key in kwargs:
             if key in sent_args:
-                raise CATRegister("%s specified two times" % (key, ))
+                raise CATError("%s specified two times" % (key, ))
 
         self._values = {}
         for (name, length, argtype) in self.register_fields:
             if kwargs[name] == "":
                 pass
             elif not isinstance(kwargs[name], argtype):
-                raise TypeError(
-                    "argument %s should be of type %s but got %s" % (
+                raise TypeError("argument %s should be of type %s but got %s" % (
                     name, _argtype_name(argtype), type(kwargs[name]).__name__))
             self._values[name] = self._arg_to_string(kwargs[name], length,
                                                      argtype)
@@ -440,7 +438,7 @@ class CATRegister(object):
         for (name, a, b) in self.register_fields:
             values.append(self._values[name])
         return '%s%s\r\n' % (self.register_type,
-                              ''.join(values))
+                             ''.join(values))
     #
     # Private
     #
@@ -512,7 +510,7 @@ class CATRegisterE00(CATRegister):
         ('soft_version', 10, basestring),
         ('line01', 42, basestring),
         ('line02', 42, basestring),
-        ]
+    ]
 
 
 class CATRegisterE01(CATRegister):
@@ -537,7 +535,7 @@ class CATRegisterE01(CATRegister):
         ('final_date', 8, datetime.date),
         ('library_version', 8, basestring),
         ('cotepe', 15, basestring),
-        ]
+    ]
 
 
 class CATRegisterE02(CATRegister):
@@ -560,7 +558,165 @@ class CATRegisterE02(CATRegister):
         ('cro', 6, number),
         ('total', 18, number),
         ('user_number', 2, number),
-        ]
+    ]
+
+
+class CATRegisterE03(CATRegister):
+    """Register E03 - Service Provider Identification
+    """
+    register_type = "E03"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('provider_number', 2, number),
+        ('register_date', 8, datetime.date),
+        ('register_hour', 6, datetime.time),
+        ('provider_cnpj', 14, number),
+        ('provider_ie', 14, basestring),
+        ('total', 18, number)
+    ]
+
+
+class CATRegisterE04(CATRegister):
+    """Register E04 - Previous Users list
+    """
+    register_type = "E04"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_number', 2, number),
+        ('register_date', 8, datetime.date),
+        ('register_hour', 6, datetime.time),
+        ('user_cnpj', 14, number),
+        ('user_ie', 14, basestring),
+        ('cro', 6, number),
+        ('gt', 18, number)
+    ]
+
+
+class CATRegisterE05(CATRegister):
+    """Register E05 - GT Encodings
+    """
+    register_type = "E05"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_cnpj', 14, number),
+        ('register_date', 8, datetime.date),
+        ('register_hour', 6, datetime.time),
+        ('c0', 1, basestring),
+        ('c1', 1, basestring),
+        ('c2', 1, basestring),
+        ('c3', 1, basestring),
+        ('c4', 1, basestring),
+        ('c5', 1, basestring),
+        ('c6', 1, basestring),
+        ('c7', 1, basestring),
+        ('c8', 1, basestring),
+        ('c9', 1, basestring),
+    ]
+
+
+class CATRegisterE06(CATRegister):
+    """Register E06 - Currency Symbols list
+    """
+    register_type = "E06"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_cnpj', 14, number),
+        ('register_date', 8, datetime.date),
+        ('register_hour', 6, datetime.time),
+        ('currency_symbol', 4, basestring)
+    ]
+
+
+class CATRegisterE07(CATRegister):
+    """Register E07 - Changes in ECF software version.
+    """
+    register_type = "E07"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('software_version', 10, basestring),
+        ('register_date', 8, datetime.date)
+    ]
+
+
+class CATRegisterE08(CATRegister):
+    """Register E08 - MFD devices list
+    """
+    register_type = "E08"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_cnpj', 14, number),
+        ('mfd_number', 20, basestring)
+    ]
+
+
+class CATRegisterE09(CATRegister):
+    """Register E09 - Technical Intervention list
+    """
+    register_type = "E09"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('cro', 6, number),
+        ('register_date', 8, datetime.date),
+        ('register_hour', 6, datetime.time),
+        ('lost_mt_data', 1, bool)
+    ]
+
+
+class CATRegisterE10(CATRegister):
+    # RFD - Registro de fita-detalhe
+    """Register E10 - Issued RFD list
+    """
+    register_type = "E10"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('cfd', 6, number),
+        ('emission_date', 8, datetime.date),
+        ('initial_coo', 6, number),
+        ('final_coo', 6, number),
+        ('user_cnpj', 14, number)
+    ]
+
+
+class CATRegisterE11(CATRegister):
+    """Register E11 - Current position of counters and totalizers
+    """
+    register_type = "E11"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('crz', 6, number),
+        ('cro', 6, number),
+        ('coo', 6, number),
+        ('gnf', 6, number),
+        ('ccf', 6, number),
+        ('cvc', 6, number),
+        ('cbp', 6, number),
+        ('crg', 6, number),
+        ('cmv', 6, number),
+        ('cfd', 6, number),
+        ('gt', 18, number),
+        # Date that file was generated
+        ('capture_date', 8, datetime.date),
+        # Hour that file was generated
+        ('capture_hour', 6, datetime.time)
+    ]
 
 
 class CATRegisterE12(CATRegister):
@@ -580,7 +736,7 @@ class CATRegisterE12(CATRegister):
         ('reduction_time', 6, datetime.time),
         ('total', 14, number),
         ('issqn_discount', 1, bool),            # False, right now
-        ]
+    ]
 
 
 class CATRegisterE13(CATRegister):
@@ -595,7 +751,7 @@ class CATRegisterE13(CATRegister):
         ('crz', 6, number),
         ('partial_totalizer', 7, basestring),   # See table 6.5.1.2
         ('value', 13, number),                  # currency
-        ]
+    ]
 
 
 class CATRegisterE14(CATRegister):
@@ -629,7 +785,7 @@ class CATRegisterE14(CATRegister):
         ('client_name', 40, basestring),
         # cpf or cnpj, depending on the client
         ('client_cpf_cnpj', 14, number),
-        ]
+    ]
 
 
 class CATRegisterE15(CATRegister):
@@ -687,10 +843,88 @@ class CATRegisterE16(CATRegister):
         ('grg', 6, number),
         ('cdc', 4, number),
         ('crz', 6, number),
-        ('denomination', 2, basestring), # See table
+        ('denomination', 2, basestring),  # See table
         ('emission_date', 8, datetime.date),
         ('emission_hour', 6, datetime.time),
-        ]
+    ]
+
+
+class CATRegisterE17(CATRegister):
+    """Register E17 - Z reduction detail - non-fiscal totalizers
+    """
+    register_type = "E17"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_number', 2, number),
+        ('crz', 6, number),
+        ('non_fiscal_totalizer', 15, basestring),
+        ('value', 13, number),
+    ]
+
+
+class CATRegisterE18(CATRegister):
+    """Register E18 - Z reduction detail - payment methods and change.
+    """
+    register_type = "E18"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_number', 2, number),
+        ('crz', 6, number),
+        ('description', 15, basestring),
+        ('value', 13, number)
+    ]
+
+
+class CATRegisterE19(CATRegister):
+    """Register E19 - Non-fiscal coupon
+    """
+    register_type = "E19"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_number', 2, number),
+        ('coo', 6, number),
+        ('gnf', 6, number),
+        ('emission_start', 8, datetime.date),
+        ('subtotal', 14, number),
+        ('subtotal_discount', 13, number),
+        ('discount_type', 1, basestring),
+        ('subtotal_surcharge', 13, number),
+        ('surcharge_type', 1, basestring),
+        ('total', 14, number),
+        ('canceled', 1, bool),
+        ('surcharge_canceled', 13, number),
+        ('discount_surcharge_order', 1, basestring),
+        ('client_name', 40, basestring),
+        ('client_cpf_cnpj', 14, number)
+    ]
+
+
+class CATRegisterE20(CATRegister):
+    """Register E20 - Non-fiscal document detail
+    """
+    register_type = "E20"
+    register_fields = [
+        ('serial_number', 20, basestring),
+        ('additional_mf', 1, basestring),
+        ('ecf_model', 20, basestring),
+        ('user_number', 2, number),
+        ('coo', 6, number),
+        ('gnf', 6, number),
+        ('item_number', 3, number),
+        ('denomination', 15, basestring),
+        ('value', 13, number),
+        ('item_discount', 13, number),
+        ('item_surcharge', 13, number),
+        ('total', 13, number),
+        ('canceled', 1, basestring),
+        ('item_canceled_surcharge', 13, number)
+    ]
 
 
 class CATRegisterE21(CATRegister):
