@@ -25,7 +25,6 @@
 """Generate a CAT archive from the Stoqlib domain classes."""
 
 import os
-import string
 
 from kiwi.component import get_utility
 from storm.expr import And
@@ -39,8 +38,8 @@ from stoqlib.lib.interfaces import IAppInfo
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
-from cat52 import CATFile, CATError, BRAND_CODES, MODEL_CODES
-from ecfdomain import FiscalSaleHistory, ECFDocumentHistory
+from ecf.cat52 import CATFile, CATError, BRAND_CODES, MODEL_CODES
+from ecf.ecfdomain import FiscalSaleHistory, ECFDocumentHistory
 
 _ = stoqlib_gettext
 
@@ -75,8 +74,11 @@ class StoqlibCATGenerator(object):
         self._add_registers()
 
     def _get_file_name(self):
-        #FFM12345.DMA
+        # FFM12345.DMA
+        # pylint: disable=W0402
+        import string
         base = string.digits + string.uppercase
+        # pylint: enable=W0402
 
         brand = BRAND_CODES[self.printer.brand]
         model = MODEL_CODES[(self.printer.brand, self.printer.model)]
@@ -95,13 +97,13 @@ class StoqlibCATGenerator(object):
 
     def _get_z_reductions(self):
         return self.store.find(FiscalDayHistory,
-                 And(Date(FiscalDayHistory.emission_date) == self.start,
-                     FiscalDayHistory.serial == self.printer.device_serial))
+                               And(Date(FiscalDayHistory.emission_date) == self.start,
+                                   FiscalDayHistory.serial == self.printer.device_serial))
 
     def _get_sales(self, returned=False):
         # TODO: We need to add station_id to the sales table
         query = And(Date(Sale.confirm_date) == self.start,
-                    #Sale.station_id == self.printer.station_id
+                    # Sale.station_id == self.printer.station_id
                     )
         if returned:
             query = And(Date(Sale.return_date) == self.end, )
@@ -110,8 +112,8 @@ class StoqlibCATGenerator(object):
 
     def _get_other_documents(self):
         return self.store.find(ECFDocumentHistory,
-                And(Date(ECFDocumentHistory.emission_date) == self.start,
-                    ECFDocumentHistory.printer_id == self.printer.id))
+                               And(Date(ECFDocumentHistory.emission_date) == self.start,
+                                   ECFDocumentHistory.printer_id == self.printer.id))
 
     def _add_registers(self):
         appinfo = get_utility(IAppInfo)
@@ -124,7 +126,7 @@ class StoqlibCATGenerator(object):
         self._add_other_documents()
 
     def _add_ecf_identification(self):
-        #XXX: We need to verity that all items are related to the current printer.
+        # XXX: We need to verity that all items are related to the current printer.
         items = list(self._get_z_reductions())
 
         initial_crz = 0
@@ -156,7 +158,7 @@ class StoqlibCATGenerator(object):
 
     def _add_fiscal_coupon_information(self):
         sales = list(self._get_sales())
-        iss_tax = sysparam(self.store).ISS_TAX * 100
+        iss_tax = sysparam.get_decimal('ISS_TAX') * 100
 
         for sale in sales:
             client = sale.client
@@ -201,7 +203,7 @@ class StoqlibCATGenerator(object):
                 continue
 
             # Sales cancelled right after being made dont have an invoice number
-            if returned_sales[0].invoice_number != None:
+            if returned_sales[0].invoice_number is not None:
                 continue
 
             for payment in sale.payments:
