@@ -24,10 +24,9 @@
 """FiscalPrinting (ECF) integration."""
 
 from decimal import Decimal
+import logging
 
-from kiwi.argcheck import argcheck
-from kiwi.log import Logger
-from zope.interface import implements
+from zope.interface import implementer
 from stoqdrivers.enum import TaxType, UnitType
 from stoqdrivers.exceptions import (DriverError, CouponNotOpenError,
                                     CancelItemError)
@@ -38,14 +37,15 @@ from stoqlib.database.runtime import new_store
 from stoqlib.domain.devices import FiscalDayHistory, FiscalDayTax
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.exceptions import DeviceError
+from stoqlib.lib.ibpt import calculate_tax_for_item
 from stoqlib.lib.message import warning
 from stoqlib.lib.translation import stoqlib_gettext
 
-from ecfdomain import FiscalSaleHistory, ECFDocumentHistory
+from ecf.ecfdomain import FiscalSaleHistory, ECFDocumentHistory
 
 _ = stoqlib_gettext
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class CouponPrinter(object):
@@ -107,16 +107,22 @@ class CouponPrinter(object):
             return False
         except CancelItemError:
             return False
-        except DriverError, details:
+        except DriverError as details:
             warning(_("Could not cancel coupon"),
-                str(details))
+                    str(details))
             return False
 
         return True
 
     def cancel_last_coupon(self):
         """Cancel the last non-fiscal coupon or sale."""
-        self._driver.cancel_last_coupon()
+        try:
+            self._driver.cancel_last_coupon()
+        except DriverError as details:
+            warning(_("Could not cancel coupon"),
+                    str(details))
+            return False
+        return True
 
     def add_cash(self, value):
         """
@@ -139,27 +145,27 @@ class CouponPrinter(object):
         try:
             self._register_emitted_document(ECFDocumentHistory.TYPE_SUMMARY)
             self._driver.summarize()
-        except DriverError, details:
+        except DriverError as details:
             warning(_("Could not print summary"),
-                str(details))
+                    str(details))
 
     def memory_by_date(self, start_date, end_date):
         try:
             self._register_emitted_document(
-                                        ECFDocumentHistory.TYPE_MEMORY_READ)
+                ECFDocumentHistory.TYPE_MEMORY_READ)
             self._driver.till_read_memory(start_date, end_date)
-        except DriverError, details:
+        except DriverError as details:
             warning(_("Could not read memory"),
-                str(details))
+                    str(details))
 
     def memory_by_reductions(self, start, end):
         try:
             self._register_emitted_document(
-                                        ECFDocumentHistory.TYPE_MEMORY_READ)
+                ECFDocumentHistory.TYPE_MEMORY_READ)
             self._driver.till_read_memory_by_reductions(start, end)
-        except DriverError, details:
+        except DriverError as details:
             warning(_("Could not read memory"),
-                str(details))
+                    str(details))
 
     def create_coupon(self, coupon):
         return Coupon(coupon, self._printer, self._driver)
@@ -217,7 +223,7 @@ class CouponPrinter(object):
         if coupon_start == 0:
             results = store.find(FiscalDayHistory,
                                  station=self._printer.station).order_by(
-                                 Desc(FiscalDayHistory.emission_date))
+                Desc(FiscalDayHistory.emission_date))
             if results.count():
                 coupon_start = results[0].coupon_end + 1
             else:
@@ -261,19 +267,20 @@ class CouponPrinter(object):
 #
 
 
+@implementer(IContainer)
 class Coupon(object):
     """ This class is used just to allow us cancel an item with base in a
     Sellable object. Currently, services can't be added, and they
     are just ignored -- be aware, if a coupon with only services is
     emitted, it will not be opened in fact, but just ignored.
     """
-    implements(IContainer)
 
     def __init__(self, coupon, printer, driver):
         self._coupon = coupon
         self._printer = printer
         self._driver = driver
         self._item_ids = {}
+        self._total_taxes = 0
 
         self._customer_document = None
         self._customer_document_type = None
@@ -281,19 +288,24 @@ class Coupon(object):
     def _get_capability(self, name):
         return self._driver.get_capabilities()[name]
 
+    def _add_tax_for_item(self, item):
+        tax_item = calculate_tax_for_item(item)
+        self._total_taxes += tax_item
+
     #
     # IContainer implementation
     #
 
     def add_item(self, item):
         """
-        @param item: A :class:`SellableItem` subclass
+        @param item: A :class:`SaleItem` subclass
         @returns: id of the item.:
           0 >= if it was added successfully
           -1 if an error happend
           0 if added but not printed (gift certificates, free deliveries)
         """
         sellable = item.sellable
+        self._add_tax_for_item(item)
         max_len = self._get_capability("item_description").max_len
         description = sellable.description[:max_len]
         unit_desc = ''
@@ -308,20 +320,27 @@ class Coupon(object):
 
         try:
             tax_constant = self._printer.get_tax_constant_for_device(sellable)
-        except DeviceError, e:
+        except DeviceError as e:
             warning(_("Could not print item"), str(e))
             return -1
 
+        base_price = item.base_price
+        discount_value = (base_price - item.price) * item.quantity
+        # If the selling value is greater than the base price
+        if discount_value < 0:
+            discount_value = 0
+            base_price = item.price
+
         try:
-            return self._driver.add_item(code, description, item.price,
+            return self._driver.add_item(code, description, base_price,
                                          tax_constant.device_value,
                                          item.quantity, unit,
-                                         unit_desc=unit_desc)
-        except DriverError, e:
+                                         unit_desc=unit_desc,
+                                         discount=discount_value)
+        except DriverError as e:
             warning(_("Could not print item"), str(e))
             return -1
 
-    @argcheck(int)
     def remove_item(self, item_id):
         self._driver.cancel_item(item_id)
 
@@ -386,7 +405,7 @@ class Coupon(object):
 
             # When adding a money payment, use base_value so that the payback
             # is show correctly.
-            if payment.is_money():
+            if payment.is_of_method(u'money'):
                 self._driver.add_payment(constant.device_value,
                                          payment.base_value)
 
@@ -408,8 +427,16 @@ class Coupon(object):
         return True
 
     def close(self, sale):
+        sale_total = sale.get_sale_subtotal()
+        total_taxes_percentage = (self._total_taxes / sale_total) * 100
+        msg = "Val Aprox Tributos R${:0.2f} ({:0.2f}%) Fonte:IBPT"
+        parts = [msg.format(self._total_taxes, total_taxes_percentage),
+                 _(u'Salesperson: %s') % sale.get_salesperson_name(),
+                 _('Stoq Retail Management')]
+        message = '\n'.join(parts)
+        message += ' - www.stoq.com.br'
         self._create_fiscal_sale_data(sale)
-        coupon_id = self._driver.close()
+        coupon_id = self._driver.close(message)
         return coupon_id
 
     def _create_fiscal_sale_data(self, sale):
@@ -451,5 +478,5 @@ class Coupon(object):
         self._driver.payment_receipt_close()
 
         # Right now, we are printing the two receipts at once
-        #if self.supports_duplicate_receipt:
+        # if self.supports_duplicate_receipt:
         #    self._driver.payment_receipt_print_duplicate()
