@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2007 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2007-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,16 +23,17 @@
 ##
 
 import datetime
+
 from stoqdrivers.constants import describe_constant
 from stoqdrivers.printers.base import BasePrinter
 from stoqdrivers.printers.fiscal import FiscalPrinter
 from stoqdrivers.serialbase import VirtualPort, SerialPort
 from stoqdrivers.enum import PaymentMethodType, UnitType, TaxType
 from storm.references import Reference, ReferenceSet
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.properties import DecimalCol
-from stoqlib.database.properties import (BoolCol, IntCol,
+from stoqlib.database.properties import (BoolCol, IdCol, IntCol,
                                          UnicodeCol, BLOBCol, DateTimeCol)
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IActive, IDescribable
@@ -42,6 +43,8 @@ from stoqlib.lib.translation import stoqlib_gettext
 _ = stoqlib_gettext
 
 
+@implementer(IActive)
+@implementer(IDescribable)
 class ECFPrinter(Domain):
     """
     @param model:
@@ -58,7 +61,6 @@ class ECFPrinter(Domain):
     @cvar register_date: when the current user was registred
     @cvar register_cro: cro when the user was registred
     """
-    implements(IActive, IDescribable)
 
     __storm_table__ = 'ecf_printer'
 
@@ -66,13 +68,13 @@ class ECFPrinter(Domain):
     brand = UnicodeCol()
     device_name = UnicodeCol()
     device_serial = UnicodeCol()
-    station_id = IntCol()
+    station_id = IdCol()
     station = Reference(station_id, 'BranchStation.id')
     is_active = BoolCol(default=True)
     baudrate = IntCol()
-    last_sale_id = IntCol(default=None)
+    last_sale_id = IdCol(default=None)
     last_sale = Reference(last_sale_id, 'Sale.id')
-    last_till_entry_id = IntCol(default=None)
+    last_till_entry_id = IdCol(default=None)
     last_till_entry = Reference(last_till_entry_id, 'TillEntry.id')
     user_number = IntCol(default=None)
     register_date = DateTimeCol(default=None)
@@ -150,9 +152,9 @@ class ECFPrinter(Domain):
             raise AssertionError
 
         return self.store.find(DeviceConstant,
-            printer=self,
-            constant_type=DeviceConstant.TYPE_PAYMENT,
-            constant_enum=int(constant_enum)).one()
+                               printer=self,
+                               constant_type=DeviceConstant.TYPE_PAYMENT,
+                               constant_enum=int(constant_enum)).one()
 
     def get_tax_constant_for_device(self, sellable):
         """
@@ -234,6 +236,7 @@ class ECFPrinter(Domain):
         return store.find(cls, station=station, is_active=True).one()
 
 
+@implementer(IDescribable)
 class DeviceConstant(Domain):
     """
     Describes a device constant
@@ -249,7 +252,6 @@ class DeviceConstant(Domain):
     @cvar device_value: the device value
     @cvar printer: printer
     """
-    implements(IDescribable)
 
     __storm_table__ = 'device_constant'
 
@@ -258,7 +260,7 @@ class DeviceConstant(Domain):
     constant_value = DecimalCol(default=None)
     constant_enum = IntCol(default=None)
     device_value = BLOBCol()
-    printer_id = IntCol()
+    printer_id = IdCol()
     printer = Reference(printer_id, 'ECFPrinter.id')
 
     (TYPE_UNIT,
@@ -291,10 +293,10 @@ class DeviceConstant(Domain):
         @rtype: :class:`DeviceConstant`
         """
         return store.find(DeviceConstant,
-            printer=printer,
-            constant_type=DeviceConstant.TYPE_TAX,
-            constant_enum=int(TaxType.CUSTOM),
-            constant_value=constant_value).one()
+                          printer=printer,
+                          constant_type=DeviceConstant.TYPE_TAX,
+                          constant_enum=int(TaxType.CUSTOM),
+                          constant_value=constant_value).one()
 
     @classmethod
     def get_tax_constant(cls, printer, constant_enum, store):
@@ -315,9 +317,9 @@ class DeviceConstant(Domain):
             raise ValueError("Use get_custom_tax_constant for custom "
                              "tax codes")
         return store.find(DeviceConstant,
-            printer=printer,
-            constant_type=DeviceConstant.TYPE_TAX,
-            constant_enum=int(constant_enum)).one()
+                          printer=printer,
+                          constant_type=DeviceConstant.TYPE_TAX,
+                          constant_enum=int(constant_enum)).one()
 
     def get_description(self):
         return self.constant_name
@@ -333,7 +335,7 @@ class FiscalSaleHistory(Domain):
 
     document_type = IntCol(default=TYPE_CPF)
     document = UnicodeCol(default=None)
-    sale_id = IntCol()
+    sale_id = IdCol()
     sale = Reference(sale_id, 'Sale.id')
     coo = IntCol(default=0)
     document_counter = IntCol(default=0)
@@ -350,7 +352,7 @@ class ECFDocumentHistory(Domain):
 
     __storm_table__ = 'ecf_document_history'
 
-    printer_id = IntCol()
+    printer_id = IdCol()
     printer = Reference(printer_id, 'ECFPrinter.id')
     type = IntCol()
     coo = IntCol(default=0)
