@@ -29,7 +29,7 @@ from serial import SerialException
 
 import gtk
 from kiwi.enums import ListType
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 from stoqdrivers.interfaces import ICouponPrinter
 from stoqdrivers.printers.base import (get_supported_printers_by_iface,
                                        get_baudrate_values)
@@ -42,14 +42,15 @@ from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.lists import ModelListDialog, ModelListSlave
 from stoqlib.gui.dialogs.progressdialog import ProgressDialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
+from stoqlib.lib.environment import is_developer_mode
 from stoqlib.lib.devicemanager import DeviceManager
 from stoqlib.lib.message import info, yesno, warning
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
 
-from ecfprinterstatus import ECFAsyncPrinterStatus
-from ecfdomain import ECFPrinter, DeviceConstant
-from deviceconstanteditor import DeviceConstantsDialog
+from ecf.ecfprinterstatus import ECFAsyncPrinterStatus
+from ecf.ecfdomain import ECFPrinter, DeviceConstant
+from ecf.deviceconstanteditor import DeviceConstantsDialog
 
 _ = stoqlib_gettext
 
@@ -158,7 +159,7 @@ class ECFEditor(BaseEditor):
 
     def _on_progress_dialog__cancel(self, progress):
         # FIXME:
-        #status.stop()
+        # status.stop()
         pass
 
     def on_printer__content_changed(self, combo):
@@ -181,9 +182,9 @@ class ECFEditor(BaseEditor):
         if not self._populate_ecf_printer(status):
             return
 
-        if not yesno(_("An ECF Printer was added. You need to restart Stoq "
-                       "before using it. Would you like to restart it now?"),
-                     gtk.RESPONSE_NO, _("Restart later"), _("Restart now")):
+        if yesno(_("An ECF Printer was added. You need to restart Stoq "
+                   "before using it. Would you like to restart it now?"),
+                 gtk.RESPONSE_YES, _("Restart now"), _("Restart later")):
             self.store.commit()
             raise SystemExit
 
@@ -212,7 +213,9 @@ class ECFEditor(BaseEditor):
                 printer = _PrinterModel(brand, printer_class)
                 printers.append((printer.get_description(), printer))
 
-        if sysparam(self.store).DEMO_MODE:
+        # Allow to use virtual printer for both demo mode and developer mode
+        # so it's easier for testers and developers to test ecf functionality
+        if sysparam.get_bool('DEMO_MODE') or is_developer_mode():
             from stoqdrivers.printers.virtual.Simple import Simple
             printer = _PrinterModel('virtual', Simple)
             printers.append((printer.get_description(), printer))
@@ -248,9 +251,9 @@ class ECFEditor(BaseEditor):
                 # If the constant is not defined in the system, create it
                 if not constant:
                     constant = SellableTaxConstant(tax_value=value,
-                                           tax_type=int(TaxType.CUSTOM),
-                                           description=u'%0.2f %%' % value,
-                                           store=self.store)
+                                                   tax_type=int(TaxType.CUSTOM),
+                                                   description=u'%0.2f %%' % value,
+                                                   store=self.store)
             elif tax_enum == TaxType.SERVICE:
                 constant = self.store.find(DeviceConstant,
                                            constant_enum=int(tax_enum),
@@ -291,12 +294,12 @@ class ECFEditor(BaseEditor):
                          'cartao debito': PaymentMethodType.DEBIT_CARD,
                          'financeira': PaymentMethodType.FINANCIAL,
                          'vale compra': PaymentMethodType.GIFT_CERTIFICATE
-                          }
+                         }
 
         for device_value, constant_name in driver.get_payment_constants():
             lower = constant_name.lower()
-            lower = lower.replace('é', 'e') # Workaround method names with
-            lower = lower.replace('ã', 'a') # accents
+            lower = lower.replace('é', 'e')  # Workaround method names with
+            lower = lower.replace('ã', 'a')  # accents
             payment_enum = payment_enums.get(lower)
             if payment_enum is None:
                 continue
@@ -304,7 +307,7 @@ class ECFEditor(BaseEditor):
             DeviceConstant(constant_enum=int(payment_enum),
                            constant_name=unicode(constant_name),
                            constant_type=DeviceConstant.TYPE_PAYMENT,
-                           constant_value=value,
+                           constant_value=None,
                            device_value=device_value,
                            printer=model,
                            store=self.store)
@@ -318,7 +321,7 @@ class ECFListSlave(ModelListSlave):
         Column('device_serial', title=_('Serial'), data_type=str, width=100),
         Column('station.name', title=_('Computer'), data_type=str, width=100),
         Column('is_active', title=_('Active'), data_type=bool, width=60),
-        ]
+    ]
 
     def __init__(self, parent, store):
         ModelListSlave.__init__(self, parent, store)
