@@ -23,15 +23,17 @@
 ##
 
 import datetime
+import logging
 import os
 import time
 
 import gtk
 from serial import SerialException
 
-from kiwi.log import Logger
 from kiwi.python import Settable
 from stoqdrivers.exceptions import CouponOpenError, DriverError
+
+from stoqlib.api import api
 from stoqlib.database.runtime import (get_current_station,
                                       get_default_store,
                                       new_store)
@@ -44,27 +46,27 @@ from stoqlib.domain.events import (SaleStatusChangedEvent, TillAddCashEvent,
                                    HasPendingReduceZ, ECFIsLastSaleEvent,
                                    HasOpenCouponEvent)
 from stoqlib.domain.person import Individual, Company
-from stoqlib.domain.sale import Sale
+from stoqlib.domain.sale import Sale, SaleComment
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import DeviceError
-from stoqlib.gui.keybindings import add_bindings, get_accels
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.events import (StartApplicationEvent, StopApplicationEvent,
                                 CouponCreatedEvent)
+from stoqlib.gui.utils.keybindings import add_bindings, get_accels
 from stoqlib.lib.message import info, warning, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
-from cat52 import MODEL_CODES
-from catgenerator import StoqlibCATGenerator
-from couponprinter import CouponPrinter
-from ecfdomain import ECFPrinter, FiscalSaleHistory
-from ecfprinterdialog import ECFListDialog
-from ecfmemorydialog import FiscalMemoryDialog
-from paulistainvoicedialog import PaulistaInvoiceDialog
+from ecf.cat52 import MODEL_CODES
+from ecf.catgenerator import StoqlibCATGenerator
+from ecf.couponprinter import CouponPrinter
+from ecf.ecfdomain import ECFPrinter, FiscalSaleHistory
+from ecf.ecfprinterdialog import ECFListDialog
+from ecf.ecfmemorydialog import FiscalMemoryDialog
+from ecf.paulistainvoicedialog import PaulistaInvoiceDialog
 
 _ = stoqlib_gettext
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class ECFUI(object):
@@ -100,7 +102,7 @@ class ECFUI(object):
         add_bindings([
             ('plugin.ecf.read_memory', '<Primary>F9'),
             ('plugin.ecf.summarize', '<Primary>F11'),
-            ])
+        ])
 
     #
     # Private
@@ -118,9 +120,9 @@ class ECFUI(object):
 
         try:
             self._printer = CouponPrinter(printer)
-        except SerialException, e:
+        except SerialException as e:
             warning(_('Error opening serial port'), str(e))
-        except DriverError, e:
+        except DriverError as e:
             warning(str(e))
         return None
 
@@ -138,15 +140,20 @@ class ECFUI(object):
             self._printer_verified = True
 
     def _add_ui_menus(self, appname, app, uimanager):
+        self._current_app = app
         if appname == 'pos':
             self._create_printer()
             self._add_pos_menus(uimanager)
         elif appname == 'till':
             self._create_printer()
             self._add_till_menus(uimanager)
+        elif appname == 'sales':
+            # The sales app needs the printer to check if the
+            # sale being returned is the last sale on the ECF.
+            self._create_printer()
         elif appname == 'admin':
             self._add_admin_menus(uimanager)
-            app.main_window.tasks.add_item(
+            app.tasks.add_item(
                 _('Fiscal Printers'), 'fiscal-printer', 'printer',
                 self._on_ConfigurePrinter__activate)
 
@@ -174,21 +181,21 @@ class ECFUI(object):
             ('ECFMenu', None, _('ECF')),
             ('ConfigurePrinter', None, _('Configure fiscal printer...'),
              None, None, self._on_ConfigurePrinter__activate),
-            ])
+        ])
         uimanager.insert_action_group(ag, 0)
         self._ui = uimanager.add_ui_from_string(ui_string)
 
     def _add_pos_menus(self, uimanager):
-        if sysparam(self.default_store).POS_SEPARATE_CASHIER:
+        if sysparam.get_bool('POS_SEPARATE_CASHIER'):
             return
 
         ui_string = """<ui>
           <menubar name="menubar">
             <placeholder name="ExtraMenubarPH">
               <menu action="ECFMenu">
-                <menuitem action="CancelLastDocument" name="CancelLastDocument"/>
-                <menuitem action="Summary" name="Summary"/>
-                <menuitem action="ReadMemory" name="ReadMemory"/>
+                <menuitem action="CancelLastDocument"/>
+                <menuitem action="Summary"/>
+                <menuitem action="ReadMemory"/>
               </menu>
             </placeholder>
           </menubar>
@@ -203,7 +210,7 @@ class ECFUI(object):
              group.get('read_memory'), None, self._on_ReadMemory__activate),
             ('CancelLastDocument', None, _('Cancel Last Document'),
              None, None, self._on_CancelLastDocument__activate),
-            ])
+        ])
         ag.add_action_with_accel(self._till_summarize_action,
                                  group.get('summarize'))
 
@@ -215,6 +222,7 @@ class ECFUI(object):
           <menubar name="menubar">
             <placeholder name="ExtraMenubarPH">
               <menu action="ECFMenu">
+                <menuitem action="CancelLastDocument"/>
                 <menuitem action="Summary"/>
                 <menuitem action="ReadMemory"/>
               </menu>
@@ -228,7 +236,9 @@ class ECFUI(object):
             ('ECFMenu', None, _('ECF')),
             ('ReadMemory', None, _('Read Memory'),
              group.get('read_memory'), None, self._on_ReadMemory__activate),
-            ])
+            ('CancelLastDocument', None, _('Cancel Last Document'),
+             None, None, self._on_CancelLastDocument__activate),
+        ])
         ag.add_action_with_accel(self._till_summarize_action,
                                  group.get('summarize'))
         uimanager.insert_action_group(ag, 0)
@@ -266,8 +276,8 @@ class ECFUI(object):
             except DriverError:
                 response = warning(
                     _(u"It's not possible to emit a read X for the "
-                          "configured printer.\nWould you like to ignore "
-                          "this error and continue?"),
+                      "configured printer.\nWould you like to ignore "
+                      "this error and continue?"),
                     buttons=((_(u"Cancel"), gtk.RESPONSE_CANCEL),
                              (_(u"Ignore"), gtk.RESPONSE_YES),
                              (_(u"Try Again"), gtk.RESPONSE_NONE)))
@@ -298,14 +308,14 @@ class ECFUI(object):
 
         printer = self._printer.get_printer()
 
-        if (sysparam(self.default_store).ENABLE_PAULISTA_INVOICE and not
+        if (sysparam.get_bool('ENABLE_PAULISTA_INVOICE') and not
             (printer.user_number and printer.register_date and
              printer.register_cro)):
             response = warning(
                 short=_(u"You need to set some details about your ECF "
-                         "if you want to save the paulista invoice file. "
-                         "Go to the admin application and fill the "
-                         "required information for the ECF."),
+                        "if you want to save the paulista invoice file. "
+                        "Go to the admin application and fill the "
+                        "required information for the ECF."),
                 buttons=((_(u"Cancel Close Till"), gtk.RESPONSE_CANCEL), ))
             return False
 
@@ -337,7 +347,7 @@ class ECFUI(object):
                 # XXX: Make sure this is tested
                 day = till.opening_date
 
-            dir = sysparam(self.default_store).CAT52_DEST_DIR.path
+            dir = sysparam.get_string('CAT52_DEST_DIR')
             dir = os.path.expanduser(dir)
             if not os.path.exists(dir):
                 os.mkdir(dir)
@@ -351,7 +361,7 @@ class ECFUI(object):
 
     def _needs_cat52(self, printer):
         # If the param is not enabled, we dont need.
-        if not sysparam(self.default_store).ENABLE_PAULISTA_INVOICE:
+        if not sysparam.get_bool('ENABLE_PAULISTA_INVOICE'):
             return False
 
         # Even if the parameter is enabled, we can only generate cat52 for
@@ -427,15 +437,18 @@ class ECFUI(object):
             ('cancel', self._on_coupon__cancel),
             ('get-coo', self._on_coupon__get_coo),
             ('get-supports-duplicate-receipt', self._on_coupon__get_supports_duplicate),
-            ('print-payment-receipt', self._on_coupon__print_payment_receipt),
-            ]:
+            ('print-payment-receipt', self._on_coupon__print_payment_receipt)]:
             fiscalcoupon.connect_object(signal, callback, coupon)
         return coupon
 
     def _get_last_document(self, store):
-        printer = self._printer.get_printer()
-        return ECFPrinter.get_last_document(station=printer.station,
-                                            store=store)
+        station = api.get_current_station(store)
+        return ECFPrinter.get_last_document(station=station, store=store)
+
+    def _is_ecf_last_sale(self, sale):
+        store = sale.store
+        is_last_sale = store.find(ECFPrinter, last_sale=sale).count() > 0
+        return is_last_sale
 
     def _confirm_last_document_cancel(self, last_doc):
         if last_doc.last_sale is None and last_doc.last_till_entry is None:
@@ -443,32 +456,38 @@ class ECFUI(object):
             return
 
         if last_doc.last_sale:
-            msg = _("Do you really want to cancel the sale number %d "
-                    "and value %.2f ?") % (last_doc.last_sale.id,
+            msg = _("Do you really want to cancel the sale number %s "
+                    "and value %.2f ?") % (last_doc.last_sale.identifier,
                                            last_doc.last_sale.total_amount)
         elif last_doc.last_till_entry.value > 0:
             msg = _("Do you really want to cancel the last cash added "
                     "number %d and value %.2f ?") % (
-                        last_doc.last_till_entry.id,
-                        last_doc.last_till_entry.value)
+                last_doc.last_till_entry.identifier,
+                last_doc.last_till_entry.value)
         else:
             msg = _("Do you really want to cancel the last cash removed "
                     "number %d and value %.2f ?") % (
-                        last_doc.last_till_entry.id,
-                        last_doc.last_till_entry.value)
+                last_doc.last_till_entry.identifier,
+                last_doc.last_till_entry.value)
         return yesno(msg, gtk.RESPONSE_NO, _("Cancel Last Document"),
                      _("Not now"))
 
     def _cancel_last_till_entry(self, last_doc, store):
-        till_entry = store.fetch(last_doc.last_till_entry)
+        last_till_entry = store.fetch(last_doc.last_till_entry)
+        value = last_till_entry.value
+        till = Till.get_current(store)
         try:
             self._printer.cancel_last_coupon()
-            if till_entry.value > 0:
-                till_entry.description = _(u"Cash out")
+            if last_till_entry.value > 0:
+                till_entry = till.add_debit_entry(
+                    # TRANSLATORS: cash out = sangria, cash in = suprimento
+                    value, _(u"Cash out: last cash in cancelled"))
+                self._set_last_till_entry(till_entry, store)
             else:
-                till_entry.description = _(u"Cash in")
-            till_entry.value = -till_entry.value
-            last_doc.last_till_entry = None
+                till_entry = till.add_credit_entry(
+                    # TRANSLATORS: cash out = sangria, cash in = suprimento
+                    -value, _(u"Cash in: last cash out cancelled"))
+                self._set_last_till_entry(till_entry, store)
             info(_("Document was cancelled"))
         except:
             info(_("Cancelling failed, nothing to cancel"))
@@ -478,16 +497,21 @@ class ECFUI(object):
         if last_doc.last_sale.status == Sale.STATUS_RETURNED:
             return
         sale = store.fetch(last_doc.last_sale)
-        returned_sale = sale.create_sale_return_adapter()
-        returned_sale.reason = _(u"Cancelling last document on ECF")
-        returned_sale.return_()
+        value = sale.total_amount
+        sale.cancel()
+        comment = _(u"Cancelling last document on ECF")
+        SaleComment(store=store, sale=sale, comment=comment,
+                    author=api.get_current_user(store))
+        till = Till.get_current(store)
+        # TRANSLATORS: cash out = sangria
+        till.add_debit_entry(value, _(u"Cash out: last sale cancelled"))
         last_doc.last_sale = None
         info(_("Document was cancelled"))
 
     def _cancel_last_document(self):
         try:
             self._validate_printer()
-        except DeviceError, e:
+        except DeviceError as e:
             warning(str(e))
             return
 
@@ -506,7 +530,7 @@ class ECFUI(object):
                 warning(_("You do not have this value on till."))
                 store.close()
                 return
-            cancelled = self._printer.cancel()
+            cancelled = self._printer.cancel_last_coupon()
             if not cancelled:
                 info(_("Cancelling sale failed, nothing to cancel"))
                 store.close()
@@ -518,7 +542,7 @@ class ECFUI(object):
     def _till_summarize(self):
         try:
             self._validate_printer()
-        except DeviceError, e:
+        except DeviceError as e:
             warning(str(e))
             return
 
@@ -528,7 +552,7 @@ class ECFUI(object):
     def _fiscal_memory_dialog(self):
         try:
             self._validate_printer()
-        except DeviceError, e:
+        except DeviceError as e:
             warning(str(e))
             return
         retval = run_dialog(FiscalMemoryDialog, None, self.default_store, self._printer)
@@ -555,7 +579,7 @@ class ECFUI(object):
                             document=document)
 
     def _identify_customer(self, coupon, sale=None):
-        if not sysparam(self.default_store).ENABLE_PAULISTA_INVOICE:
+        if not sysparam.get_bool('ENABLE_PAULISTA_INVOICE'):
             return
 
         model = None
@@ -567,7 +591,8 @@ class ECFUI(object):
         if model:
             initial_client_document = model.document
 
-        model = run_dialog(PaulistaInvoiceDialog, self, self.default_store, model)
+        model = run_dialog(PaulistaInvoiceDialog, self._current_app,
+                           self.default_store, model)
 
         # User cancelled the dialog or the document didn't change.
         if not model or model.document == initial_client_document:
@@ -580,10 +605,10 @@ class ECFUI(object):
     #
 
     def _on_StartApplicationEvent(self, appname, app):
-        self._add_ui_menus(appname, app, app.main_window.uimanager)
+        self._add_ui_menus(appname, app, app.window.uimanager)
 
     def _on_StopApplicationEvent(self, appname, app):
-        self._remove_ui_menus(app.main_window.uimanager)
+        self._remove_ui_menus(app.window.uimanager)
 
     def _on_SaleStatusChanged(self, sale, old_status):
         if sale.status == Sale.STATUS_CONFIRMED:
@@ -591,8 +616,7 @@ class ECFUI(object):
             self._set_last_sale(sale, sale.store)
 
     def _on_ECFIsLastSale(self, sale):
-        last_doc = self._get_last_document(sale.store)
-        return last_doc.last_sale == sale
+        return self._is_ecf_last_sale(sale)
 
     def _on_TillOpen(self, till):
         return self._open_till(till)
@@ -697,7 +721,7 @@ class ECFUI(object):
     def _on_GerencialReportPrintEvent(self, receipt, close_previous=False):
         try:
             self._validate_printer()
-        except DeviceError, e:
+        except DeviceError as e:
             warning(str(e))
             return
 
