@@ -31,16 +31,16 @@ from stoqlib.lib.message import info
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.validators import validate_cpf, validate_cnpj
 
-from ecfdomain import FiscalSaleHistory
+from ecf.ecfdomain import FiscalSaleHistory
 
 _ = stoqlib_gettext
 
 
 class PaulistaInvoiceDialog(BaseEditor):
-    """"""
+    """A dialog to generate Paulista invoices"""
     title = _(u"Paulista Invoice")
     hide_footer = False
-    size = (260, 160)
+    size = (-1, 160)
     model_type = Settable
     gladefile = "PaulistaInvoice"
     proxy_widgets = ("document", )
@@ -58,12 +58,12 @@ class PaulistaInvoiceDialog(BaseEditor):
     def _setup_widgets(self):
         self._initial_document = self.model.document
         self._initial_document_type = self.model.document_type
-        self.handler_block(self.document, 'validate')
+        self.handler_block('document', 'validate')
         if self._initial_document_type == FiscalSaleHistory.TYPE_CPF:
             self._set_cpf()
         else:
             self.cnpj.set_active(True)
-        self.handler_unblock(self.document, 'validate')
+        self.handler_unblock('document', 'validate')
 
     def _set_cpf(self):
         self.doc_label.set_text(_(u"CPF:"))
@@ -72,6 +72,7 @@ class PaulistaInvoiceDialog(BaseEditor):
         if self._initial_document_type == FiscalSaleHistory.TYPE_CPF:
             self.document.set_text(self._initial_document)
         self.document.grab_focus()
+        self.main_dialog.set_cancel_label(_(u"Without CPF"))
 
     def _set_cnpj(self):
         self.doc_label.set_text(_(u"CNPJ:"))
@@ -80,6 +81,7 @@ class PaulistaInvoiceDialog(BaseEditor):
         if self._initial_document_type == FiscalSaleHistory.TYPE_CNPJ:
             self.document.set_text(self._initial_document)
         self.document.grab_focus()
+        self.main_dialog.set_cancel_label(_(u"Without CNPJ"))
 
     #
     # BaseEditor
