@@ -23,6 +23,7 @@
 ##
 """ NF-e XML document generation """
 
+from decimal import Decimal
 import datetime
 import math
 import os.path
@@ -31,13 +32,15 @@ import StringIO
 from xml.etree import ElementTree
 from xml.sax.saxutils import escape
 
-from kiwi.python import strip_accents
+from kiwi.python import strip_accents, Settable
 
+from stoqlib.domain.sale import SaleItem, SaleComment
+from stoqlib.enums import NFeDanfeOrientation
 from stoqlib.exceptions import ModelDataError
+from stoqlib.lib.ibpt import calculate_tax_for_item
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.lib.validators import validate_cnpj
-from stoqlib.enums import NFeDanfeOrientation
 
 
 def nfe_tostring(element):
@@ -77,10 +80,7 @@ class NFeGenerator(object):
     """
     def __init__(self, sale, store):
         self._sale = sale
-
-        # Fetch the ids so we can override them in the tests
-        self.sale_id = sale.id
-        self.payment_ids = [p.id for p in self._sale.payments]
+        self._total_taxes = 0
 
         self.store = store
         self.root = ElementTree.Element(
@@ -96,10 +96,11 @@ class NFeGenerator(object):
         self._add_identification(branch)
         self._add_issuer(branch)
         self._add_recipient(self._sale.client)
-        self._add_sale_items(self._sale.get_items())
+        sale_items = self._sale.get_items().order_by(SaleItem.te_id)
+        self._add_sale_items(sale_items)
         self._add_totals()
         self._add_transport_data(self._sale.transporter,
-                                 self._sale.get_items())
+                                 sale_items)
         self._add_billing_data()
         self._add_additional_information()
 
@@ -174,11 +175,11 @@ class NFeGenerator(object):
         company = branch.person.company
         assert company is not None
 
-        #FIXME: fix get_cnpj_number method (fails if start with zero).
+        # FIXME: fix get_cnpj_number method (fails if start with zero).
         cnpj = ''.join([c for c in company.cnpj if c in '1234567890'])
         if not validate_cnpj(cnpj):
             raise ModelDataError(_("The CNPJ of %s is not valid.")
-                                   % branch.person.name)
+                                 % branch.person.name)
 
         return cnpj
 
@@ -194,8 +195,8 @@ class NFeGenerator(object):
         assert nnf
 
         payments = self._sale.payments
-        series = sysparam(self.store).NFE_SERIAL_NUMBER
-        orientation = sysparam(self.store).NFE_DANFE_ORIENTATION
+        series = sysparam.get_int('NFE_SERIAL_NUMBER')
+        orientation = sysparam.get_int('NFE_DANFE_ORIENTATION')
         ecf_info = self._sale.get_nfe_coupon_info()
         nat_op = self._sale.operation_nature or ''
 
@@ -226,6 +227,7 @@ class NFeGenerator(object):
 
     def _add_issuer(self, branch):
         cnpj = self._get_cnpj(branch)
+        # FIXME: Should we use branch.get_description here?
         name = branch.person.name
         person = branch.person
         company = person.company
@@ -241,17 +243,19 @@ class NFeGenerator(object):
         person = recipient.person
         name = person.name
         individual = person.individual
+        company = person.company
         email = person.email
-        if individual is not None:
+        if individual and individual.cpf:
             cpf = ''.join([c for c in individual.cpf if c in '1234567890'])
             self._nfe_recipient = NFeRecipient(name, cpf=cpf, email=email)
-        else:
-            cnpj = self._get_cnpj(recipient)
-            company = person.company
+        elif company and company.cnpj:
+            cnpj = ''.join([c for c in company.cnpj if c in '1234567890'])
             state_registry = company.state_registry
             self._nfe_recipient = NFeRecipient(name, cnpj=cnpj,
                                                state_registry=state_registry,
                                                email=email)
+        else:
+            self._nfe_recipient = NFeRecipient(name, cpf='', email=email)
 
         self._nfe_recipient.set_address(person.get_main_address(),
                                         person.get_phone_number_number())
@@ -259,6 +263,9 @@ class NFeGenerator(object):
 
     def _add_sale_items(self, sale_items):
         for item_number, sale_item in enumerate(sale_items):
+            tax_item = calculate_tax_for_item(sale_item)
+            self._total_taxes += tax_item
+
             # item_number should start from 1, not zero.
             item_number += 1
             nfe_item = NFeProduct(item_number)
@@ -279,7 +286,7 @@ class NFeGenerator(object):
                                          sale_item.get_nfe_cfop_code(),
                                          sale_item.quantity,
                                          sale_item.price,
-                                         sellable.get_unit_description(),
+                                         sellable.unit_description,
                                          barcode=sellable.barcode,
                                          ncm=ncm,
                                          ex_tipi=ex_tipi,
@@ -325,18 +332,24 @@ class NFeGenerator(object):
         sale_total = self._sale.get_total_sale_amount()
         items_total = self._sale.get_sale_subtotal()
 
-        fat = NFeInvoice(self.sale_id, items_total,
+        fat = NFeInvoice(int(self._sale.identifier), items_total,
                          self._sale.discount_value, sale_total)
         self._nfe_data.append(fat)
 
         payments = self._sale.payments
         for i, p in enumerate(payments):
-            dup = NFeDuplicata(self.payment_ids[i], p.due_date, p.value)
+            dup = NFeDuplicata(int(p.identifier), p.due_date, p.value)
             self._nfe_data.append(dup)
 
     def _add_additional_information(self):
-        fisco_info = sysparam(self.store).NFE_FISCO_INFORMATION
-        nfe_info = NFeAdditionalInformation(fisco_info, self._sale.notes)
+        sale_total = self._sale.get_sale_subtotal()
+        total_tax_percentage = (self._total_taxes / sale_total) * 100
+        tax_msg = "Val Aprox Tributos R$ {:0.2f} ({:0.2f}%) Fonte: IBPT - "
+        fisco_info = tax_msg.format(self._total_taxes, total_tax_percentage)
+        fisco_info += sysparam.get_string('NFE_FISCO_INFORMATION')
+        notes = '\n'.join([c.comment for c in
+                           self._sale.comments.order_by(SaleComment.date)])
+        nfe_info = NFeAdditionalInformation(fisco_info, notes)
         self._nfe_data.append(nfe_info)
 
 #
@@ -411,7 +424,8 @@ class BaseNFeXMLGroup(object):
         return date.strftime('%Y-%m-%d')
 
     def format_value(self, value, precision=2):
-        return '%.*f' % (precision, value or 0)
+        _format = Decimal('10e-%d' % precision)
+        return value.quantize(_format)
 
     def escape(self, string):
         # Pg. 71
@@ -540,7 +554,7 @@ class NFeIdentification(BaseNFeXMLGroup):
                   (u'tpImp', '2'),
                   (u'tpEmis', '1'),
                   (u'cDV', ''),
-                  #TODO: Change tpAmb=1 in the final version.
+                  # TODO: Change tpAmb=1 in the final version.
                   (u'tpAmb', '1'),
                   (u'finNFe', '1'),
                   (u'procEmi', '3'),
@@ -617,7 +631,7 @@ class NFeAddress(BaseNFeXMLGroup):
     - Attributes:
         - xLgr: logradouro.
         - nro: número.
-        - XCpl: complemento
+        - xCpl: complemento
         - xBairro: bairro.
         - cMun: código do município.
         - xMun: nome do município.
@@ -629,7 +643,7 @@ class NFeAddress(BaseNFeXMLGroup):
     """
     attributes = [(u'xLgr', ''),
                   (u'nro', ''),
-                  (u'XCpl', ''),
+                  (u'xCpl', ''),
                   (u'xBairro', ''),
                   (u'cMun', ''),
                   (u'xMun', ''),
@@ -648,7 +662,7 @@ class NFeAddress(BaseNFeXMLGroup):
                                address.postal_code if i in '1234567890'])
 
         self.set_attr('xLgr', address.street)
-        self.set_attr('nro', address.streetnumber or '')
+        self.set_attr('nro', address.streetnumber or '0')
         self.set_attr('xCpl', address.complement)
         self.set_attr('xBairro', address.district)
         self.set_attr('xMun', location.city)
@@ -702,7 +716,7 @@ class NFeIssuer(BaseNFeXMLGroup):
 
     def get_doc_txt(self):
         doc_value = self.get_attr('CNPJ')
-        if doc_value:
+        if doc_value is not None:
             doc_tag = self.doc_cnpj_tag
         else:
             doc_tag = self.doc_cpf_tag
@@ -716,7 +730,7 @@ class NFeIssuer(BaseNFeXMLGroup):
             ie = ''
         crt = self.get_attr('CRT') or ''
         base = '%s|%s||%s||||%s|\n' % (self.txttag, self.get_attr('xNome'),
-                                      ie, crt)
+                                       ie, crt)
         return base + self.get_doc_txt() + self._address.as_txt()
 
 
@@ -771,9 +785,22 @@ class NFeProduct(BaseNFeXMLGroup):
     def add_tax_details(self, sale_item, crt):
         nfe_tax = NFeTax()
 
-        # TODO: handle service tax (ISS) and ICMS.
+        # TODO: handle service tax (ISS).
+
+        # If the sale was also printed on a coupon, then we cannot add icms
+        # details to the NF-e, we should add a empty empty icms informatio tag
+        if sale_item.sale.coupon_id:
+            # in this case, the cst should be 90 ou 900 (for the 'SIMPLES'). and
+            # the values should be empty (note that they should not be 0.00,
+            # since that those values may be invalid. Just '')
+            sale_icms = Settable()
+            sale_icms.csosn = 900
+            sale_icms.cst = 90
+            # We still have to export the 'orig' field of the icms info.
+            sale_icms.orig = sale_item.icms_info.orig
+        else:
+            sale_icms = sale_item.icms_info
 
-        sale_icms = sale_item.get_nfe_icms_info()
         if sale_icms:
             nfe_icms = NFeICMS(sale_icms, crt)
             nfe_tax.append(nfe_icms)
@@ -783,13 +810,13 @@ class NFeProduct(BaseNFeXMLGroup):
             nfe_ipi = NFeIPI(sale_ipi)
             nfe_tax.append(nfe_ipi)
 
-        if True: # if sale_item.pis_info
+        if True:  # if sale_item.pis_info
             nfe_pis = NFePIS()
             pis = NFePISOutr()
             nfe_pis.append(pis)
             nfe_tax.append(nfe_pis)
 
-        if True: # if sale_item.cofins_info
+        if True:  # if sale_item.cofins_info
             nfe_cofins = NFeCOFINS()
             cofins = NFeCOFINSOutr()
             nfe_cofins.append(cofins)
@@ -881,7 +908,7 @@ class NFeProductDetails(BaseNFeXMLGroup):
         self.set_attr('EXTIPI', ex_tipi or '')
         # XXX: Genero was removed from nfe 2.0. Figure out what to do with
         # the value from the product
-        #self.set_attr('genero', genero or '')
+        # self.set_attr('genero', genero or '')
 
         self.set_attr('CFOP', cfop)
         self.set_attr('vUnCom', self.format_value(price, precision=4))
@@ -920,7 +947,7 @@ class NFeICMS(BaseNFeXMLGroup):
         # Simples Nacional
         if crt in [1, 2]:
             icms_tag_class = NFE_ICMS_CSOSN_MAP.get(sale_icms_info.csosn)
-        else: # Regime normal
+        else:  # Regime normal
             icms_tag_class = NFE_ICMS_CST_MAP.get(sale_icms_info.cst)
 
         if icms_tag_class:
@@ -980,7 +1007,8 @@ class BaseNFeICMS(BaseNFeXMLGroup):
                 continue
 
             value = getattr(sale_icms_info, info_name, '')
-            if precision is not None:
+            # Only format if the value is a number
+            if precision is not None and isinstance(value, Decimal):
                 value = self.format_value(value, precision)
             if value is None:
                 value = ''
@@ -1143,7 +1171,7 @@ class NFeICMS90(BaseNFeICMS):
     attributes = [(u'orig', ''),
                   (u'CST', ''),
                   (u'modBC', ''),
-                  (u'pRedBC', ''), # Note: documentation (1.1) is wrong!
+                  (u'pRedBC', ''),  # Note: documentation (1.1) is wrong!
                   (u'vBC', ''),
                   (u'pICMS', ''),
                   (u'vICMS', ''),
@@ -1688,7 +1716,7 @@ class NFeVolume(BaseNFeXMLGroup):
 
 # Pg. 126 - Cobranca
 class NFeBilling(BaseNFeXMLGroup):
-    """
+    """NFe Billing node
     """
     tag = u'cobr'
     txttag = 'Y'
@@ -1696,7 +1724,7 @@ class NFeBilling(BaseNFeXMLGroup):
 
 # Fatura
 class NFeInvoice(BaseNFeXMLGroup):
-    """
+    """NFe Invoice node
     """
     tag = u'fat'
     txttag = 'Y02'
@@ -1721,7 +1749,7 @@ class NFeInvoice(BaseNFeXMLGroup):
 
 
 class NFeDuplicata(BaseNFeXMLGroup):
-    """
+    """NFE Duplicate node
     """
     tag = u'dup'
     txttag = 'Y07'
@@ -1775,4 +1803,5 @@ NFE_ICMS_CSOSN_MAP = {
     300: NFeICMSSN102,
     400: NFeICMSSN102,
     500: NFeICMSSN500,
+    900: NFeICMSSN900,
 }
