@@ -78,20 +78,18 @@ class StoqCommandHandler:
             manager = get_plugin_manager()
             if cmd in manager.installed_plugins_names:
                 if not len(args):
-                    raise SystemExit(
-                        "%s: %s requires at least 2 argument(s)" % (
+                    raise SystemExit("%s: %s requires at least 2 argument(s)" % (
                         self.prog_name, cmd))
                 plugin = manager.get_plugin(cmd)
                 return plugin.handle_dbadmin_command(args[0], options, args[1:])
             else:
-                print "%s: Invalid command: `%s' type `%s help' for usage." % (
-                    self.prog_name, cmd, self.prog_name)
+                print("%s: Invalid command: `%s' type `%s help' for usage." % (
+                    self.prog_name, cmd, self.prog_name))
                 return 1
 
         nargs = func.func_code.co_argcount - 2
         if len(args) < nargs:
-            raise SystemExit(
-                "%s: %s requires at least %d argument(s)" % (
+            raise SystemExit("%s: %s requires at least %d argument(s)" % (
                 self.prog_name, cmd, nargs))
         self.args = args
         return func(options, *args)
@@ -112,12 +110,12 @@ class StoqCommandHandler:
 
         max_len = max_len + 2
 
-        print 'Usage: stoqdbadmin [plugin] <command> [<args>]'
-        print
-        print 'Available commands:'
+        print('Usage: stoqdbadmin [plugin] <command> [<args>]')
+        print()
+        print('Available commands:')
 
         for name, doc in cmds:
-            print '  %s%s' % (name.ljust(max_len), doc)
+            print('  %s%s' % (name.ljust(max_len), doc))
 
         self._read_config(options, load_plugins=False,
                           register_station=False)
@@ -127,7 +125,7 @@ class StoqCommandHandler:
         for plugin_name in manager.installed_plugins_names:
             plugin = manager.get_plugin(plugin_name)
             for command in plugin.get_dbadmin_commands():
-                print '   %s %s' % (plugin_name, command)
+                print('   %s %s' % (plugin_name, command))
 
         return 0
 
@@ -158,8 +156,15 @@ class StoqCommandHandler:
         if options.password:
             db_settings.password = options.password
 
-        initialize_system(password=options.password or config.get_password(),
-                          force=options.force)
+        try:
+            initialize_system(password=unicode(options.password),
+                              force=options.force)
+        except ValueError as e:
+            # Database server is missing pg_trgm
+            if 'pg_trgm' in str(e):
+                return 31
+            else:
+                raise
 
         if options.create_examples or options.demo:
             from stoqlib.importers.stoqlibexamples import create
@@ -200,10 +205,10 @@ class StoqCommandHandler:
     def cmd_configure(self, options):
         """Save initial configuration"""
         if not options.dbname:
-            print 'dbname missing'
+            print('dbname missing')
             return 1
         if not options.address:
-            print 'address missing'
+            print('address missing')
             return 1
         config = self._read_config(options, create=True, register_station=False,
                                    check_schema=False, load_plugins=False)
@@ -229,16 +234,16 @@ class StoqCommandHandler:
 
         for plugin_name in plugin_names:
             if plugin_name not in manager.available_plugins_names:
-                print 'ERROR:', plugin_name, 'is not installed.'
-                print "Available plugins are:"
+                print('ERROR:', plugin_name, 'is not installed.')
+                print("Available plugins are:")
                 for plugin_name in manager.available_plugins_names:
-                    print "  %s" % (plugin_name, )
+                    print("  %s" % (plugin_name, ))
                 return
 
             try:
                 manager.install_plugin(plugin_name)
             except PluginError as err:
-                print 'ERROR:', err
+                print('ERROR:', err)
                 return
 
     def _register_station(self):
@@ -261,7 +266,7 @@ class StoqCommandHandler:
                           is_active=True,
                           branch=branch,
                           name=get_hostname())
-        except StoqlibError, e:
+        except StoqlibError as e:
             raise SystemExit("ERROR: %s" % e)
 
         store.commit()
@@ -288,7 +293,7 @@ class StoqCommandHandler:
         proc = Process(args)
         proc.communicate()
         if proc.returncode != 0:
-            print "ERROR: Failed to run %r" % (args, )
+            print("ERROR: Failed to run %r" % (args, ))
             return 30
         return 0
 
@@ -440,7 +445,7 @@ def main(args):
 
     # import library or else externals won't be on sys.path
     from stoqlib.lib.kiwilibrary import library
-    library # pyflakes
+    library  # pylint: disable=W0104
 
     from stoq.lib.options import get_option_parser
     parser = get_option_parser()
@@ -455,4 +460,4 @@ if __name__ == '__main__':
     try:
         sys.exit(main(sys.argv))
     except KeyboardInterrupt:
-        print 'Interrupted'
+        print('Interrupted')
