@@ -26,13 +26,11 @@ Base class for sharing code between accounts payable and receivable."""
 
 import urllib
 
-import datetime
 from dateutil.relativedelta import relativedelta
 
 import gtk
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter
 import pango
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.api import api
 from stoqlib.domain.payment.category import PaymentCategory
 from stoqlib.domain.payment.payment import Payment
@@ -43,10 +41,12 @@ from stoqlib.gui.dialogs.paymentchangedialog import (PaymentDueDateChangeDialog,
                                                      PaymentStatusChangeDialog)
 from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
 from stoqlib.gui.dialogs.paymentflowhistorydialog import PaymentFlowHistoryDialog
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.translation import stoqlib_gettext as _
 from storm.expr import And
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
 
 class FilterItem(object):
@@ -60,16 +60,15 @@ class FilterItem(object):
         return '<FilterItem "%s">' % (self.name, )
 
 
-class BaseAccountWindow(SearchableAppWindow):
-    embedded = True
+class BaseAccountWindow(ShellApp):
 
     #
     # Application
     #
 
     def create_ui(self):
-        if api.sysparam(self.store).SMART_LIST_LOADING:
-            self.search.search.enable_lazy_search()
+        if api.sysparam.get_bool('SMART_LIST_LOADING'):
+            self.search.enable_lazy_search()
         self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.search.set_summary_label(column='value',
                                       label='<b>%s</b>' % (_('Total'), ),
@@ -95,7 +94,7 @@ class BaseAccountWindow(SearchableAppWindow):
             elif v == 'status:paid':
                 msg = _("No paid payments found.")
             elif v == 'status:not-paid':
-                if self.search_table == InPaymentView:
+                if self.search_spec == InPaymentView:
                     msg = _("No payments to receive found.")
                 else:
                     msg = _("No payments to pay found.")
@@ -120,20 +119,20 @@ class BaseAccountWindow(SearchableAppWindow):
     #
 
     def add_payment(self, category=None):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(self.editor_class, store, category=category)
 
         if store.committed:
             self._update_filter_items()
-            self.search.refresh()
-            self.select_result(self.store.find(self.search_table,
+            self.refresh()
+            self.select_result(self.store.find(self.search_spec,
                                                id=store.retval.id).one())
 
     def show_details(self, payment_view):
         """Shows some details about the payment, allowing to edit a few
         properties
         """
-        with api.trans() as store:
+        with api.new_store() as store:
             payment = store.fetch(payment_view.payment)
             run_dialog(self.editor_class, self, store, payment)
 
@@ -147,7 +146,7 @@ class BaseAccountWindow(SearchableAppWindow):
         """Shows a dialog with comments saved on the payment
         @param payment_view: an OutPaymentView or InPaymentView instance
         """
-        with api.trans() as store:
+        with api.new_store() as store:
             run_dialog(PaymentCommentsDialog, self, store,
                        payment_view.payment)
 
@@ -158,13 +157,14 @@ class BaseAccountWindow(SearchableAppWindow):
     def change_due_date(self, payment_view, order):
         """ Receives a payment_view and change the payment due date
         related to the view.
-        @param payment_view: an OutPaymentView or InPaymentView instance
-        @param order: a Sale or Purchase instance related to this payment. This
-          will be used to show the identifier of the order
+
+        :param payment_view: an OutPaymentView or InPaymentView instance
+        :param order: a Sale or Purchase instance related to this payment.
+          This will be used to show the identifier of the order
         """
         assert payment_view.can_change_due_date()
 
-        with api.trans() as store:
+        with api.new_store() as store:
             payment = store.fetch(payment_view.payment)
             order = store.fetch(order)
             run_dialog(PaymentDueDateChangeDialog, self, store,
@@ -177,12 +177,13 @@ class BaseAccountWindow(SearchableAppWindow):
 
     def change_status(self, payment_view, order, status):
         """Show a dialog do enter a reason for status change
-        @param payment_view: an OutPaymentView or InPaymentView instance
-        @param order: a Sale or Purchase instance related to this payment. This
-          will be used to show the identifier of the order
-        @param status: The new status to set the payment to
+
+        :param payment_view: an OutPaymentView or InPaymentView instance
+        :param order: a Sale or Purchase instance related to this payment.
+          This will be used to show the identifier of the order
+        :param status: The new status to set the payment to
         """
-        with api.trans() as store:
+        with api.new_store() as store:
             payment = store.fetch(payment_view.payment)
             order = store.fetch(payment_view.sale)
 
@@ -204,7 +205,8 @@ class BaseAccountWindow(SearchableAppWindow):
         combo.color_attribute = 'color'
         combo.set_row_separator_func(self._on_main_filter__row_separator_func)
         self._update_filter_items()
-        self.executer.add_filter_query_callback(
+        executer = self.search.get_query_executer()
+        executer.add_filter_query_callback(
             self.main_filter,
             self._on_main_filter__query_callback)
         self.add_filter(self.main_filter, SearchFilterPosition.TOP)
@@ -234,18 +236,18 @@ class BaseAccountWindow(SearchableAppWindow):
         if item is None:
             return None
         kind, value = item.value.split(':')
-        payment_view = self.search_table
+        payment_view = self.search_spec
         if kind == 'status':
             if value == 'paid':
                 return payment_view.status == Payment.STATUS_PAID
             elif value == 'not-paid':
                 return payment_view.status == Payment.STATUS_PENDING
             elif value == 'late':
-                tolerance = api.sysparam(self.store).TOLERANCE_FOR_LATE_PAYMENTS
+                tolerance = api.sysparam.get_int('TOLERANCE_FOR_LATE_PAYMENTS')
                 return And(
                     payment_view.status == Payment.STATUS_PENDING,
-                    payment_view.due_date < datetime.date.today() -
-                                              relativedelta(days=tolerance))
+                    payment_view.due_date < localtoday() -
+                    relativedelta(days=tolerance))
         elif kind == 'category':
             return payment_view.category == value
 
@@ -267,7 +269,11 @@ class BaseAccountWindow(SearchableAppWindow):
         return False
 
     def _on_main_filter__query_callback(self, state):
-        return self._create_main_query(state)
+        query = self._create_main_query(state)
+        current = api.get_current_branch(self.store)
+        if query:
+            return And(query, Payment.branch_id == current.id)
+        return Payment.branch_id == current.id
 
     def _on_results__cell_data_func(self, column, renderer, pv, text):
         if not isinstance(renderer, gtk.CellRendererText):
