@@ -39,18 +39,19 @@ from stoqlib.domain.person import Client
 from stoqlib.gui.editors.callseditor import CallsEditor
 from stoqlib.gui.editors.paymenteditor import (InPaymentEditor,
                                                OutPaymentEditor)
-from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.editors.workordereditor import WorkOrderEditor
 from stoqlib.gui.stockicons import (STOQ_CALENDAR_TODAY,
                                     STOQ_CALENDAR_WEEK,
                                     STOQ_CALENDAR_MONTH,
                                     STOQ_CALENDAR_LIST)
-from stoqlib.gui.webview import WebView
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.widgets.webview import WebView
 from stoqlib.lib import dateutils
 from stoqlib.lib.daemonutils import start_daemon
 from stoqlib.lib.defaults import get_weekday_start
 from stoqlib.lib.translation import stoqlib_gettext as _
 
-from stoq.gui.application import AppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
 
 def parse_javascript_date(jsdate):
@@ -106,7 +107,7 @@ class CalendarView(WebView):
             # day column format : eg "Monday 9/7", see:
             # http://arshaw.com/fullcalendar/docs/text/columnFormat/
             'day': _('dddd M/d'),
-            }
+        }
 
         options['timeFormat'] = {
             # for agendaWeek and agendaDay, eg "5:00 - 6:30", see:
@@ -115,7 +116,7 @@ class CalendarView(WebView):
             # for all other views, eg "7p", see:
             # http://arshaw.com/fullcalendar/docs/text/timeFormat/
             '': _('h(:mm)t'),
-            }
+        }
 
         options['titleFormat'] = {
             # month title, eg "September 2009", see:
@@ -127,7 +128,7 @@ class CalendarView(WebView):
             # day time, eg "Tuesday, Sep 8, 2009" see:
             # http://arshaw.com/fullcalendar/docs/text/titleFormat/
             'day': _('dddd, MMM d, yyyy'),
-            }
+        }
 
         if get_weekday_start() == MO:
             firstday = 1
@@ -158,7 +159,8 @@ class CalendarView(WebView):
             out_payments=events.get('out-payments', True),
             purchase_orders=events.get('purchase-orders', True),
             client_calls=events.get('client-calls', True),
-            )
+            work_orders=events.get('work-orders', True),
+        )
 
     def _save_user_settings(self):
         events = api.user_settings.get('calendar-events', {})
@@ -166,6 +168,7 @@ class CalendarView(WebView):
         events['out-payments'] = self._show_events['out_payments']
         events['purchase-orders'] = self._show_events['purchase_orders']
         events['client-calls'] = self._show_events['client_calls']
+        events['work-orders'] = self._show_events['work_orders']
 
     def _update_calendar_size(self, width, height):
         self._calendar_run('option', 'aspectRatio', float(width) / height)
@@ -246,15 +249,17 @@ class CalendarView(WebView):
         self._save_user_settings()
 
 
-class CalendarApp(AppWindow):
+class CalendarApp(ShellApp):
 
-    app_name = _('Calendar')
+    app_title = _('Calendar')
     gladefile = 'calendar'
-    embedded = True
 
-    def __init__(self, app, store=None):
+    def __init__(self, window, store=None):
+        # Create this here because CalendarView will update it.
+        # It will only be shown on create_ui though
+        self.date_label = gtk.Label('')
         self._calendar = CalendarView(self)
-        AppWindow.__init__(self, app, store=store)
+        ShellApp.__init__(self, window, store=store)
         self._setup_daemon()
 
     @api.async
@@ -267,7 +272,7 @@ class CalendarApp(AppWindow):
         self._calendar.load()
 
     #
-    # AppWindow overrides
+    # ShellApp overrides
     #
 
     def create_actions(self):
@@ -280,6 +285,8 @@ class CalendarApp(AppWindow):
              group.get('new_payable'), _("Add a new account payable")),
             ('NewReceivable', None, _("Account receivable"),
              group.get('new_receivable'), _("Add a new account receivable")),
+            ('NewWorkOrder', None, _("Work order"),
+             group.get('new_work_order'), _("Add a new work order")),
             # View
             ('Back', gtk.STOCK_GO_BACK, _("Back"),
              group.get('go_back'), _("Go back")),
@@ -289,9 +296,9 @@ class CalendarApp(AppWindow):
              group.get('show_today'), _("Show today")),
             ('CalendarEvents', None, _("Calendar events")),
             ('CurrentView', None, _("Display view as")),
-            ]
+        ]
         self.calendar_ui = self.add_ui_actions('', actions,
-                                                filename='calendar.xml')
+                                               filename='calendar.xml')
         self.set_help_section(_("Calendar help"), 'app-calendar')
 
         toggle_actions = [
@@ -303,7 +310,9 @@ class CalendarApp(AppWindow):
              None, _("Show purchases in the list")),
             ('ClientCallEvents', None, _("Client Calls"),
              None, _("Show client calls in the list")),
-            ]
+            ('WorkOrderEvents', None, _("Work orders"),
+             None, _("Show work orders in the list")),
+        ]
         self.add_ui_actions('', toggle_actions, 'ToggleActions',
                             'toggle')
 
@@ -314,6 +323,7 @@ class CalendarApp(AppWindow):
                           u'payable'),
             purchase_orders=(self.PurchaseEvents, None, u'stock'),
             client_calls=(self.ClientCallEvents, self.NewClientCall, u'sales'),
+            work_orders=(self.WorkOrderEvents, self.NewWorkOrder, u'services'),
         )
 
         user = api.get_current_user(self.store)
@@ -339,7 +349,7 @@ class CalendarApp(AppWindow):
              '', _("Show one week")),
             ('ViewDay', STOQ_CALENDAR_LIST, _("View as day"),
              '', _("Show one day")),
-            ]
+        ]
         self.add_ui_actions('', radio_actions, 'RadioActions',
                             'radio')
         self.ViewMonth.set_short_label(_("Month"))
@@ -358,9 +368,9 @@ class CalendarApp(AppWindow):
             self.ViewDay.props.active = True
 
     def create_ui(self):
-        self.app.launcher.add_new_items([self.NewClientCall,
-                                         self.NewPayable,
-                                         self.NewReceivable])
+        self.window.add_new_items([self.NewClientCall,
+                                   self.NewPayable,
+                                   self.NewReceivable])
 
         # Reparent the toolbar, to show the date next to it.
         self.hbox = gtk.HBox()
@@ -368,7 +378,6 @@ class CalendarApp(AppWindow):
         toolbar.reparent(self.hbox)
 
         # A label to show the current calendar date.
-        self.date_label = gtk.Label('')
         self.date_label.show()
         self.hbox.pack_start(self.date_label, False, False, 6)
         self.hbox.show()
@@ -377,23 +386,23 @@ class CalendarApp(AppWindow):
 
         self.main_vbox.pack_start(self._calendar)
         self._calendar.show()
-        self.app.launcher.Print.set_tooltip(_("Print this calendar"))
+        self.window.Print.set_tooltip(_("Print this calendar"))
 
-    def activate(self, params):
-        self.app.launcher.SearchToolItem.set_sensitive(False)
+    def activate(self, refresh=True):
+        self.window.SearchToolItem.set_sensitive(False)
         # FIXME: Are we 100% sure we can always print something?
-        # self.app.launcher.Print.set_sensitive(True)
+        # self.window.Print.set_sensitive(True)
 
     def deactivate(self):
         # Put the toolbar back at where it was
-        main_vbox = self.app.launcher.main_vbox
+        main_vbox = self.window.main_vbox
         toolbar = self.uimanager.get_widget('/toolbar')
         self.hbox.remove(toolbar)
         main_vbox.pack_start(toolbar, False, False)
         main_vbox.reorder_child(toolbar, 1)
 
         self.uimanager.remove_ui(self.calendar_ui)
-        self.app.launcher.SearchToolItem.set_sensitive(True)
+        self.window.SearchToolItem.set_sensitive(True)
 
     # Private
 
@@ -403,17 +412,25 @@ class CalendarApp(AppWindow):
             in_payments=self.AccountsReceivableEvents.get_active(),
             purchase_orders=self.PurchaseEvents.get_active(),
             client_calls=self.ClientCallEvents.get_active(),
-            )
+            work_orders=self.WorkOrderEvents.get_active(),
+        )
 
     def _new_client_call(self):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(CallsEditor, store, None, None, Client)
 
         if store.committed:
             self._update_events()
 
+    def _new_work_order(self):
+        with api.new_store() as store:
+            self.run_dialog(WorkOrderEditor, store)
+
+        if store.committed:
+            self._update_events()
+
     def _new_payment(self, editor):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(editor, store)
 
         if store.committed:
@@ -445,6 +462,9 @@ class CalendarApp(AppWindow):
     def on_NewReceivable__activate(self, action):
         self._new_payment(InPaymentEditor)
 
+    def on_NewWorkOrder__activate(self, action):
+        self._new_work_order()
+
     def on_Back__activate(self, action):
         self._calendar.go_prev()
 
