@@ -46,39 +46,40 @@ Current flow of the database steps:
   * :obj:`FinishInstallationStep`
 """
 
-import os
+import logging
 import platform
 
 import glib
 import gtk
 from kiwi.component import provide_utility
 from kiwi.datatypes import ValidationError
-from kiwi.log import Logger
 from kiwi.python import Settable
 from kiwi.ui.delegates import GladeSlaveDelegate
 
 from stoqlib.api import api
 from stoqlib.exceptions import DatabaseInconsistency
-from stoqlib.database.admin import (USER_ADMIN_DEFAULT_NAME, ensure_admin_user,
+from stoqlib.database.admin import (USER_ADMIN_DEFAULT_NAME,
                                     create_default_profile_settings)
 from stoqlib.database.interfaces import (ICurrentBranchStation,
                                          ICurrentBranch)
 from stoqlib.database.settings import (DatabaseSettings, test_local_database,
-                                       validate_database_name)
+                                       validate_database_name,
+                                       check_extensions, get_database_version)
 from stoqlib.domain.person import LoginUser
 from stoqlib.domain.station import BranchStation
 from stoqlib.domain.system import SystemTable
 from stoqlib.exceptions import DatabaseError
 from stoqlib.gui.base.wizards import (BaseWizard, WizardEditorStep,
                                       WizardStep)
-from stoqlib.gui.logo import render_logo_pixbuf
 from stoqlib.gui.slaves.userslave import PasswordEditorSlave
-from stoqlib.gui.processview import ProcessView
+from stoqlib.gui.utils.logo import render_logo_pixbuf
+from stoqlib.gui.widgets.processview import ProcessView
 from stoqlib.lib.configparser import StoqConfig
 from stoqlib.lib.formatters import raw_phone_number
 from stoqlib.lib.kiwilibrary import library
 from stoqlib.lib.message import error, warning, yesno
 from stoqlib.lib.osutils import get_product_key, read_registry_key
+from stoqlib.lib.pgpass import write_pg_pass
 from stoqlib.lib.validators import validate_email
 from stoqlib.lib.webservice import WebService
 from stoqlib.lib.translation import stoqlib_gettext as _
@@ -89,7 +90,7 @@ from stoq.gui.shell.shell import PRIVACY_STRING
 from stoq.lib.options import get_option_parser
 from stoq.lib.startup import setup
 
-logger = Logger(__name__)
+logger = logging.getLogger(__name__)
 
 
 LOGO_WIDTH = 91
@@ -152,7 +153,7 @@ class DatabaseLocationStep(BaseWizardStep):
             settings.port = self.wizard.get_win32_postgres_port()
             return PostgresAdminPasswordStep(self.wizard, self)
         else:
-            settings.address = "" # Unix socket really
+            settings.address = ""  # Unix socket really
 
         return self.wizard.connect_for_settings(self)
 
@@ -276,7 +277,7 @@ class InstallationModeStep(BaseWizardStep):
         self.empty_database_radio.grab_focus()
 
     def next_step(self):
-        self.wizard.enable_production = not self.empty_database_radio.get_active()
+        self.wizard.create_examples = not self.empty_database_radio.get_active()
         return PluginStep(self.wizard, self)
 
     def on_empty_database_radio__activate(self, radio):
@@ -370,7 +371,7 @@ class TefStep(WizardEditorStep):
 
         webapi = WebService()
         response = webapi.tef_request(self.model.name, self.model.email,
-                                   self.model.phone)
+                                      self.model.phone)
         response.addCallback(self._on_response_done)
         response.addErrback(self._on_response_error)
 
@@ -417,7 +418,7 @@ class TefStep(WizardEditorStep):
             self.wizard.tef_request_done = True
             self.wizard.go_to_next()
 
-    def _on_response_error(self, error):
+    def _on_response_error(self, err):
         self._show_error()
 
 
@@ -545,17 +546,17 @@ class InstallPostgresStep(BaseWizardStep):
     def _can_install(self):
         try:
             import aptdaemon
-            aptdaemon # pyflakes
+            aptdaemon  # pylint: disable=W0104
             return True
         except ImportError:
             return False
 
     def _install_postgres(self):
-        from stoqlib.gui.aptpackageinstaller import AptPackageInstaller
+        from stoqlib.gui.utils.aptpackageinstaller import AptPackageInstaller
         self.wizard.disable_back()
         self.wizard.disable_next()
         apti = AptPackageInstaller(parent=self.wizard.get_toplevel())
-        apti.install('postgresql')
+        apti.install('postgresql', 'postgresql-contrib')
         apti.connect('done', self._on_apt_install__done)
         apti.connect('auth-failed', self._on_apt_install__auth_failed)
 
@@ -580,7 +581,7 @@ class InstallPostgresStep(BaseWizardStep):
     #   Callbacks
     #
 
-    def _on_apt_install__done(self, api, error):
+    def _on_apt_install__done(self, apt, err):
         if error is not None:
             warning(_("Something went wrong while trying to install "
                       "the PostgreSQL server."))
@@ -596,7 +597,7 @@ class InstallPostgresStep(BaseWizardStep):
             #        to tell him that postgres installation succeeded.
             self.wizard.go_to_next()
 
-    def _on_apt_install__auth_failed(self, api):
+    def _on_apt_install__auth_failed(self, apt):
         self.wizard.enable_back()
         self.wizard.enable_next()
         self.label.set_markup(
@@ -621,12 +622,12 @@ class CreateDatabaseStep(BaseWizardStep):
         return FinishInstallationStep(self.wizard)
 
     def _maybe_create_database(self):
-        logger.info('_maybe_create_database (db_is_local=%s, remove_demo=%s)'
-                    % (self.wizard.db_is_local, self.wizard.remove_demo))
+        logger.info('_maybe_create_database (db_is_local=%s, enable_production=%s)'
+                    % (self.wizard.db_is_local, self.wizard.enable_production))
         if self.wizard.db_is_local:
             self._launch_stoqdbadmin()
             return
-        elif self.wizard.remove_demo:
+        elif self.wizard.enable_production:
             self._launch_stoqdbadmin()
             return
 
@@ -634,19 +635,28 @@ class CreateDatabaseStep(BaseWizardStep):
         settings = self.wizard.settings
         self.wizard.config.load_settings(settings)
 
-        # store = settings.get_super_store()
-        # version = store.dbVersion()
-        # if version < (8, 1):
-        #     info(_("Stoq requires PostgresSQL 8.1 or later, but %s found") %
-        #          ".".join(map(str, version)))
-        #     store.close()
-        #     return False
+        store = settings.create_super_store()
+        version = get_database_version(store)
+
+        if version < (9, 1):
+            store.close()
+            error(_("Stoq requires PostgresSQL 9.1 or later, but %s found") % (
+                ".".join(map(str, version))))
+
+        try:
+            check_extensions(store=store)
+        except ValueError:
+            store.close()
+            error(_("Missing PostgreSQL extension on the server, "
+                    "please install postgresql-contrib on it"))
+
+        store.close()
 
         # Secondly, ask the user if he really wants to create the database,
         dbname = settings.dbname
-        if not yesno(_("The specified database '%s' does not exist.\n"
-                       "Do you want to create it?") % dbname,
-                     gtk.RESPONSE_NO, _("Don't create"), _("Create database")):
+        if yesno(_(u"The specified database '%s' does not exist.\n"
+                   u"Do you want to create it?") % dbname,
+                 gtk.RESPONSE_YES, _(u"Create database"), _(u"Don't create")):
             self.process_view.feed("** Creating database\r\n")
             self._launch_stoqdbadmin()
         else:
@@ -669,8 +679,11 @@ class CreateDatabaseStep(BaseWizardStep):
                 '--no-load-config',
                 '--no-register-station',
                 '-v']
-        if self.wizard.enable_production and not self.wizard.remove_demo:
+        if self.wizard.create_examples:
             args.append('--demo')
+        elif self.wizard.enable_production:
+            args.append('--force')
+
         if self.wizard.plugins:
             args.append('--enable-plugins')
             args.append(','.join(self.wizard.plugins))
@@ -711,7 +724,7 @@ class CreateDatabaseStep(BaseWizardStep):
         elif line == 'INIT START':
             text = _("Creating additional database objects ...")
             value = 0.8
-        elif line == 'INIT DONE' and self.wizard.enable_production:
+        elif line == 'INIT DONE' and self.wizard.create_examples:
             text = _("Creating examples ...")
             value = 0.85
         elif line.startswith('PLUGIN'):
@@ -740,6 +753,11 @@ class CreateDatabaseStep(BaseWizardStep):
                     return
                 self._launch_stoqdbadmin()
                 return
+            elif returncode == 31:
+                # Missing postgresql-contrib package
+                self.expander.set_expanded(True)
+                warning(_("Your database is missing the postgresql-contrib "
+                          "package. Install it and try again"))
             else:
                 # Unknown error, just inform user that something went wrong.
                 self.expander.set_expanded(True)
@@ -749,7 +767,6 @@ class CreateDatabaseStep(BaseWizardStep):
         self.label.set_text("")
         self.wizard.load_config_and_call_setup()
         create_default_profile_settings()
-        ensure_admin_user(self.wizard.config.get_password())
         self.progressbar.set_text(_("Done."))
         self.progressbar.set_fraction(1.0)
         self.wizard.enable_next()
@@ -824,9 +841,9 @@ class FirstTimeConfigWizard(BaseWizard):
             config = StoqConfig()
         self.settings = config.get_settings()
 
-        self.enable_production = False
+        self.create_examples = False
         self.config = config
-        self.remove_demo = False
+        self.enable_production = False
         self.has_installed_db = False
         self.options = options
         self.plugins = []
@@ -835,9 +852,9 @@ class FirstTimeConfigWizard(BaseWizard):
         self.auth_type = TRUST_AUTHENTICATION
 
         if config.get('Database', 'enable_production') == 'True':
-            self.remove_demo = True
+            self.enable_production = True
 
-        if self.remove_demo:
+        if self.enable_production:
             first_step = PluginStep(self)
         else:
             first_step = WelcomeStep(self)
@@ -853,14 +870,13 @@ class FirstTimeConfigWizard(BaseWizard):
         #        The whole BranchStation/Branch creation is weird, it should
         #        be done at the same place.
         logger.info('_create_station')
-        if self.enable_production:
-            branch = api.sysparam(store).MAIN_COMPANY
+        if self.create_examples:
+            branch = api.sysparam.get_object(store, 'MAIN_COMPANY')
             assert branch
             provide_utility(ICurrentBranch, branch)
         else:
             branch = None
 
-        # FIXME: what about LTSP
         station_name = get_hostname()
         if store.find(BranchStation, branch=branch, name=station_name).one():
             return
@@ -882,8 +898,8 @@ class FirstTimeConfigWizard(BaseWizard):
 
     def _set_online_services(self, store):
         logger.info('_set_online_services (%s)' %
-                            self.enable_online_services)
-        api.sysparam(store).ONLINE_SERVICES = int(self.enable_online_services)
+                    self.enable_online_services)
+        api.sysparam.set_bool(store, 'ONLINE_SERVICES', self.enable_online_services)
 
     # Public API
 
@@ -901,14 +917,14 @@ class FirstTimeConfigWizard(BaseWizard):
     def try_connect(self, settings, warn=True):
         logger.info('try_connect (warn=%s)' % (warn))
         logger.info('settings: address=%s username=%s, dbname=%s' % (
-                        settings.address, settings.username, settings.dbname))
+            settings.address, settings.username, settings.dbname))
         self.config.load_settings(settings)
         try:
             if settings.has_database():
                 store = settings.create_store()
                 self.has_installed_db = SystemTable.is_available(store)
                 store.close()
-        except DatabaseError, e:
+        except DatabaseError as e:
             if warn:
                 warning(e.short, str(e.msg))
             logger.info('Failed to connect')
@@ -919,7 +935,7 @@ class FirstTimeConfigWizard(BaseWizard):
 
     def check_incomplete_database(self):
         logger.info('check_incomplete_database (db_is_local=%s)' %
-                (self.db_is_local, ))
+                   (self.db_is_local, ))
         # If we don't have postgres installed we cannot have
         # an incomplete database
         if self.db_is_local and not test_local_database():
@@ -929,7 +945,7 @@ class FirstTimeConfigWizard(BaseWizard):
         try:
             if not self.settings.has_database():
                 return False
-        except DatabaseError, e:
+        except DatabaseError as e:
             # If we're install stoq locally and hasn't created a database
             # user yet, we'll receive an authentiction error, there's no
             # way to reliably check for this, so assume all errors are
@@ -938,7 +954,7 @@ class FirstTimeConfigWizard(BaseWizard):
             if self.db_is_local:
                 return False
             msg = (_('It was not possible to connect to the database.') +
-                  '\n' + _('Check the server configuration and try again.'))
+                   '\n' + _('Check the server configuration and try again.'))
             warning(msg, str(e))
             return True
 
@@ -1006,49 +1022,9 @@ class FirstTimeConfigWizard(BaseWizard):
         if self.auth_type != PASSWORD_AUTHENTICATION:
             return
 
-        logger.info('write_pgpass')
-        # There's no way to pass in the password to psql via the command line,
-        # so we need to setup a pgpass where we store the password entered here
-        if platform.system() == 'Windows':
-            directory = os.path.join(os.environ['APPDATA'],
-                                     'postgresql')
-            passfile = os.path.join(directory, 'pgpass.conf')
-        else:
-            directory = os.environ.get('HOME', '/')
-            passfile = os.path.join(directory, '.pgpass')
-        pgpass = os.environ.get('PGPASSFILE', passfile)
-
-        # FIXME: remove duplicates when trying several different passwords
-        if os.path.exists(pgpass):
-            lines = []
-            for line in open(pgpass):
-                if line[-1] == '\n':
-                    line = line[:-1]
-                lines.append(line)
-        else:
-            lines = []
-
-        # _get_store_internal connects to the 'postgres' database,
-        # we need to allow connections without asking the password,
-        # otherwise stoqdbadmin will be stuck in the wizard when creating
-        # a new database.
-        for dbname in ['postgres', self.settings.dbname]:
-            line = '%s:%s:%s:%s:%s' % (self.settings.address,
-                                       self.settings.port,
-                                       dbname,
-                                       self.settings.username,
-                                       self.settings.password)
-            if line in lines:
-                continue
-            lines.append(line)
-
-        if not os.path.exists(directory):
-            os.makedirs(directory)
-        fd = open(pgpass, 'w')
-        fd.write('\n'.join(lines))
-        fd.write('\n')
-        fd.close()
-        os.chmod(pgpass, 0600)
+        write_pg_pass(self.settings.dbname, self.settings.address,
+                      self.settings.port, self.settings.username,
+                      self.settings.password)
 
     #
     # WizardStep hooks
@@ -1069,7 +1045,7 @@ class FirstTimeConfigWizard(BaseWizard):
             store.commit()
 
         # Write configuration to disk
-        if self.remove_demo:
+        if self.enable_production:
             self.config.remove('Database', 'enable_production')
         self.config.flush()
 
