@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2011-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -34,61 +34,51 @@ from dateutil.relativedelta import relativedelta
 import gobject
 import gtk
 from kiwi.currency import currency
-from kiwi.db.query import DateQueryState, DateIntervalQueryState
 from kiwi.python import Settable
 from kiwi.ui.dialogs import selectfile
-from kiwi.ui.objectlist import ColoredColumn, Column, SearchColumn, ObjectList
-from kiwi.ui.search import Any, DateSearchFilter, DateSearchOption, SearchContainer
+from kiwi.ui.objectlist import ColoredColumn, Column
+import pango
 from stoqlib.api import api
 from stoqlib.database.expr import Date
+from stoqlib.database.queryexecuter import DateQueryState, DateIntervalQueryState
 from stoqlib.domain.account import Account, AccountTransaction, AccountTransactionView
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.views import InPaymentView, OutPaymentView
-from stoqlib.database.queryexecuter import StoqlibQueryExecuter
-from stoqlib.gui.accounttree import AccountTree
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.accounteditor import AccountEditor
 from stoqlib.gui.editors.accounttransactioneditor import AccountTransactionEditor
 from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.dialogs.importerdialog import ImporterDialog
 from stoqlib.gui.dialogs.financialreportdialog import FinancialReportDialog
-from stoqlib.gui.keybindings import get_accels
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchoptions import Any, DateSearchOption
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.search.searchresultview import SearchResultListView
+from stoqlib.gui.search.searchslave import SearchSlave
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.utils.printing import print_report
+from stoqlib.gui.widgets.accounttree import AccountTree
+from stoqlib.gui.widgets.notebookbutton import NotebookCloseButton
 from stoqlib.lib.dateutils import get_month_names
 from stoqlib.lib.message import yesno
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.payment import AccountTransactionReport
-from storm.expr import Or, And
+from storm.expr import And, Or
 
-from stoq.gui.application import AppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
 
-class NotebookCloseButton(gtk.Button):
-    pass
-gobject.type_register(NotebookCloseButton)
+class FinancialSearchResults(SearchResultListView):
 
-
-class FinancialSearchResults(ObjectList):
-    pass
-gobject.type_register(FinancialSearchResults)
-
-
-class TransactionSearchContainer(SearchContainer):
-    results_class = FinancialSearchResults
-
-    def __init__(self, page, columns):
-        self.page = page
-        self.model = page.model
-        SearchContainer.__init__(self, columns)
-
-    def add_results(self, results, clear=True):
-        if clear:
-            self.page.search.results.clear()
-
-        if self.page.query.table == AccountTransactionView:
-            self.page.append_transactions(results)
+    def search_completed(self, results):
+        page = self.page
+        executer = page.search.get_query_executer()
+        if executer.search_spec == AccountTransactionView:
+            page.append_transactions(results)
         else:
-            self.page.search.results.extend(results)
+            super(FinancialSearchResults, self).search_completed(results)
+
+gobject.type_register(FinancialSearchResults)
 
 
 class MonthOption(DateSearchOption):
@@ -122,16 +112,18 @@ class TransactionPage(object):
         return self.parent_window
 
     def _create_search(self):
-        self.search = TransactionSearchContainer(
-            self, columns=self._get_columns(self.model.kind))
-        self.query = StoqlibQueryExecuter(self.app.store)
-        self.search.set_query_executer(self.query)
-        self.search.results.connect('row-activated', self._on_row__activated)
-        self.results = self.search.results
-        tree_view = self.search.results.get_treeview()
+        self.search = SearchSlave(self._get_columns(self.model.kind),
+                                  store=self.app.store)
+        self.search.connect('result-item-activated',
+                            self._on_search__item_activated)
+        self.search.enable_advanced_search()
+        self.search.set_result_view(FinancialSearchResults)
+        self.result_view = self.search.result_view
+        self.result_view.page = self
+        self.result_view.set_cell_data_func(self._on_result_view__cell_data_func)
+        tree_view = self.search.result_view.get_treeview()
         tree_view.set_rules_hint(True)
         tree_view.set_grid_lines(gtk.TREE_VIEW_GRID_LINES_BOTH)
-        self.search.enable_advanced_search()
 
     def _add_date_filter(self):
         self.date_filter = DateSearchFilter(_('Date:'))
@@ -147,7 +139,7 @@ class TransactionPage(object):
                            'year': year})
             self.date_filter.add_option(option, i + 1)
         self.date_filter.add_custom_options()
-        self.date_filter.mode.select_item_by_position(0)
+        self.date_filter.select(Any)
         self.search.add_filter(self.date_filter)
 
     def _append_date_query(self, field):
@@ -161,11 +153,13 @@ class TransactionPage(object):
         return queries
 
     def _payment_query(self, store):
-        queries = self._append_date_query(self.query.table.due_date)
+        executer = self.search.get_query_executer()
+        search_spec = executer.search_spec
+        queries = self._append_date_query(search_spec.due_date)
         if queries:
-            return store.find(self.query.table, And(*queries))
+            return store.find(search_spec, And(*queries))
 
-        return store.find(self.query.table)
+        return store.find(search_spec)
 
     def _transaction_query(self, store):
         queries = [Or(self.model.id == AccountTransaction.account_id,
@@ -179,22 +173,22 @@ class TransactionPage(object):
 
     def _setup_search(self):
         if self.model.kind == 'account':
-            self.query.set_table(AccountTransactionView)
+            self.search.set_search_spec(AccountTransactionView)
             self.search.set_text_field_columns(['description'])
-            self.query.set_query(self._transaction_query)
+            self.search.set_query(self._transaction_query)
         elif self.model.kind == 'payable':
             self.search.set_text_field_columns(['description', 'supplier_name'])
-            self.query.set_table(OutPaymentView)
-            self.query.set_query(self._payment_query)
+            self.search.set_search_spec(OutPaymentView)
+            self.search.set_query(self._payment_query)
         elif self.model.kind == 'receivable':
             self.search.set_text_field_columns(['description', 'drawee'])
-            self.query.set_table(InPaymentView)
-            self.query.set_query(self._payment_query)
+            self.search.set_search_spec(InPaymentView)
+            self.search.set_query(self._payment_query)
         else:
             raise TypeError("unknown model kind: %r" % (self.model.kind, ))
 
     def refresh(self):
-        self.search.results.clear()
+        self.search.result_view.clear()
         if self.model.kind == 'account':
             transactions = AccountTransactionView.get_for_account(self.model, self.app.store)
             self.append_transactions(transactions)
@@ -211,6 +205,24 @@ class TransactionPage(object):
         else:
             return self._get_account_columns()
 
+    def _on_result_view__cell_data_func(self, column, renderer, account_view, text):
+        if not isinstance(renderer, gtk.CellRendererText):
+            return text
+
+        if self.model.kind != 'account':
+            return text
+
+        trans = account_view.transaction
+        is_imbalance = self.app._imbalance_account_id in [
+            trans.dest_account_id,
+            trans.source_account_id]
+
+        renderer.set_property('weight-set', is_imbalance)
+        if is_imbalance:
+            renderer.set_property('weight', pango.WEIGHT_BOLD)
+
+        return text
+
     def _get_account_columns(self):
         def format_withdrawal(value):
             if value < 0:
@@ -243,7 +255,7 @@ class TransactionPage(object):
 
     def _get_payment_columns(self):
         return [SearchColumn('due_date', title=_("Due date"), data_type=datetime.date, sorted=True),
-                SearchColumn('identifier', title=_("Code"), data_type=int),
+                IdentifierColumn('identifier', title=_("Code")),
                 SearchColumn('description', title=_("Description"), data_type=unicode, expand=True),
                 SearchColumn('value', title=_("Value"),
                              data_type=currency)]
@@ -257,12 +269,12 @@ class TransactionPage(object):
 
     def _populate_payable_payments(self, view_class):
         for view in self.app.store.find(view_class):
-            self.search.results.append(view)
+            self.search.result_view.append(view)
 
     def _add_transaction(self, transaction, description, value):
         item = Settable(transaction=transaction)
         self._update_transaction(item, transaction, description, value)
-        self.search.results.append(item)
+        self.search.result_view.append(item)
         return item
 
     def _update_transaction(self, item, transaction, description, value):
@@ -274,7 +286,7 @@ class TransactionPage(object):
 
     def update_totals(self):
         total = decimal.Decimal('0')
-        for item in self.search.results:
+        for item in self.search.result_view:
             total += item.value
             item.total = total
 
@@ -289,15 +301,15 @@ class TransactionPage(object):
         transaction = run_dialog(AccountTransactionEditor, self.app,
                                  store, account_transaction, model)
 
+        store.confirm(transaction)
         if transaction:
-            store.flush()
+            item.transaction.sync()
             self._update_transaction(item, transaction,
                                      transaction.edited_account.description,
                                      transaction.value)
             self.update_totals()
-            self.search.results.update(item)
+            self.search.result_view.update(item)
             self.app.accounts.refresh_accounts(self.app.store)
-        store.confirm(transaction)
         store.close()
 
     def on_dialog__opened(self, dialog):
@@ -313,40 +325,41 @@ class TransactionPage(object):
 
         transaction = run_dialog(AccountTransactionEditor, self.app,
                                  store, None, model)
+        store.confirm(transaction)
         if transaction:
-            transaction.sync()
+            query = AccountTransactionView.id == transaction.id
+            transaction_view = store.find(AccountTransactionView, query).one()
             value = transaction.value
             other = transaction.get_other_account(model)
             if other == model:
                 value = -value
-            item = self._add_transaction(transaction, other.description, value)
+            item = self._add_transaction(transaction_view, other.description, value)
             self.update_totals()
-            self.search.results.update(item)
+            self.search.result_view.update(item)
             self.app.accounts.refresh_accounts(self.app.store)
-        store.confirm(transaction)
         store.close()
 
-    def _on_row__activated(self, objectlist, item):
+    def _on_search__item_activated(self, objectlist, item):
         if self.model.kind == 'account':
             self._edit_transaction_dialog(item)
 
 
-class FinancialApp(AppWindow):
+class FinancialApp(ShellApp):
 
-    app_name = _('Financial')
+    app_title = _('Financial')
     gladefile = 'financial'
-    embedded = True
 
-    def __init__(self, app, store=None):
+    def __init__(self, window, store=None):
+        # Account id -> TransactionPage
         self._pages = {}
         self.accounts = AccountTree()
-        AppWindow.__init__(self, app, store=store)
-        self._tills_account = api.sysparam(self.store).TILLS_ACCOUNT
-        self._imbalance_account = api.sysparam(self.store).IMBALANCE_ACCOUNT
-        self._banks_account = api.sysparam(self.store).BANKS_ACCOUNT
+        ShellApp.__init__(self, window, store=store)
+        self._tills_account_id = api.sysparam.get_object_id('TILLS_ACCOUNT')
+        self._imbalance_account_id = api.sysparam.get_object_id('IMBALANCE_ACCOUNT')
+        self._banks_account_id = api.sysparam.get_object_id('BANKS_ACCOUNT')
 
     #
-    # AppWindow overrides
+    # ShellApp overrides
     #
 
     def create_actions(self):
@@ -374,7 +387,7 @@ class FinancialApp(AppWindow):
              _("Add a new transaction")),
             ("Edit", gtk.STOCK_EDIT, _("Edit..."),
              group.get('edit')),
-            ]
+        ]
         self.financial_ui = self.add_ui_actions('', actions,
                                                 filename='financial.xml')
         self.set_help_section(_("Financial help"), 'app-financial')
@@ -390,24 +403,25 @@ class FinancialApp(AppWindow):
         self.trans_popup = self.uimanager.get_widget('/TransactionSelection')
         self.acc_popup = self.uimanager.get_widget('/AccountSelection')
 
-        self.app.launcher.add_new_items([self.NewAccount,
-                                         self.NewTransaction])
+        self.window.add_new_items([self.NewAccount,
+                                   self.NewTransaction])
 
         self.search_holder.add(self.accounts)
         self.accounts.show()
         self._create_initial_page()
         self._refresh_accounts()
 
-    def activate(self, params):
-        for page in self._pages.values():
-            page.refresh()
+    def activate(self, refresh=True):
+        if refresh:
+            for page in self._pages.values():
+                page.refresh()
         self._update_actions()
         self._update_tooltips()
-        self.app.launcher.SearchToolItem.set_sensitive(False)
+        self.window.SearchToolItem.set_sensitive(False)
 
     def deactivate(self):
         self.uimanager.remove_ui(self.financial_ui)
-        self.app.launcher.SearchToolItem.set_sensitive(True)
+        self.window.SearchToolItem.set_sensitive(True)
 
     def print_activate(self):
         self._print_transaction_report()
@@ -415,6 +429,11 @@ class FinancialApp(AppWindow):
     def export_spreadsheet_activate(self):
         self._export_spreadsheet()
 
+    def get_current_page(self):
+        widget = self._get_current_page_widget()
+        if hasattr(widget, 'page'):
+            return widget.page
+
     #
     # Private
     #
@@ -425,8 +444,8 @@ class FinancialApp(AppWindow):
         self.TransactionMenu.set_visible(not is_accounts_tab)
         self.DeleteAccount.set_visible(is_accounts_tab)
         self.DeleteTransaction.set_visible(not is_accounts_tab)
-        self.app.launcher.ExportSpreadSheet.set_sensitive(True)
-        self.app.launcher.Print.set_sensitive(not is_accounts_tab)
+        self.window.ExportSpreadSheet.set_sensitive(True)
+        self.window.Print.set_sensitive(not is_accounts_tab)
 
         self.NewAccount.set_sensitive(self._can_add_account())
         self.DeleteAccount.set_sensitive(self._can_delete_account())
@@ -438,10 +457,10 @@ class FinancialApp(AppWindow):
     def _update_tooltips(self):
         if self._is_accounts_tab():
             self.Edit.set_tooltip(_("Edit the selected account"))
-            self.app.launcher.Print.set_tooltip("")
+            self.window.Print.set_tooltip("")
         else:
             self.Edit.set_tooltip(_("Edit the selected transaction"))
-            self.app.launcher.Print.set_tooltip(
+            self.window.Print.set_tooltip(
                 _("Print a report of these transactions"))
 
     def _create_initial_page(self):
@@ -456,7 +475,8 @@ class FinancialApp(AppWindow):
             parent_view = self.accounts.get_selected()
         else:
             page_id = self.notebook.get_current_page()
-            page = self.notebook.get_nth_page(page_id)
+            widget = self.notebook.get_nth_page(page_id)
+            page = widget.page
             if page.account_view.kind == 'account':
                 parent_view = page.account_view
         retval = self._run_account_editor(None, parent_view)
@@ -482,7 +502,7 @@ class FinancialApp(AppWindow):
         if parent_account:
             if parent_account.kind in ['payable', 'receivable']:
                 parent_account = None
-            if parent_account == api.sysparam(self.store).IMBALANCE_ACCOUNT:
+            if api.sysparam.compare_object('IMBALANCE_ACCOUNT', parent_account):
                 parent_account = None
         retval = self.run_dialog(AccountEditor, store, model=model,
                                  parent_account=parent_account)
@@ -494,39 +514,38 @@ class FinancialApp(AppWindow):
 
     def _close_current_page(self):
         assert self._can_close_tab()
-        page = self._get_current_page_widget()
+
+        page = self.get_current_page()
         self._close_page(page)
 
     def _get_current_page_widget(self):
         page_id = self.notebook.get_current_page()
-        page = self.notebook.get_children()[page_id]
-        if isinstance(page, TransactionSearchContainer):
-            return page.page
-        return page
+        widget = self.notebook.get_children()[page_id]
+        return widget
 
     def _close_page(self, page):
         for page_id, child in enumerate(self.notebook.get_children()):
             if getattr(child, 'page', None) == page:
+                self.notebook.remove_page(page_id)
+                del self._pages[page.account_view.id]
                 break
         else:
             raise AssertionError(page)
-        self.notebook.remove_page(page_id)
-        del self._pages[page.account_view.id]
 
     def _is_accounts_tab(self):
         page_id = self.notebook.get_current_page()
         return page_id == 0
 
     def _is_transaction_tab(self):
-        page = self._get_current_page_widget()
+        page = self.get_current_page()
         if not isinstance(page, TransactionPage):
             return False
 
         if page.model.kind != 'account':
             return False
 
-        if (page.model == self._tills_account or
-            page.model.parent_id == self._tills_account.id):
+        if (api.sysparam.compare_object('TILLS_ACCOUNT', page.model.account) or
+            page.model.parent_id == self._tills_account_id):
             return False
         return True
 
@@ -541,12 +560,9 @@ class FinancialApp(AppWindow):
         label = gtk.Label(title)
         hbox.pack_start(label, True, False)
         if title != _("Accounts"):
-            image = gtk.image_new_from_stock(gtk.STOCK_CLOSE, gtk.ICON_SIZE_MENU)
             button = NotebookCloseButton()
-            button.set_relief(gtk.RELIEF_NONE)
             if page:
                 button.connect('clicked', lambda button: self._close_page(page))
-            button.add(image)
             hbox.pack_end(button, False, False)
         hbox.show_all()
         return hbox
@@ -554,17 +570,19 @@ class FinancialApp(AppWindow):
     def _new_page(self, account_view):
         if account_view.id in self._pages:
             page = self._pages[account_view.id]
-            page_id = self.notebook.page_num(page.search)
+            page_id = self.notebook.page_num(page.search.vbox)
         else:
             pixbuf = self.accounts.get_pixbuf(account_view)
             page = TransactionPage(account_view,
                                    self, self.get_toplevel())
-            page.search.results.connect('selection-changed',
-                                        self._on_transaction__selection_changed)
-            page.search.results.connect('right-click',
-                                        self._on_transaction__right_click)
+            page.search.connect('result-selection-changed',
+                                self._on_search__result_selection_changed)
+            page.search.connect('result-item-popup-menu',
+                                self._on_search__result_item_popup_menu)
             hbox = self._create_tab_label(account_view.description, pixbuf, page)
-            page_id = self.notebook.append_page(page.search, hbox)
+            widget = page.search.vbox
+            widget.page = page
+            page_id = self.notebook.append_page(widget, hbox)
             page.show()
             page.account_view = account_view
             self._pages[account_view.id] = page
@@ -625,11 +643,11 @@ class FinancialApp(AppWindow):
         if self._is_accounts_tab():
             run_dialog(FinancialReportDialog, self, self.store)
         else:
-            page = self._get_current_page_widget()
+            page = self.get_current_page()
             sse = SpreadSheetExporter()
-            sse.export(object_list=page.results,
-                       name=self.app_name,
-                       filename_prefix=self.app.name)
+            sse.export(object_list=page.result_view,
+                       name=self.app_title,
+                       filename_prefix=self.app_name)
 
     def _can_add_account(self):
         if self._is_accounts_tab():
@@ -649,9 +667,9 @@ class FinancialApp(AppWindow):
         if account_view.kind != 'account':
             return False
 
-        if account_view.id in [self._banks_account.id,
-                               self._imbalance_account.id,
-                               self._tills_account.id]:
+        if account_view.id in [self._banks_account_id,
+                               self._imbalance_account_id,
+                               self._tills_account_id]:
             return False
         return True
 
@@ -678,8 +696,8 @@ class FinancialApp(AppWindow):
         if not self._is_transaction_tab():
             return False
 
-        page = self._get_current_page_widget()
-        transaction = page.results.get_selected()
+        page = self.get_current_page()
+        transaction = page.result_view.get_selected()
         if transaction is None:
             return False
 
@@ -689,15 +707,15 @@ class FinancialApp(AppWindow):
         if not self._is_transaction_tab():
             return False
 
-        page = self._get_current_page_widget()
-        transaction = page.results.get_selected()
+        page = self.get_current_page()
+        transaction = page.result_view.get_selected()
         if transaction is None:
             return False
 
         return True
 
     def _add_transaction(self):
-        page = self._get_current_page_widget()
+        page = self.get_current_page()
         page.add_transaction_dialog()
         self._refresh_accounts()
 
@@ -706,18 +724,17 @@ class FinancialApp(AppWindow):
         account = store.fetch(account_view.account)
         methods = PaymentMethod.get_by_account(store, account)
         if methods.count() > 0:
-            if yesno(
+            if not yesno(
                 _('This account is used in at least one payment method.\n'
                   'To be able to delete it the payment methods needs to be'
-                  're-configured first'), gtk.RESPONSE_YES,
-                _("Keep account"), _("Configure payment methods")):
+                  're-configured first'), gtk.RESPONSE_NO,
+                _("Configure payment methods"), _("Keep account")):
                 store.close()
                 return
-
-        elif yesno(
+        elif not yesno(
             _('Are you sure you want to remove account "%s" ?') % (
-              (account_view.description, )), gtk.RESPONSE_YES,
-            _("Keep account"), _("Remove account")):
+                (account_view.description, )), gtk.RESPONSE_NO,
+            _("Remove account"), _("Keep account")):
             store.close()
             return
 
@@ -728,22 +745,22 @@ class FinancialApp(AppWindow):
         self.accounts.remove(account_view)
         self.accounts.flush()
 
-        imbalance = api.sysparam(store).IMBALANCE_ACCOUNT
+        imbalance_id = api.sysparam.get_object_id('IMBALANCE_ACCOUNT')
         for method in methods:
-            method.destination_account = imbalance
+            method.destination_account_id = imbalance_id
 
         account.remove(store)
         store.commit(close=True)
 
     def _delete_transaction(self, item):
         msg = _('Are you sure you want to remove transaction "%s" ?') % (
-                (item.description))
-        if yesno(msg, gtk.RESPONSE_YES,
-                 _("Keep transaction"), _("Remove transaction")):
+            (item.description))
+        if not yesno(msg, gtk.RESPONSE_YES,
+                     _(u"Remove transaction"), _(u"Keep transaction")):
             return
 
-        account_transactions = self._get_current_page_widget()
-        account_transactions.results.remove(item)
+        account_transactions = self.get_current_page()
+        account_transactions.result_view.remove(item)
 
         store = api.new_store()
         if isinstance(item.transaction, AccountTransactionView):
@@ -757,8 +774,9 @@ class FinancialApp(AppWindow):
     def _print_transaction_report(self):
         assert not self._is_accounts_tab()
 
-        page = self._get_current_page_widget()
-        print_report(AccountTransactionReport, page.results, list(page.results),
+        page = self.get_current_page()
+        print_report(AccountTransactionReport, page.result_view,
+                     list(page.result_view),
                      account=page.model,
                      filters=page.search.get_search_filters())
 
@@ -779,15 +797,9 @@ class FinancialApp(AppWindow):
     def on_accounts__row_activated(self, ktree, account_view):
         self._new_page(account_view)
 
-    def _on_transaction__selection_changed(self, ktree, account_transaction):
-        self._update_actions()
-
     def on_accounts__selection_changed(self, ktree, account_view):
         self._update_actions()
 
-    def _on_transaction__right_click(self, results, result, event):
-        self.trans_popup.popup(None, None, None, event.button, event.time)
-
     def on_accounts__right_click(self, results, result, event):
         self.acc_popup.popup(None, None, None, event.button, event.time)
 
@@ -796,14 +808,20 @@ class FinancialApp(AppWindow):
             account_view = self.accounts.get_selected()
             self._edit_existing_account(account_view)
         elif self._is_transaction_tab():
-            page = self._get_current_page_widget()
-            transaction = page.results.get_selected()
+            page = self.get_current_page()
+            transaction = page.result_view.get_selected()
             page._edit_transaction_dialog(transaction)
 
     def after_notebook__switch_page(self, notebook, page, page_id):
         self._update_actions()
         self._update_tooltips()
 
+    def _on_search__result_selection_changed(self, search):
+        self._update_actions()
+
+    def _on_search__result_item_popup_menu(self, search, result, event):
+        self.trans_popup.popup(None, None, None, event.button, event.time)
+
     # Toolbar
 
     def new_activate(self):
@@ -823,8 +841,8 @@ class FinancialApp(AppWindow):
         self._delete_account(account_view)
 
     def on_DeleteTransaction__activate(self, action):
-        transactions = self._get_current_page_widget()
-        transaction = transactions.results.get_selected()
+        transactions = self.get_current_page()
+        transaction = transactions.result_view.get_selected()
         self._delete_transaction(transaction)
         self._refresh_accounts()
 
