@@ -24,39 +24,39 @@
 """ Main gui definition for inventory application. """
 
 import datetime
-import gtk
 
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import Column, SearchColumn
+import gtk
+from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.inventory import Inventory
 from stoqlib.domain.person import Branch
 from stoqlib.domain.product import ProductStockItem
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.exceptions import DatabaseInconsistency
-from stoqlib.gui.dialogs.openinventorydialog import OpenInventoryDialog
-from stoqlib.gui.dialogs.productadjustmentdialog import ProductsAdjustmentDialog
-from stoqlib.gui.dialogs.productcountingdialog import ProductCountingDialog
-from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.editors.inventoryadjustmenteditor import InventoryAdjustmentEditor
+from stoqlib.gui.editors.inventoryeditor import InventoryOpenEditor
+from stoqlib.gui.dialogs.inventorydetails import InventoryDetailsDialog
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.wizards.inventorywizard import InventoryCountWizard
 from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.product import ProductCountingReport
 from stoqlib.reporting.inventory import InventoryReport
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
 
-class InventoryApp(SearchableAppWindow):
+class InventoryApp(ShellApp):
 
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
-
-    app_name = _('Inventory')
+    app_title = _('Inventory')
     gladefile = "inventory"
-    search_table = Inventory
+    search_spec = Inventory
     search_labels = _('Matching:')
     report_table = InventoryReport
-    embedded = True
 
     #
     # Application
@@ -72,6 +72,9 @@ class InventoryApp(SearchableAppWindow):
 
             # Inventory
             ('InventoryMenu', None, _('Inventory')),
+            ('Details', gtk.STOCK_INFO, _('Details...'),
+             group.get('inventory_details'),
+             _('See details about this inventory')),
             ('CountingAction', gtk.STOCK_INDEX, _('_Count...'),
              group.get('inventory_count'),
              _('Register the actual stock of products in the selected '
@@ -94,27 +97,30 @@ class InventoryApp(SearchableAppWindow):
 
         self.AdjustAction.set_short_label(_("Adjust"))
         self.CountingAction.set_short_label(_("Count"))
+        self.Details.set_short_label(_("Details"))
         self.Cancel.set_short_label(_("Cancel"))
         self.AdjustAction.props.is_important = True
         self.CountingAction.props.is_important = True
+        self.Details.props.is_important = True
         self.Cancel.props.is_important = True
 
     def create_ui(self):
         self.popup = self.uimanager.get_widget('/InventorySelection')
 
-        self.app.launcher.add_new_items([self.NewInventory])
-        self.app.launcher.Print.set_tooltip(
+        self.window.add_new_items([self.NewInventory])
+        self.window.Print.set_tooltip(
             _("Print a report of these inventories"))
 
-    def activate(self, params):
-        # Avoid letting this sensitive if has-rows is never emitted
-        self.search.refresh()
+    def activate(self, refresh=True):
+        if refresh:
+            # Avoid letting this sensitive if has-rows is never emitted
+            self.refresh()
         self._update_widgets()
-        self.app.launcher.SearchToolItem.set_sensitive(False)
+        self.window.SearchToolItem.set_sensitive(False)
 
     def deactivate(self):
         self.uimanager.remove_ui(self.inventory_ui)
-        self.app.launcher.SearchToolItem.set_sensitive(True)
+        self.window.SearchToolItem.set_sensitive(True)
 
     def new_activate(self):
         if not self.NewInventory.get_sensitive():
@@ -123,36 +129,34 @@ class InventoryApp(SearchableAppWindow):
             return
         self._open_inventory()
 
-    #
-    # SearchableAppWindow
-    #
-
     def create_filters(self):
         # Disable string search right now, until we use a proper Viewable
         # for this application
-        self.disable_search_entry()
-        self.branch_filter = ComboSearchFilter(
-            _('Show inventories at:'), self._get_branches_for_filter())
-        self.add_filter(self.branch_filter,
-                        position=SearchFilterPosition.TOP,
+        self.search.disable_search_entry()
+        self.branch_filter = ComboSearchFilter(_('Show inventories at:'),
+                                               self._get_branches_for_filter())
+
+        current = api.get_current_branch(self.store)
+        self.branch_filter.select(current.id)
+
+        self.add_filter(self.branch_filter, SearchFilterPosition.TOP,
                         columns=["branch_id"])
 
     def get_columns(self):
-        return [SearchColumn('identifier', title=_('Code'), sorted=True,
-                       order=gtk.SORT_DESCENDING,
-                       data_type=int, format='%03d', width=80),
+        return [IdentifierColumn('identifier', title=_('Code'),
+                                 sorted=True, order=gtk.SORT_DESCENDING),
                 SearchColumn('status_str', title=_('Status'),
                              data_type=str, width=100,
                              valid_values=self._get_status_values(),
                              search_attribute='status'),
-                Column('branch.person.name', title=_('Branch'),
+                Column('branch.description', title=_('Branch'),
                        data_type=str, expand=True),
                 SearchColumn('open_date', title=_('Opened'),
-                       long_title=_('Date Opened'),
-                       data_type=datetime.date, width=120),
+                             long_title=_('Date Opened'),
+                             data_type=datetime.date, width=120),
                 SearchColumn('close_date', title=_('Closed'),
-                       long_title=_('Date Closed'),
-                       data_type=datetime.date, width=120)]
+                             long_title=_('Date Closed'),
+                             data_type=datetime.date, width=120)]
 
     #
     # Private API
@@ -167,7 +171,7 @@ class InventoryApp(SearchableAppWindow):
         return self.store.find(Branch)
 
     def _get_branches_for_filter(self):
-        items = [(b.person.name, b.id) for b in self._get_branches()]
+        items = [(b.get_description(), b.id) for b in self._get_branches()]
         if not items:
             raise DatabaseInconsistency('You should have at least one '
                                         'branch on your database.'
@@ -185,46 +189,33 @@ class InventoryApp(SearchableAppWindow):
             has_open = selected.is_open()
             has_adjusted = selected.has_adjusted_items()
 
-        self.set_sensitive([self.PrintProductListing], bool(selected))
+        self.set_sensitive([self.PrintProductListing, self.Details],
+                           bool(selected))
         self.set_sensitive([self.Cancel], has_open and not has_adjusted)
         self.set_sensitive([self.NewInventory], self._can_open())
-        self.set_sensitive([self.CountingAction], has_open)
+        self.set_sensitive([self.CountingAction], has_open and not all_counted)
         self.set_sensitive([self.AdjustAction], has_open and all_counted)
-        self.app.launcher.set_new_menu_sensitive(self._can_open())
-
-    def _get_available_branches_to_inventory(self):
-        """Returns a list of branches where we can open an inventory.
-        Note that we can open a inventory if:
-            - There's no inventory opened yet (in the same branch)
-            - The branch must have some stock
-        """
-        available_branches = []
-        for branch in self._get_branches():
-            has_open_inventory = Inventory.has_open(self.store, branch)
-            if not has_open_inventory:
-                stock = self.store.find(ProductStockItem, branch=branch)
-                if stock.count() > 0:
-                    available_branches.append(branch)
-
-        return available_branches
+        self.window.set_new_menu_sensitive(self._can_open())
 
     def _can_open(self):
-        # we can open an inventory if we have at least one branch
-        # available
-        return bool(self._get_available_branches_to_inventory())
+        branch = api.get_current_branch(self.store)
+        if Inventory.has_open(self.store, branch):
+            return False
+
+        # It doesn't make sense to open an inventory if we don't have any stock
+        return self.store.find(ProductStockItem, branch=branch).count() > 0
 
     def _open_inventory(self):
-        store = api.new_store()
-        branches = self._get_available_branches_to_inventory()
-        model = self.run_dialog(OpenInventoryDialog, store, branches)
-        store.confirm(model)
-        store.close()
-        self.refresh()
-        self._update_widgets()
+        with api.new_store() as store:
+            rv = self.run_dialog(InventoryOpenEditor, store)
+
+        if rv:
+            self.refresh()
+            self._update_widgets()
 
     def _cancel_inventory(self):
-        if yesno(_('Are you sure you want to cancel this inventory ?'),
-                 gtk.RESPONSE_YES, _("Don't cancel"), _("Cancel inventory")):
+        if not yesno(_('Are you sure you want to cancel this inventory ?'),
+                     gtk.RESPONSE_NO, _("Cancel inventory"), _("Don't cancel")):
             return
 
         store = api.new_store()
@@ -238,7 +229,7 @@ class InventoryApp(SearchableAppWindow):
     def _register_product_counting(self):
         store = api.new_store()
         inventory = store.fetch(self.results.get_selected())
-        model = self.run_dialog(ProductCountingDialog, store, inventory)
+        model = self.run_dialog(InventoryCountWizard, store, inventory)
         store.confirm(model)
         store.close()
         self.refresh()
@@ -247,7 +238,7 @@ class InventoryApp(SearchableAppWindow):
     def _adjust_product_quantities(self):
         store = api.new_store()
         inventory = store.fetch(self.results.get_selected())
-        model = self.run_dialog(ProductsAdjustmentDialog, store, inventory)
+        model = self.run_dialog(InventoryAdjustmentEditor, store, inventory)
         store.confirm(model)
         store.close()
         self.refresh()
@@ -260,6 +251,12 @@ class InventoryApp(SearchableAppWindow):
         for item in inventory.get_items():
             yield item.product.sellable
 
+    def _show_inventory_details(self):
+        store = api.new_store()
+        inventory = store.fetch(self.results.get_selected())
+        self.run_dialog(InventoryDetailsDialog, store, inventory)
+        store.close()
+
     #
     # Callbacks
     #
@@ -273,12 +270,18 @@ class InventoryApp(SearchableAppWindow):
     def on_AdjustAction__activate(self, action):
         self._adjust_product_quantities()
 
+    def on_Details__activate(self, action):
+        self._show_inventory_details()
+
     def on_results__selection_changed(self, results, product):
         self._update_widgets()
 
     def on_results__right_click(self, results, result, event):
         self.popup.popup(None, None, None, event.button, event.time)
 
+    def on_results__double_click(self, results, inventory):
+        self._show_inventory_details()
+
     def on_Cancel__activate(self, widget):
         self._cancel_inventory()
 
