@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2011-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -21,52 +21,37 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
+""" Application to launcher other application.  """
 
 import operator
 
 import gtk
 from kiwi.component import get_utility
 from stoqlib.api import api
-from stoqlib.gui.base.dialogs import add_current_toplevel
 from stoqlib.lib.interfaces import IApplicationDescriptions
 from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
-from stoq.gui.application import AppWindow
+
+from stoq.gui.shell.shellapp import ShellApp
 from stoq.lib.applist import Application
 
 _ = stoqlib_gettext
+
 (COL_LABEL,
  COL_PIXBUF,
  COL_APP) = range(3)
 
 
-class LauncherApp(object):
-    def __init__(self, launcher, options):
-        self.launcher = launcher
-        self.shell = launcher.shell
-        self.embedded = False
-        self.main_window = launcher
-        self.options = options
-        self.name = 'launcher'
-        self.in_ui_test = False
+class LauncherApp(ShellApp):
 
+    gladefile = "launcher"
 
-class Launcher(AppWindow):
-
-    app_name = _('Stoq')
-    gladefile = 'launcher'
-
-    def __init__(self, options, shell, store=None):
-        self.shell = shell
-        app = LauncherApp(self, options)
-        AppWindow.__init__(self, app, store=store)
+    app_title = "Stoq"
 
     #
-    # AppWindow
+    # ShellApp
     #
 
     def create_ui(self):
-        toplevel = self.get_toplevel().get_toplevel()
-        add_current_toplevel(toplevel)
         self.model.set_sort_column_id(COL_LABEL, gtk.SORT_ASCENDING)
         self.iconview.set_markup_column(COL_LABEL)
         self.iconview.set_pixbuf_column(COL_PIXBUF)
@@ -87,39 +72,39 @@ class Launcher(AppWindow):
         if len(self.model):
             self.iconview.select_path(self.model[0].path)
             self.iconview.grab_focus()
-
-    #
-    # Public API
-    #
-
-    def show_app(self, app, app_window, params=None):
-        self.iconview_vbox.hide()
-        super(Launcher, self).show_app(app, app_window, params)
-
-    def hide_app(self):
-        super(Launcher, self).hide_app()
         self.iconview_vbox.show()
+
+    def activate(self, refresh=True):
+        # Menu
+        self.window.ChangePassword.set_visible(True)
+        self.window.SignOut.set_visible(True)
+        self.window.Close.set_sensitive(False)
+        self.window.Quit.set_visible(True)
+        self.window.Print.set_sensitive(False)
+        self.window.Print.set_visible(False)
+        self.window.ExportSpreadSheet.set_visible(False)
+        self.window.ExportSpreadSheet.set_sensitive(False)
+
+        # Toolbar
+        self.window.set_new_menu_sensitive(True)
+        self.window.NewToolItem.set_tooltip(_("Open a new window"))
+        self.window.SearchToolItem.set_tooltip("")
+        self.window.SearchToolItem.set_sensitive(False)
+
+    def deactivate(self):
+        self.iconview_vbox.hide()
+
+    def setup_focus(self):
         self.iconview.grab_focus()
 
-    def run_app_by_name(self, app_name, params=None):
-        self.hide_app()
-        app = self._get_app_by_name(app_name)
-        if app is None:
-            raise ValueError(app_name)
-        return self.shell.run_embedded(app, self, params)
-
-    #
-    # Private
-    #
+    def new_activate(self):
+        self.window.new_window()
 
     def _get_app_by_name(self, app_name):
         for row in self.model:
             if row[COL_APP].name == app_name:
                 return row[COL_APP]
 
-    def _run_app(self, app):
-        self.shell.run_embedded(app, self)
-
     def _get_available_applications(self):
         user = api.get_current_user(self.store)
 
@@ -134,8 +119,8 @@ class Launcher(AppWindow):
         # sorting by app_full_name
         for name, full, icon, descr in locale_sorted(
             descriptions, key=operator.itemgetter(1)):
-            #FIXME:
-            #if name in self._hidden_apps:
+            # FIXME:
+            # if name in self._hidden_apps:
             #    continue
             # and name not in self._blocked_apps:
             if permissions.get(name):
@@ -145,9 +130,10 @@ class Launcher(AppWindow):
         return available_applications
 
     #
-    # Kiwi callbacks
+    # Callbacks
     #
 
     def on_iconview__item_activated(self, iconview, path):
+        self.window.hide_app(empty=True)
         app = self.model[path][COL_APP]
-        self._run_app(app)
+        self.window.run_application(app.name)
