@@ -33,9 +33,9 @@ import pango
 import gtk
 from kiwi.currency import currency
 from kiwi.python import all
-from kiwi.ui.search import DateSearchFilter
-from kiwi.ui.objectlist import Column, SearchColumn
+from kiwi.ui.objectlist import Column
 from kiwi.ui.gadgets import render_pixbuf
+
 from stoqlib.api import api
 from stoqlib.domain.payment.category import PaymentCategory
 from stoqlib.domain.payment.payment import Payment
@@ -44,10 +44,13 @@ from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.paymenteditor import OutPaymentEditor
 from stoqlib.gui.editors.paymentseditor import PurchasePaymentsEditor
-from stoqlib.gui.keybindings import get_accels
-from stoqlib.gui.printing import print_report
 from stoqlib.gui.search.paymentsearch import OutPaymentBillCheckSearch
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchfilters import DateSearchFilter
 from stoqlib.gui.slaves.paymentconfirmslave import PurchasePaymentConfirmSlave
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.utils.printing import print_report
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.message import warning
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.payment import PayablePaymentReport
@@ -60,9 +63,9 @@ class PayableApp(BaseAccountWindow):
 
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
-    app_name = _('Accounts payable')
+    app_title = _('Accounts payable')
     gladefile = 'payable'
-    search_table = OutPaymentView
+    search_spec = OutPaymentView
     search_label = _('matching:')
     report_table = PayablePaymentReport
     editor_class = OutPaymentEditor
@@ -114,8 +117,8 @@ class PayableApp(BaseAccountWindow):
 
             # Search
             ('PaymentCategories', None, _("Payment categories..."),
-            group.get('search_payment_categories'),
-            _('Search for payment categories')),
+             group.get('search_payment_categories'),
+             _('Search for payment categories')),
             ('BillCheckSearch', None, _('Bills and checks...'),
              group.get('search_bills'),
              _('Search for bills and checks')),
@@ -131,26 +134,19 @@ class PayableApp(BaseAccountWindow):
         self.Pay.set_sensitive(False)
         self.PrintReceipt.set_sensitive(False)
         self.popup = self.uimanager.get_widget('/PayableSelection')
-        self.app.launcher.add_new_items([self.AddPayment])
-        self.app.launcher.NewToolItem.set_tooltip(self.AddPayment.get_tooltip())
-        self.app.launcher.add_search_items([self.BillCheckSearch])
-        self.app.launcher.SearchToolItem.set_tooltip(
+        self.window.add_new_items([self.AddPayment])
+        self.window.NewToolItem.set_tooltip(self.AddPayment.get_tooltip())
+        self.window.add_search_items([self.BillCheckSearch])
+        self.window.SearchToolItem.set_tooltip(
             self.BillCheckSearch.get_tooltip())
-        self.app.launcher.Print.set_tooltip(
+        self.window.Print.set_tooltip(
             _("Print a report of these payments"))
 
-    def activate(self, params):
-        # FIXME: double negation is weird here
-        if not params.get('no-refresh'):
-            self.search.refresh()
+    def activate(self, refresh=True):
+        if refresh:
+            self.refresh()
         self._update_widgets()
 
-        # FIXME: Move this to a better place when done
-        if self.app.options.debug:
-            from stoqlib.gui.dialogs.chartdialog import ChartDialog
-            c = ChartDialog()
-            c.show_all()
-
     def deactivate(self):
         self.uimanager.remove_ui(self.payable_ui)
 
@@ -160,25 +156,21 @@ class PayableApp(BaseAccountWindow):
     def search_activate(self):
         run_dialog(OutPaymentBillCheckSearch, self, self.store)
 
-    #
-    # SearchableAppWindow
-    #
-
     def create_filters(self):
-        self.set_text_field_columns(['description', 'supplier_name'])
+        self.set_text_field_columns(['description', 'supplier_name',
+                                     'identifier_str'])
         self.create_main_filter()
 
     def get_columns(self):
-        return [SearchColumn('identifier', title=_('#'), long_title=_('Payment ID'),
-                             width=60, data_type=int, format='%04d'),
+        return [IdentifierColumn('identifier', long_title=_('Payment #')),
                 SearchColumn('description', title=_('Description'),
-                              data_type=str, ellipsize=pango.ELLIPSIZE_END,
-                              expand=True, pack_end=True),
+                             data_type=str, ellipsize=pango.ELLIPSIZE_END,
+                             expand=True, pack_end=True),
                 Column('color', title=_('Description'), width=20,
                        data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf,
                        column='description'),
                 Column('comments_number', title=_(u'Comments'),
-                        visible=False),
+                       visible=False),
                 SearchColumn('supplier_name', title=_('Supplier'),
                              data_type=str, width=140,
                              ellipsize=pango.ELLIPSIZE_END),
@@ -208,10 +200,10 @@ class PayableApp(BaseAccountWindow):
         self.main_filter.select(None)
         dfilter = DateSearchFilter(_("Paid or due date"))
         dfilter.set_removable()
-        dfilter.mode.select_item_by_position(5)
+        dfilter.select(data=DateSearchFilter.Type.USER_DAY)
         self.add_filter(dfilter, columns=["paid_date", "due_date"])
         dfilter.start_date.set_date(date)
-        self.search.refresh()
+        self.refresh()
 
     #
     # Private
@@ -271,7 +263,7 @@ class PayableApp(BaseAccountWindow):
         return payable_views[0].can_change_due_date()
 
     def _edit(self, payable_views):
-        with api.trans() as store:
+        with api.new_store() as store:
             order = store.fetch(payable_views[0].purchase)
             run_dialog(PurchasePaymentsEditor, self, store, order)
 
@@ -291,13 +283,13 @@ class PayableApp(BaseAccountWindow):
         purchase_order = payable_views[0].purchase
 
         if (purchase_order and
-            api.sysparam(self.store).BLOCK_INCOMPLETE_PURCHASE_PAYMENTS and
+            api.sysparam.get_bool('BLOCK_INCOMPLETE_PURCHASE_PAYMENTS') and
             not purchase_order.status == PurchaseOrder.ORDER_CLOSED):
 
             return warning(_("Can't confirm the payment if the purchase "
                              "is not completely received yet."))
 
-        with api.trans() as store:
+        with api.new_store() as store:
             payments = [store.fetch(view.payment) for view in payable_views]
 
             run_dialog(PurchasePaymentConfirmSlave, self, store,
@@ -352,6 +344,10 @@ class PayableApp(BaseAccountWindow):
         return all((view.purchase_id == purchase or not respect_purchase) and
                    view.is_paid() for view in payable_views)
 
+    def _can_set_not_paid(self, payable_views):
+        return all(view.payment.method.operation.can_set_not_paid(view.payment)
+                   for view in payable_views)
+
     def _same_purchase(self, payable_views):
         """Determines if a list of payable_views are in the same purchase"""
         if not payable_views:
@@ -382,7 +378,9 @@ class PayableApp(BaseAccountWindow):
         self.Pay.set_sensitive(self._can_pay(selected))
         self.PrintReceipt.set_sensitive(self._are_paid(selected,
                                                        respect_purchase=True))
-        self.SetNotPaid.set_sensitive(self._are_paid(selected, respect_purchase=False))
+        self.SetNotPaid.set_sensitive(self._are_paid(
+            selected, respect_purchase=False) and
+            self._can_set_not_paid(selected))
 
     def _get_status_values(self):
         items = [(value, key) for key, value in Payment.statuses.items()]
@@ -397,7 +395,7 @@ class PayableApp(BaseAccountWindow):
             FilterItem(_('Paid payments'), 'status:paid'),
             FilterItem(_('To pay'), 'status:not-paid'),
             FilterItem(_('Late payments'), 'status:late'),
-            ]
+        ]
 
         self.add_filter_items(PaymentCategory.TYPE_PAYABLE, options)
 
@@ -432,7 +430,7 @@ class PayableApp(BaseAccountWindow):
     def on_PrintReceipt__activate(self, action):
         payment_views = self.results.get_selected_rows()
         payments = [v.payment for v in payment_views]
-        date = datetime.date.today()
+        date = localtoday().date()
         print_report(OutPaymentReceipt, payment=payments[0],
                      order=payment_views[0].purchase, date=date)
 
