@@ -24,20 +24,22 @@
 """ Main interface definition for pos application.  """
 
 from decimal import Decimal
+import logging
 
 import pango
 import gtk
 from kiwi.currency import currency
 from kiwi.datatypes import converter, ValidationError
-from kiwi.log import Logger
 from kiwi.python import Settable
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 from kiwi.ui.widgets.contextmenu import ContextMenu, ContextMenuItem
+from storm.expr import And, Lower
 
 from stoqdrivers.enum import UnitType
 from stoqlib.api import api
 from stoqlib.domain.devices import DeviceSettings
 from stoqlib.domain.payment.group import PaymentGroup
+from stoqlib.domain.product import StorableBatch
 from stoqlib.domain.sale import Sale, Delivery
 from stoqlib.domain.sellable import Sellable
 from stoqlib.drivers.scale import read_scale_info
@@ -46,53 +48,64 @@ from stoqlib.gui.events import POSConfirmSaleEvent, CloseLoanWizardFinishEvent
 from stoqlib.lib.barcode import parse_barcode, BarcodeInfo
 from stoqlib.lib.decorators import cached_property, public
 from stoqlib.lib.defaults import quantize
+from stoqlib.lib.formatters import (format_sellable_description,
+                                    format_quantity, get_formatted_price)
 from stoqlib.lib.message import warning, info, yesno, marker
+from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.gui.base.dialogs import push_fullscreen, pop_fullscreen
 from stoqlib.gui.base.gtkadds import button_set_image_with_label
+from stoqlib.gui.dialogs.batchselectiondialog import BatchDecreaseSelectionDialog
+from stoqlib.gui.dialogs.sellableimage import SellableImageViewer
 from stoqlib.gui.editors.deliveryeditor import CreateDeliveryEditor
 from stoqlib.gui.editors.serviceeditor import ServiceItemEditor
 from stoqlib.gui.fiscalprinter import FiscalPrinterHelper
-from stoqlib.gui.keybindings import get_accels
-from stoqlib.gui.logo import render_logo_pixbuf
 from stoqlib.gui.search.deliverysearch import DeliverySearch
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.productsearch import ProductSearch
 from stoqlib.gui.search.salesearch import (SaleWithToolbarSearch,
                                            SoldItemsByBranchSearch)
-from stoqlib.gui.search.sellablesearch import SellableSearch
+from stoqlib.gui.search.sellablesearch import SaleSellableSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
 from stoqlib.gui.search.paymentreceivingsearch import PaymentReceivingSearch
 from stoqlib.gui.search.workordersearch import WorkOrderFinishedSearch
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.utils.logo import render_logo_pixbuf
 from stoqlib.gui.wizards.loanwizard import CloseLoanWizard
 from stoqlib.gui.wizards.salereturnwizard import SaleTradeWizard
 
-from stoq.gui.application import AppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 @public(since="1.5.0")
 class TemporarySaleItem(object):
     def __init__(self, sellable, quantity, price=None,
-                 notes=None, can_remove=True, quantity_decreased=0):
+                 notes=None, can_remove=True, quantity_decreased=0, batch=None):
         # Use only 3 decimal places for the quantity
         self.quantity = Decimal('%.3f' % quantity)
         self.quantity_decreased = quantity_decreased
+        self.batch = batch
         self.sellable = sellable
         self.description = sellable.get_description()
-        self.unit = sellable.get_unit_description()
+        self.unit = sellable.unit_description
         self.code = sellable.code
         self.can_remove = can_remove
 
         if not price:
             price = sellable.price
+        self.base_price = sellable.base_price
         self.price = price
         self.deliver = False
         self.estimated_fix_date = None
         self.notes = notes
 
+    @property
+    def full_description(self):
+        return format_sellable_description(self.sellable, self.batch)
+
     # FIXME: Single joins dont cache de value if its None, and we use that a lot
     # here. Add a cache until we fix SingleJoins to cache de value properly.
     @cached_property(ttl=0)
@@ -116,23 +129,20 @@ class TemporarySaleItem(object):
         return '%s %s' % (qtd_string, self.unit)
 
 
-class PosApp(AppWindow):
+class PosApp(ShellApp):
 
-    app_name = _('Point of Sales')
+    app_title = _('Point of Sales')
     gladefile = "pos"
-    embedded = True
 
-    def __init__(self, app, store=None):
+    def __init__(self, window, store=None):
         self._suggested_client = None
         self._current_store = None
         self._trade = None
         self._trade_infobar = None
-        self._trade_total_paid = 0
 
-        AppWindow.__init__(self, app, store=store)
+        ShellApp.__init__(self, window, store=store)
 
         self._delivery = None
-        self.param = api.sysparam(self.store)
         self._coupon = None
         # Cant use self._coupon to verify if there is a sale, since
         # CONFIRM_SALES_ON_TILL doesnt create a coupon
@@ -185,6 +195,13 @@ class PosApp(AppWindow):
         ]
         self.pos_ui = self.add_ui_actions('', actions,
                                           filename='pos.xml')
+
+        toggle_actions = [
+            ('DetailsViewer', None, _('Details viewer'),
+             group.get('toggle_details_viewer')),
+        ]
+        self.add_ui_actions('', toggle_actions, 'ToggleActions', 'toggle')
+
         self.set_help_section(_("POS help"), 'app-pos')
 
     def create_ui(self):
@@ -214,11 +231,15 @@ class PosApp(AppWindow):
         self._setup_proxies()
         self._clear_order()
 
-    def activate(self, params):
+    def activate(self, refresh=True):
         # Admin app doesn't have anything to print/export
-        for widget in (self.app.launcher.Print, self.app.launcher.ExportSpreadSheet):
+        for widget in (self.window.Print, self.window.ExportSpreadSheet):
             widget.set_visible(False)
 
+        # Hides or shows sellable description
+        self._confirm_quantity = sysparam.get_bool('CONFIRM_QTY_ON_BARCODE_ACTIVATE')
+        self.sellable_description.set_visible(self._confirm_quantity)
+
         # Hide toolbar specially for pos
         self.uimanager.get_widget('/toolbar').hide()
         self.uimanager.get_widget('/menubar/ViewMenu/ToggleToolbar').hide()
@@ -234,6 +255,9 @@ class PosApp(AppWindow):
         CloseLoanWizardFinishEvent.connect(self._on_CloseLoanWizardFinishEvent)
 
     def deactivate(self):
+        api.user_settings.set('pos-show-details-viewer',
+                              self.DetailsViewer.get_active())
+
         self.uimanager.remove_ui(self.pos_ui)
 
         # Re enable toolbar
@@ -273,7 +297,7 @@ class PosApp(AppWindow):
     def get_columns(self):
         return [Column('code', title=_('Reference'),
                        data_type=str, width=130, justify=gtk.JUSTIFY_RIGHT),
-                Column('description',
+                Column('full_description',
                        title=_('Description'), data_type=str, expand=True,
                        searchable=True, ellipsize=pango.ELLIPSIZE_END),
                 Column('price', title=_('Price'), data_type=currency,
@@ -312,24 +336,15 @@ class PosApp(AppWindow):
                               self._on_PrinterHelper__ecf_changed)
         self._printer.setup_midnight_check()
 
-    def _set_product_on_sale(self):
-        sellable = self._get_sellable()
-        # If the sellable has a weight unit specified and we have a scale
-        # configured for this station, go and check out what the printer says.
-        if (sellable and sellable.unit and
-            sellable.unit.unit_index == UnitType.WEIGHT and
-            self._scale_settings):
-            self._read_scale()
-
     def _setup_proxies(self):
         self.sellableitem_proxy = self.add_proxy(
             Settable(quantity=Decimal(1)), ['quantity'])
 
     def _update_parameter_widgets(self):
-        self.delivery_button.props.visible = self.param.HAS_DELIVERY_MODE
+        self.delivery_button.props.visible = sysparam.get_bool('HAS_DELIVERY_MODE')
 
         window = self.get_toplevel()
-        if self.param.POS_FULL_SCREEN:
+        if sysparam.get_bool('POS_FULL_SCREEN'):
             window.fullscreen()
             push_fullscreen(window)
         else:
@@ -337,9 +352,9 @@ class PosApp(AppWindow):
             window.unfullscreen()
 
         for widget in [self.TillOpen, self.TillClose, self.TillVerify]:
-            widget.set_visible(not self.param.POS_SEPARATE_CASHIER)
+            widget.set_visible(not sysparam.get_bool('POS_SEPARATE_CASHIER'))
 
-        if self.param.CONFIRM_SALES_ON_TILL:
+        if sysparam.get_bool('CONFIRM_SALES_ON_TILL'):
             confirm_label = _("_Close")
         else:
             confirm_label = _("_Checkout")
@@ -347,7 +362,7 @@ class PosApp(AppWindow):
                                     gtk.STOCK_APPLY, confirm_label)
 
     def _setup_widgets(self):
-        self._inventory_widgets = [self.Sales, self.barcode, self.quantity,
+        self._inventory_widgets = [self.barcode, self.quantity,
                                    self.sale_items, self.advanced_search,
                                    self.checkout_button, self.NewTrade,
                                    self.LoanClose, self.WorkOrderClose]
@@ -362,6 +377,15 @@ class PosApp(AppWindow):
 
         self.quantity.set_digits(3)
 
+        self._image_slave = SellableImageViewer(size=(175, 175))
+        self.attach_slave('image_holder', self._image_slave)
+        self.details_lbl.set_ellipsize(pango.ELLIPSIZE_END)
+        self.extra_details_lbl.set_ellipsize(pango.ELLIPSIZE_END)
+
+        self.details_box.set_visible(False)
+        self.DetailsViewer.set_active(
+            api.user_settings.get('pos-show-details-viewer', True))
+
     def _create_context_menu(self):
         menu = ContextMenu()
 
@@ -398,7 +422,7 @@ class PosApp(AppWindow):
         self._reset_quantity_proxy()
         self._update_totals()
 
-    def _update_list(self, sellable):
+    def _update_list(self, sellable, batch=None):
         assert isinstance(sellable, Sellable)
         try:
             sellable.check_taxes_validity()
@@ -408,58 +432,105 @@ class PosApp(AppWindow):
             return
 
         quantity = self.sellableitem_proxy.model.quantity
+        if sellable.product:
+            self._add_product_sellable(sellable, quantity, batch=batch)
+        elif sellable.service:
+            self._add_service_sellable(sellable, quantity)
 
-        is_service = sellable.service
-        if is_service and quantity > 1:
-            # It's not a common operation to add more than one item at
-            # a time, it's also problematic since you'd have to show
-            # one dialog per service item. See #3092
-            info(_("It's not possible to add more than one service "
-                   "at a time to an order. So, only one was added."))
-
+    def _add_service_sellable(self, sellable, quantity):
         sale_item = TemporarySaleItem(sellable=sellable,
                                       quantity=quantity)
-        if is_service:
-            with api.trans() as store:
-                rv = self.run_dialog(ServiceItemEditor, store, sale_item)
+        with api.new_store() as store:
+            rv = self.run_dialog(ServiceItemEditor, store, sale_item)
+
+        if not rv:
+            return
+
+        self._update_added_item(sale_item)
+
+    def _add_product_sellable(self, sellable, quantity, batch=None):
+        product = sellable.product
+        if product.storable and not batch and product.storable.is_batch:
+            available_batches = list(product.storable.get_available_batches(
+                api.get_current_branch(self.store)))
+            # The trivial case, where there's just one batch, use it directly
+            if len(available_batches) == 1:
+                batch = available_batches[0]
+                sale_item = TemporarySaleItem(sellable=sellable,
+                                              quantity=quantity,
+                                              batch=batch)
+                self._update_added_item(sale_item)
+                return
+
+            rv = self.run_dialog(BatchDecreaseSelectionDialog, self.store,
+                                 model=sellable.product_storable,
+                                 quantity=quantity)
             if not rv:
                 return
-        self._update_added_item(sale_item)
+
+            for batch, b_quantity in rv.items():
+                sale_item = TemporarySaleItem(sellable=sellable,
+                                              quantity=b_quantity,
+                                              batch=batch)
+                self._update_added_item(sale_item)
+        else:
+            sale_item = TemporarySaleItem(sellable=sellable,
+                                          quantity=quantity,
+                                          batch=batch)
+            self._update_added_item(sale_item)
 
     def _get_subtotal(self):
         return currency(sum([item.total for item in self.sale_items]))
 
-    def _get_sellable(self):
-        barcode = self.barcode.get_text()
-        if not barcode:
-            raise StoqlibError("_get_sellable needs a barcode")
-        barcode = unicode(barcode)
+    def _get_sellable_and_batch(self):
+        text = self.barcode.get_text()
+        if not text:
+            raise StoqlibError("_get_sellable_and_batch needs a barcode")
+        text = unicode(text)
 
-        fmt = api.sysparam(self.store).SCALE_BARCODE_FORMAT
+        fmt = api.sysparam.get_int('SCALE_BARCODE_FORMAT')
 
         # Check if this barcode is from a scale
-        info = parse_barcode(barcode, fmt)
-        if info:
-            barcode = info.code
-            weight = info.weight
+        barinfo = parse_barcode(text, fmt)
+        if barinfo:
+            text = barinfo.code
+            weight = barinfo.weight
 
-        sellable = self.store.find(Sellable, barcode=barcode,
-                                   status=Sellable.STATUS_AVAILABLE).one()
+        batch = None
+        query = Sellable.status == Sellable.STATUS_AVAILABLE
+
+        # FIXME: Put this logic for getting the sellable based on
+        # barcode/code/batch_number on domain. Note that something very
+        # simular is done on abstractwizard.py
+
+        sellable = self.store.find(
+            Sellable, And(query, Lower(Sellable.barcode) == text.lower())).one()
 
         # If the barcode didnt match, maybe the user typed the product code
         if not sellable:
-            sellable = self.store.find(Sellable, code=barcode,
-                                       status=Sellable.STATUS_AVAILABLE).one()
+            sellable = self.store.find(
+                Sellable, And(query, Lower(Sellable.code) == text.lower())).one()
+
+        # If none of the above found, try to get the batch number
+        if not sellable:
+            query = Lower(StorableBatch.batch_number) == text.lower()
+            batch = self.store.find(StorableBatch, query).one()
+            if batch:
+                sellable = batch.storable.product.sellable
+                if not sellable.is_available:
+                    # If the sellable is not available, reset both
+                    sellable = None
+                    batch = None
 
         # If the barcode has the price information, we need to calculate the
         # corresponding weight.
-        if info and sellable and info.mode == BarcodeInfo.MODE_PRICE:
-            weight = info.price / sellable.price
+        if barinfo and sellable and barinfo.mode == BarcodeInfo.MODE_PRICE:
+            weight = barinfo.price / sellable.price
 
-        if info and sellable:
+        if barinfo and sellable:
             self.quantity.set_value(weight)
 
-        return sellable
+        return sellable, batch
 
     def _select_first_item(self):
         if len(self.sale_items):
@@ -480,9 +551,7 @@ class PosApp(AppWindow):
     def _disable_printer_ui(self):
         self._set_sale_sensitive(False)
 
-        # It's possible to do a Sangria from the Sale search,
-        # disable it for now
-        widgets = [self.TillOpen, self.TillClose, self.TillVerify, self.Sales]
+        widgets = [self.TillOpen, self.TillClose, self.TillVerify]
         self.set_sensitive(widgets, False)
 
         text = _(u"POS operations requires a connected fiscal printer.")
@@ -507,10 +576,10 @@ class PosApp(AppWindow):
         self.till_status_label.set_markup(text)
 
         self.set_sensitive([self.TillOpen], closed)
-        self.set_sensitive([self.TillVerify],
-                           not closed and not blocked)
-        self.set_sensitive([self.TillClose, self.NewTrade,
+        self.set_sensitive([self.TillVerify, self.NewTrade,
                             self.LoanClose, self.WorkOrderClose],
+                           not closed and not blocked)
+        self.set_sensitive([self.TillClose],
                            not closed or blocked)
 
         self._set_sale_sensitive(not closed and not blocked)
@@ -521,7 +590,8 @@ class PosApp(AppWindow):
                             self.NewDelivery,
                             self.ConfirmOrder), has_sale_items)
         # We can cancel an order whenever we have a coupon opened.
-        self.set_sensitive([self.CancelOrder], self._sale_started)
+        self.set_sensitive([self.CancelOrder, self.DetailsViewer],
+                           self._sale_started)
         has_products = False
         has_services = False
         for sale_item in self.sale_items:
@@ -536,11 +606,9 @@ class PosApp(AppWindow):
         sale_item = self.sale_items.get_selected()
 
         if sale_item is not None and sale_item.service:
-            store = sale_item.service.store
             # We are fetching DELIVERY_SERVICE into the sale_items' store
             # instead of the default store to avoid accidental commits.
-            delivery_service = store.fetch(self.param.DELIVERY_SERVICE)
-            can_edit = sale_item.service != delivery_service
+            can_edit = not sysparam.compare_object('DELIVERY_SERVICE', sale_item.service)
         else:
             can_edit = False
         self.set_sensitive([self.edit_item_button], can_edit)
@@ -549,11 +617,56 @@ class PosApp(AppWindow):
 
         self.set_sensitive((self.checkout_button,
                             self.ConfirmOrder), has_products or has_services)
-        self.till_status_box.props.visible = not self._sale_started
-        self.sale_items.props.visible = self._sale_started
+        self.till_status_box.set_visible(not self._sale_started)
+        self.sale_items_pane.set_visible(self._sale_started)
 
         self._update_totals()
         self._update_buttons()
+        self._update_sellable_details()
+
+    def _update_sellable_details(self):
+        sale_item = self.sale_items.get_selected()
+        sellable = sale_item and sale_item.sellable
+        self._image_slave.set_sellable(sellable)
+
+        if sale_item:
+            markup = '<b>%s</b>\n%s x %s' % (
+                api.escape(sale_item.description),
+                api.escape(format_quantity(sale_item.quantity)),
+                api.escape(get_formatted_price(sale_item.price)))
+
+            if sellable.service:
+                fix_date = (sale_item.estimated_fix_date.strftime('%x')
+                            if sale_item.estimated_fix_date else '')
+                extra_markup_parts = [
+                    (_("Estimated fix date"), fix_date),
+                    (_("Notes"), sale_item.notes)]
+            elif sellable.product:
+                product = sellable.product
+                manufacturer = (product.manufacturer.name if
+                                product.manufacturer else '')
+                extra_markup_parts = [
+                    (_("Manufacturer"), manufacturer),
+                    (_("Brand"), product.brand),
+                    (_("Family"), product.family),
+                    (_("Model"), product.model),
+                    (_("Width"), product.width or ''),
+                    (_("Height"), product.height or ''),
+                    (_("Depth"), product.depth or ''),
+                    (_("Weight"), product.weight or '')]
+
+            extra_markup = '\n'.join(
+                '<b>%s</b>: %s' % (api.escape(label), api.escape(str(text)))
+                for label, text in extra_markup_parts if text)
+        else:
+            markup = ''
+            extra_markup = ''
+
+        self.details_lbl.set_markup(markup)
+        self.details_lbl.set_tooltip_markup(markup)
+
+        self.extra_details_lbl.set_markup(extra_markup)
+        self.extra_details_lbl.set_tooltip_markup(extra_markup)
 
     def _has_barcode_str(self):
         return self.barcode.get_text().strip() != ''
@@ -578,21 +691,18 @@ class PosApp(AppWindow):
 
     def _run_advanced_search(self, search_str=None, message=None):
         sellable_view_item = self.run_dialog(
-            SellableSearch,
+            SaleSellableSearch,
             self.store,
-            selection_mode=gtk.SELECTION_BROWSE,
             search_str=search_str,
             sale_items=self.sale_items,
             quantity=self.sellableitem_proxy.model.quantity,
-            double_click_confirm=True,
             info_message=message)
         if not sellable_view_item:
             self.barcode.grab_focus()
             return
 
         sellable = sellable_view_item.sellable
-        self._update_list(sellable)
-        self.barcode.grab_focus()
+        self._add_sellable(sellable)
 
     def _reset_quantity_proxy(self):
         self.sellableitem_proxy.model.quantity = Decimal(1)
@@ -602,12 +712,13 @@ class PosApp(AppWindow):
     def _get_deliverable_items(self):
         """Returns a list of sale items which can be delivered"""
         return [item for item in self.sale_items
-                        if item.sellable.product is not None]
+                if item.sellable.product is not None]
 
     def _check_delivery_removed(self, sale_item):
         # If a delivery was removed, we need to remove all
         # the references to it eg self._delivery
-        if sale_item.sellable == self.param.DELIVERY_SERVICE.sellable:
+        if (sale_item.sellable ==
+            sysparam.get_object(self.store, 'DELIVERY_SERVICE').sellable):
             self._delivery = None
 
     #
@@ -615,11 +726,7 @@ class PosApp(AppWindow):
     #
 
     def _add_sale_item(self, search_str=None):
-        quantity = self._read_quantity()
-        if quantity == 0:
-            return
-
-        sellable = self._get_sellable()
+        sellable, batch = self._get_sellable_and_batch()
         if not sellable:
             message = (_("The barcode '%s' does not exist. "
                          "Searching for a product instead...")
@@ -627,10 +734,17 @@ class PosApp(AppWindow):
             self._run_advanced_search(search_str, message)
             return
 
+        self._add_sellable(sellable, batch=batch)
+
+    def _add_sellable(self, sellable, batch=None):
+        quantity = self._read_quantity()
+        if quantity == 0:
+            return
+
         if not sellable.is_valid_quantity(quantity):
             warning(_(u"You cannot sell fractions of this product. "
                       u"The '%s' unit does not allow that") %
-                      sellable.get_unit_description())
+                    sellable.unit_description)
             return
 
         if sellable.product:
@@ -646,20 +760,25 @@ class PosApp(AppWindow):
             if not self._check_available_stock(storable, sellable):
                 info(_("You cannot sell more items of product %s. "
                        "The available quantity is not enough.") %
-                        sellable.get_description())
+                     sellable.get_description())
                 self.barcode.set_text('')
                 self.barcode.grab_focus()
                 return
 
-        self._update_list(sellable)
+        self._update_list(sellable, batch=batch)
+        self.sellable_description.set_text('')
         self.barcode.grab_focus()
 
     def _check_available_stock(self, storable, sellable):
         branch = api.get_current_branch(self.store)
         available = storable.get_balance_for_branch(branch)
-        added = sum([sale_item.quantity
+        # Items that were already decreased should not be considered here
+        added = sum([sale_item.quantity - sale_item.quantity_decreased
                      for sale_item in self.sale_items
-                         if sale_item.sellable == sellable])
+                     # FIXME: We are using .id to workaround a problem when
+                     # those sellables are not on the same store.
+                     # See the fixme on self.checkout and fix this together
+                     if sale_item.sellable.id == sellable.id])
         added += self.sellableitem_proxy.model.quantity
         return available - added >= 0
 
@@ -688,16 +807,14 @@ class PosApp(AppWindow):
         if self._trade and remove:
             self._trade.remove()
         self._trade = None
-        self._trade_total_paid = 0
         self._remove_trade_infobar()
 
     def _edit_sale_item(self, sale_item):
         if sale_item.service:
-            delivery_service = self.param.DELIVERY_SERVICE
-            if sale_item.service == delivery_service:
+            if sysparam.compare_object('DELIVERY_SERVICE', sale_item.service):
                 self._edit_delivery()
                 return
-            with api.trans() as store:
+            with api.new_store() as store:
                 model = self.run_dialog(ServiceItemEditor, store, sale_item)
             if model:
                 self.sale_items.update(sale_item)
@@ -717,7 +834,7 @@ class PosApp(AppWindow):
                 return False
 
         log.info("Cancelling coupon")
-        if not self.param.CONFIRM_SALES_ON_TILL:
+        if not sysparam.get_bool('CONFIRM_SALES_ON_TILL'):
             if self._coupon:
                 self._coupon.cancel()
         self._coupon = None
@@ -726,13 +843,13 @@ class PosApp(AppWindow):
         return True
 
     def _create_delivery(self):
-        delivery_sellable = self.param.DELIVERY_SERVICE.sellable
-        if delivery_sellable in self.sale_items:
-            self._delivery = delivery_sellable
+        delivery_param = sysparam.get_object(self.store, 'DELIVERY_SERVICE')
+        if delivery_param.sellable in self.sale_items:
+            self._delivery = delivery_param.sellable
 
         delivery = self._edit_delivery()
         if delivery:
-            self._add_delivery_item(delivery, delivery_sellable)
+            self._add_delivery_item(delivery, delivery_param.sellable)
             self._delivery = delivery
 
     def _edit_delivery(self):
@@ -740,7 +857,7 @@ class PosApp(AppWindow):
         If there's no delivery, create one.
         @returns: The delivery
         """
-        #FIXME: Canceling the editor still saves the changes.
+        # FIXME: Canceling the editor still saves the changes.
         return self.run_dialog(CreateDeliveryEditor, self.store,
                                self._delivery,
                                sale_items=self._get_deliverable_items())
@@ -769,15 +886,16 @@ class PosApp(AppWindow):
         user = api.get_current_user(store)
         branch = api.get_current_branch(store)
         salesperson = user.person.salesperson
-        cfop = api.sysparam(store).DEFAULT_SALES_CFOP
+        cfop_id = api.sysparam.get_object_id('DEFAULT_SALES_CFOP')
+        nature = api.sysparam.get_string('DEFAULT_OPERATION_NATURE')
         group = PaymentGroup(store=store)
         sale = Sale(store=store,
                     branch=branch,
                     salesperson=salesperson,
                     group=group,
-                    cfop=cfop,
+                    cfop_id=cfop_id,
                     coupon_id=None,
-                    operation_nature=api.sysparam(store).DEFAULT_OPERATION_NATURE)
+                    operation_nature=nature)
 
         if self._delivery:
             sale.client = store.fetch(self._delivery.client)
@@ -786,7 +904,7 @@ class PosApp(AppWindow):
                 store=store,
                 address=store.fetch(self._delivery.address),
                 transporter=store.fetch(self._delivery.transporter),
-                )
+            )
         else:
             delivery = None
             sale.client = self._suggested_client
@@ -795,7 +913,8 @@ class PosApp(AppWindow):
             sale_item = sale.add_sellable(
                 store.fetch(fake_sale_item.sellable),
                 price=fake_sale_item.price, quantity=fake_sale_item.quantity,
-                quantity_decreased=fake_sale_item.quantity_decreased)
+                quantity_decreased=fake_sale_item.quantity_decreased,
+                batch=store.fetch(fake_sale_item.batch))
             sale_item.notes = fake_sale_item.notes
             sale_item.estimated_fix_date = fake_sale_item.estimated_fix_date
 
@@ -806,6 +925,22 @@ class PosApp(AppWindow):
 
         return sale
 
+    def _set_additional_info(self, search_str=None):
+        """Show additional information about a product.
+
+        If parameter 'CONFIRM_QTY_ON_BARCODE_ACTIVATE' if set to true it shall
+        set the product's name into a bold label below the barcode search label.
+        """
+        sellable, batch = self._get_sellable_and_batch()
+        if sellable:
+            self.sellable_description.set_text(sellable.description)
+        else:
+            self.barcode.grab_focus()
+            message = (_("The barcode '%s' does not exist. "
+                         "Searching for a product instead...")
+                       % self.barcode.get_text())
+            self._run_advanced_search(search_str, message)
+
     @public(since="1.5.0")
     def checkout(self, cancel_clear=False):
         """Initiates the sale wizard to confirm sale.
@@ -815,6 +950,12 @@ class PosApp(AppWindow):
         """
         assert len(self.sale_items) >= 1
 
+        # FIXME: We should create self._current_store when adding the first
+        # item, so we can simplify a lot of code on this module by using it
+        # directly. The way it is now, most of the items will come from
+        # self.store (so we need to fetch them to the store we define bellow)
+        # and some from self._current_store (closed loan items, closed work
+        # order items, etc)
         if self._current_store:
             store = self._current_store
             savepoint = 'before_run_fiscalprinter_confirm'
@@ -836,15 +977,14 @@ class PosApp(AppWindow):
         else:
             sale = self._create_sale(store)
 
-        if self.param.CONFIRM_SALES_ON_TILL:
+        if sysparam.get_bool('CONFIRM_SALES_ON_TILL'):
             sale.order()
-            store.commit(close=True)
+            store.commit()
         else:
             assert self._coupon
 
             ordered = self._coupon.confirm(sale, store, savepoint,
-                                           subtotal=self._get_subtotal(),
-                                           total_paid=self._trade_total_paid)
+                                           subtotal=self._get_subtotal())
             # Dont call store.confirm() here, since coupon.confirm()
             # above already did it
             if not ordered:
@@ -859,10 +999,14 @@ class PosApp(AppWindow):
                 return
 
             log.info("Checking out")
-            store.close()
 
         self._coupon = None
         POSConfirmSaleEvent.emit(sale, self.sale_items[:])
+
+        # We must close the connection only after the event is emmited, since it
+        # may use value from the sale that will become invalid after it is
+        # closed
+        store.close()
         self._clear_order()
 
     def _remove_selected_item(self):
@@ -875,13 +1019,17 @@ class PosApp(AppWindow):
         self._update_widgets()
         self.barcode.grab_focus()
 
-    def _checkout_or_add_item(self):
+    def _checkout_or_add_item(self, must_add=False):
         search_str = self.barcode.get_text()
         if search_str == '':
             if len(self.sale_items) >= 1:
                 self.checkout()
         else:
-            self._add_sale_item(search_str)
+            if not self._confirm_quantity or must_add:
+                self._add_sale_item(search_str)
+            else:
+                self.quantity.grab_focus()
+                self._set_additional_info(search_str)
 
     def _remove_trade_infobar(self):
         if not self._trade_infobar:
@@ -900,9 +1048,8 @@ class PosApp(AppWindow):
         msg = _("There is a trade with value %s in progress...\n"
                 "When checking out, it will be used as part of "
                 "the payment.") % (value, )
-        self._trade_infobar = self.add_info_bar(gtk.MESSAGE_INFO, msg,
-                                                action_widget=button)
-        self._trade_total_paid += self._trade.returned_total
+        self._trade_infobar = self.window.add_info_bar(
+            gtk.MESSAGE_INFO, msg, action_widget=button)
 
     #
     # Coupon related
@@ -931,7 +1078,7 @@ class PosApp(AppWindow):
         See :class:`stoqlib.gui.fiscalprinter.FiscalCoupon` for more information
         """
         self._sale_started = True
-        if self.param.CONFIRM_SALES_ON_TILL:
+        if sysparam.get_bool('CONFIRM_SALES_ON_TILL'):
             return
 
         if self._coupon is None:
@@ -943,7 +1090,7 @@ class PosApp(AppWindow):
         return self._coupon.add_item(sale_item)
 
     def _coupon_remove_item(self, sale_item):
-        if self.param.CONFIRM_SALES_ON_TILL:
+        if sysparam.get_bool('CONFIRM_SALES_ON_TILL'):
             return
 
         assert self._coupon
@@ -969,7 +1116,7 @@ class PosApp(AppWindow):
         self.run_dialog(ClientSearch, self.store, hide_footer=True)
 
     def on_Sales__activate(self, action):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(SaleWithToolbarSearch, store)
 
     def on_SoldItemsByBranchSearch__activate(self, action):
@@ -1004,6 +1151,9 @@ class PosApp(AppWindow):
     def on_TillVerify__activate(self, action):
         self._printer.verify_till()
 
+    def on_DetailsViewer__activate(self, button):
+        self.details_box.set_visible(button.get_active())
+
     def on_LoanClose__activate(self, action):
         if self.check_open_inventory():
             return
@@ -1018,7 +1168,9 @@ class PosApp(AppWindow):
                              require_sale_items=True)
         if rv:
             if self._suggested_client is None:
-                self._suggested_client = rv.client
+                # The loan close wizard lets to close more than one loan at
+                # the same time (but only from the same client and branch)
+                self._suggested_client = rv[0].client
             self._current_store = store
         elif self._current_store:
             store.rollback_to_savepoint('before_run_wizard_closeloan')
@@ -1035,15 +1187,15 @@ class PosApp(AppWindow):
         else:
             store = api.new_store()
 
-        rv = self.run_dialog(WorkOrderFinishedSearch, store)
+        rv = self.run_dialog(WorkOrderFinishedSearch, store,
+                             double_click_confirm=True)
         if rv:
             work_order = rv.work_order
             for item in work_order.order_items:
                 self.add_sale_item(
                     TemporarySaleItem(sellable=item.sellable,
                                       quantity=item.quantity,
-                                      # Quantity was already decreased on work order
-                                      quantity_decreased=item.quantity,
+                                      quantity_decreased=item.quantity_decreased,
                                       price=item.price,
                                       can_remove=False))
             work_order.close()
@@ -1122,7 +1274,7 @@ class PosApp(AppWindow):
         self._update_buttons()
 
     def on_quantity__activate(self, entry):
-        self._checkout_or_add_item()
+        self._checkout_or_add_item(must_add=True)
 
     def on_quantity__validate(self, entry, value):
         self._update_buttons()
@@ -1162,7 +1314,7 @@ class PosApp(AppWindow):
         # We dont have an ecf. Disable till related operations
         self._disable_printer_ui()
 
-    def _on_CloseLoanWizardFinishEvent(self, loan, sale, wizard):
+    def _on_CloseLoanWizardFinishEvent(self, loans, sale, wizard):
         for item in wizard.get_sold_items():
             sellable, quantity, price = item
             self.add_sale_item(
