@@ -27,35 +27,36 @@ import datetime
 
 import gtk
 
-from kiwi.ui.objectlist import SearchColumn, Column
-from kiwi.ui.search import ComboSearchFilter, SearchFilterPosition
+from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.production import ProductionOrder
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.dialogs.productiondetails import ProductionDetailsDialog
 from stoqlib.gui.dialogs.productionquotedialog import ProductionQuoteDialog
 from stoqlib.gui.dialogs.startproduction import StartProductionDialog
-from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.productionsearch import (ProductionProductSearch,
                                                  ProductionItemsSearch,
                                                  ProductionHistorySearch)
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
 from stoqlib.gui.search.servicesearch import ServiceSearch
-from stoqlib.gui.wizards.productionwizard import ProductionWizard
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
 from stoqlib.gui.stockicons import STOQ_PRODUCTION_APP
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.wizards.productionwizard import ProductionWizard
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.production import ProductionReport
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
 
-class ProductionApp(SearchableAppWindow):
+class ProductionApp(ShellApp):
 
-    app_name = _(u'Production')
+    app_title = _(u'Production')
     gladefile = "production"
-    search_table = ProductionOrder
+    search_spec = ProductionOrder
     search_label = _(u'matching:')
     report_table = ProductionReport
-    embedded = True
 
     #
     # Application
@@ -75,7 +76,7 @@ class ProductionApp(SearchableAppWindow):
              _('Purchase quote...'),
              group.get('new_production_quote')),
 
-             # Production
+            # Production
             ('ProductionMenu', None, _('Production')),
             ('StartProduction', gtk.STOCK_CONVERT, _('Start production...'),
              group.get('production_start'),
@@ -85,7 +86,7 @@ class ProductionApp(SearchableAppWindow):
              _('Edit the selected production')),
             ('ProductionDetails', gtk.STOCK_INFO, _('Production details...'),
              group.get('production_details'),
-            _('Show production details and register produced items')),
+             _('Show production details and register produced items')),
 
             # Search
             ("SearchProduct", None, _("Production products..."),
@@ -116,22 +117,23 @@ class ProductionApp(SearchableAppWindow):
 
     def create_ui(self):
         self.popup = self.uimanager.get_widget('/ProductionSelection')
-        self.app.launcher.add_new_items([self.NewProduction,
-                                         self.ProductionPurchaseQuote])
-        self.app.launcher.add_search_items([
+        self.window.add_new_items([self.NewProduction,
+                                   self.ProductionPurchaseQuote])
+        self.window.add_search_items([
             self.SearchProduct,
             self.SearchService,
             self.SearchProductionItem,
-            ])
-        self.app.launcher.Print.set_tooltip(
+        ])
+        self.window.Print.set_tooltip(
             _("Print a report of these productions"))
 
         self._inventory_widgets = [self.StartProduction]
         self.register_sensitive_group(self._inventory_widgets,
                                       lambda: not self.has_open_inventory())
 
-    def activate(self, params):
-        self.search.refresh()
+    def activate(self, refresh=True):
+        if refresh:
+            self.refresh()
         self._update_widgets()
         self.check_open_inventory()
 
@@ -151,10 +153,10 @@ class ProductionApp(SearchableAppWindow):
         self.add_filter(self.status_filter, SearchFilterPosition.TOP, ['status'])
 
     def get_columns(self):
-        return [SearchColumn('identifier', title=_(u'# '), sorted=True, data_type=int,
-                             format='%04d', width=80, order=gtk.SORT_DESCENDING),
+        return [IdentifierColumn('identifier', sorted=True,
+                                 order=gtk.SORT_DESCENDING),
                 Column('status_string', title=_(u'Status'), data_type=str,
-                        visible=False),
+                       visible=False),
                 SearchColumn('description', title=_(u'Description'),
                              data_type=str, expand=True),
                 Column('responsible.person.name', title=_(u'Responsible'),
@@ -254,7 +256,7 @@ class ProductionApp(SearchableAppWindow):
         self._start_production_order()
 
     def on_ProductionPurchaseQuote__activate(self, action):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(ProductionQuoteDialog, store)
 
     # Search
