@@ -29,18 +29,14 @@ from decimal import Decimal
 import pango
 import gtk
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
-from kiwi.ui.objectlist import SearchColumn
-from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
 from stoqlib.api import api
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseOrderView
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.sellablepricedialog import SellablePriceDialog
 from stoqlib.gui.dialogs.stockcostdialog import StockCostDialog
 from stoqlib.gui.dialogs.manufacturerdialog import ProductManufacturerDialog
-from stoqlib.gui.editors.producteditor import ProductEditor
-from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.categorysearch import SellableCategorySearch
 from stoqlib.gui.search.consignmentsearch import ConsignmentItemSearch
 from stoqlib.gui.search.personsearch import SupplierSearch, TransporterSearch
@@ -49,11 +45,15 @@ from stoqlib.gui.search.productsearch import (ProductSearch,
                                               ProductClosedStockSearch,
                                               ProductsSoldSearch)
 from stoqlib.gui.search.purchasesearch import PurchasedItemsSearch
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchfilters import ComboSearchFilter, DateSearchFilter
 from stoqlib.gui.search.sellableunitsearch import SellableUnitSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
 from stoqlib.gui.stockicons import (STOQ_PRODUCTS, STOQ_SUPPLIERS)
+from stoqlib.gui.utils.keybindings import get_accels
 from stoqlib.gui.wizards.consignmentwizard import (ConsignmentWizard,
                                                    CloseInConsignmentWizard)
+from stoqlib.gui.wizards.productwizard import ProductCreateWizard
 from stoqlib.gui.wizards.purchasefinishwizard import PurchaseFinishWizard
 from stoqlib.gui.wizards.purchasequotewizard import (QuotePurchaseWizard,
                                                      ReceiveQuoteWizard)
@@ -64,19 +64,18 @@ from stoqlib.lib.permissions import PermissionManager
 from stoqlib.lib.translation import stoqlib_ngettext, stoqlib_gettext as _
 from stoqlib.reporting.purchase import PurchaseReport
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
 
-class PurchaseApp(SearchableAppWindow):
+class PurchaseApp(ShellApp):
 
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
-    app_name = _('Purchase')
+    app_title = _('Purchase')
     gladefile = "purchase"
-    search_table = PurchaseOrderView
+    search_spec = PurchaseOrderView
     search_label = _('matching:')
     report_table = PurchaseReport
-    embedded = True
 
     action_permissions = {
         'ProductUnits': ('ProductUnit', PermissionManager.PERM_SEARCH),
@@ -179,15 +178,15 @@ class PurchaseApp(SearchableAppWindow):
         self.popup = self.uimanager.get_widget('/PurchaseSelection')
 
     def create_ui(self):
-        if api.sysparam(self.store).SMART_LIST_LOADING:
-            self.search.search.enable_lazy_search()
+        if api.sysparam.get_bool('SMART_LIST_LOADING'):
+            self.search.enable_lazy_search()
 
-        self.app.launcher.add_new_items([
+        self.window.add_new_items([
             self.NewOrder,
             self.NewQuote,
             self.NewProduct,
             self.NewConsignment])
-        self.app.launcher.add_search_items([
+        self.window.add_search_items([
             self.Products,
             self.Suppliers,
             self.SearchQuotes,
@@ -205,20 +204,20 @@ class PurchaseApp(SearchableAppWindow):
         self.register_sensitive_group(self._inventory_widgets,
                                       lambda: not self.has_open_inventory())
 
-    def activate(self, params):
-        self.app.launcher.NewToolItem.set_tooltip(
+    def activate(self, refresh=True):
+        self.window.NewToolItem.set_tooltip(
             _("Create a new purchase order"))
-        self.app.launcher.SearchToolItem.set_tooltip(
+        self.window.SearchToolItem.set_tooltip(
             _("Search for purchase orders"))
-        self.app.launcher.Print.set_tooltip(
+        self.window.Print.set_tooltip(
             _("Print a report of these orders"))
-        if not params.get('no-refresh'):
+        if refresh:
             self._update_view()
         self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.check_open_inventory()
 
     def setup_focus(self):
-        self.search.refresh()
+        self.refresh()
 
     def deactivate(self):
         self.uimanager.remove_ui(self.purchase_ui)
@@ -239,37 +238,30 @@ class PurchaseApp(SearchableAppWindow):
                 _("No orders could be found."),
                 _("Would you like to %s ?") % (
                     '<a href="new_order">%s</a>' % (
-                api.escape(_("create a new order"), )))
-                ))
+                        api.escape(_("create a new order"), )))
+            ))
 
         # FIXME: Push number of results to Statusbar
 
     def set_open_inventory(self):
         self.set_sensitive(self._inventory_widgets, False)
 
-    #
-    # SearchableAppWindow
-    #
-
     def create_filters(self):
-        self.set_text_field_columns(['supplier_name'])
+        self.set_text_field_columns(['supplier_name', 'identifier_str'])
         self.status_filter = ComboSearchFilter(_('Show orders'),
                                                self._get_status_values())
         self.add_filter(self.status_filter, SearchFilterPosition.TOP, ['status'])
 
     def get_columns(self):
-        return [SearchColumn('identifier', title=_('#'),
-                             long_title=_('Order number'),
-                             data_type=int, justify=gtk.JUSTIFY_RIGHT,
-                             width=60),
+        return [IdentifierColumn('identifier', long_title=_('Order #')),
                 SearchColumn('status_str', title=_('Status'), width=100,
                              data_type=str, search_attribute='status',
                              valid_values=self._get_status_values(),
                              visible=False),
                 SearchColumn('open_date', title=_('Opened'),
-                              long_title=_('Date Opened'), width=90,
-                              data_type=datetime.date, sorted=True,
-                              order=gtk.SORT_DESCENDING),
+                             long_title=_('Date Opened'), width=90,
+                             data_type=datetime.date, sorted=True,
+                             order=gtk.SORT_DESCENDING),
                 SearchColumn('supplier_name', title=_('Supplier'),
                              data_type=str, searchable=True, expand=True,
                              ellipsize=pango.ELLIPSIZE_END),
@@ -290,10 +282,10 @@ class PurchaseApp(SearchableAppWindow):
     def search_for_date(self, date):
         dfilter = DateSearchFilter(_("Expected receival date"))
         dfilter.set_removable()
-        dfilter.mode.select_item_by_position(5)
+        dfilter.select(data=DateSearchFilter.Type.USER_DAY)
         self.add_filter(dfilter, columns=["expected_receival_date"])
         dfilter.start_date.set_date(date)
-        self.search.refresh()
+        self.refresh()
 
     #
     # Private
@@ -316,14 +308,15 @@ class PurchaseApp(SearchableAppWindow):
                 order.status == PurchaseOrder.ORDER_PENDING
                 for order in selection)
             can_cancel = all(order_view.purchase.can_cancel()
-                for order_view in selection)
+                             for order_view in selection)
         else:
             can_send_supplier = False
             can_cancel = False
 
         if one_selected:
             can_edit = (selection[0].status == PurchaseOrder.ORDER_PENDING or
-                        selection[0].status == PurchaseOrder.ORDER_QUOTING)
+                        selection[0].status == PurchaseOrder.ORDER_QUOTING or
+                        selection[0].status == PurchaseOrder.ORDER_CONFIRMED)
             can_finish = (selection[0].status == PurchaseOrder.ORDER_CONFIRMED and
                           selection[0].received_quantity > 0)
 
@@ -334,7 +327,7 @@ class PurchaseApp(SearchableAppWindow):
         self.Finish.set_sensitive(can_finish)
 
     def _new_order(self, order=None, edit_mode=False):
-        with api.trans() as store:
+        with api.new_store() as store:
             order = store.fetch(order)
             self.run_dialog(PurchaseWizard, store, order, edit_mode)
 
@@ -350,10 +343,10 @@ class PurchaseApp(SearchableAppWindow):
             raise ValueError('You should have only one order selected, '
                              'got %d instead' % qty)
         purchase = selected[0].purchase
-        if purchase.status == PurchaseOrder.ORDER_PENDING:
-            self._new_order(purchase, edit_mode=False)
-        else:
+        if purchase.status == PurchaseOrder.ORDER_QUOTING:
             self._quote_order(purchase)
+        else:
+            self._new_order(purchase, edit_mode=False)
 
     def _run_details_dialog(self):
         order_views = self.results.get_selected_rows()
@@ -368,7 +361,7 @@ class PurchaseApp(SearchableAppWindow):
         orders = self.results.get_selected_rows()
         valid_order_views = [
             order for order in orders
-                      if order.status == PurchaseOrder.ORDER_PENDING]
+            if order.status == PurchaseOrder.ORDER_PENDING]
 
         if not valid_order_views:
             warning(_("There are no pending orders selected."))
@@ -382,10 +375,10 @@ class PurchaseApp(SearchableAppWindow):
         confirm_label = stoqlib_ngettext(_("Confirm order"),
                                          _("Confirm orders"),
                                          len(valid_order_views))
-        if yesno(msg, gtk.RESPONSE_NO, _("Don't confirm"), confirm_label):
+        if not yesno(msg, gtk.RESPONSE_YES, confirm_label, _("Don't confirm")):
             return
 
-        with api.trans() as store:
+        with api.new_store() as store:
             for order_view in valid_order_views:
                 order = store.fetch(order_view.purchase)
                 order.confirm()
@@ -399,7 +392,7 @@ class PurchaseApp(SearchableAppWindow):
             raise ValueError('You should have only one order selected '
                              'at this point, got %d' % qty)
 
-        with api.trans() as store:
+        with api.new_store() as store:
             order = store.fetch(order_views[0].purchase)
             self.run_dialog(PurchaseFinishWizard, store, order)
 
@@ -414,10 +407,10 @@ class PurchaseApp(SearchableAppWindow):
         select_label = stoqlib_ngettext(_('The selected order will be cancelled.'),
                                         _('The selected orders will be cancelled.'),
                                         len(order_views))
-        if yesno(select_label, gtk.RESPONSE_NO,
-                 _("Don't cancel"), cancel_label):
+        if not yesno(select_label, gtk.RESPONSE_YES,
+                     cancel_label, _("Don't cancel")):
             return
-        with api.trans() as store:
+        with api.new_store() as store:
             for order_view in order_views:
                 order = store.fetch(order_view.purchase)
                 order.cancel()
@@ -427,12 +420,12 @@ class PurchaseApp(SearchableAppWindow):
 
     def _get_status_values(self):
         items = [(text, value)
-                    for value, text in PurchaseOrder.statuses.items()]
+                 for value, text in PurchaseOrder.statuses.items()]
         items.insert(0, (_('Any'), None))
         return items
 
     def _quote_order(self, quote=None):
-        with api.trans() as store:
+        with api.new_store() as store:
             quote = store.fetch(quote)
             self.run_dialog(QuotePurchaseWizard, store, quote)
 
@@ -442,11 +435,11 @@ class PurchaseApp(SearchableAppWindow):
             self.select_result(res)
 
     def _new_product(self):
-        with api.trans() as store:
-            self.run_dialog(ProductEditor, store, model=None)
+        with api.new_store() as store:
+            self.run_dialog(ProductCreateWizard, store)
 
     def _new_consignment(self):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(ConsignmentWizard, store, model=None)
 
         if store.committed:
@@ -500,7 +493,7 @@ class PurchaseApp(SearchableAppWindow):
     # Consignment
 
     def on_CloseInConsignment__activate(self, action):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(CloseInConsignmentWizard, store)
 
     def on_SearchInConsignmentItems__activate(self, action):
@@ -510,7 +503,7 @@ class PurchaseApp(SearchableAppWindow):
         self.run_dialog(SellableCategorySearch, self.store)
 
     def on_SearchQuotes__activate(self, action):
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(ReceiveQuoteWizard, store)
         self.refresh()
 
@@ -550,7 +543,7 @@ class PurchaseApp(SearchableAppWindow):
             warning(_("Can't use prices editor without client categories"))
             return
 
-        with api.trans() as store:
+        with api.new_store() as store:
             self.run_dialog(SellablePriceDialog, store)
 
     # Toolitem
