@@ -34,23 +34,26 @@ import gtk
 from kiwi.currency import currency
 from kiwi.python import all
 from kiwi.ui.gadgets import render_pixbuf
-from kiwi.ui.objectlist import SearchColumn, Column
-from kiwi.ui.search import DateSearchFilter
+from kiwi.ui.objectlist import Column
+
 from stoqlib.api import api
 from stoqlib.domain.payment.category import PaymentCategory
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.views import InPaymentView
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import TillError
-from stoqlib.gui.printing import print_report
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.paymenteditor import InPaymentEditor
 from stoqlib.gui.editors.paymentseditor import SalePaymentsEditor
-from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.paymentsearch import InPaymentBillCheckSearch
 from stoqlib.gui.search.paymentsearch import CardPaymentSearch
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchfilters import DateSearchFilter
 from stoqlib.gui.slaves.paymentconfirmslave import SalePaymentConfirmSlave
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.gui.wizards.renegotiationwizard import PaymentRenegotiationWizard
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.message import warning
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.payment import ReceivablePaymentReport
@@ -63,9 +66,9 @@ class ReceivableApp(BaseAccountWindow):
 
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
-    app_name = _('Accounts receivable')
+    app_title = _('Accounts receivable')
     gladefile = 'receivable'
-    search_table = InPaymentView
+    search_spec = InPaymentView
     search_label = _('matching:')
     report_table = ReceivablePaymentReport
     editor_class = InPaymentEditor
@@ -122,8 +125,8 @@ class ReceivableApp(BaseAccountWindow):
 
             # Search
             ('PaymentCategories', None, _("Payment categories..."),
-            group.get('search_payment_categories'),
-            _('Search for payment categories')),
+             group.get('search_payment_categories'),
+             _('Search for payment categories')),
             ('BillCheckSearch', None, _('Bills and checks...'),
              group.get('search_bills'),
              _('Search for bills and checks')),
@@ -138,19 +141,18 @@ class ReceivableApp(BaseAccountWindow):
         self.Receive.set_short_label(_('Receive'))
         self.Details.set_short_label(_('Details'))
         self.Receive.props.is_important = True
-        self.app.launcher.add_new_items([self.AddReceiving])
-        self.app.launcher.add_search_items([self.BillCheckSearch,
-                                            self.CardPaymentSearch])
-        self.app.launcher.Print.set_tooltip(
+        self.window.add_new_items([self.AddReceiving])
+        self.window.add_search_items([self.BillCheckSearch,
+                                      self.CardPaymentSearch])
+        self.window.Print.set_tooltip(
             _("Print a report of this payments"))
         self.popup = self.uimanager.get_widget('/ReceivableSelection')
 
-    def activate(self, params):
+    def activate(self, refresh=True):
         self._update_widgets()
 
-        # FIXME: double negation is weird here
-        if not params.get('no-refresh'):
-            self.search.refresh()
+        if refresh:
+            self.refresh()
 
     def deactivate(self):
         self.uimanager.remove_ui(self.receivable_ui)
@@ -161,17 +163,12 @@ class ReceivableApp(BaseAccountWindow):
     def search_activate(self):
         self._run_bill_check_search()
 
-    #
-    # SearchableAppWindow hooks
-    #
-
     def create_filters(self):
-        self.set_text_field_columns(['description', 'drawee'])
+        self.set_text_field_columns(['description', 'drawee', 'identifier_str'])
         self.create_main_filter()
 
     def get_columns(self):
-        return [SearchColumn('identifier', title=_('#'), long_title=_("Payment ID"),
-                             width=60, data_type=int, format='%04d'),
+        return [IdentifierColumn('identifier', long_title=_("Payment #")),
                 SearchColumn('description', title=_('Description'),
                              data_type=str, ellipsize=pango.ELLIPSIZE_END,
                              expand=True, pack_end=True),
@@ -179,7 +176,7 @@ class ReceivableApp(BaseAccountWindow):
                        data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf,
                        column='description'),
                 Column('comments_number', title=_(u'Comments'),
-                        visible=False),
+                       visible=False),
                 SearchColumn('drawee', title=_('Drawee'), data_type=str,
                              ellipsize=pango.ELLIPSIZE_END, width=140),
                 SearchColumn('due_date', title=_('Due date'),
@@ -207,10 +204,10 @@ class ReceivableApp(BaseAccountWindow):
         self.main_filter.select(None)
         dfilter = DateSearchFilter(_("Paid or due date"))
         dfilter.set_removable()
-        dfilter.mode.select_item_by_position(5)
+        dfilter.select(data=DateSearchFilter.Type.USER_DAY)
         self.add_filter(dfilter, columns=["paid_date", "due_date"])
         dfilter.start_date.set_date(date)
-        self.search.refresh()
+        self.refresh()
 
     #
     # Private
@@ -231,7 +228,8 @@ class ReceivableApp(BaseAccountWindow):
         self.PrintReceipt.set_sensitive(
             one_item and self._is_paid(selected))
         self.SetNotPaid.set_sensitive(
-            one_item and self._is_paid(selected))
+            one_item and self._is_paid(selected) and
+            self._can_set_not_paid(selected))
         self.Edit.set_sensitive(self._can_edit(selected))
         self.PrintDocument.set_sensitive(self._can_print(selected))
 
@@ -274,6 +272,10 @@ class ReceivableApp(BaseAccountWindow):
 
         return receivable_view[0].is_paid()
 
+    def _can_set_not_paid(self, receivable_views):
+        return all(view.payment.method.operation.can_set_not_paid(view.payment)
+                   for view in receivable_views)
+
     def _can_receive(self, receivable_views):
         """
         Determines if a list of receivable_views can be received.
@@ -406,7 +408,7 @@ class ReceivableApp(BaseAccountWindow):
             FilterItem(_('Received payments'), 'status:paid'),
             FilterItem(_('To receive'), 'status:not-paid'),
             FilterItem(_('Late payments'), 'status:late'),
-            ]
+        ]
         self.add_filter_items(PaymentCategory.TYPE_RECEIVABLE, options)
 
     #
@@ -436,7 +438,7 @@ class ReceivableApp(BaseAccountWindow):
     def on_PrintReceipt__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
         payment = receivable_view.payment
-        date = datetime.date.today()
+        date = localtoday().date()
         print_report(InPaymentReceipt, payment=payment,
                      order=receivable_view.sale, date=date)
 
@@ -466,7 +468,7 @@ class ReceivableApp(BaseAccountWindow):
     def on_Renegotiate__activate(self, action):
         try:
             Till.get_current(self.store)
-        except TillError, e:
+        except TillError as e:
             warning(str(e))
             return
         receivable_views = self.results.get_selected_rows()
@@ -482,14 +484,14 @@ class ReceivableApp(BaseAccountWindow):
         if store.confirm(retval):
             # FIXME: Storm is not expiring the groups correctly.
             # Figure out why. See bug 5087
-            self.search.refresh()
+            self.refresh()
             self._update_widgets()
         store.close()
 
     def on_Edit__activate(self, action):
         try:
             Till.get_current(self.store)
-        except TillError, e:
+        except TillError as e:
             warning(str(e))
             return
 
@@ -499,7 +501,7 @@ class ReceivableApp(BaseAccountWindow):
         retval = run_dialog(SalePaymentsEditor, self, store, sale)
 
         if store.confirm(retval):
-            self.search.refresh()
+            self.refresh()
         store.close()
 
     def on_PrintDocument__activate(self, action):
