@@ -30,40 +30,46 @@ from dateutil.relativedelta import relativedelta
 import pango
 import gtk
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import SearchColumn
 from storm.expr import And, Or
+
 from stoqlib.api import api
 from stoqlib.database.expr import Date
 from stoqlib.domain.invoice import InvoicePrinter
-from stoqlib.domain.sale import Sale, SaleView
+from stoqlib.domain.sale import Sale, SaleView, SaleComment
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.dialogs.invoicedialog import SaleInvoicePrinterDialog
-from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.editors.saleeditor import SaleClientEditor
+from stoqlib.gui.editors.noteeditor import NoteEditor
 from stoqlib.gui.search.callsearch import ClientCallsSearch
 from stoqlib.gui.search.commissionsearch import CommissionSearch
 from stoqlib.gui.search.deliverysearch import DeliverySearch
 from stoqlib.gui.search.loansearch import LoanItemSearch, LoanSearch
+from stoqlib.gui.search.returnedsalesearch import ReturnedSaleSearch
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.productsearch import ProductSearch
-from stoqlib.gui.search.salesearch import (SoldItemsByBranchSearch,
-                                           SalesByPaymentMethodSearch)
-from stoqlib.gui.search.salespersonsearch import SalesPersonSalesSearch
 from stoqlib.gui.search.creditcheckhistorysearch import CreditCheckHistorySearch
-from stoqlib.gui.search.servicesearch import ServiceSearch
 from stoqlib.gui.slaves.saleslave import SaleListToolbar
+from stoqlib.gui.search.salespersonsearch import SalesPersonSalesSearch
+from stoqlib.gui.search.salesearch import (SoldItemsByBranchSearch,
+                                           SalesByPaymentMethodSearch,
+                                           ReservedProductSearch)
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
+from stoqlib.gui.search.servicesearch import ServiceSearch
 from stoqlib.gui.stockicons import (STOQ_PRODUCTS, STOQ_SERVICES,
                                     STOQ_CLIENTS, STOQ_DELIVERY)
+from stoqlib.gui.utils.keybindings import get_accels
 from stoqlib.gui.wizards.loanwizard import NewLoanWizard, CloseLoanWizard
 from stoqlib.gui.wizards.salequotewizard import SaleQuoteWizard
+from stoqlib.gui.wizards.workorderquotewizard import WorkOrderQuoteWizard
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.invoice import SaleInvoice, print_sale_invoice
-from stoqlib.lib.message import info, yesno
+from stoqlib.lib.message import info, warning
 from stoqlib.lib.permissions import PermissionManager
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.sale import SalesReport
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
 
 class FilterItem(object):
@@ -74,6 +80,8 @@ class FilterItem(object):
 
 
 SALES_FILTERS = {
+    'sold': Or(Sale.status == Sale.STATUS_CONFIRMED,
+               Sale.status == Sale.STATUS_PAID),
     'sold-today': And(Date(Sale.open_date) == date.today(),
                       Or(Sale.status == Sale.STATUS_CONFIRMED,
                          Sale.status == Sale.STATUS_PAID)),
@@ -90,18 +98,18 @@ SALES_FILTERS = {
 }
 
 
-class SalesApp(SearchableAppWindow):
+class SalesApp(ShellApp):
 
-    app_name = _('Sales')
+    app_title = _('Sales')
     gladefile = 'sales_app'
-    search_table = SaleView
+    search_spec = SaleView
     search_label = _('matching:')
     report_table = SalesReport
-    embedded = True
 
     cols_info = {Sale.STATUS_INITIAL: 'open_date',
                  Sale.STATUS_CONFIRMED: 'confirm_date',
                  Sale.STATUS_PAID: 'close_date',
+                 Sale.STATUS_ORDERED: 'open_date',
                  Sale.STATUS_CANCELLED: 'cancel_date',
                  Sale.STATUS_QUOTE: 'open_date',
                  Sale.STATUS_RETURNED: 'return_date',
@@ -111,10 +119,10 @@ class SalesApp(SearchableAppWindow):
         "SalesPrintInvoice": ('app.sales.print_invoice', PermissionManager.PERM_SEARCH),
     }
 
-    def __init__(self, app, store=None):
+    def __init__(self, window, store=None):
         self.summary_label = None
         self._visible_date_col = None
-        SearchableAppWindow.__init__(self, app, store=store)
+        ShellApp.__init__(self, window, store=store)
 
     #
     # Application
@@ -126,6 +134,8 @@ class SalesApp(SearchableAppWindow):
             # File
             ("SaleQuote", None, _("Sale quote..."), '',
              _('Create a new quote for a sale')),
+            ("WorkOrderQuote", None, _("Sale with work order..."), '',
+             _('Create a new quote for a sale with work orders')),
             ("LoanNew", None, _("Loan...")),
             ("LoanClose", None, _("Close loan...")),
 
@@ -166,11 +176,17 @@ class SalesApp(SearchableAppWindow):
              group.get("search_loans")),
             ("LoanSearchItems", None, _("Loan items..."),
              group.get("search_loan_items")),
+            ("ReturnedSaleSearch", None, _("Returned sales..."),
+             group.get("returned_sales")),
+            ("SearchReservedProduct", None, _("Reserved products..."),
+             group.get("search_reserved_product"),
+             _("Search for Reserved Products")),
 
             # Sale
             ("SaleMenu", None, _("Sale")),
 
-            ("SalesCancel", None, _("Cancel quote...")),
+            ("SalesCancel", None, _("Cancel...")),
+            ("ChangeClient", gtk.STOCK_EDIT, _("Change client...")),
             ("SalesPrintInvoice", gtk.STOCK_PRINT, _("_Print invoice...")),
             ("Return", gtk.STOCK_CANCEL, _("Return..."), '',
              _("Return the selected sale, canceling it's payments")),
@@ -185,11 +201,13 @@ class SalesApp(SearchableAppWindow):
                                             filename="sales.xml")
 
         self.SaleQuote.set_short_label(_("New Sale Quote"))
+        self.SaleQuote.set_short_label(_("New Sale Quote with Work Order"))
         self.SearchClient.set_short_label(_("Clients"))
         self.SearchProduct.set_short_label(_("Products"))
         self.SearchService.set_short_label(_("Services"))
         self.SearchDelivery.set_short_label(_("Deliveries"))
         self.SalesCancel.set_short_label(_("Cancel"))
+        self.ChangeClient.set_short_label(_("Change Client"))
         self.Edit.set_short_label(_("Edit"))
         self.Return.set_short_label(_("Return"))
         self.Details.set_short_label(_("Details"))
@@ -197,35 +215,39 @@ class SalesApp(SearchableAppWindow):
         self.set_help_section(_("Sales help"), 'app-sales')
 
     def create_ui(self):
-        if api.sysparam(self.store).SMART_LIST_LOADING:
-            self.search.search.enable_lazy_search()
+        if api.sysparam.get_bool('SMART_LIST_LOADING'):
+            self.search.enable_lazy_search()
+        if not api.sysparam.get_bool('CHANGE_CLIENT_AFTER_CONFIRMED'):
+            self.ChangeClient.set_visible(False)
 
         self.popup = self.uimanager.get_widget('/SaleSelection')
 
-        self._columns = self.get_columns()
         self._setup_columns()
         self._setup_widgets()
 
-        self.app.launcher.add_new_items([self.SaleQuote])
-        self.app.launcher.add_search_items([
-          self.SearchProduct,
-          self.SearchClient,
-          self.SearchService,
-          self.SearchDelivery])
-        self.app.launcher.Print.set_tooltip(_("Print a report of these sales"))
+        self.window.add_new_items([self.SaleQuote, self.WorkOrderQuote])
+        self.window.add_search_items([
+            self.SearchProduct,
+            self.SearchClient,
+            self.SearchService,
+            self.SearchDelivery])
+        self.window.Print.set_tooltip(_("Print a report of these sales"))
+
+    def activate(self, refresh=True):
+        if refresh:
+            self.refresh()
 
-    def activate(self, params):
         self.check_open_inventory()
         self._update_toolbar()
 
     def setup_focus(self):
-        self.search.refresh()
+        self.refresh()
 
     def deactivate(self):
         self.uimanager.remove_ui(self.sales_ui)
 
     def new_activate(self):
-        self._new_sale_quote()
+        self._new_sale_quote(wizard=SaleQuoteWizard)
 
     def search_activate(self):
         self._search_product()
@@ -233,20 +255,18 @@ class SalesApp(SearchableAppWindow):
     def set_open_inventory(self):
         self.set_sensitive(self._inventory_widgets, False)
 
-    #
-    # SearchableAppWindow
-    #
-
     def create_filters(self):
-        self.executer.set_query(self._query)
-        self.set_text_field_columns(['client_name', 'salesperson_name'])
+        self.search.set_query(self._query)
+        self.set_text_field_columns(['client_name', 'salesperson_name',
+                                     'identifier_str'])
 
         status_filter = ComboSearchFilter(_('Show sales'),
                                           self._get_filter_options())
         status_filter.combo.set_row_separator_func(
-                            lambda model, titer: model[titer][0] == 'sep')
+            lambda model, titer: model[titer][0] == 'sep')
 
-        self.executer.add_filter_query_callback(
+        executer = self.search.get_query_executer()
+        executer.add_filter_query_callback(
             status_filter, self._get_status_query)
         self.add_filter(status_filter, position=SearchFilterPosition.TOP)
 
@@ -256,9 +276,8 @@ class SalesApp(SearchableAppWindow):
                                         search_attribute='status',
                                         valid_values=self._get_status_values())
 
-        cols = [SearchColumn('identifier', title=_('#'), width=80,
-                             long_title=_('Order number'),
-                             format='%05d', data_type=int, sorted=True),
+        cols = [IdentifierColumn('identifier', long_title=_('Order #'),
+                                 sorted=True),
                 SearchColumn('open_date', title=_('Open date'), width=120,
                              data_type=date, justify=gtk.JUSTIFY_RIGHT,
                              visible=False),
@@ -282,11 +301,11 @@ class SalesApp(SearchableAppWindow):
                              data_type=str, width=140, expand=True,
                              ellipsize=pango.ELLIPSIZE_END),
                 SearchColumn('salesperson_name', title=_('Salesperson'),
-                              data_type=str, width=130,
-                              ellipsize=pango.ELLIPSIZE_END),
+                             data_type=str, width=130,
+                             ellipsize=pango.ELLIPSIZE_END),
                 SearchColumn('total_quantity', title=_('Items'),
-                              data_type=decimal.Decimal, width=60,
-                              format_func=format_quantity),
+                             data_type=decimal.Decimal, width=60,
+                             format_func=format_quantity),
                 SearchColumn('total', title=_('Total'), data_type=currency,
                              width=120)]
         return cols
@@ -314,16 +333,16 @@ class SalesApp(SearchableAppWindow):
                                             parent=self)
 
     def _can_cancel(self, view):
-        # Here we want to cancel only quoting sales. This is why we don't use
-        # Sale.can_cancel here.
-        return bool(view and view.status == Sale.STATUS_QUOTE)
-
-    def _can_edit(self, view):
+        # If ALLOW_CANCEL_CONFIRMED_SALES is set, we can use Sale.can_cancel to
+        # check if we can cancel that sale. Otherwise we can only cancel quoting
+        # sales
+        if api.sysparam.get_bool("ALLOW_CANCEL_CONFIRMED_SALES") and view:
+            return view.sale.can_cancel()
         return bool(view and view.status == Sale.STATUS_QUOTE)
 
     def _update_toolbar(self, *args):
         sale_view = self.results.get_selected()
-        #FIXME: Disable invoice printing if the sale was returned. Remove this
+        # FIXME: Disable invoice printing if the sale was returned. Remove this
         #       when we add proper support for returned sales invoice.
         can_print_invoice = bool(sale_view and
                                  sale_view.client_name is not None and
@@ -335,8 +354,10 @@ class SalesApp(SearchableAppWindow):
         self.set_sensitive([self.sale_toolbar.return_sale_button, self.Details],
                            bool(sale_view))
         self.set_sensitive([self.sale_toolbar.edit_button, self.Edit],
-                           self._can_edit(sale_view))
-
+                           bool(sale_view and sale_view.can_edit()))
+        # If the sale cannot be edit anymore, we only allow to change the client
+        self.set_sensitive([self.ChangeClient],
+                           bool(sale_view and not sale_view.can_edit()))
         self.sale_toolbar.set_report_filters(self.search.get_search_filters())
 
     def _print_invoice(self):
@@ -372,27 +393,25 @@ class SalesApp(SearchableAppWindow):
         if self._visible_date_col:
             self._visible_date_col.visible = False
 
-        for col in self._columns:
-            if col.attribute == self.cols_info[sale_status]:
-                self._visible_date_col = col
-                col.visible = True
-                break
+        col = self.search.get_column_by_attribute(self.cols_info[sale_status])
+        if col is not None:
+            self._visible_date_col = col
+            col.visible = True
 
-        self.results.set_columns(self._columns)
+        self.results.set_columns(self.search.columns)
         # Adding summary label again and make it properly aligned with the
         # new columns setup
         self._create_summary_label()
 
     def _get_status_values(self):
-        items = [(value, key) for key, value in Sale.statuses.items()
-                    # No reason to show orders in sales app
-                    if key != Sale.STATUS_ORDERED]
+        items = [(value, key) for key, value in Sale.statuses.items()]
         items.insert(0, (_('Any'), None))
         return items
 
     def _get_filter_options(self):
         options = [
             (_('All Sales'), None),
+            (_('Sold'), FilterItem('custom', 'sold')),
             (_('Sold today'), FilterItem('custom', 'sold-today')),
             (_('Sold in the last 7 days'), FilterItem('custom', 'sold-7days')),
             (_('Sold in the last 28 days'), FilterItem('custom', 'sold-28days')),
@@ -401,15 +420,14 @@ class SalesApp(SearchableAppWindow):
         ]
 
         for key, value in Sale.statuses.items():
-            if key == Sale.STATUS_ORDERED:
-                continue
-
             options.append((value, FilterItem('status', key)))
         return options
 
     def _get_status_query(self, state):
         if state.value is None:
-            return SaleView.status != Sale.STATUS_ORDERED
+            # FIXME; We cannot return None here, otherwise, the query will have
+            # a 'AND NULL', which will return nothing.
+            return True
 
         if state.value.name == 'custom':
             self._setup_columns(None)
@@ -423,28 +441,44 @@ class SalesApp(SearchableAppWindow):
 
     def _query(self, store):
         branch = api.get_current_branch(self.store)
-        return self.search_table.find_by_branch(store, branch)
+        return self.search_spec.find_by_branch(store, branch)
+
+    def _new_sale_quote(self, wizard):
+        if self.check_open_inventory():
+            warning(_("You cannot create a quote with an open inventory."))
+            return
 
-    def _new_sale_quote(self):
         store = api.new_store()
-        model = self.run_dialog(SaleQuoteWizard, store)
+        model = self.run_dialog(wizard, store)
         store.confirm(model)
         store.close()
 
+        if model:
+            self.refresh()
+
     def _search_product(self):
-        hide_cost_column = not api.sysparam(self.store).SHOW_COST_COLUMN_IN_SALES
+        hide_cost_column = not api.sysparam.get_bool('SHOW_COST_COLUMN_IN_SALES')
         self.run_dialog(ProductSearch, self.store, hide_footer=True,
                         hide_toolbar=True, hide_cost_column=hide_cost_column)
 
+    def _change_sale_client(self):
+        sale_view = self.results.get_selected()
+        with api.new_store() as store:
+            sale = store.fetch(sale_view.sale)
+            self.run_dialog(SaleClientEditor, store=store, model=sale)
+
+        if store.committed:
+            self.refresh()
+
     #
     # Kiwi callbacks
     #
 
     def _on_sale_toolbar__sale_returned(self, toolbar, sale):
-        self.search.refresh()
+        self.refresh()
 
     def _on_sale_toolbar__sale_edited(self, toolbar, sale):
-        self.search.refresh()
+        self.refresh()
 
     def on_results__selection_changed(self, results, sale):
         self._update_toolbar()
@@ -458,19 +492,36 @@ class SalesApp(SearchableAppWindow):
     # Sales
 
     def on_SaleQuote__activate(self, action):
-        self._new_sale_quote()
+        self._new_sale_quote(wizard=SaleQuoteWizard)
+
+    def on_WorkOrderQuote__activate(self, action):
+        self._new_sale_quote(wizard=WorkOrderQuoteWizard)
 
     def on_SalesCancel__activate(self, action):
-        if yesno(_('This will cancel the selected quote. Are you sure?'),
-                 gtk.RESPONSE_NO, _("Don't cancel"), _("Cancel quote")):
-            return
-        store = api.new_store()
         sale_view = self.results.get_selected()
+
+        store = api.new_store()
         sale = store.fetch(sale_view.sale)
+        msg_text = _(u"This will cancel the sale, Are you sure?")
+        model = SaleComment(store=store, sale=sale,
+                            author=api.get_current_user(store))
+
+        retval = self.run_dialog(
+            NoteEditor, store, model=model, attr_name='comment',
+            message_text=msg_text, label_text=_(u"Reason"),
+            mandatory=True, ok_button_label=_(u"Cancel sale"),
+            cancel_button_label=_(u"Don't cancel"))
+
+        if not retval:
+            store.rollback()
+            return
+
         sale.cancel()
-        store.confirm(True)
-        store.close()
-        self.search.refresh()
+        store.commit(close=True)
+        self.refresh()
+
+    def on_ChangeClient__activate(self, action):
+        self._change_sale_client()
 
     def on_SalesPrintInvoice__activate(self, action):
         return self._print_invoice()
@@ -499,6 +550,12 @@ class SalesApp(SearchableAppWindow):
     def on_LoanSearchItems__activate(self, action):
         self.run_dialog(LoanItemSearch, self.store)
 
+    def on_ReturnedSaleSearch__activate(self, action):
+        self.run_dialog(ReturnedSaleSearch, self.store)
+
+    def on_SearchReservedProduct__activate(self, action):
+        self.run_dialog(ReservedProductSearch, self.store)
+
     # Search
 
     def on_SearchClient__activate(self, button):
@@ -543,3 +600,11 @@ class SalesApp(SearchableAppWindow):
         if self.check_open_inventory():
             return
         self.sale_toolbar.return_sale()
+
+    # Sale toobar
+
+    def on_sale_toolbar__sale_edited(self, widget, sale):
+        self.refresh()
+
+    def on_sale_toolbar__sale_returned(self, widget, sale):
+        self.refresh()
