@@ -23,15 +23,18 @@
 ##
 ##
 
+# NOTE: We need to be careful about imports at this point, we cannot yet
+#       depend that all libraries are present, nor that all external
+#       dependencies are properly configured, so only import the standard
+#       library here.
 import locale
 import logging
 import os
 import platform
 import sys
+import time
 import traceback
 
-from stoqlib.lib.translation import stoqlib_gettext as _
-
 log = logging.getLogger(__name__)
 
 
@@ -70,6 +73,7 @@ class ShellBootstrap(object):
         self._setup_kiwi()
         self._show_splash()
         self._setup_twisted()
+        self._setup_psycopg()
         self._check_version_policy()
         self._setup_ui_dialogs()
         self._setup_cookiefile()
@@ -78,6 +82,7 @@ class ShellBootstrap(object):
         self._load_key_bindings()
         self._setup_debug_options()
         self._check_locale()
+        self._setup_autoreload()
 
     def _setup_gobject(self):
         if not self._initial:
@@ -98,6 +103,7 @@ class ShellBootstrap(object):
 
     def _set_user_locale(self):
         from stoqlib.lib.settings import get_settings
+        from stoqlib.lib.translation import stoqlib_gettext as _
 
         self._locale_error = None
         settings = get_settings()
@@ -117,16 +123,44 @@ class ShellBootstrap(object):
             os.environ['LC_ALL'] = lang
             os.environ['LANGUAGE'] = lang
 
+    def _setup_autoreload(self):
+        if not self._options.autoreload:
+            return
+
+        from stoqlib.lib.autoreload import install_autoreload
+        install_autoreload()
+
     def _prepare_logfiles(self):
-        from stoq.lib.logging import setup_logging
-        self._log_filename, self.stream = setup_logging("stoq")
+        from stoqlib.lib.osutils import get_application_dir
+
+        stoqdir = get_application_dir("stoq")
+        log_dir = os.path.join(stoqdir, 'logs', time.strftime('%Y'),
+                               time.strftime('%m'))
+        if not os.path.exists(log_dir):
+            os.makedirs(log_dir)
+
+        filename = 'stoq_%s.%s.log' % (time.strftime('%Y-%m-%d_%H-%M-%S'), os.getpid())
+        self._log_filename = os.path.join(log_dir, filename)
+
+        from kiwi.log import set_log_file
+        self._stream = set_log_file(self._log_filename, 'stoq*')
+
+        if hasattr(os, 'symlink'):
+            link_file = os.path.join(stoqdir, 'stoq.log')
+            if os.path.exists(link_file):
+                os.unlink(link_file)
+            os.symlink(self._log_filename, link_file)
 
-        from stoqlib.lib.environment import is_developer_mode
         # We want developers to see deprecation warnings.
+        from stoqlib.lib.environment import is_developer_mode
         if is_developer_mode():
             import warnings
+            if self._options.non_fatal_warnings:
+                action = "default"
+            else:
+                action = "error"
             warnings.filterwarnings(
-                "default", category=DeprecationWarning,
+                action, category=DeprecationWarning,
                 module="^(stoq|kiwi)")
 
     def _set_app_info(self):
@@ -142,8 +176,8 @@ class ShellBootstrap(object):
         if hasattr(library, 'get_revision'):
             rev = library.get_revision()
             if rev is not None:
-                stoq_version += ' r' + rev
-                stoq_ver += ('r' + rev,)
+                stoq_version += ' ' + rev
+                stoq_ver += (rev,)
         info = AppInfo()
         info.set("name", "Stoq")
         info.set("version", stoq_version)
@@ -166,7 +200,6 @@ class ShellBootstrap(object):
         import gtk
         from kiwi.environ import environ
 
-        gtk.gdk.threads_init()
         # Total madness to make sure we can draw treeview lines,
         # this affects the GtkTreeView::grid-line-pattern style property
         #
@@ -188,6 +221,20 @@ class ShellBootstrap(object):
         settings = gtk.settings_get_default()
         settings.props.gtk_button_images = True
 
+        from stoqlib.lib.environment import is_developer_mode
+        if is_developer_mode() and gtk.gtk_version[0] == 2:
+            from gtk import gdk
+
+            # Install a Control-Q handler that forcefully exits
+            # the program without saving any kind of state
+            def event_handler(event):
+                if (event.type == gdk.KEY_PRESS and
+                    event.state & gdk.CONTROL_MASK and
+                    event.keyval == gtk.keysyms.q):
+                    os._exit(0)
+                gtk.main_do_event(event)
+            gdk.event_handler_set(event_handler)
+
     def _setup_kiwi(self):
         from kiwi.ui.views import set_glade_loader_func
         set_glade_loader_func(self._glade_loader_func)
@@ -199,12 +246,12 @@ class ShellBootstrap(object):
     def _show_splash(self):
         if not self._options.splashscreen:
             return
-        from stoqlib.gui.splash import show_splash
+        from stoqlib.gui.widgets.splash import show_splash
         show_splash()
 
     def _setup_twisted(self, raise_=True):
         # FIXME: figure out why twisted is already loaded
-        #assert not 'twisted' in sys.modules
+        # assert not 'twisted' in sys.modules
         from stoqlib.net import gtk2reactor
         from twisted.internet.error import ReactorAlreadyInstalledError
         try:
@@ -213,6 +260,13 @@ class ShellBootstrap(object):
             if self._initial and raise_:
                 raise
 
+    def _setup_psycopg(self):
+        # This will only be required when we use uuid.UUID instances
+        # for UUIDCol
+        #from psycopg2.extras import register_uuid
+        #register_uuid()
+        return
+
     def _check_version_policy(self):
         # No need to bother version checking when not running in developer mode
         from stoqlib.lib.environment import is_developer_mode
@@ -228,29 +282,28 @@ class ShellBootstrap(object):
         #
 
         # We reserve the first 89 for the stable series.
-        FIRST_UNSTABLE_EXTRA_VERSION = 90
+        FIRST_UNSTABLE_MICRO_VERSION = 90
 
         # Stable series of Stoq must:
         # 1) have extra_version set to < 90
         # 2) Depend on a stoqlib version with extra_version < 90
         #
         if stoq.stable:
-            if (stoq.extra_version >= FIRST_UNSTABLE_EXTRA_VERSION and
+            if (stoq.micro_version >= FIRST_UNSTABLE_MICRO_VERSION and
                 not 'rc' in stoq.extra_version):
                 raise SystemExit(
-                    "Stable stoq release should set extra_version to %d or lower" % (
-                    FIRST_UNSTABLE_EXTRA_VERSION, ))
-
+                    "Stable stoq release should set micro_version to "
+                    "%d or lower" % (FIRST_UNSTABLE_MICRO_VERSION, ))
         # Unstable series of Stoq must have:
         # 1) have extra_version set to >= 90
         # 2) Must depend stoqlib version with extra_version >= 90
         #
         else:
-            if stoq.extra_version < FIRST_UNSTABLE_EXTRA_VERSION:
+            if stoq.micro_version < FIRST_UNSTABLE_MICRO_VERSION:
                 raise SystemExit(
-                   "Unstable stoq (%s) must set extra_version to %d or higher, "
-                   "or did you forget to set stoq.stable to True?" % (
-                   stoq.version, FIRST_UNSTABLE_EXTRA_VERSION))
+                    "Unstable stoq (%s) must set micro_version to %d or higher, "
+                    "or did you forget to set stoq.stable to True?" % (
+                        stoq.version, FIRST_UNSTABLE_MICRO_VERSION))
 
     def _setup_ui_dialogs(self):
         # This needs to be here otherwise we can't install the dialog
@@ -297,12 +350,12 @@ class ShellBootstrap(object):
     def _setup_domain_slave_mapper(self):
         from kiwi.component import provide_utility
         from stoqlib.gui.interfaces import IDomainSlaveMapper
-        from stoqlib.gui.domainslavemapper import DefaultDomainSlaveMapper
+        from stoqlib.gui.slaves.domainslavemapper import DefaultDomainSlaveMapper
         provide_utility(IDomainSlaveMapper, DefaultDomainSlaveMapper(),
                         replace=True)
 
     def _load_key_bindings(self):
-        from stoqlib.gui.keybindings import load_user_keybindings
+        from stoqlib.gui.utils.keybindings import load_user_keybindings
         load_user_keybindings()
 
     def _check_locale(self):
@@ -316,8 +369,8 @@ class ShellBootstrap(object):
         if not self._options.debug:
             return
         from gtk import keysyms
-        from stoqlib.gui.keyboardhandler import install_global_keyhandler
-        from stoqlib.gui.introspection import introspect_slaves
+        from stoqlib.gui.utils.introspection import introspect_slaves
+        from stoqlib.gui.utils.keyboardhandler import install_global_keyhandler
         install_global_keyhandler(keysyms.F12, introspect_slaves)
 
     #
@@ -327,18 +380,17 @@ class ShellBootstrap(object):
     def _debug_hook(self, exctype, value, tb):
         self._write_exception_hook(exctype, value, tb)
         traceback.print_exception(exctype, value, tb)
-        print
-        print '-- Starting debugger --'
-        print
+        print()
+        print('-- Starting debugger --')
+        print()
         import pdb
         pdb.pm()
 
-    def _glade_loader_func(self, view, filename, domain):
-        from kiwi.environ import environ
+    def _glade_loader_func(self, view, filename, domain, resource_str_func):
         from kiwi.ui.builderloader import BuilderWidgetTree
         if not filename.endswith('ui'):
             filename += '.ui'
-        ui_string = environ.get_resource_string('stoq', 'glade', filename)
+        ui_string = resource_str_func('stoq', 'glade', filename)
 
         return BuilderWidgetTree(view, None, domain, ui_string)
 
@@ -352,7 +404,7 @@ class ShellBootstrap(object):
 
         appname = 'unknown'
         try:
-            from stoq.gui.shell import get_shell
+            from stoq.gui.shell.shell import get_shell
             shell = get_shell()
             if shell:
                 appname = shell.get_current_app_name()
@@ -368,10 +420,12 @@ class ShellBootstrap(object):
         except ImportError:
             pass
 
-        log.info('An error occurred in application "%s", toplevel window=%s:' % (
+        log.info('An error occurred in application "%s", toplevel window=%s' % (
             appname, window_name))
 
-        traceback.print_exception(exctype, value, tb, file=self.stream)
+        exc_lines = traceback.format_exception(exctype, value, tb)
+        for line in ''.join(exc_lines).split('\n')[:-1]:
+            log.error(line)
 
         from stoqlib.lib.crashreport import collect_traceback
         collect_traceback((exctype, value, tb))
@@ -385,3 +439,14 @@ class ShellBootstrap(object):
         d.addCallback(lambda *x: reactor.stop())
         reactor.run()
         raise SystemExit
+
+
+def boot_shell(options, initial=True):
+    bootstrap = ShellBootstrap(options=options, initial=initial)
+    bootstrap.bootstrap()
+
+    # We can now import Shell which can import any dependencies it like,
+    # as all should be configured properly at this point
+    from stoq.gui.shell.shell import Shell
+    shell = Shell(bootstrap, options)
+    return shell
