@@ -26,13 +26,16 @@
 """ Stoq shell routines"""
 
 import logging
-import operator
 import os
 import sys
 
-from stoqlib.lib.translation import stoqlib_gettext as _
+import glib
 
-from stoq.gui.shell.bootstrap import ShellBootstrap
+# FIXME: We can import whatever we want here, but don't import anything
+#        significant, it's good to maintain lazy loaded things during startup
+from stoqlib.exceptions import StoqlibError
+from stoqlib.lib.translation import stoqlib_gettext as _
+from twisted.internet.defer import inlineCallbacks, succeed
 
 log = logging.getLogger(__name__)
 _shell = None
@@ -48,12 +51,13 @@ PRIVACY_STRING = _(
 
 class ShellDatabaseConnection(object):
     """Sets up a database connection
-    - Connects to a database
+
+      - Connects to a database
       - Telling why if it failed
-    - Runs database wizard if needed
-    - Runs schema migration
-    - Activates plugins
-    - Sets up main branch
+      - Runs database wizard if needed
+      - Runs schema migration
+      - Activates plugins
+      - Sets up main branch
     """
 
     def __init__(self, options):
@@ -89,6 +93,16 @@ class ShellDatabaseConnection(object):
             run_dialog(FirstTimeConfigWizard, None, self._options, self._config)
             self._ran_wizard = True
 
+    def _get_password(self):
+        import binascii
+        configdir = self._config.get_config_directory()
+        filename = os.path.join(configdir, 'data')
+        if not os.path.exists(filename):
+            return
+
+        data = open(filename).read()
+        return binascii.a2b_base64(data)
+
     def _try_connect(self):
         from stoqlib.lib.message import error
         try:
@@ -99,8 +113,10 @@ class ShellDatabaseConnection(object):
                   _("Invalid config file settings, got error '%s', "
                     "of type '%s'") % (value, type))
 
-        from stoqlib.exceptions import StoqlibError
         from stoqlib.database.exceptions import PostgreSQLError
+        from stoqlib.database.runtime import get_default_store
+        from stoqlib.exceptions import DatabaseError
+        from stoqlib.lib.pgpass import write_pg_pass
         from stoq.lib.startup import setup
 
         # XXX: progress dialog for connecting (if it takes more than
@@ -109,9 +125,33 @@ class ShellDatabaseConnection(object):
         try:
             setup(self._config, self._options, register_station=False,
                   check_schema=False, load_plugins=False)
+            # the setup call above is not really trying to connect (since
+            # register_station, check_schema and load_plugins are all False).
+            # Try to really connect here.
+            get_default_store()
         except (StoqlibError, PostgreSQLError) as e:
+            log.debug('Connection failed.')
             error(_('Could not connect to the database'),
                   'error=%s uri=%s' % (str(e), store_dsn))
+        except DatabaseError:
+            log.debug('Connection failed. Tring to setup .pgpass')
+            # This is probably a missing password configuration. Setup the
+            # pgpass file and try again.
+            password = self._get_password()
+            if not password:
+                # There is no password stored in data file. Abort
+                raise
+
+            from stoqlib.database.settings import db_settings
+            write_pg_pass(db_settings.dbname, db_settings.address,
+                          db_settings.port, db_settings.username, password)
+            # Now that there is a pg_pass file, try to connect again
+            try:
+                get_default_store()
+            except DatabaseError as e:
+                log.debug('Connection failed again.')
+                error(_('Could not connect to the database'),
+                      'error=%s uri=%s' % (str(e), store_dsn))
 
     def _post_connect(self):
         self._check_schema_migration()
@@ -147,11 +187,10 @@ class ShellDatabaseConnection(object):
         from stoqlib.lib.message import info
 
         default_store = get_default_store()
-        set_current_branch_station(default_store, station_name=None)
 
         compaines = default_store.find(Company)
         if (compaines.count() == 0 or
-            not sysparam(default_store).MAIN_COMPANY):
+            not sysparam.has_object('MAIN_COMPANY')):
             from stoqlib.gui.base.dialogs import run_dialog
             from stoqlib.gui.dialogs.branchdialog import BranchDialog
             if self._ran_wizard:
@@ -164,11 +203,15 @@ class ShellDatabaseConnection(object):
             if not person:
                 raise SystemExit
             branch = person.branch
-            sysparam(store).MAIN_COMPANY = branch.id
-            get_current_station(store).branch = branch
+            sysparam.set_object(store, 'MAIN_COMPANY', branch)
+            current_station = get_current_station(store)
+            if current_station is not None:
+                current_station.branch = branch
             store.commit()
             store.close()
 
+        set_current_branch_station(default_store, station_name=None)
+
     def _run_update_wizard(self):
         from stoqlib.gui.base.dialogs import run_dialog
         from stoq.gui.update import SchemaUpdateWizard
@@ -184,19 +227,18 @@ class Shell(object):
     - handles login
     - runs applications
     """
-    def __init__(self, options, initial=True):
+    def __init__(self, bootstrap, options, initial=True):
         global _shell
         _shell = self
         self._appname = None
-        self._bootstrap = ShellBootstrap(options=options,
-                                         initial=initial)
+        self._bootstrap = bootstrap
         self._dbconn = ShellDatabaseConnection(options=options)
         self._blocked_apps = []
-        self._current_app = None
         self._hidden_apps = []
         self._login = None
         self._options = options
         self._user = None
+        self.windows = []
 
     #
     # Private
@@ -204,14 +246,14 @@ class Shell(object):
 
     def _do_login(self):
         from stoqlib.exceptions import LoginError
-        from stoqlib.gui.login import LoginHelper
+        from stoqlib.gui.utils.login import LoginHelper
         from stoqlib.lib.message import error
 
         self._login = LoginHelper(username=self._options.login_username)
         try:
             if not self.login():
                 return False
-        except LoginError, e:
+        except LoginError as e:
             error(str(e))
             return False
         self._check_param_online_services()
@@ -219,12 +261,11 @@ class Shell(object):
         return True
 
     def _check_param_online_services(self):
-        from stoqlib.database.runtime import get_default_store, new_store
+        from stoqlib.database.runtime import new_store
         from stoqlib.lib.parameters import sysparam
         import gtk
 
-        sparam = sysparam(get_default_store())
-        if sparam.ONLINE_SERVICES is None:
+        if sysparam.get_bool('ONLINE_SERVICES') is None:
             from kiwi.ui.dialogs import HIGAlertDialog
             # FIXME: All of this is to avoid having to set markup as the default
             #        in kiwi/ui/dialogs:HIGAlertDialog.set_details, after 1.0
@@ -243,7 +284,7 @@ class Shell(object):
             response = dialog.run()
             dialog.destroy()
             store = new_store()
-            sysparam(store).ONLINE_SERVICES = int(bool(response == gtk.RESPONSE_YES))
+            sysparam.set_bool(store, 'ONLINE_SERVICES', response == gtk.RESPONSE_YES)
             store.commit()
             store.close()
 
@@ -257,53 +298,109 @@ class Shell(object):
         from stoqlib.gui.base.dialogs import run_dialog
         run_dialog(WelcomeDialog)
 
-    def _load_app(self, appdesc, app_window):
-        import gtk
-        module = __import__("stoq.gui.%s" % (appdesc.name, ),
-                            globals(), locals(), [''])
-        window = appdesc.name.capitalize() + 'App'
-        window_class = getattr(module, window, None)
-        if window_class is None:
-            raise SystemExit("%s app misses a %r attribute" % (
-                appdesc.name, window))
+    def _maybe_correct_demo_position(self, shell_window):
+        # Possibly correct window position (livecd workaround for small
+        # screens)
+        from stoqlib.lib.parameters import sysparam
+        from stoqlib.lib.pluginmanager import get_plugin_manager
+        manager = get_plugin_manager()
+        if (sysparam.get_bool('DEMO_MODE') and
+            manager.is_active(u'ecf')):
+            pos = shell_window.toplevel.get_position()
+            if pos[0] < 220:
+                shell_window.toplevel.move(220, pos[1])
 
-        embedded = getattr(window_class, 'embedded', False)
-        from stoq.gui.application import App
-        app = App(window_class, self._login, self._options, self, embedded,
-                  app_window, appdesc.name)
+    def _maybe_schedule_idle_logout(self):
+        # Verify if the user will use automatic logout.
+        from stoqlib.lib.parameters import sysparam
+        minutes = sysparam.get_int('AUTOMATIC_LOGOUT')
+        # If user defined 0 minutes, ignore automatic logout.
+        if minutes != 0:
+            seconds = minutes * 60
+            glib.timeout_add_seconds(5, self._verify_idle_logout, seconds)
 
-        toplevel = app.main_window.get_toplevel()
-        icon = toplevel.render_icon(appdesc.icon, gtk.ICON_SIZE_MENU)
-        toplevel.set_icon(icon)
+    def _verify_idle_logout(self, seconds):
+        # This is called once every 10 seconds
+        from stoqlib.gui.utils.idle import get_idle_seconds
+        if get_idle_seconds() > seconds:
+            return self._idle_logout()
+        # Call us again in 10 seconds
+        return True
 
-        from stoqlib.gui.events import StartApplicationEvent
-        StartApplicationEvent.emit(appdesc.name, app)
-
-        return app
-
-    def _get_available_applications(self):
+    def _idle_logout(self):
+        # Before performing logout, verify that the currently opened window
+        # is modal.
         from kiwi.component import get_utility
-        from stoqlib.lib.interfaces import IApplicationDescriptions
-        from stoq.lib.applist import Application
+        from stoqlib.gui.base.dialogs import has_modal_window
+        from stoqlib.lib.interfaces import ICookieFile
+        # If not a modal window, logout.
+        # Otherwise returns True to continue checking the automatic logout.
+        if not has_modal_window():
+            log.debug('Automatic logout')
+            get_utility(ICookieFile).clear()
+            self.quit(restart=True)
+        return True
 
-        permissions = {}
-        for settings in self._user.profile.profile_settings:
-            permissions[settings.app_dir_name] = settings.has_permission
+    def _logout(self):
+        from stoqlib.database.runtime import (get_current_user,
+                                              get_default_store)
+        log.debug('Logging out the current user')
+        try:
+            user = get_current_user(get_default_store())
+            if user:
+                user.logout()
+        except StoqlibError:
+            pass
 
-        descriptions = get_utility(IApplicationDescriptions).get_descriptions()
+    @inlineCallbacks
+    def _terminate(self, restart=False, app=None):
+        log.info("Terminating Stoq")
 
-        available_applications = []
+        # This removes all temporary files created when calling
+        # get_resource_filename() that extract files to the file system
+        import pkg_resources
+        pkg_resources.cleanup_resources()
 
-        # sorting by app_full_name
-        for name, full, icon, descr in sorted(descriptions,
-                                              key=operator.itemgetter(1)):
-            if name in self._hidden_apps:
-                continue
-            if permissions.get(name) and name not in self._blocked_apps:
-                available_applications.append(
-                    Application(name, full, icon, descr))
+        log.debug('Stopping deamon')
+        from stoqlib.lib.daemonutils import stop_daemon
+        stop_daemon()
 
-        return available_applications
+        # Finally, go out of the reactor and show possible crash reports
+        yield self._quit_reactor_and_maybe_show_crashreports()
+
+        if restart:
+            from stoqlib.lib.process import Process
+            log.info('Restarting Stoq')
+            args = [sys.argv[0], '--no-splash-screen']
+            if app is not None:
+                args.append(app)
+            Process(args)
+
+        # os._exit() forces a quit without running atexit handlers
+        # and does not block on any running threads
+        # FIXME: This is the wrong solution, we should figure out why there
+        #        are any running threads/processes at this point
+        log.debug("Terminating by calling os._exit()")
+        os._exit(0)
+
+        raise AssertionError("Should never happen")
+
+    def _show_crash_reports(self):
+        from stoqlib.lib.crashreport import has_tracebacks
+        if not has_tracebacks():
+            return succeed(None)
+        if 'STOQ_DISABLE_CRASHREPORT' in os.environ:
+            return succeed(None)
+        from stoqlib.gui.dialogs.crashreportdialog import show_dialog
+        return show_dialog()
+
+    @inlineCallbacks
+    def _quit_reactor_and_maybe_show_crashreports(self):
+        log.debug("Show some crash reports")
+        yield self._show_crash_reports()
+        log.debug("Shutdown reactor")
+        from twisted.internet import reactor
+        reactor.stop()
 
     #
     # Public API
@@ -322,123 +419,110 @@ class Shell(object):
         if not user:
             try:
                 user = self._login.validate_user()
-            except LoginError, e:
+            except LoginError as e:
                 info(str(e))
 
         if user:
             self._user = user
         return bool(user)
 
-    def get_app_by_name(self, appname):
-        """
-        @param appname: a string
-        @returns: a :class:`Application` object
-        """
-        from kiwi.component import get_utility
-        from stoq.lib.applist import Application
-        from stoqlib.lib.interfaces import IApplicationDescriptions
-        descriptions = get_utility(IApplicationDescriptions).get_descriptions()
-        for name, full, icon, descr in descriptions:
-            if name == appname:
-                return Application(name, full, icon, descr)
-
     def get_current_app_name(self):
         """
         Get the name of the currently running application
         @returns: the name
         @rtype: str
         """
-        return self._appname
+        if not self.windows:
+            return ''
+        app = self.windows[0].current_app
+        if not app:
+            return ''
+        return app.app_name
 
-    def block_application(self, appname):
-        """Blocks an application to be loaded.
-        @param appname: the name of the application. Raises ValueError if the
-                        application was already blocked.
+    def create_window(self):
         """
-        if appname not in self._blocked_apps:
-            self._blocked_apps.append(appname)
-        else:
-            raise ValueError('%s was already blocked.' % appname)
+        Creates a new shell window.
 
-    def unblock_application(self, appname):
-        """Unblocks a previously blocked application.
-        @param appname: the name of the blocked application. Raises ValueError
-                        if the application was not previously blocked.
+        Note that it will not contain any applications and it will be hidden.
+
+        :returns: the shell_window
         """
-        if appname in self._blocked_apps:
-            self._blocked_apps.remove(appname)
-        else:
-            raise ValueError('%s was not blocked.' % appname)
+        from stoq.gui.shell.shellwindow import ShellWindow
+        from stoqlib.database.runtime import get_default_store
+        shell_window = ShellWindow(self._options,
+                                   shell=self,
+                                   store=get_default_store())
+        self.windows.append(shell_window)
 
-    def run(self, appdesc=None, appname=None):
+        self._maybe_correct_demo_position(shell_window)
+
+        return shell_window
+
+    def close_window(self, shell_window):
+        """
+        Close a currently open window
+        :param ShellWindow shell_window: the shell_window
+        """
+        shell_window.close()
+        self.windows.remove(shell_window)
+
+    def main(self, appname, action_name=None):
+        """
+        Start the shell.
+        This will:
+        - connect to the database
+        - login the current user
+        - create a new window
+        - run the launcher/application selector app
+        - run a mainloop
+
+        This will only exit when the complete stoq application
+        is shutdown.
+
+        :param appname: name of the application to run
+        :param action_name: action to activate or ``None``
+        """
+        self._dbconn.connect()
         if not self._do_login():
             raise SystemExit
-        from stoq.gui.launcher import Launcher
-        from stoqlib.gui.events import StartApplicationEvent
-        from stoqlib.lib.message import error
-        import gtk
-        app_window = Launcher(self._options, self)
-        app_window.show()
-        app = app_window.app
-        StartApplicationEvent.emit(app.name, app)
+        if appname is None:
+            appname = u'launcher'
+        shell_window = self.create_window()
+        app = shell_window.run_application(unicode(appname))
+        shell_window.show()
 
-        # A GtkWindowGroup controls grabs (blocking mouse/keyboard interaction),
-        # by default all windows are added to the same window group.
-        # We want to avoid setting modallity on other windows
-        # when running a dialog using gtk_dialog_run/run_dialog.
-        window_group = gtk.WindowGroup()
-        window_group.add_window(app_window.get_toplevel())
+        if action_name is not None:
+            action = getattr(app, action_name, None)
+            if action is not None:
+                action.activate()
 
-        if appname is not None:
-            appdesc = self.get_app_by_name(appname)
+        self._maybe_schedule_idle_logout()
 
-        if not appdesc:
-            return
-        if (appdesc.name != 'launcher' and
-            not self._user.profile.check_app_permission(appdesc.name)):
-            error(_("This user lacks credentials \nfor application %s") %
-                  appdesc.name)
-            return
-
-        self.run_embedded(appdesc, app_window)
-
-    def run_embedded(self, appdesc, app_window, params=None):
-        app = self._load_app(appdesc, app_window)
-        app.launcher = app_window
-
-        self._current_app = app
-        self._appname = appdesc.name
-
-        if appdesc.name in self._blocked_apps:
-            app_window.show()
-            return
-
-        app.run(params)
-
-        # Possibly correct window position (livecd workaround for small
-        # screens)
-        from stoqlib.lib.pluginmanager import get_plugin_manager
-        manager = get_plugin_manager()
-        from stoqlib.api import api
-        if (api.sysparam(api.get_default_store()).DEMO_MODE
-            and manager.is_active(u'ecf')):
-            pos = app.main_window.toplevel.get_position()
-            if pos[0] < 220:
-                app.main_window.toplevel.move(220, pos[1])
-
-        return app
-
-    def main(self, appname):
-        self._bootstrap.bootstrap()
-        self._dbconn.connect()
-        self.run(appname=appname)
-
-        from twisted.internet import reactor
         log.debug("Entering reactor")
         self._bootstrap.entered_main = True
+        from twisted.internet import reactor
         reactor.run()
         log.info("Leaving reactor")
 
+    def quit(self, restart=False, app=None):
+        """
+        Quit the shell and exit the application.
+        This will save user settings and then forcefully terminate
+        the application
+
+        :param restart: if ``True`` restart after terminating
+        :param str app: if not ``None``, name of the application to restart
+        """
+        from stoqlib.api import api
+        self._logout()
+
+        # Write user settings to disk, this obviously only happens when
+        # termination the complete stoq application
+        log.debug("Flushing user settings")
+        api.user_settings.flush()
+
+        self._terminate(restart=restart, app=app)
+
 
 def get_shell():
     return _shell
