@@ -24,34 +24,38 @@
 """ Main gui definition for stock application.  """
 
 import decimal
+import logging
 
 import pango
 import gtk
+
 from kiwi.datatypes import converter
-from kiwi.enums import SearchFilterPosition
-from kiwi.log import Logger
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import Column, SearchColumn
+
 from stoqlib.api import api
-from stoqlib.exceptions import DatabaseInconsistency
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.domain.person import Branch
 from stoqlib.domain.views import ProductFullStockView
+from stoqlib.domain.transfer import TransferOrder
 from stoqlib.lib.defaults import sort_sellable_code
 from stoqlib.lib.message import warning
-from stoqlib.lib.translation import stoqlib_gettext as _
+from stoqlib.lib.translation import stoqlib_ngettext, stoqlib_gettext as _
 from stoqlib.gui.dialogs.initialstockdialog import InitialStockDialog
 from stoqlib.gui.dialogs.productstockdetails import ProductStockHistoryDialog
 from stoqlib.gui.dialogs.sellableimage import SellableImageViewer
 from stoqlib.gui.editors.producteditor import ProductStockEditor
-from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.loansearch import LoanItemSearch, LoanSearch
 from stoqlib.gui.search.receivingsearch import PurchaseReceivingSearch
 from stoqlib.gui.search.productsearch import (ProductSearchQuantity,
                                               ProductStockSearch,
+                                              ProductBrandSearch,
+                                              ProductBatchSearch,
                                               ProductClosedStockSearch)
 from stoqlib.gui.search.purchasesearch import PurchasedItemsSearch
 from stoqlib.gui.search.transfersearch import TransferOrderSearch
+from stoqlib.gui.search.searchcolumns import SearchColumn
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
 from stoqlib.gui.search.stockdecreasesearch import StockDecreaseSearch
+from stoqlib.gui.utils.keybindings import get_accels
 from stoqlib.gui.wizards.loanwizard import NewLoanWizard, CloseLoanWizard
 from stoqlib.gui.wizards.receivingwizard import ReceivingOrderWizard
 from stoqlib.gui.wizards.stockdecreasewizard import StockDecreaseWizard
@@ -59,19 +63,18 @@ from stoqlib.gui.wizards.stocktransferwizard import StockTransferWizard
 from stoqlib.reporting.product import SimpleProductReport
 from stoqlib.gui.stockicons import STOQ_RECEIVING
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
-class StockApp(SearchableAppWindow):
-    app_name = _('Stock')
+class StockApp(ShellApp):
+    app_title = _('Stock')
     gladefile = "stock"
-    search_table = ProductFullStockView
+    search_spec = ProductFullStockView
     search_labels = _('Matching:')
     report_table = SimpleProductReport
     pixbuf_converter = converter.get_converter(gtk.gdk.Pixbuf)
-    embedded = True
 
     #
     # Application
@@ -100,6 +103,12 @@ class StockApp(SearchableAppWindow):
             ("SearchPurchasedStockItems", None, _("Purchased items..."),
              group.get('search_purchased_stock_items'),
              _("Search for purchased items")),
+            ("SearchBrandItems", None, _("Brand items..."),
+             group.get('search_brand_items'),
+             _("Search for brand items on stock")),
+            ("SearchBatchItems", None, _("Batch items..."),
+             group.get('search_batch_items'),
+             _("Search for batch items on stock")),
             ("SearchStockItems", None, _("Stock items..."),
              group.get('search_stock_items'),
              _("Search for items on stock")),
@@ -114,11 +123,11 @@ class StockApp(SearchableAppWindow):
             ("ProductMenu", None, _("Product")),
             ("ProductStockHistory", gtk.STOCK_INFO, _("History..."),
              group.get('history'),
-            _('Show the stock history of the selected product')),
+             _('Show the stock history of the selected product')),
             ("EditProduct", gtk.STOCK_EDIT, _("Edit..."),
              group.get('edit_product'),
-            _("Edit the selected product, allowing you to change it's "
-              "details")),
+             _("Edit the selected product, allowing you to change it's "
+               "details")),
         ]
         self.stock_ui = self.add_ui_actions('', actions,
                                             filename='stock.xml')
@@ -139,21 +148,22 @@ class StockApp(SearchableAppWindow):
         self.ProductStockHistory.props.is_important = True
 
     def create_ui(self):
-        if api.sysparam(self.store).SMART_LIST_LOADING:
-            self.search.search.enable_lazy_search()
+        if api.sysparam.get_bool('SMART_LIST_LOADING'):
+            self.search.enable_lazy_search()
 
         self.popup = self.uimanager.get_widget('/StockSelection')
-        self.app.launcher.add_new_items([self.NewReceiving, self.NewTransfer,
-                                         self.NewStockDecrease, self.LoanNew])
-        self.app.launcher.add_search_items([
+        self.window.add_new_items([self.NewReceiving, self.NewTransfer,
+                                   self.NewStockDecrease, self.LoanNew])
+        self.window.add_search_items([
             self.SearchStockItems,
+            self.SearchBrandItems,
             self.SearchStockDecrease,
             self.SearchClosedStockItems,
             self.SearchProductHistory,
             self.SearchPurchasedStockItems,
             self.SearchTransfer,
-            ])
-        self.app.launcher.Print.set_tooltip(
+        ])
+        self.window.Print.set_tooltip(
             _("Print a report of these products"))
         self._inventory_widgets = [self.NewTransfer, self.NewReceiving,
                                    self.StockInitial, self.NewStockDecrease,
@@ -173,20 +183,33 @@ class StockApp(SearchableAppWindow):
                                       format='<b>%s</b>',
                                       parent=self.get_statusbar_message_area())
 
-    def activate(self, params):
-        self.app.launcher.NewToolItem.set_tooltip(
+    def activate(self, refresh=True):
+        self.window.NewToolItem.set_tooltip(
             _("Create a new receiving order"))
-        self.app.launcher.SearchToolItem.set_tooltip(
+        self.window.SearchToolItem.set_tooltip(
             _("Search for stock items"))
 
-        self.check_open_inventory()
+        if refresh:
+            self.refresh()
+
+        open_inventory = self.check_open_inventory()
+
+        if not open_inventory:
+            self.transfers_bar = self._create_pending_info_message()
+        else:
+            self.transfers_bar = None
+
         self._update_widgets()
 
     def setup_focus(self):
-        self.search.refresh()
+        self.refresh()
 
     def deactivate(self):
+        if self.transfers_bar:
+            self.transfers_bar.hide()
+
         self.uimanager.remove_ui(self.stock_ui)
+        self._close_image_viewer()
 
     def new_activate(self):
         if not self.NewReceiving.get_sensitive():
@@ -200,15 +223,13 @@ class StockApp(SearchableAppWindow):
     def set_open_inventory(self):
         self.set_sensitive(self._inventory_widgets, False)
 
-    #
-    # SearchableAppWindow
-    #
-
     def create_filters(self):
-        self.executer.set_query(self._query)
-        self.set_text_field_columns(['description'])
+        self.search.set_query(self._query)
+        self.set_text_field_columns(['description', 'code', 'barcode',
+                                     'category_description', 'manufacturer'])
+        branches = Branch.get_active_branches(self.store)
         self.branch_filter = ComboSearchFilter(
-            _('Show by:'), self._get_branches())
+            _('Show by:'), api.for_combo(branches, empty=_("All branches")))
         self.branch_filter.select(api.get_current_branch(self.store))
         self.add_filter(self.branch_filter, position=SearchFilterPosition.TOP)
 
@@ -229,31 +250,38 @@ class StockApp(SearchableAppWindow):
                              data_type=str, visible=False),
                 SearchColumn('location', title=_("Location"), data_type=str,
                              width=100, visible=False),
-                Column('stock', title=_('Quantity'),
-                       data_type=decimal.Decimal, width=100),
+                SearchColumn('stock', title=_('Quantity'),
+                             data_type=decimal.Decimal, width=100),
                 SearchColumn('unit', title=_("Unit"), data_type=str,
                              width=40, visible=False),
-                Column('has_image', title=_('Picture'),
-                       data_type=bool, width=80),
-                 ]
+                SearchColumn('has_image', title=_('Picture'),
+                             data_type=bool, width=80),
+                ]
 
     #
     # Private API
     #
 
+    def _open_image_viewer(self):
+        assert self.image_viewer is None
+
+        self.image_viewer = SellableImageViewer(size=(325, 325))
+        self.image_viewer.toplevel.connect(
+            'delete-event', self.on_image_viewer_closed)
+        self.image_viewer.show_all()
+
+        self._update_widgets()
+
+    def _close_image_viewer(self):
+        if self.image_viewer is None:
+            return
+
+        self.image_viewer.destroy()
+        self.image_viewer = None
+
     def _query(self, store):
         branch = self.branch_filter.get_state().value
-        return self.search_table.find_by_branch(store, branch)
-
-    def _get_branches(self):
-        items = [(b.person.name, b)
-                  for b in self.store.find(Branch)]
-        if not items:
-            raise DatabaseInconsistency('You should have at least one '
-                                        'branch on your database.'
-                                        'Found zero')
-        items.insert(0, [_('All branches'), None])
-        return items
+        return self.search_spec.find_by_branch(store, branch)
 
     def _update_widgets(self):
         branch = api.get_current_branch(self.store)
@@ -263,7 +291,7 @@ class StockApp(SearchableAppWindow):
 
         sellable = item and item.product.sellable
         if sellable:
-            if sellable.has_image:
+            if item.has_image:
                 thumbnail = sellable.image.thumbnail
                 pixbuf = self.pixbuf_converter.from_string(thumbnail)
             else:
@@ -309,7 +337,7 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(StockTransferWizard, store)
         store.confirm(model)
         store.close()
-        self.search.refresh()
+        self.refresh()
 
     def _receive_purchase(self):
         if self.check_open_inventory():
@@ -318,15 +346,47 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(ReceivingOrderWizard, store)
         store.confirm(model)
         store.close()
-        self.search.refresh()
+        self.refresh()
+
+    def _create_pending_info_message(self):
+        branch = api.get_current_branch(self.store)
+        n_transfers = TransferOrder.get_pending_transfers(self.store, branch).count()
+
+        if not n_transfers:
+            return None
+
+        msg = stoqlib_ngettext(_(u"You have %s incoming transfer"),
+                               _(u"You have %s incoming transfers"),
+                               n_transfers) % n_transfers
+        info_bar = self.window.add_info_bar(gtk.MESSAGE_QUESTION, msg)
+        button = info_bar.add_button(_(u"Receive"), gtk.RESPONSE_OK)
+        button.connect('clicked', self._on_info_transfers__clicked)
+
+        return info_bar
+
+    def _search_transfers(self):
+        branch = api.get_current_branch(self.store)
+        self.run_dialog(TransferOrderSearch, self.store)
+
+        if self.transfers_bar:
+            n_transfers = TransferOrder.get_pending_transfers(self.store, branch).count()
+
+            if n_transfers > 0:
+                msg = stoqlib_ngettext(_(u"You have %s incoming transfer"),
+                                       _(u"You have %s incoming transfers"),
+                                       n_transfers) % n_transfers
+                self.transfers_bar.set_message(msg)
+            else:
+                self.transfers_bar.hide()
+        self.refresh()
 
     #
     # Callbacks
     #
 
     def on_image_viewer_closed(self, window, event):
-        self.StockPictureViewer.props.active = False
         self.image_viewer = None
+        self.StockPictureViewer.set_active(False)
 
     def on_results__has_rows(self, results, product):
         self._update_widgets()
@@ -354,6 +414,9 @@ class StockApp(SearchableAppWindow):
         store.confirm(model)
         store.close()
 
+    def _on_info_transfers__clicked(self, button):
+        self._search_transfers()
+
     # Stock
 
     def on_NewReceiving__activate(self, button):
@@ -369,32 +432,23 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(StockDecreaseWizard, store)
         store.confirm(model)
         store.close()
-        self.search.refresh()
+        self.refresh()
 
     def on_StockInitial__activate(self, action):
         if self.check_open_inventory():
             return
-        branch = self.branch_filter.get_state().value
-        store = api.new_store()
-        retval = self.run_dialog(InitialStockDialog, store, branch)
-        store.confirm(retval)
-        store.close()
-        self.search.refresh()
 
-    def on_StockPictureViewer__activate(self, button):
-        if self.image_viewer:
-            self.StockPictureViewer.props.active = False
-            self.image_viewer.destroy()
-            self.image_viewer = None
+        with api.new_store() as store:
+            self.run_dialog(InitialStockDialog, store)
+
+        if store.committed:
+            self.refresh()
+
+    def on_StockPictureViewer__toggled(self, button):
+        if button.get_active():
+            self._open_image_viewer()
         else:
-            self.StockPictureViewer.props.active = True
-            self.image_viewer = SellableImageViewer()
-            selected = self.results.get_selected()
-            if selected:
-                self.image_viewer.set_sellable(selected.product.sellable)
-            self.image_viewer.toplevel.connect(
-                "delete-event", self.on_image_viewer_closed)
-            self.image_viewer.toplevel.set_property("visible", True)
+            self._close_image_viewer()
 
     # Loan
 
@@ -405,7 +459,7 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(NewLoanWizard, store)
         store.confirm(model)
         store.close()
-        self.search.refresh()
+        self.refresh()
 
     def on_LoanClose__activate(self, action):
         if self.check_open_inventory():
@@ -414,7 +468,7 @@ class StockApp(SearchableAppWindow):
         model = self.run_dialog(CloseLoanWizard, store)
         store.confirm(model)
         store.close()
-        self.search.refresh()
+        self.refresh()
 
     def on_LoanSearch__activate(self, action):
         self.run_dialog(LoanSearch, self.store)
@@ -428,7 +482,7 @@ class StockApp(SearchableAppWindow):
         self.run_dialog(PurchaseReceivingSearch, self.store)
 
     def on_SearchTransfer__activate(self, action):
-        self.run_dialog(TransferOrderSearch, self.store)
+        self._search_transfers()
 
     def on_SearchPurchasedStockItems__activate(self, action):
         self.run_dialog(PurchasedItemsSearch, self.store)
@@ -436,6 +490,12 @@ class StockApp(SearchableAppWindow):
     def on_SearchStockItems__activate(self, action):
         self.run_dialog(ProductStockSearch, self.store)
 
+    def on_SearchBrandItems__activate(self, action):
+        self.run_dialog(ProductBrandSearch, self.store)
+
+    def on_SearchBatchItems__activate(self, action):
+        self.run_dialog(ProductBatchSearch, self.store)
+
     def on_SearchClosedStockItems__activate(self, action):
         self.run_dialog(ProductClosedStockSearch, self.store)
 
