@@ -22,10 +22,9 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import mock
+import contextlib
 
-from stoq.gui.admin import AdminApp
-from stoq.gui.test.baseguitest import BaseGUITest
+import mock
 from stoqlib.api import api
 from stoqlib.database.runtime import StoqlibStore
 from stoqlib.gui.dialogs.clientcategorydialog import ClientCategoryDialog
@@ -53,31 +52,36 @@ from stoqlib.gui.search.profilesearch import UserProfileSearch
 from stoqlib.gui.search.stationsearch import StationSearch
 from stoqlib.gui.search.taxclasssearch import TaxTemplatesSearch
 
+from stoq.gui.admin import AdminApp
+from stoq.gui.test.baseguitest import BaseGUITest
+
 
 class TestAdmin(BaseGUITest):
     def _activate_task(self, app, task_name):
-        for row in app.main_window.iconview.get_model():
+        for row in app.iconview.get_model():
             if row[1] == task_name:
-                app.main_window.iconview.item_activated(row.path)
+                app.iconview.item_activated(row.path)
                 break
 
-    @mock.patch('stoq.gui.admin.AdminApp.run_dialog')
-    def _check_search_task(self, app, task_name, search_dialog, run_dialog):
-        self._activate_task(app, task_name)
-        self.assertEquals(run_dialog.call_count, 1)
-        args, kwargs = run_dialog.call_args
-        search, store = args
-        self.assertEquals(search, search_dialog)
-        self.assertTrue(isinstance(store, StoqlibStore))
+    def _check_search_task(self, app, task_name, search_dialog):
+        with mock.patch('stoq.gui.admin.AdminApp.run_dialog') as run_dialog:
+            self._activate_task(app, task_name)
+            self.assertEquals(run_dialog.call_count, 1)
+            args, kwargs = run_dialog.call_args
+            search, store = args
+            self.assertEquals(search, search_dialog)
+            self.assertTrue(isinstance(store, StoqlibStore))
 
-    @mock.patch('stoq.gui.admin.AdminApp.run_dialog')
-    def _check_dialog_task(self, app, task_name, dialog, run_dialog):
-        with mock.patch.object(self.store, 'commit'):
-            with mock.patch.object(self.store, 'close'):
-                self._activate_task(app, task_name)
-                run_dialog.assert_called_once_with(dialog, self.store)
+    def _check_dialog_task(self, app, task_name, dialog):
+        with contextlib.nested(
+                mock.patch('stoq.gui.admin.AdminApp.run_dialog'),
+                mock.patch.object(self.store, 'commit'),
+                mock.patch.object(self.store, 'close')) as ctx:
+            self._activate_task(app, task_name)
+            run_dialog = ctx[0]
+            run_dialog.assert_called_once_with(dialog, self.store)
 
-    def testInitial(self):
+    def test_initial(self):
         app = self.create_app(AdminApp, u'admin')
         self.check_app(app, u'admin')
 
@@ -90,8 +94,8 @@ class TestAdmin(BaseGUITest):
 
         with mock.patch.object(self.store, 'commit'):
             with mock.patch.object(self.store, 'close'):
-                self.activate(app.main_window.NewUser)
-                run_dialog.assert_called_once_with(UserEditor, app.main_window,
+                self.activate(app.NewUser)
+                run_dialog.assert_called_once_with(UserEditor, app,
                                                    self.store)
 
     @mock.patch('stoq.gui.admin.api.new_store')
@@ -125,7 +129,7 @@ class TestAdmin(BaseGUITest):
 
         # adding the invoice_layouts to the the item list (because it
         # isn't included there by default)
-        app.main_window.tasks.add_item(u'foo', u'invoice_layouts', None)
+        app.tasks.add_item(u'foo', u'invoice_layouts', None)
 
         self._check_dialog_task(app, u'invoice_layouts', InvoiceLayoutDialog)
 
@@ -135,7 +139,7 @@ class TestAdmin(BaseGUITest):
 
         # adding the sintegra to the the item list (because it
         # isn't included there by default)
-        app.main_window.tasks.add_item(u'bar', u'sintegra', None)
+        app.tasks.add_item(u'bar', u'sintegra', None)
 
         self._activate_task(app, u'sintegra')
         info.assert_called_once_with(u'You must define a manager to this branch '
@@ -149,6 +153,6 @@ class TestAdmin(BaseGUITest):
     def test_hide_item(self):
         app = self.create_app(AdminApp, u'admin')
 
-        app.main_window.tasks.hide_item(u'branches')
-        tasks = [(row[1]) for row in app.main_window.tasks.model]
+        app.tasks.hide_item(u'branches')
+        tasks = [(row[1]) for row in app.tasks.model]
         self.assertFalse(u'branches' in tasks)
