@@ -35,46 +35,44 @@ from stoqlib.reporting.payment import AccountTransactionReport
 class TestFinancial(BaseGUITest):
     def _open_page(self, app, page_name, page_child=None):
         """ This function opens a page and returns it """
-        accounts = app.main_window.accounts
+
+        def activate(row):
+            accounts.double_click(row.path)
+            return app.get_current_page()
+
+        accounts = app.accounts
         for row in accounts.get_model():
             if row[0].description != page_name:
                 continue
 
             if not page_child:
-                accounts.double_click(row.path)
-                page_id = app.main_window.notebook.get_current_page()
-                page = app.main_window.notebook.get_children()[page_id]
-                return page
+                return activate(row)
 
             for sub in row.iterchildren():
-                if sub[0].description != page_child:
-                    continue
-                accounts.double_click(sub.path)
-                page_id = app.main_window.notebook.get_current_page()
-                page = app.main_window.notebook.get_children()[page_id]
-                return page
+                if sub[0].description == page_child:
+                    return activate(sub)
 
-    def testInitial(self):
+    def test_initial(self):
         app = self.create_app(FinancialApp, u'financial')
         self.check_app(app, u'financial')
 
-    def testTransactionPage(self):
+    def test_transaction_page(self):
         app = self.create_app(FinancialApp, u'financial')
 
         self._open_page(app, u"Banks", u"Banco do Brasil")
         self.check_app(app, u'financial-transaction-page')
 
-    def testPayablePage(self):
+    def test_payable_page(self):
         app = self.create_app(FinancialApp, u'financial')
 
         page = self._open_page(app, u"Accounts Payable")
-        page.search()
+        page.search.search()
 
-    def testReceivablePage(self):
+    def test_receivable_page(self):
         app = self.create_app(FinancialApp, u'financial')
 
         page = self._open_page(app, u"Accounts Receivable")
-        page.search()
+        page.search.search()
 
     @mock.patch('stoq.gui.financial.run_dialog')
     @mock.patch('stoq.gui.financial.api.new_store')
@@ -90,12 +88,12 @@ class TestFinancial(BaseGUITest):
         app = self.create_app(FinancialApp, u"financial")
         page = self._open_page(app, u"The Account")
 
-        olist = page.results
+        olist = page.result_view
         olist.select(olist[0])
 
         with mock.patch.object(self.store, 'commit'):
             with mock.patch.object(self.store, 'close'):
-                self.activate(app.main_window.Edit)
+                self.activate(app.Edit)
                 self.assertEquals(run_dialog.call_count, 1)
                 args, kwargs = run_dialog.call_args
                 editor, _app, store, account_transaction, model = args
@@ -121,7 +119,7 @@ class TestFinancial(BaseGUITest):
 
         with mock.patch.object(self.store, 'commit'):
             with mock.patch.object(self.store, 'close'):
-                self.activate(app.main_window.NewTransaction)
+                self.activate(app.NewTransaction)
                 self.assertEquals(run_dialog.call_count, 1)
                 args, kwargs = run_dialog.call_args
                 editor, _app, store, account_transaction, model = args
@@ -140,12 +138,13 @@ class TestFinancial(BaseGUITest):
         app = self.create_app(FinancialApp, u"financial")
         page = self._open_page(app, u"The Account")
 
-        self.activate(app.main_window.Print)
+        self.activate(app.Print)
 
-        print_report.assert_called_once_with(AccountTransactionReport,
-                                             page.results, list(page.results),
-                                             account=page.model,
-                                             filters=page.get_search_filters())
+        print_report.assert_called_once_with(
+            AccountTransactionReport,
+            page.result_view, list(page.result_view),
+            account=page.model,
+            filters=page.search.get_search_filters())
 
     @mock.patch('stoq.gui.financial.SpreadSheetExporter.export')
     def test_export_spreadsheet(self, export):
@@ -156,16 +155,16 @@ class TestFinancial(BaseGUITest):
         app = self.create_app(FinancialApp, u"financial")
         page = self._open_page(app, u"The Account")
 
-        self.activate(app.main_window.ExportSpreadSheet)
+        self.activate(app.ExportSpreadSheet)
 
-        export.assert_called_once_with(object_list=page.results,
+        export.assert_called_once_with(object_list=page.result_view,
                                        name=u'Financial',
                                        filename_prefix=u'financial')
 
     @mock.patch('stoq.gui.financial.yesno')
     @mock.patch('stoq.gui.financial.api.new_store')
     def test_delete_account(self, new_store, yesno):
-        yesno.return_value = False
+        yesno.return_value = True
         new_store.return_value = self.store
 
         at = self.create_account_transaction(self.create_account())
@@ -173,7 +172,7 @@ class TestFinancial(BaseGUITest):
         at.edited_account = at.account
 
         app = self.create_app(FinancialApp, u"financial")
-        accounts = app.main_window.accounts
+        accounts = app.accounts
 
         for account in accounts:
             if account.description == at.account.description:
@@ -182,17 +181,17 @@ class TestFinancial(BaseGUITest):
         accounts.select(selected_account)
         with mock.patch.object(self.store, 'commit'):
             with mock.patch.object(self.store, 'close'):
-                self.activate(app.main_window.DeleteAccount)
+                self.activate(app.DeleteAccount)
                 yesno.assert_called_once_with(u'Are you sure you want to remove '
                                               u'account "The Account" ?',
-                                              gtk.RESPONSE_YES, u'Keep account',
-                                              u'Remove account')
+                                              gtk.RESPONSE_NO,
+                                              u'Remove account', u'Keep account')
                 self.assertTrue(selected_account not in accounts)
 
     @mock.patch('stoq.gui.financial.yesno')
     @mock.patch('stoq.gui.financial.api.new_store')
     def test_delete_transaction(self, new_store, yesno):
-        yesno.return_value = False
+        yesno.return_value = True
         new_store.return_value = self.store
 
         at = self.create_account_transaction(self.create_account())
@@ -202,18 +201,18 @@ class TestFinancial(BaseGUITest):
         app = self.create_app(FinancialApp, u"financial")
         page = self._open_page(app, u"The Account")
 
-        olist = page.results
+        olist = page.result_view
         olist.select(olist[0])
 
         with mock.patch.object(self.store, 'commit'):
             with mock.patch.object(self.store, 'close'):
-                self.activate(app.main_window.DeleteTransaction)
+                self.activate(app.DeleteTransaction)
                 yesno.assert_called_once_with(u'Are you sure you want to remove '
                                               u'transaction "Test Account '
                                               u'Transaction" ?',
                                               gtk.RESPONSE_YES,
-                                              u'Keep transaction',
-                                              u'Remove transaction')
+                                              u'Remove transaction',
+                                              u'Keep transaction')
                 self.assertEquals(len(olist), 0)
 
     @mock.patch('stoq.gui.financial.FinancialApp.run_dialog')
@@ -224,7 +223,7 @@ class TestFinancial(BaseGUITest):
         app = self.create_app(FinancialApp, u"financial")
         with mock.patch.object(self.store, 'commit'):
             with mock.patch.object(self.store, 'close'):
-                self.activate(app.main_window.NewAccount)
+                self.activate(app.NewAccount)
                 run_dialog.assert_called_once_with(AccountEditor, self.store,
                                                    model=None, parent_account=None)
 
@@ -239,7 +238,7 @@ class TestFinancial(BaseGUITest):
         at.edited_account = at.account
 
         app = self.create_app(FinancialApp, u"financial")
-        accounts = app.main_window.accounts
+        accounts = app.accounts
 
         for account in accounts:
             if account.description == at.account.description:
@@ -248,7 +247,7 @@ class TestFinancial(BaseGUITest):
         accounts.select(selected_account)
         with mock.patch.object(self.store, 'commit'):
             with mock.patch.object(self.store, 'close'):
-                self.activate(app.main_window.Edit)
+                self.activate(app.Edit)
                 run_dialog.assert_called_once_with(AccountEditor, self.store,
                                                    parent_account=None,
                                                    model=at.account)
