@@ -22,11 +22,13 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
+import contextlib
 
 import mock
+from stoqlib.api import api
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.purchase import PurchaseOrder
+from stoqlib.lib.dateutils import localdate
 from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
 from stoqlib.gui.dialogs.paymentchangedialog import PaymentDueDateChangeDialog
 from stoqlib.gui.editors.paymenteditor import OutPaymentEditor
@@ -40,127 +42,131 @@ from stoq.gui.test.baseguitest import BaseGUITest
 
 
 class TestPayable(BaseGUITest):
-    @mock.patch('stoq.gui.payable.run_dialog')
-    @mock.patch('stoq.gui.payable.api.new_store')
-    def _check_run_dialog(self, app, action, dialog, other_args,
-                          new_store, run_dialog):
-        new_store.return_value = self.store
+    def _check_run_dialog(self, app, action, dialog, other_args):
+        with contextlib.nested(
+                mock.patch('stoq.gui.payable.run_dialog'),
+                mock.patch('stoq.gui.payable.api.new_store'),
+                mock.patch.object(self.store, 'commit'),
+                mock.patch.object(self.store, 'close')) as ctx:
+            new_store = ctx[1]
+            new_store.return_value = self.store
 
-        with mock.patch.object(self.store, 'commit'):
-            with mock.patch.object(self.store, 'close'):
-                self.activate(action)
-                run_dialog.assert_called_once()
-                args, kwargs = run_dialog.call_args
-                self.assertEquals(args[0], dialog)
-                self.assertEquals(args[1], app)
-                self.assertEquals(args[2], self.store)
+            self.activate(action)
 
-                if not other_args or len(other_args) != len(args[2:]):
-                    return
+            run_dialog = ctx[0]
+            self.assertEqual(run_dialog.call_count, 1)
+            args, kwargs = run_dialog.call_args
+            self.assertEquals(args[0], dialog)
+            self.assertEquals(args[1], app)
+            self.assertEquals(args[2], self.store)
 
-                for arg in args[2:]:
-                    for other_arg in other_args:
-                        self.assertEquals(arg, other_arg)
+            if not other_args or len(other_args) != len(args[2:]):
+                return
+
+            for arg in args[2:]:
+                for other_arg in other_args:
+                    self.assertEquals(arg, other_arg)
 
     def setUp(self):
         BaseGUITest.setUp(self)
 
     def create_purchase_payment(self):
-        order = self.create_purchase_order()
+        branch = api.get_current_branch(self.store)
+        order = self.create_purchase_order(branch=branch)
         order.identifier = 12345
         order.status = PurchaseOrder.ORDER_PENDING
         order.add_item(self.create_sellable(), 1)
         payment = self.add_payments(order, method_type=u'money')[0]
-        payment.open_date = payment.due_date = datetime.date(2012, 1, 1)
+        payment.open_date = payment.due_date = localdate(2012, 1, 1)
         order.confirm()
         payment.identifier = 67890
         order.close()
         return order, payment
 
-    def testInitial(self):
+    def test_initial(self):
         app = self.create_app(PayableApp, u'payable')
         self.check_app(app, u'payable')
 
-    def testSelect(self):
+    def test_select(self):
         purchase, payment = self.create_purchase_payment()
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[1])
         self.check_app(app, u'payable-selected')
 
     @mock.patch('stoq.gui.payable.run_dialog')
-    def testPay(self, run_dialog):
+    def test_pay(self, run_dialog):
         purchase, payment = self.create_purchase_payment()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[1])
 
         with mock.patch('stoq.gui.payable.api', new=self.fake.api):
-            self.activate(app.main_window.Pay)
+            self.activate(app.Pay)
 
         run_dialog.assert_called_once_with(
-            PurchasePaymentConfirmSlave, app.main_window,
+            PurchasePaymentConfirmSlave, app,
             self.store.readonly, payments=[payment])
 
     @mock.patch('stoq.gui.payable.run_dialog')
-    def testEdit(self, run_dialog):
+    def test_edit(self, run_dialog):
         purchase, payment = self.create_purchase_payment()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[1])
 
         with mock.patch('stoq.gui.payable.api', new=self.fake.api):
-            self.activate(app.main_window.Edit)
+            self.activate(app.Edit)
 
         run_dialog.assert_called_once_with(
-            PurchasePaymentsEditor, app.main_window,
+            PurchasePaymentsEditor, app,
             self.store.readonly, purchase)
 
     @mock.patch('stoq.gui.accounts.run_dialog')
-    def testChangeDueDate(self, run_dialog):
+    def test_change_due_date_dialog(self, run_dialog):
         purchase, payment = self.create_purchase_payment()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[1])
 
         with mock.patch('stoq.gui.accounts.api', new=self.fake.api):
-            self.activate(app.main_window.ChangeDueDate)
+            self.activate(app.ChangeDueDate)
 
         run_dialog.assert_called_once_with(
-            PaymentDueDateChangeDialog, app.main_window,
+            PaymentDueDateChangeDialog, app,
             self.store.readonly, payment, purchase)
 
     @mock.patch('stoq.gui.accounts.run_dialog')
-    def testDetails(self, run_dialog):
+    def test_details(self, run_dialog):
         purchase, payment = self.create_purchase_payment()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[1])
 
         with mock.patch('stoq.gui.accounts.api', new=self.fake.api):
-            self.activate(app.main_window.Details)
+            self.activate(app.Details)
 
         run_dialog.assert_called_once_with(
-            OutPaymentEditor, app.main_window,
+            OutPaymentEditor, app,
             self.store.readonly, payment)
 
     @mock.patch('stoq.gui.accounts.run_dialog')
-    def testComments(self, run_dialog):
+    def test_comments(self, run_dialog):
         purchase, payment = self.create_purchase_payment()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[1])
 
         with mock.patch('stoq.gui.accounts.api', new=self.fake.api):
-            self.activate(app.main_window.Comments)
+            self.activate(app.Comments)
 
         run_dialog.assert_called_once_with(
-            PaymentCommentsDialog, app.main_window,
+            PaymentCommentsDialog, app,
             self.store.readonly, payment)
 
     def test_can_edit(self):
@@ -168,35 +174,38 @@ class TestPayable(BaseGUITest):
         purchase.status = PurchaseOrder.ORDER_CANCELLED
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
-        self.assertFalse(app.main_window._can_edit([olist[-1]]))
+        olist = app.results
+        self.assertFalse(app._can_edit([olist[-1]]))
 
     def test_can_pay(self):
         sale, payment1 = self.create_purchase_payment()
         payment2 = self.add_payments(sale, method_type=u'bill')[0]
         payment2.identifier = 67891
 
-        app = self.create_app(PayableApp, u'receivable')
+        app = self.create_app(PayableApp, u'payable')
 
-        olist = app.main_window.results
+        olist = app.results
         payments = list(olist)[-2:]
 
         for payment in payments:
             payment.status = Payment.STATUS_PENDING
-        self.assertTrue(app.main_window._can_pay(payments))
+        self.assertTrue(app._can_pay(payments))
 
     @mock.patch('stoq.gui.payable.print_report')
-    def test_print_receipt(self, print_report):
+    @mock.patch('stoq.gui.payable.localtoday')
+    def test_print_receipt(self, localtoday_, print_report):
+        today_ = localdate(2012, 1, 1)
+        localtoday_.return_value = today_
         purchase, payment = self.create_purchase_payment()
         payment.pay()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.PrintReceipt)
+        self.activate(app.PrintReceipt)
         print_report.assert_called_once_with(OutPaymentReceipt, payment=payment,
-                                             order=purchase, date=datetime.date.today())
+                                             order=purchase, date=today_.date())
 
     @mock.patch('stoq.gui.payable.PayableApp.change_status')
     def test_cancel_payment(self, change_status):
@@ -205,10 +214,10 @@ class TestPayable(BaseGUITest):
         payment.payment_type = Payment.TYPE_OUT
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.CancelPayment)
+        self.activate(app.CancelPayment)
         change_status.assert_called_once_with(olist[-1], None,
                                               Payment.STATUS_CANCELLED)
 
@@ -218,10 +227,10 @@ class TestPayable(BaseGUITest):
         payment.pay()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.SetNotPaid)
+        self.activate(app.SetNotPaid)
         change_status.assert_called_once_with(olist[-1], purchase,
                                               Payment.STATUS_PENDING)
 
@@ -230,13 +239,13 @@ class TestPayable(BaseGUITest):
         purchase, payment = self.create_purchase_payment()
 
         app = self.create_app(PayableApp, u'payable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.ChangeDueDate)
+        self.activate(app.ChangeDueDate)
         change_due_date.assert_called_once_with(olist[-1], purchase)
 
     def test_run_search(self):
         app = self.create_app(PayableApp, u'payable')
-        self._check_run_dialog(app.main_window, app.main_window.BillCheckSearch,
+        self._check_run_dialog(app, app.BillCheckSearch,
                                OutPaymentBillCheckSearch, [])
