@@ -22,15 +22,17 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+import contextlib
 from decimal import Decimal
+from kiwi.currency import currency
 import mock
 import gtk
 
-
 from stoqlib.api import api
 from stoqlib.database.runtime import StoqlibStore
 from stoqlib.domain.events import TillOpenEvent
 from stoqlib.domain.payment.method import PaymentMethod
+from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.service import Service
@@ -45,15 +47,18 @@ from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.productsearch import ProductSearch
 from stoqlib.gui.search.salesearch import (SaleWithToolbarSearch,
                                            SoldItemsByBranchSearch)
-from stoqlib.gui.search.sellablesearch import SellableSearch
+from stoqlib.gui.search.sellablesearch import SaleSellableSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
+from stoqlib.reporting.booklet import BookletReport
 
 from stoq.gui.pos import PosApp, TemporarySaleItem
 from stoq.gui.test.baseguitest import BaseGUITest
 
+__tests__ = 'stoq/gui/pos.py'
+
 
 class TestPos(BaseGUITest):
-    def testInitial(self):
+    def test_initial(self):
         app = self.create_app(PosApp, u'pos')
         self.check_app(app, u'pos')
 
@@ -73,7 +78,7 @@ class TestPos(BaseGUITest):
 
     def _get_pos_with_open_till(self):
         app = self.create_app(PosApp, u'pos')
-        pos = app.main_window
+        pos = app
         self._pos_open_till(pos)
         return pos
 
@@ -87,36 +92,72 @@ class TestPos(BaseGUITest):
         self._add_product(pos, sellable)
         return service
 
-    def _auto_confirm_sale_wizard(self, wizard, app, store, sale,
-                                  subtotal, total_paid):
+    def _auto_confirm_sale(self, wizard, app, store, sale,
+                           subtotal, total_paid, payment_method):
         # This is in another store and as we want to avoid committing
         # we need to open the till again
         self._open_till(store)
 
         sale.order()
-        money_method = PaymentMethod.get_by_name(store, u'money')
         total = sale.get_total_sale_amount()
-        money_method.create_inpayment(sale.group, sale.branch, total)
+        payment_method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, total)
         self.sale = sale
         return sale
 
+    def _auto_confirm_sale_wizard(self, wizard, app, store, sale,
+                                  subtotal, total_paid):
+        payment_method = PaymentMethod.get_by_name(store, u'money')
+        return self._auto_confirm_sale(wizard, app, store, sale, subtotal,
+                                       total_paid, payment_method)
+
+    def _auto_confirm_sale_wizard_with_bill(self, wizard, app, store, sale,
+                                            subtotal, total_paid):
+        sale.client = self._create_client(store)
+        payment_method = PaymentMethod.get_by_name(store, u'bill')
+        return self._auto_confirm_sale(wizard, app, store, sale, subtotal,
+                                       total_paid, payment_method)
+
+    def _auto_confirm_sale_wizard_with_store_credit(self, wizard, app, store, sale,
+                                                    subtotal, total_paid):
+        sale.client = self._create_client(store)
+        payment_method = PaymentMethod.get_by_name(store, u'store_credit')
+        return self._auto_confirm_sale(wizard, app, store, sale, subtotal,
+                                       total_paid, payment_method)
+
+    def _create_client(self, store):
+        from stoqlib.domain.address import Address, CityLocation
+        from stoqlib.domain.person import Client, Person
+
+        person = Person(name=u'Person', store=store)
+        city = CityLocation.get_default(store)
+        Address(store=store,
+                street=u'Rua Principal',
+                streetnumber=123,
+                postal_code=u'12345-678',
+                is_main_address=True,
+                person=person,
+                city_location=city)
+        client = Client(person=person, store=store)
+        client.credit_limit = currency("1000")
+        return client
+
     def _called_once_with_store(self, func, *expected_args):
         args = func.call_args[0]
         for arg, expected in zip(args, expected_args):
             self.assertEquals(arg, expected)
 
     @mock.patch('stoqlib.database.runtime.StoqlibStore.confirm')
-    def testTillOpen(self, confirm):
+    def test_till_open(self, confirm):
         app = self.create_app(PosApp, u'pos')
-        pos = app.main_window
+        pos = app
         self._pos_open_till(pos)
 
         self.check_app(app, u'pos-till-open')
 
     @mock.patch('stoqlib.database.runtime.StoqlibStore.confirm')
-    def testCheckout(self, confirm):
+    def test_checkout(self, confirm):
         app = self.create_app(PosApp, u'pos')
-        pos = app.main_window
+        pos = app
         self._pos_open_till(pos)
 
         pos.barcode.set_text(u'1598756984265')
@@ -143,9 +184,77 @@ class TestPos(BaseGUITest):
             for store in close_calls:
                 store.close()
 
-    def testAddSaleItem(self):
+    @mock.patch('stoqlib.reporting.boleto.warning')
+    def test_checkout_with_bill(self, warning):
         app = self.create_app(PosApp, u'pos')
-        pos = app.main_window
+        pos = app
+        self._pos_open_till(pos)
+        pos.barcode.set_text(u'1598756984265')
+        self.activate(pos.barcode)
+        self.check_app(app, u'pos-bill-checkout-pre')
+        close_calls = []
+
+        def close(store):
+            if not store in close_calls:
+                close_calls.insert(0, store)
+
+        try:
+            with contextlib.nested(
+                mock.patch.object(StoqlibStore, 'confirm'),
+                mock.patch.object(StoqlibStore, 'close', new=close),
+                mock.patch('stoqlib.gui.fiscalprinter.run_dialog',
+                           self._auto_confirm_sale_wizard_with_bill)):
+
+                self.activate(pos.ConfirmOrder)
+                description = ("Account 'Imbalance' must be a bank account.\n"
+                               "You need to configure the bill payment method in "
+                               "the admin application and try again")
+                warning.assert_called_once_with('Could not print Bill Report',
+                                                description=description)
+                models = self.collect_sale_models(self.sale)
+                self.check_app(app, u'pos-bill-checkout-post', models=models)
+        finally:
+            for store in close_calls:
+                store.close()
+
+    @mock.patch('stoqlib.gui.fiscalprinter.yesno')
+    @mock.patch('stoqlib.gui.fiscalprinter.print_report')
+    def test_checkout_with_store_credit(self, print_report, yesno):
+        app = self.create_app(PosApp, u'pos')
+        pos = app
+        self._pos_open_till(pos)
+        pos.barcode.set_text(u'1598756984265')
+        self.activate(pos.barcode)
+        self.check_app(app, u'pos-booklets-checkout-pre')
+        close_calls = []
+
+        def close(store):
+            if not store in close_calls:
+                close_calls.insert(0, store)
+
+        try:
+            with contextlib.nested(
+                mock.patch.object(StoqlibStore, 'confirm'),
+                mock.patch.object(StoqlibStore, 'close', new=close),
+                mock.patch('stoqlib.gui.fiscalprinter.run_dialog',
+                           self._auto_confirm_sale_wizard_with_store_credit)):
+                self.activate(pos.ConfirmOrder)
+
+                yesno.assert_called_once_with(
+                    'Do you want to print the booklets for this sale?',
+                    gtk.RESPONSE_YES, 'Print booklets', "Don't print")
+                payments = list(self.sale.group.get_payments_by_method_name(u'store_credit'))
+                print_report.assert_called_once_with(BookletReport, payments)
+
+                models = self.collect_sale_models(self.sale)
+                self.check_app(app, u'pos-booklets-checkout-post', models=models)
+        finally:
+            for store in close_calls:
+                store.close()
+
+    def test_add_sale_item(self):
+        app = self.create_app(PosApp, u'pos')
+        pos = app
         self._pos_open_till(pos)
 
         sale_item = TemporarySaleItem(sellable=self.create_sellable(), quantity=1)
@@ -155,8 +264,21 @@ class TestPos(BaseGUITest):
 
         self.check_app(app, u'pos-add-sale-item')
 
+    @mock.patch('stoq.gui.pos.PosApp.run_dialog')
+    def test_add_service_sellable(self, run_dialog):
+        pos = self.create_app(PosApp, u'pos')
+        self._pos_open_till(pos)
+        service = self.create_service()
+
+        sale_item = TemporarySaleItem(sellable=service.sellable, quantity=2)
+        pos.add_sale_item(sale_item)
+
+        service.sellable.barcode = u'99991234'
+        pos.barcode.set_text(u'99991234')
+        self.activate(pos.barcode)
+
     @mock.patch('stoq.gui.pos.POSConfirmSaleEvent.emit')
-    def testPOSConfirmSaleEvent(self, emit):
+    def test_pos_confirm_sale_event(self, emit):
         pos = self._get_pos_with_open_till()
 
         sellable = self.store.find(Sellable)[0]
@@ -177,7 +299,7 @@ class TestPos(BaseGUITest):
     @mock.patch('stoq.gui.pos.yesno')
     def test_can_change_application(self, yesno):
         app = self.create_app(PosApp, u'pos')
-        pos = app.main_window
+        pos = app
 
         retval = pos.can_change_application()
         self.assertTrue(retval)
@@ -190,8 +312,10 @@ class TestPos(BaseGUITest):
         yesno.return_value = False
         retval = pos.can_change_application()
         self.assertFalse(retval)
-        yesno.assert_called_once_with(u'You must finish the current sale before '
-            u'you change to another application.', gtk.RESPONSE_NO, u'Cancel sale', u'Finish sale')
+        yesno.assert_called_once_with(
+            u'You must finish the current sale before '
+            u'you change to another application.', gtk.RESPONSE_NO,
+            u'Cancel sale', u'Finish sale')
 
     @mock.patch('stoq.gui.pos.yesno')
     def test_can_close_application(self, yesno):
@@ -210,8 +334,67 @@ class TestPos(BaseGUITest):
         yesno.return_value = False
         retval = pos.can_close_application()
         self.assertFalse(retval)
-        yesno.assert_called_once_with(u'You must finish or cancel the current sale before '
-            u'you can close the POS application.', gtk.RESPONSE_NO, u'Cancel sale', u'Finish sale')
+        yesno.assert_called_once_with(
+            u'You must finish or cancel the current sale before '
+            u'you can close the POS application.', gtk.RESPONSE_NO,
+            u'Cancel sale', u'Finish sale')
+
+    def test_get_sellable_and_batch(self):
+        # Testing BarcodeInfo inserted with scale and price mode
+        with self.sysparam(SCALE_BARCODE_FORMAT=0, CONFIRM_QTY_ON_BARCODE_ACTIVATE=True):
+            pos = self._get_pos_with_open_till()
+
+            sellable = self.create_sellable()
+            sellable.price = 100
+            sellable.barcode = u'4628'
+
+            # Set a barcode number on the barcode field and activate it
+            pos.barcode.set_text('2' + sellable.barcode + '00200000')
+            self.activate(pos.barcode)
+
+            self.assertEqual(2, float(pos.quantity.get_text()))
+
+    def test_set_additional_info(self):
+        from stoqlib.domain.product import Product
+
+        # The test that requires qty confirmation before adding a product
+        with self.sysparam(CONFIRM_QTY_ON_BARCODE_ACTIVATE=True):
+            pos = self._get_pos_with_open_till()
+
+            # Set a barcode number on the barcode field and activate it
+            sellable = self.store.find(Product)[0].sellable
+            pos.barcode.set_text(sellable.code)
+            self.activate(pos.barcode)
+
+            self.assertEquals(pos.sellable_description.get_text(), sellable.description)
+            self.assertTrue(pos.quantity.is_focus())
+
+        # The product is directly added
+        with self.sysparam(CONFIRM_QTY_ON_BARCODE_ACTIVATE=False):
+            pos = self._get_pos_with_open_till()
+
+            # Set a barcode number on the barcode field and activate it
+            sellable = self.store.find(Product)[0].sellable
+            pos.barcode.set_text(sellable.code)
+            self.activate(pos.barcode)
+
+            self.assertFalse(pos.sellable_description.get_visible())
+            self.assertFalse(pos.quantity.is_focus())
+
+        # A non existing product is added, focus shall remain in barcode entry
+        with self.sysparam(CONFIRM_QTY_ON_BARCODE_ACTIVATE=True):
+            pos = self._get_pos_with_open_till()
+
+            # Set a barcode number on the barcode field and activate it
+            sellable = self.store.find(Product)[0].sellable
+            pos.barcode.set_text('01xzp')
+            with mock.patch.object(pos, 'run_dialog') as run_dialog:
+                run_dialog.return_value = None
+                self.assertEquals(run_dialog.call_count, 0)
+                self.activate(pos.barcode)
+                self.assertEquals(run_dialog.call_count, 1)
+
+            self.assertTrue(pos.barcode.is_focus())
 
     def test_advanced_search(self):
         pos = self._get_pos_with_open_till()
@@ -220,14 +403,13 @@ class TestPos(BaseGUITest):
         with mock.patch.object(pos, 'run_dialog') as run_dialog:
             run_dialog.return_value = None
             self.activate(pos.barcode)
-            run_dialog.assert_called_once_with(SellableSearch, pos.store,
-                    selection_mode=gtk.SELECTION_BROWSE,
-                    search_str=u'item',
-                    sale_items=pos.sale_items,
-                    quantity=Decimal('1'),
-                    double_click_confirm=True,
-                    info_message=(u"The barcode 'item' does not exist. "
-                                  u"Searching for a product instead..."))
+            run_dialog.assert_called_once_with(
+                SaleSellableSearch, pos.store,
+                search_str=u'item',
+                sale_items=pos.sale_items,
+                quantity=Decimal('1'),
+                info_message=(u"The barcode 'item' does not exist. "
+                              u"Searching for a product instead..."))
 
         with mock.patch.object(pos, 'run_dialog') as run_dialog:
             return_value = self.store.find(SellableFullStockView)[0]
