@@ -22,8 +22,9 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import mock
+import contextlib
 
+import mock
 from stoqlib.gui.dialogs.productiondetails import ProductionDetailsDialog
 from stoqlib.gui.dialogs.productionquotedialog import ProductionQuoteDialog
 from stoqlib.gui.dialogs.startproduction import StartProductionDialog
@@ -38,51 +39,54 @@ from stoq.gui.test.baseguitest import BaseGUITest
 
 
 class TestProduction(BaseGUITest):
-    @mock.patch('stoq.gui.production.ProductionApp.run_dialog')
-    @mock.patch('stoq.gui.production.api.new_store')
-    def _check_run_dialog(self, action, dialog, other_args, other_kwargs,
-                          new_store, run_dialog):
-        new_store.return_value = self.store
+    def _check_run_dialog(self, action, dialog, other_args, other_kwargs):
+        with contextlib.nested(
+                mock.patch('stoq.gui.production.ProductionApp.run_dialog'),
+                mock.patch('stoq.gui.production.api.new_store'),
+                mock.patch.object(self.store, 'commit'),
+                mock.patch.object(self.store, 'close')) as ctx:
+            new_store = ctx[1]
+            new_store.return_value = self.store
 
-        with mock.patch.object(self.store, 'commit'):
-            with mock.patch.object(self.store, 'close'):
-                self.activate(action)
-                expected_args = [dialog, self.store]
-                if other_args:
-                    expected_args.extend(other_args)
-                run_dialog.assert_called_once_with(*expected_args, **other_kwargs)
+            self.activate(action)
+            expected_args = [dialog, self.store]
+            if other_args:
+                expected_args.extend(other_args)
 
-    def testInitial(self):
+            run_dialog = ctx[0]
+            run_dialog.assert_called_once_with(*expected_args, **other_kwargs)
+
+    def test_initial(self):
         app = self.create_app(ProductionApp, u'production')
         self.check_app(app, u'production')
 
-    def testSelect(self):
+    def test_select(self):
         self.create_production_order()
         app = self.create_app(ProductionApp, u'production')
-        results = app.main_window.results
+        results = app.results
         results.select(results[0])
 
     def test_run_dialogs(self):
         self.create_production_order()
         app = self.create_app(ProductionApp, u'production')
-        results = app.main_window.results
+        results = app.results
         results.select(results[0])
 
-        self._check_run_dialog(app.main_window.EditProduction,
+        self._check_run_dialog(app.EditProduction,
                                ProductionWizard, [results[0]], {})
         results.select(results[0])
-        self._check_run_dialog(app.main_window.StartProduction,
+        self._check_run_dialog(app.StartProduction,
                                StartProductionDialog, [results[0]], {})
         results.select(results[0])
-        self._check_run_dialog(app.main_window.ProductionDetails,
+        self._check_run_dialog(app.ProductionDetails,
                                ProductionDetailsDialog, [results[0]], {})
-        self._check_run_dialog(app.main_window.ProductionPurchaseQuote,
+        self._check_run_dialog(app.ProductionPurchaseQuote,
                                ProductionQuoteDialog, [], {})
-        self._check_run_dialog(app.main_window.SearchProduct,
+        self._check_run_dialog(app.SearchProduct,
                                ProductionProductSearch, [], {})
-        self._check_run_dialog(app.main_window.SearchService,
+        self._check_run_dialog(app.SearchService,
                                ServiceSearch, [], {u'hide_price_column': True})
-        self._check_run_dialog(app.main_window.SearchProductionHistory,
+        self._check_run_dialog(app.SearchProductionHistory,
                                ProductionHistorySearch, [], {})
-        self._check_run_dialog(app.main_window.SearchProductionItem,
+        self._check_run_dialog(app.SearchProductionItem,
                                ProductionItemsSearch, [], {})
