@@ -26,16 +26,17 @@ import datetime
 import mock
 import gtk
 
-from kiwi.ui.search import SearchResults
 from stoqlib.api import api
 
 from stoq.gui.purchase import PurchaseApp
 from stoq.gui.test.baseguitest import BaseGUITest
 from stoqlib.domain.purchase import PurchaseItem, PurchaseOrder, PurchaseOrderView
-from stoqlib.domain.receiving import ReceivingOrderItem, ReceivingOrder
-from stoqlib.gui.editors.producteditor import ProductEditor
+from stoqlib.domain.receiving import (ReceivingOrderItem, ReceivingOrder,
+                                      PurchaseReceivingMap)
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
+from stoqlib.gui.search.searchresultview import SearchResultListView
 from stoqlib.gui.wizards.consignmentwizard import ConsignmentWizard
+from stoqlib.gui.wizards.productwizard import ProductCreateWizard
 from stoqlib.gui.wizards.purchasefinishwizard import PurchaseFinishWizard
 from stoqlib.gui.wizards.purchasequotewizard import QuotePurchaseWizard
 from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
@@ -43,32 +44,32 @@ from stoqlib.reporting.purchase import PurchaseReport
 
 
 class TestPurchase(BaseGUITest):
-    def testInitial(self):
+    def test_initial(self):
         app = self.create_app(PurchaseApp, u'purchase')
-        for purchase in app.main_window.results:
+        for purchase in app.results:
             purchase.open_date = datetime.datetime(2012, 1, 1)
         self.check_app(app, u'purchase')
 
-    def testSelect(self):
+    def test_select(self):
         self.create_purchase_order()
         app = self.create_app(PurchaseApp, u'purchase')
-        results = app.main_window.results
+        results = app.results
         results.select(results[0])
 
     @mock.patch('stoq.gui.purchase.PurchaseApp.run_dialog')
     def test_edit_quote_order(self, run_dialog):
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         purchase = self.create_purchase_order()
 
         app = self.create_app(PurchaseApp, u'purchase')
-        for purchase in app.main_window.results:
+        for purchase in app.results:
             purchase.open_date = datetime.datetime(2012, 1, 1)
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
 
         with mock.patch('stoq.gui.purchase.api', new=self.fake.api):
             self.fake.set_retval(purchase)
-            self.activate(app.main_window.NewQuote)
+            self.activate(app.NewQuote)
 
             self.assertEquals(run_dialog.call_count, 1)
             args, kwargs = run_dialog.call_args
@@ -79,16 +80,16 @@ class TestPurchase(BaseGUITest):
 
     @mock.patch('stoq.gui.purchase.PurchaseApp.print_report')
     def test_print_report(self, print_report):
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         app = self.create_app(PurchaseApp, u'purchase')
 
-        self.activate(app.launcher.Print)
+        self.activate(app.window.Print)
         self.assertEquals(print_report.call_count, 1)
 
         args, kwargs = print_report.call_args
         report, results, views = args
         self.assertEquals(report, PurchaseReport)
-        self.assertTrue(isinstance(results, SearchResults))
+        self.assertTrue(isinstance(results, SearchResultListView))
         for view in views:
             self.assertTrue(isinstance(view, PurchaseOrderView))
 
@@ -98,23 +99,23 @@ class TestPurchase(BaseGUITest):
     def test_new_quote_order(self, new_store, run_dialog, select_result):
         new_store.return_value = self.store
 
-        self.clean_domain([ReceivingOrderItem, ReceivingOrder,
-                           PurchaseItem, PurchaseOrder])
+        self.clean_domain([ReceivingOrderItem, PurchaseReceivingMap,
+                           ReceivingOrder, PurchaseItem, PurchaseOrder])
 
         quotation = self.create_quotation()
         quotation.purchase.add_item(self.create_sellable(), 2)
         quotation.purchase.status = PurchaseOrder.ORDER_PENDING
 
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         app = self.create_app(PurchaseApp, u'purchase')
 
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
         self.store.retval = olist[0]
 
         with mock.patch.object(self.store, 'close'):
             with mock.patch.object(self.store, 'commit'):
-                self.activate(app.main_window.Edit)
+                self.activate(app.Edit)
                 run_dialog.assert_called_once_with(PurchaseWizard,
                                                    self.store,
                                                    quotation.purchase, False)
@@ -122,16 +123,16 @@ class TestPurchase(BaseGUITest):
 
     @mock.patch('stoq.gui.purchase.PurchaseApp.run_dialog')
     def test_details_dialog(self, run_dialog):
-        self.clean_domain([ReceivingOrderItem, ReceivingOrder,
-                           PurchaseItem, PurchaseOrder])
+        self.clean_domain([ReceivingOrderItem, PurchaseReceivingMap,
+                           ReceivingOrder, PurchaseItem, PurchaseOrder])
 
         purchase = self.create_purchase_order()
         purchase.add_item(self.create_sellable(), 2)
 
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         app = self.create_app(PurchaseApp, u'purchase')
 
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
         olist.double_click(0)
 
@@ -147,35 +148,36 @@ class TestPurchase(BaseGUITest):
     @mock.patch('stoq.gui.purchase.api.new_store')
     def test_confirm_order(self, new_store, yesno):
         new_store.return_value = self.store
-        yesno.return_value = False
+        yesno.return_value = True
 
-        self.clean_domain([ReceivingOrderItem, ReceivingOrder,
-                           PurchaseItem, PurchaseOrder])
+        self.clean_domain([ReceivingOrderItem, PurchaseReceivingMap,
+                           ReceivingOrder, PurchaseItem, PurchaseOrder])
 
         purchase = self.create_purchase_order()
         purchase.add_item(self.create_sellable(), 2)
         purchase.status = PurchaseOrder.ORDER_PENDING
 
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         app = self.create_app(PurchaseApp, u'purchase')
 
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
 
         with mock.patch.object(self.store, 'close'):
             with mock.patch.object(self.store, 'commit'):
-                self.activate(app.main_window.Confirm)
+                self.activate(app.Confirm)
                 yesno.assert_called_once_with(u'The selected order will be '
-                                              u'marked as sent.', gtk.RESPONSE_NO,
-                                              u"Don't confirm", u"Confirm order")
+                                              u'marked as sent.',
+                                              gtk.RESPONSE_YES,
+                                              u"Confirm order", u"Don't confirm")
                 self.assertEquals(purchase.status, PurchaseOrder.ORDER_CONFIRMED)
 
     @mock.patch('stoq.gui.purchase.PurchaseApp.run_dialog')
     @mock.patch('stoq.gui.purchase.api.new_store')
     def test_finish_order(self, new_store, run_dialog):
         new_store.return_value = self.store
-        self.clean_domain([ReceivingOrderItem, ReceivingOrder,
-                           PurchaseItem, PurchaseOrder])
+        self.clean_domain([ReceivingOrderItem, PurchaseReceivingMap,
+                           ReceivingOrder, PurchaseItem, PurchaseOrder])
 
         purchase = self.create_purchase_order()
         purchase.add_item(self.create_sellable(), 2)
@@ -183,15 +185,15 @@ class TestPurchase(BaseGUITest):
         purchase.status = PurchaseOrder.ORDER_CONFIRMED
         purchase.received_quantity = 2
 
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         app = self.create_app(PurchaseApp, u'purchase')
 
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
 
         with mock.patch.object(self.store, 'close'):
             with mock.patch.object(self.store, 'commit'):
-                self.activate(app.main_window.Finish)
+                self.activate(app.Finish)
                 run_dialog.assert_called_once_with(PurchaseFinishWizard,
                                                    self.store, purchase)
 
@@ -199,27 +201,27 @@ class TestPurchase(BaseGUITest):
     @mock.patch('stoq.gui.purchase.api.new_store')
     def test_cancel_order(self, new_store, yesno):
         new_store.return_value = self.store
-        yesno.return_value = False
+        yesno.return_value = True
 
-        self.clean_domain([ReceivingOrderItem, ReceivingOrder,
-                           PurchaseItem, PurchaseOrder])
+        self.clean_domain([ReceivingOrderItem, PurchaseReceivingMap,
+                           ReceivingOrder, PurchaseItem, PurchaseOrder])
 
         purchase = self.create_purchase_order()
         purchase.add_item(self.create_sellable(), 2)
         purchase.status = PurchaseOrder.ORDER_PENDING
 
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         app = self.create_app(PurchaseApp, u'purchase')
 
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
 
         with mock.patch.object(self.store, 'close'):
             with mock.patch.object(self.store, 'commit'):
-                self.activate(app.main_window.Cancel)
+                self.activate(app.Cancel)
                 yesno.assert_called_once_with(u'The selected order will be '
-                                              u'cancelled.', gtk.RESPONSE_NO,
-                                              u"Don't cancel", u"Cancel order")
+                                              u'cancelled.', gtk.RESPONSE_YES,
+                                              u"Cancel order", u"Don't cancel")
                 self.assertEquals(purchase.status, PurchaseOrder.ORDER_CANCELLED)
 
     @mock.patch('stoq.gui.purchase.PurchaseApp.run_dialog')
@@ -227,39 +229,39 @@ class TestPurchase(BaseGUITest):
     def test_new_product(self, new_store, run_dialog):
         new_store.return_value = self.store
 
-        self.clean_domain([ReceivingOrderItem, ReceivingOrder,
-                           PurchaseItem, PurchaseOrder])
+        self.clean_domain([ReceivingOrderItem, PurchaseReceivingMap,
+                           ReceivingOrder, PurchaseItem, PurchaseOrder])
 
         purchase = self.create_purchase_order()
         purchase.add_item(self.create_sellable(), 2)
         purchase.status = PurchaseOrder.ORDER_PENDING
 
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         app = self.create_app(PurchaseApp, u'purchase')
 
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
 
         with mock.patch.object(self.store, 'close'):
             with mock.patch.object(self.store, 'commit'):
-                self.activate(app.main_window.NewProduct)
-                run_dialog.assert_called_once_with(ProductEditor,
-                                                   self.store, model=None)
+                self.activate(app.NewProduct)
+                run_dialog.assert_called_once_with(ProductCreateWizard,
+                                                   self.store)
 
     @mock.patch('stoq.gui.purchase.PurchaseApp.run_dialog')
     def test_new_consignment(self, run_dialog):
-        api.sysparam(self.store).update_parameter(u'SMART_LIST_LOADING', u'0')
+        api.sysparam.set_bool(self.store, 'SMART_LIST_LOADING', False)
         purchase = self.create_purchase_order()
 
         app = self.create_app(PurchaseApp, u'purchase')
-        for purchase in app.main_window.results:
+        for purchase in app.results:
             purchase.open_date = datetime.datetime(2012, 1, 1)
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[0])
 
         with mock.patch('stoq.gui.purchase.api', new=self.fake.api):
             self.fake.set_retval(purchase)
-            self.activate(app.main_window.NewConsignment)
+            self.activate(app.NewConsignment)
 
             self.assertEquals(run_dialog.call_count, 1)
             args, kwargs = run_dialog.call_args
