@@ -22,12 +22,13 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
+import contextlib
 
 import mock
 from stoqlib.domain.account import Account
 from stoqlib.domain.payment.method import CheckData, PaymentMethod
 from stoqlib.domain.payment.payment import Payment
+from stoqlib.lib.dateutils import localdatetime, localtoday
 from stoqlib.gui.dialogs.paymentchangedialog import PaymentDueDateChangeDialog
 from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
 from stoqlib.gui.editors.paymenteditor import InPaymentEditor
@@ -43,29 +44,32 @@ from stoq.gui.test.baseguitest import BaseGUITest
 
 
 class TestReceivable(BaseGUITest):
-    @mock.patch('stoq.gui.receivable.run_dialog')
-    @mock.patch('stoq.gui.receivable.api.new_store')
-    def _check_run_dialog(self, app, action, dialog, new_store,
-                          run_dialog):
-        new_store.return_value = self.store
+    def _check_run_dialog(self, app, action, dialog):
+        with contextlib.nested(
+                mock.patch('stoq.gui.receivable.run_dialog'),
+                mock.patch('stoq.gui.receivable.api.new_store'),
+                mock.patch.object(self.store, 'commit'),
+                mock.patch.object(self.store, 'close')) as ctx:
+            new_store = ctx[1]
+            new_store.return_value = self.store
 
-        with mock.patch.object(self.store, 'commit'):
-            with mock.patch.object(self.store, 'close'):
-                self.activate(action)
-                self.assertEquals(run_dialog.call_count, 1)
-                args, kwargs = run_dialog.call_args
-                self.assertEquals(args[0], dialog)
-                self.assertEquals(args[1], app)
-                self.assertEquals(args[2], self.store)
+            self.activate(action)
+
+            run_dialog = ctx[0]
+            self.assertEquals(run_dialog.call_count, 1)
+            args, kwargs = run_dialog.call_args
+            self.assertEquals(args[0], dialog)
+            self.assertEquals(args[1], app)
+            self.assertEquals(args[2], self.store)
 
     def setUp(self):
         BaseGUITest.setUp(self)
 
-    def testInitial(self):
+    def test_initial(self):
         app = self.create_app(ReceivableApp, u'receivable')
         self.check_app(app, u'receivable')
 
-    def testInitialWithoutPayments(self):
+    def test_initial_without_payments(self):
         from stoqlib.domain.till import TillEntry
         from stoqlib.domain.commission import Commission
         from stoqlib.domain.account import AccountTransaction
@@ -80,36 +84,38 @@ class TestReceivable(BaseGUITest):
         app = self.create_app(ReceivableApp, u'receivable')
 
         # Note that set_message is always called twice (once from
-        # stoqlib.gui.base.search and later by stoq.gui.application), so we
-        # cannot use assert_called_once_with
+        # stoqlib.gui.search.search{editor,dialog,slave} and later by
+        # stoq.gui.application), so we cannot use assert_called_once_with
         set_message = mock.MagicMock()
-        app.main_window.search.set_message = set_message
+        app.search.set_message = set_message
 
-        app.main_window.main_filter.set_state(None)
-        app.main_window.search.refresh()
-        set_message.assert_called_with('No payments found.\n\nWould you '
-                'like to <a href="new_payment">create a new payment</a>?')
+        app.main_filter.set_state(None)
+        app.search.refresh()
+        set_message.assert_called_with(
+            'No payments found.\n\nWould you '
+            'like to <a href="new_payment">create a new payment</a>?')
 
         set_message.reset_mock()
-        app.main_window.main_filter.set_state(None, 'Received payments')
+        app.main_filter.set_state(None, 'Received payments')
         set_message.assert_called_with('No paid payments found.')
 
         set_message.reset_mock()
-        app.main_window.main_filter.set_state(None, 'To receive')
+        app.main_filter.set_state(None, 'To receive')
         set_message.assert_called_with('No payments to receive found.')
 
         set_message.reset_mock()
-        app.main_window.main_filter.set_state(None, 'Late payments')
+        app.main_filter.set_state(None, 'Late payments')
         set_message.assert_called_with('No late payments found.')
 
         set_message.reset_mock()
-        app.main_window.main_filter.set_state(None, category.id)
-        set_message.assert_called_with('No payments in the <b>Sample '
-         'category</b> category were found.\n\nWould you like to <a '
-         'href="new_payment?Sample%20category">create a new payment</a>?')
+        app.main_filter.set_state(None, category.id)
+        set_message.assert_called_with(
+            'No payments in the <b>Sample '
+            'category</b> category were found.\n\nWould you like to <a '
+            'href="new_payment?Sample%20category">create a new payment</a>?')
 
         # Reset the state to None, since thats the expected by the other tests
-        app.main_window.main_filter.set_state(None)
+        app.main_filter.set_state(None)
 
     def create_receivable_sale(self):
         sale = self.create_sale()
@@ -119,111 +125,111 @@ class TestReceivable(BaseGUITest):
         payment = self.add_payments(sale, method_type=u'bill')[0]
         payment.identifier = 67890
         sale.confirm()
-        payment.due_date = datetime.datetime(2012, 1, 1)
-        #payment.paid_date = datetime.datetime(2012, 2, 2)
+        payment.due_date = localdatetime(2012, 1, 1)
+        # payment.paid_date = datetime.datetime(2012, 2, 2)
         return sale, payment
 
-    def testSelect(self):
+    def test_select(self):
         sale, payment = self.create_receivable_sale()
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[1])
         self.check_app(app, u'receivable-selected')
 
     @mock.patch('stoq.gui.receivable.run_dialog')
-    def testReceive(self, run_dialog):
+    def test_receive(self, run_dialog):
         sale, payment = self.create_receivable_sale()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[3])
         assert olist[3].payment == payment
 
         with mock.patch('stoq.gui.receivable.api', new=self.fake.api):
-            self.activate(app.main_window.Receive)
+            self.activate(app.Receive)
 
     @mock.patch('stoq.gui.receivable.run_dialog')
-    def testEdit(self, run_dialog):
+    def test_edit(self, run_dialog):
         sale, payment = self.create_receivable_sale()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[3])
 
         with mock.patch('stoq.gui.receivable.api', new=self.fake.api):
-            self.activate(app.main_window.Edit)
+            self.activate(app.Edit)
 
         run_dialog.assert_called_once_with(
-            SalePaymentsEditor, app.main_window,
+            SalePaymentsEditor, app,
             self.store.readonly, sale)
 
     @mock.patch('stoq.gui.accounts.run_dialog')
-    def testChangeDueDate(self, run_dialog):
+    def test_change_due_date_dialog(self, run_dialog):
         sale, payment = self.create_receivable_sale()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[3])
 
         with mock.patch('stoq.gui.accounts.api', new=self.fake.api):
-            self.activate(app.main_window.ChangeDueDate)
+            self.activate(app.ChangeDueDate)
 
         run_dialog.assert_called_once_with(
-            PaymentDueDateChangeDialog, app.main_window,
+            PaymentDueDateChangeDialog, app,
             self.store.readonly, payment, sale)
 
     @mock.patch('stoq.gui.accounts.run_dialog')
-    def testDetails(self, run_dialog):
+    def test_details(self, run_dialog):
         sale, payment = self.create_receivable_sale()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[3])
 
         with mock.patch('stoq.gui.accounts.api', new=self.fake.api):
-            self.activate(app.main_window.Details)
+            self.activate(app.Details)
 
         run_dialog.assert_called_once_with(
-            InPaymentEditor, app.main_window,
+            InPaymentEditor, app,
             self.store.readonly, payment)
 
     @mock.patch('stoq.gui.accounts.run_dialog')
-    def testComments(self, run_dialog):
+    def test_comments(self, run_dialog):
         sale, payment = self.create_receivable_sale()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[3])
 
         with mock.patch('stoq.gui.accounts.api', new=self.fake.api):
-            self.activate(app.main_window.Comments)
+            self.activate(app.Comments)
         run_dialog.assert_called_once_with(
-            PaymentCommentsDialog, app.main_window,
+            PaymentCommentsDialog, app,
             self.store.readonly, payment)
 
     @mock.patch('stoq.gui.receivable.run_dialog')
-    def testRenegotiate(self, run_dialog):
+    def test_renegotiate(self, run_dialog):
         sale, payment = self.create_receivable_sale()
         sale.client = self.create_client()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[3])
 
         with mock.patch('stoq.gui.receivable.api', new=self.fake.api):
-            self.activate(app.main_window.Renegotiate)
+            self.activate(app.Renegotiate)
 
         run_dialog.assert_called_once_with(
-            PaymentRenegotiationWizard, app.main_window,
+            PaymentRenegotiationWizard, app,
             self.store.readonly, [payment.group])
 
     @mock.patch('stoq.gui.receivable.print_report')
-    def testPrintDocument(self, print_report):
+    def test_print_document(self, print_report):
         sale, payment = self.create_receivable_sale()
         sale.client = self.create_client()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[3])
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
@@ -231,7 +237,7 @@ class TestReceivable(BaseGUITest):
         method.destination_account = account
 
         with mock.patch('stoq.gui.receivable.api', new=self.fake.api):
-            self.activate(app.main_window.PrintDocument)
+            self.activate(app.PrintDocument)
 
         print_report.assert_called_once_with(BillReport, [payment])
 
@@ -242,24 +248,24 @@ class TestReceivable(BaseGUITest):
 
         app = self.create_app(ReceivableApp, u'receivable')
 
-        olist = app.main_window.results
+        olist = app.results
         payments = list(olist)[-2:]
 
         for payment in payments:
             payment.status = Payment.STATUS_PENDING
-        self.assertTrue(app.main_window._can_receive(payments))
+        self.assertTrue(app._can_receive(payments))
 
     def test_can_renegotiate(self):
         app = self.create_app(ReceivableApp, u'receivable')
-        self.assertFalse(app.main_window._can_renegotiate([]))
+        self.assertFalse(app._can_renegotiate([]))
 
     def test_run_dialogs(self):
         app = self.create_app(ReceivableApp, u'receivable')
-        self._check_run_dialog(app.main_window,
-                               app.main_window.CardPaymentSearch,
+        self._check_run_dialog(app,
+                               app.CardPaymentSearch,
                                CardPaymentSearch)
-        self._check_run_dialog(app.main_window,
-                               app.main_window.BillCheckSearch,
+        self._check_run_dialog(app,
+                               app.BillCheckSearch,
                                InPaymentBillCheckSearch)
 
     @mock.patch('stoq.gui.receivable.print_report')
@@ -268,12 +274,12 @@ class TestReceivable(BaseGUITest):
         payment.pay()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.PrintReceipt)
+        self.activate(app.PrintReceipt)
         print_report.assert_called_once_with(InPaymentReceipt, payment=payment,
-                                             order=sale, date=datetime.date.today())
+                                             order=sale, date=localtoday().date())
 
     @mock.patch('stoq.gui.receivable.ReceivableApp.change_status')
     def test_cancel_payment(self, change_status):
@@ -282,10 +288,10 @@ class TestReceivable(BaseGUITest):
         payment.payment_type = Payment.TYPE_IN
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.CancelPayment)
+        self.activate(app.CancelPayment)
         change_status.assert_called_once_with(olist[-1], None,
                                               Payment.STATUS_CANCELLED)
 
@@ -295,10 +301,10 @@ class TestReceivable(BaseGUITest):
         payment.pay()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.SetNotPaid)
+        self.activate(app.SetNotPaid)
         change_status.assert_called_once_with(olist[-1], sale,
                                               Payment.STATUS_PENDING)
 
@@ -307,8 +313,8 @@ class TestReceivable(BaseGUITest):
         sale, payment = self.create_receivable_sale()
 
         app = self.create_app(ReceivableApp, u'receivable')
-        olist = app.main_window.results
+        olist = app.results
         olist.select(olist[-1])
 
-        self.activate(app.main_window.ChangeDueDate)
+        self.activate(app.ChangeDueDate)
         change_due_date.assert_called_once_with(olist[-1], sale)
