@@ -22,6 +22,8 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+import contextlib
+
 import mock
 
 from stoqlib.database.runtime import StoqlibStore
@@ -46,44 +48,47 @@ from stoq.gui.test.baseguitest import BaseGUITest
 
 
 class TestStock(BaseGUITest):
-    @mock.patch('stoq.gui.stock.StockApp.run_dialog')
-    @mock.patch('stoq.gui.stock.api.new_store')
-    def _check_run_dialog(self, action, dialog, other_args, new_store,
-                          run_dialog):
-        new_store.return_value = self.store
+    def _check_run_dialog(self, action, dialog, other_args):
+        with contextlib.nested(
+                mock.patch.object(self.store, 'commit'),
+                mock.patch.object(self.store, 'close'),
+                mock.patch('stoq.gui.stock.StockApp.run_dialog'),
+                mock.patch('stoq.gui.stock.api.new_store')) as ctx:
+            new_store = ctx[3]
+            new_store.return_value = self.store
 
-        with mock.patch.object(self.store, 'commit'):
-            with mock.patch.object(self.store, 'close'):
-                self.activate(action)
-                self.assertEquals(run_dialog.call_count, 1)
-                args, kwargs = run_dialog.call_args
-                self.assertEquals(args[0], dialog)
-                self.assertEquals(args[1], self.store)
+            self.activate(action)
 
-                if not other_args or len(other_args) != len(args[2:]):
-                    return
+            run_dialog = ctx[2]
+            self.assertEquals(run_dialog.call_count, 1)
+            args, kwargs = run_dialog.call_args
+            self.assertEquals(args[0], dialog)
+            self.assertEquals(args[1], self.store)
 
-                for arg in args[2:]:
-                    for other_arg in other_args:
-                        self.assertEquals(arg, other_arg)
+            if not other_args or len(other_args) != len(args[2:]):
+                return
 
-    def testInitial(self):
+            for arg in args[2:]:
+                for other_arg in other_args:
+                    self.assertEquals(arg, other_arg)
+
+    def test_initial(self):
         app = self.create_app(StockApp, u'stock')
         self.check_app(app, u'stock')
 
-    def testSelect(self):
+    def test_select(self):
         app = self.create_app(StockApp, u'stock')
-        results = app.main_window.results
+        results = app.results
         results.select(results[1])
 
     @mock.patch('stoq.gui.stock.StockApp.run_dialog')
     def test_product_stock_history(self, run_dialog):
         app = self.create_app(StockApp, u'stock')
 
-        results = app.main_window.results
+        results = app.results
         results.select(results[0])
 
-        self.activate(app.main_window.ProductStockHistory)
+        self.activate(app.ProductStockHistory)
         self.assertEquals(run_dialog.call_count, 1)
         args, kwargs = run_dialog.call_args
         dialog, store, sellable = args
@@ -94,39 +99,38 @@ class TestStock(BaseGUITest):
     def test_actions(self):
         app = self.create_app(StockApp, u'stock')
 
-        results = app.main_window.results
+        results = app.results
         results.select(results[0])
 
-        self._check_run_dialog(app.main_window.EditProduct,
+        self._check_run_dialog(app.EditProduct,
                                ProductStockEditor, [results[0].product])
-        self._check_run_dialog(app.main_window.NewStockDecrease,
+        self._check_run_dialog(app.NewStockDecrease,
                                StockDecreaseWizard, [])
-        branch = app.main_window.branch_filter.get_state().value
-        self._check_run_dialog(app.main_window.StockInitial,
-                               InitialStockDialog, [branch])
-        self._check_run_dialog(app.main_window.LoanNew,
+        self._check_run_dialog(app.StockInitial,
+                               InitialStockDialog, [])
+        self._check_run_dialog(app.LoanNew,
                                NewLoanWizard, [])
-        self._check_run_dialog(app.main_window.LoanClose,
+        self._check_run_dialog(app.LoanClose,
                                CloseLoanWizard, [])
-        self._check_run_dialog(app.main_window.LoanSearch,
+        self._check_run_dialog(app.LoanSearch,
                                LoanSearch, [])
-        self._check_run_dialog(app.main_window.LoanSearchItems,
+        self._check_run_dialog(app.LoanSearchItems,
                                LoanItemSearch, [])
-        self._check_run_dialog(app.main_window.SearchPurchaseReceiving,
+        self._check_run_dialog(app.SearchPurchaseReceiving,
                                PurchaseReceivingSearch, [])
-        self._check_run_dialog(app.main_window.SearchTransfer,
+        self._check_run_dialog(app.SearchTransfer,
                                TransferOrderSearch, [])
-        self._check_run_dialog(app.main_window.SearchPurchasedStockItems,
+        self._check_run_dialog(app.SearchPurchasedStockItems,
                                PurchasedItemsSearch, [])
-        self._check_run_dialog(app.main_window.SearchStockItems,
+        self._check_run_dialog(app.SearchStockItems,
                                ProductStockSearch, [])
-        self._check_run_dialog(app.main_window.SearchClosedStockItems,
+        self._check_run_dialog(app.SearchClosedStockItems,
                                ProductClosedStockSearch, [])
-        self._check_run_dialog(app.main_window.SearchProductHistory,
+        self._check_run_dialog(app.SearchProductHistory,
                                ProductSearchQuantity, [])
-        self._check_run_dialog(app.main_window.SearchStockDecrease,
+        self._check_run_dialog(app.SearchStockDecrease,
                                StockDecreaseSearch, [])
-        self._check_run_dialog(app.main_window.NewTransfer,
+        self._check_run_dialog(app.NewTransfer,
                                StockTransferWizard, [])
-        self._check_run_dialog(app.main_window.NewReceiving,
+        self._check_run_dialog(app.NewReceiving,
                                ReceivingOrderWizard, [])
