@@ -25,57 +25,66 @@
 
 import decimal
 from datetime import date
+import logging
 
 import pango
 import gtk
 from kiwi.currency import currency
 from kiwi.datatypes import converter
-from kiwi.log import Logger
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import Column, SearchColumn
+from kiwi.ui.objectlist import Column
 from storm.expr import And, Or
-
 from stoqlib.api import api
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.exceptions import (StoqlibError, TillError, SellError,
                                 ModelDataError)
 from stoqlib.database.expr import Date
 from stoqlib.domain.sale import Sale, SaleView
 from stoqlib.domain.till import Till
+from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.workorder import WorkOrder
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.message import yesno, warning
+from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.dialogs.tillhistory import TillHistoryDialog
+from stoqlib.gui.dialogs.daterangedialog import DateRangeDialog
+from stoqlib.gui.dialogs.missingitemsdialog import (MissingItemsDialog,
+                                                    get_missing_items)
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
-from stoqlib.gui.dialogs.quotedialog import ConfirmSaleMissingDialog
+from stoqlib.gui.dialogs.tillhistory import TillHistoryDialog
+from stoqlib.gui.editors.paymentseditor import SalePaymentsEditor
 from stoqlib.gui.editors.tilleditor import CashInEditor, CashOutEditor
 from stoqlib.gui.fiscalprinter import FiscalPrinterHelper
-from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.search.paymentsearch import CardPaymentSearch
 from stoqlib.gui.search.paymentreceivingsearch import PaymentReceivingSearch
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.salesearch import (SaleWithToolbarSearch,
                                            SoldItemsByBranchSearch)
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
 from stoqlib.gui.search.tillsearch import TillFiscalOperationsSearch
 from stoqlib.gui.slaves.saleslave import return_sale
+from stoqlib.gui.utils.keybindings import get_accels
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.reporting.sale import SalesReport
+from stoqlib.reporting.till import TillDailyMovementReport
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.shell.shellapp import ShellApp
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 LOGO_WIDTH = 91
 LOGO_HEIGHT = 32
 
 
-class TillApp(SearchableAppWindow):
+class TillApp(ShellApp):
 
-    app_name = _(u'Till')
+    app_title = _(u'Till')
     gladefile = 'till'
-    search_table = SaleView
+    search_spec = SaleView
     search_labels = _(u'matching:')
     report_table = SalesReport
-    embedded = True
 
     #
     # Application
@@ -91,6 +100,8 @@ class TillApp(SearchableAppWindow):
              group.get('close_till')),
             ('TillVerify', None, _('Verify till...'),
              group.get('verify_till')),
+            ("TillDailyMovement", None, _("Till daily movement..."),
+             group.get('daily_movement')),
             ('TillAddCash', None, _('Cash addition...'), ''),
             ('TillRemoveCash', None, _('Cash removal...'), ''),
             ("PaymentReceive", None, _("Payment receival..."),
@@ -102,6 +113,8 @@ class TillApp(SearchableAppWindow):
             ("SearchSale", None, _("Sales..."),
              group.get('search_sale'),
              _("Search for sales")),
+            ("SearchCardPayment", None, _("Card payments..."),
+             None, _("Search for card payments")),
             ("SearchSoldItemsByBranch", None, _("Sold items by branch..."),
              group.get('search_sold_items_by_branch'),
              _("Search for items sold by branch")),
@@ -149,17 +162,18 @@ class TillApp(SearchableAppWindow):
         self._setup_widgets()
 
     def get_title(self):
-        return _('Stoq - Till for Branch %03d') % (
-            api.get_current_branch(self.store).id, )
+        return _('[%s] - Till') % (
+            api.get_current_branch(self.store).get_description(), )
 
-    def activate(self, params):
-        self.app.launcher.add_new_items([self.TillAddCash,
-                                         self.TillRemoveCash])
-        self.app.launcher.add_search_items([self.SearchFiscalTillOperations,
-                                            self.SearchClient,
-                                            self.SearchSale])
-        self.app.launcher.Print.set_tooltip(_("Print a report of these sales"))
-        self.refresh()
+    def activate(self, refresh=True):
+        self.window.add_new_items([self.TillAddCash,
+                                   self.TillRemoveCash])
+        self.window.add_search_items([self.SearchFiscalTillOperations,
+                                      self.SearchClient,
+                                      self.SearchSale])
+        self.window.Print.set_tooltip(_("Print a report of these sales"))
+        if refresh:
+            self.refresh()
         self._printer.run_initial_checks()
         self.check_open_inventory()
 
@@ -175,27 +189,26 @@ class TillApp(SearchableAppWindow):
         self._run_search_dialog(TillFiscalOperationsSearch)
 
     #
-    # SearchableAppWindow
+    # ShellApp
     #
 
     def set_open_inventory(self):
         self.set_sensitive(self._inventory_widgets, False)
 
     def create_filters(self):
-        self.executer.set_query(self._query_executer)
-        self.set_text_field_columns(['client_name', 'salesperson_name'])
+        self.search.set_query(self._query_executer)
+        self.set_text_field_columns(['client_name', 'salesperson_name',
+                                     'identifier_str'])
         self.status_filter = ComboSearchFilter(_(u"Show orders"),
                                                self._get_status_values())
-        self.status_filter.select(Sale.STATUS_CONFIRMED)
         self.add_filter(self.status_filter, position=SearchFilterPosition.TOP,
                         columns=['status'])
 
     def get_columns(self):
-        return [SearchColumn('identifier', title=_('#'), width=60,
-                             long_title=_('Order number'),
-                             data_type=int, format='%05d', sorted=True),
+        return [IdentifierColumn('identifier', long_title=_('Order #'),
+                                 sorted=True),
                 Column('status_name', title=_(u'Status'), data_type=str,
-                        visible=False),
+                       visible=True),
                 SearchColumn('open_date', title=_('Date Started'), width=110,
                              data_type=date, justify=gtk.JUSTIFY_RIGHT),
                 SearchColumn('client_name', title=_('Client'),
@@ -222,11 +235,11 @@ class TillApp(SearchableAppWindow):
         # 3) For the order statuses, the date should be the same as today
 
         query = And(Sale.branch == self.current_branch,
-                 Or(Sale.status == Sale.STATUS_QUOTE,
-                    Sale.status == Sale.STATUS_ORDERED,
-                    Date(Sale.open_date) == date.today()))
+                    Or(Sale.status == Sale.STATUS_QUOTE,
+                       Sale.status == Sale.STATUS_ORDERED,
+                       Date(Sale.open_date) == date.today()))
 
-        return store.find(self.search_table, query)
+        return store.find(self.search_spec, query)
 
     def _setup_printer(self):
         self._printer = FiscalPrinterHelper(self.store,
@@ -242,13 +255,25 @@ class TillApp(SearchableAppWindow):
         statuses.insert(0, (_('Any'), None))
         return statuses
 
-    def _confirm_order(self):
+    def _create_sale_payments(self, order_view):
+        store = api.new_store()
+        sale = store.fetch(order_view.sale)
+        retval = run_dialog(SalePaymentsEditor, self, store, sale)
+
+        # Change the sale status to ORDERED
+        if retval and sale.can_order():
+            sale.order()
+
+        if store.confirm(retval):
+            self.refresh()
+        store.close()
+
+    def _confirm_order(self, order_view):
         if self.check_open_inventory():
             return
 
         store = api.new_store()
-        selected = self.results.get_selected()
-        sale = store.fetch(selected.sale)
+        sale = store.fetch(order_view.sale)
         expire_date = sale.expire_date
 
         if (sale.status == Sale.STATUS_QUOTE and
@@ -259,10 +284,10 @@ class TillApp(SearchableAppWindow):
             store.close()
             return
 
-        missing = sale.get_missing_items()
+        missing = get_missing_items(sale, store)
 
         if missing:
-            retval = run_dialog(ConfirmSaleMissingDialog, self, sale, missing)
+            retval = run_dialog(MissingItemsDialog, self, sale, missing)
             if retval:
                 self.refresh()
             store.close()
@@ -275,6 +300,9 @@ class TillApp(SearchableAppWindow):
         subtotal = self._add_sale_items(sale, coupon)
         try:
             if coupon.confirm(sale, store, subtotal=subtotal):
+                workorders = WorkOrder.find_by_sale(store, sale)
+                for order in workorders:
+                    order.close()
                 store.commit()
                 self.refresh()
             else:
@@ -311,6 +339,17 @@ class TillApp(SearchableAppWindow):
         text = _(u"Total: %s") % converter.as_string(currency, balance)
         self.total_label.set_text(text)
 
+    def _update_payment_total(self):
+        balance = currency(self._get_total_paid_payment())
+        text = _(u"Total payments: %s") % converter.as_string(currency, balance)
+        self.total_payment_label.set_text(text)
+
+    def _get_total_paid_payment(self):
+        """Returns the total of payments of the day"""
+        payments = self.store.find(Payment,
+                                   Date(Payment.paid_date) == localtoday())
+        return payments.sum(Payment.paid_value) or 0
+
     def _get_till_balance(self):
         """Returns the balance of till operations"""
         try:
@@ -332,6 +371,12 @@ class TillApp(SearchableAppWindow):
 
         self.total_label.set_size('xx-large')
         self.total_label.set_bold(True)
+        if not sysparam.get_bool('SHOW_TOTAL_PAYMENTS_ON_TILL'):
+            self.total_payment_label.hide()
+        else:
+            self.total_payment_label.set_size('large')
+            self.total_payment_label.set_bold(True)
+            self.total_label.set_size('large')
 
         self.till_status_label.set_size('xx-large')
         self.till_status_label.set_bold(True)
@@ -368,7 +413,7 @@ class TillApp(SearchableAppWindow):
         run_dialog(SaleDetailsDialog, self, self.store, sale_view)
 
     def _run_add_cash_dialog(self):
-        with api.trans() as store:
+        with api.new_store() as store:
             try:
                 run_dialog(CashInEditor, self, store)
             except TillError as err:
@@ -385,7 +430,7 @@ class TillApp(SearchableAppWindow):
 
         sale_view = self._check_selected()
 
-        with api.trans() as store:
+        with api.new_store() as store:
             return_sale(self.get_toplevel(), store.fetch(sale_view.sale), store)
 
         if store.committed:
@@ -434,13 +479,23 @@ class TillApp(SearchableAppWindow):
 
         self._update_toolbar_buttons()
         self._update_total()
+        if sysparam.get_bool('SHOW_TOTAL_PAYMENTS_ON_TILL'):
+            self._update_payment_total()
 
     #
     # Callbacks
     #
 
     def on_Confirm__activate(self, action):
-        self._confirm_order()
+        selected = self.results.get_selected()
+
+        # If there are unfinished workorders associated with the sale, we
+        # cannot print the coupon yet. Instead lets just create the payments.
+        workorders = WorkOrder.find_by_sale(self.store, selected.sale)
+        if not all(wo.can_close() for wo in workorders):
+            self._create_sale_payments(selected)
+        else:
+            self._confirm_order(selected)
         self._update_total()
 
     def on_results__double_click(self, results, sale):
@@ -485,11 +540,19 @@ class TillApp(SearchableAppWindow):
         self._run_add_cash_dialog()
 
     def on_TillRemoveCash__activate(self, action):
-        with api.trans() as store:
+        with api.new_store() as store:
             run_dialog(CashOutEditor, self, store)
         if store.committed:
             self._update_total()
 
+    def on_TillDailyMovement__activate(self, button):
+        date_range = self.run_dialog(DateRangeDialog)
+        if not date_range:
+            return
+
+        print_report(TillDailyMovementReport, self.store,
+                     start_date=date_range.start, end_date=date_range.end)
+
     # Search
 
     def on_SearchClient__activate(self, action):
@@ -502,6 +565,9 @@ class TillApp(SearchableAppWindow):
         self._run_search_dialog(SaleWithToolbarSearch)
         self.refresh()
 
+    def on_SearchCardPayment__activate(self, action):
+        self.run_dialog(CardPaymentSearch, self.store)
+
     def on_SearchSoldItemsByBranch__activate(self, button):
         self._run_search_dialog(SoldItemsByBranchSearch)
 
