@@ -38,20 +38,20 @@ from stoqlib.lib.translation import stoqlib_gettext as _
 DATEUTIL_REQUIRED = (1, 4, 1)
 GTK_REQUIRED = (2, 20, 0)
 GUDEV_REQUIRED = (147, )
-KIWI_REQUIRED = (1, 9, 38)
+KIWI_REQUIRED = (1, 9, 39, 2)
 MAKO_REQUIRED = (0, 2, 5)
 PIL_REQUIRED = (1, 1, 5)
 PYCAIRO_REQUIRED = (1, 8, 2)
 PYPOPPLER_REQUIRED = (0, 12, 1)
 PSQL_REQUIRED = (8, 4)
-PSYCOPG_REQUIRED = (2, 0, 5)
+PSYCOPG_REQUIRED = (2, 0, 9)
 PYGTK_REQUIRED = (2, 20, 0)
 PYGTKWEBKIT_REQUIRED = (1, 1, 7)
 PYOBJC_REQUIRED = (2, 3)
 PYSERIAL_REQUIRED = (2, 1)
 REPORTLAB_REQUIRED = (2, 4)
 STORM_REQUIRED = (0, 19)
-STOQDRIVERS_REQUIRED = (0, 9, 19)
+STOQDRIVERS_REQUIRED = (0, 9, 21)
 TWISTED_CORE_REQUIRED = (10, 0)
 TWISTED_WEB_REQUIRED = (10, 0)
 WEASYPRINT_REQUIRED = (0, 15)
@@ -123,28 +123,29 @@ class DependencyChecker(object):
         raise SystemExit
 
     def _missing(self, project, url=None, version=None):
-        msg = _("""<b>%s</b> could not be found on your system.
-%s %s or higher is required for Stoq to run.
-
-You can find a recent version of %s on it's homepage at\n%s""") % (
+        msg = _("<b>%s</b> could not be found on your system.\n"
+                "%s %s or higher is required for Stoq to run.\n\n"
+                "You can find a recent version of %s on it's homepage at\n%s") % (
             project, project, _tuple2str(version),
             project, url)
 
         self._error(_("Missing dependency"), msg)
 
     def _too_old(self, project, url=None, required=None, found=None):
-        msg = _("""<b>%s</b> was found on your system, but it is too old for Stoq to be able to run. %s %s was found, but %s is required.
-
-You can find a recent version of %s on it's homepage at\n%s""") % (
+        msg = _("<b>%s</b> was found on your system, but it is\n"
+                "too old for Stoq to be able to run. %s %s was found, "
+                "but %s is required.\n\n"
+                "You can find a recent version of %s on it's homepage at\n%s") % (
             project, project, found, _tuple2str(required),
             project, url)
 
         self._error(_("Out-dated dependency"), msg)
 
     def _incompatible(self, project, url=None, required=None, found=None):
-        msg = _("""<b>%s</b> was found on your system, but its version, %s incompatible with Stoq, you need to downgrade to %s for Stoq to work.
-
-You can find an older version of %s on it's homepage at\n%s""") % (
+        msg = _("<b>%s</b> was found on your system, but its version,\n"
+                "%s incompatible with Stoq, you need to downgrade to %s "
+                "for Stoq to work.\n\n"
+                "You can find an older version of %s on it's homepage at\n%s") % (
             project, found, _tuple2str(required),
             project, url)
 
@@ -153,7 +154,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_pygtk(self, pygtk_version, gtk_version):
         try:
             import gtk
-            gtk # stuid pyflakes
+            gtk  # pylint: disable=W0104
         except ImportError:
             try:
                 import pygtk
@@ -161,7 +162,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                 pygtk.require('2.0')
                 # Try again now when pygtk is imported
                 import gtk
-            except ImportError, e:
+            except ImportError as e:
                 # Can't display a dialog here since gtk is not available
                 raise SystemExit(
                     "ERROR: PyGTK not found, can't start Stoq: %r" % (e, ))
@@ -228,7 +229,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_pygtkwebkit(self, version):
         try:
             import webkit
-            webkit # pyflakes
+            webkit  # pylint: disable=W0104
         except ImportError:
             self._missing(project='pywebkitgtk',
                           url='http://code.google.com/p/pywebkitgtk/',
@@ -237,7 +238,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_zope_interface(self, version):
         try:
             import zope.interface
-            zope # pyflakes
+            zope  # pylint: disable=W0104
         except ImportError:
             self._missing(project='ZopeInterface',
                           url='http://www.zope.org/Products/ZopeInterface',
@@ -318,7 +319,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                           version=version)
             return
 
-        if map(int, PIL.Image.VERSION.split('.')) < list(version):
+        if list(map(int, PIL.Image.VERSION.split('.'))) < list(version):
             self._too_old(project='Python Imaging Library (PIL)',
                           url='http://www.pythonware.com/products/pil/',
                           required=version,
@@ -333,7 +334,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                           version=version)
             return
 
-        rl_version = map(int, reportlab.Version.split('.'))
+        rl_version = list(map(int, reportlab.Version.split('.')))
         if rl_version < list(version):
             self._too_old(project="Reportlab",
                           url='http://www.reportlab.org/',
@@ -350,7 +351,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
             return
 
         if (not hasattr(dateutil, "__version__") or
-            map(int, dateutil.__version__.split('.')) < list(version)):
+            list(map(int, dateutil.__version__.split('.'))) < list(version)):
             self._too_old(project="Dateutil",
                           url='http://labix.org/python-dateutil/',
                           required=version,
@@ -365,7 +366,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                           version=version)
             return
 
-        if map(int, mako.__version__.split('.')) < list(version):
+        if list(map(int, mako.__version__.split('.'))) < list(version):
             self._too_old(project="Mako",
                           url='http://www.makotemplates.org/',
                           required=version,
@@ -374,7 +375,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_pyserial(self, version):
         try:
             import serial
-            serial # pyflakes
+            serial  # pylint: disable=W0104
         except ImportError:
             self._missing(project='pySerial',
                           url='http://pyserial.sourceforge.net/',
@@ -383,14 +384,14 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_twisted_core(self, version):
         try:
             import twisted
-            twisted # pyflakes
+            twisted  # pylint: disable=W0104
         except ImportError:
             self._missing(project='TwistedCore',
                           url='http://twistedmatrix.com/',
                           version=version)
             return
 
-        if map(int, twisted.version.base().split('.')) < list(version):
+        if list(map(int, twisted.version.base().split('.'))) < list(version):
             self._too_old(project="TwistedCore",
                           url='http://www.twistedmatrix.com/',
                           required=version,
@@ -405,7 +406,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                           version=version)
             return
 
-        if map(int, twisted.web.version.base().split('.')) < list(version):
+        if list(map(int, twisted.web.version.base().split('.'))) < list(version):
             self._too_old(project="TwistedWeb",
                           url='http://www.twistedmatrix.com/',
                           required=version,
@@ -414,14 +415,14 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_weasyprint(self, version):
         try:
             import weasyprint
-            weasyprint # pyflakes
+            weasyprint  # pylint: disable=W0104
         except ImportError:
             self._missing(project='weasyprint',
                           url='http://weasyprint.org/',
                           version=version)
             return
 
-        if map(int, weasyprint.VERSION.split('.')) < list(version):
+        if list(map(int, weasyprint.VERSION.split('.'))) < list(version):
             self._too_old(project="weasyprint",
                           url='http://weasyprint.org/',
                           required=version,
@@ -430,14 +431,14 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_xlwt(self, version):
         try:
             import xlwt
-            xlwt # pyflakes
+            xlwt  # pylint: disable=W0104
         except ImportError:
             self._missing(project='xlwt',
                           url='http://www.python-excel.org/',
                           version=version)
             return
 
-        if map(int, xlwt.__VERSION__.split('.')) < list(version):
+        if list(map(int, xlwt.__VERSION__.split('.'))) < list(version):
             self._too_old(project="xlwt",
                           url='http://www.python-excel.org/',
                           required=version,
@@ -446,14 +447,14 @@ You can find an older version of %s on it's homepage at\n%s""") % (
     def _check_pyobjc(self, version):
         try:
             import objc
-            objc # pyflakes
+            objc  # pylint: disable=W0104
         except ImportError:
             self._missing(project='pyobjc',
                           url='http://pyobjc.sf.net/',
                           version=version)
             return
 
-        if map(int, objc.__version__.split('.')) < list(version):
+        if list(map(int, objc.__version__.split('.'))) < list(version):
             self._too_old(project="pyobjc",
                           url='http://pyobjc.sf.net/',
                           required=version,
@@ -461,7 +462,7 @@ You can find an older version of %s on it's homepage at\n%s""") % (
 
         try:
             import AppKit
-            AppKit # pyflakes
+            AppKit  # pylint: disable=W0104
         except ImportError:
             self._missing(project='pyobjc with cocoa support',
                           url='http://pyobjc.sf.net/',
