@@ -25,25 +25,25 @@
 ##
 """ Database startup routines"""
 
+import logging
 import os
 import sys
 
 from kiwi.component import provide_utility
-from kiwi.log import Logger
 from stoqlib.database.migration import StoqlibSchemaMigration
 from stoqlib.database.debug import enable as enable_debugging
 from stoqlib.database.runtime import (get_default_store,
                                       set_current_branch_station)
 from stoqlib.exceptions import DatabaseError
 from stoqlib.lib.configparser import register_config, StoqConfig
-from stoqlib.lib.interfaces import  IApplicationDescriptions
+from stoqlib.lib.interfaces import IApplicationDescriptions
 from stoqlib.lib.message import error
 from stoqlib.lib.osutils import read_registry_key
 from stoqlib.lib.translation import stoqlib_gettext as _
 
 from stoq.lib.options import get_option_parser
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 def setup_path():
@@ -119,7 +119,7 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
     if register_station:
         try:
             default_store = get_default_store()
-        except DatabaseError, e:
+        except DatabaseError as e:
             error(e.short, str(e.msg))
 
         config.get_settings().check_version(default_store)
