@@ -37,11 +37,15 @@ def get_shell(args):
     parser = get_option_parser()
 
     group = optparse.OptionGroup(parser, 'Stoq')
-    group.add_option('', '--wizard',
+    group.add_option('-A', '--autoreload',
                      action="store_true",
-                     dest="wizard",
-                     default=None,
-                     help='Run the wizard')
+                     dest="autoreload",
+                     help='Autoreload application when source is modified')
+    group.add_option('', '--fatal-warnings',
+                     action="store_false",
+                     dest="non_fatal_warnings",
+                     default=True,
+                     help='Make all warnings fatal')
     group.add_option('', '--login-username',
                      action="store",
                      dest="login_username",
@@ -56,6 +60,11 @@ def get_shell(args):
                      action="store_true",
                      dest="version",
                      help='Show the application version')
+    group.add_option('', '--wizard',
+                     action="store_true",
+                     dest="wizard",
+                     default=None,
+                     help='Run the wizard')
     parser.add_option_group(group)
 
     options, args = parser.parse_args(args)
@@ -64,13 +73,16 @@ def get_shell(args):
         import stoq
         raise SystemExit(stoq.version)
 
-    from stoq.gui.shell.shell import Shell
-    return args, Shell(options)
+    from stoq.gui.shell.bootstrap import boot_shell
+    shell = boot_shell(options)
+
+    return args, shell
 
 
 def main(args):
     args, shell = get_shell(args)
 
+    action_name = None
     if len(args) < 2:
         appname = None
     else:
@@ -85,4 +97,6 @@ def main(args):
             raise SystemExit("'%s' is not an application. "
                              "Valid applications are: %s" % (appname, apps))
 
-    shell.main(appname)
+        if len(args) > 2:
+            action_name = args[2]
+    shell.main(appname, action_name)
