@@ -28,7 +28,6 @@
 Singleton object which makes it easier to common stoqlib APIs without
 having to import their symbols.
 """
-from contextlib import contextmanager
 import operator
 import sys
 
@@ -65,37 +64,6 @@ class StoqAPI(object):
     def get_current_user(self, store):
         return get_current_user(store)
 
-    @contextmanager
-    def trans(self):
-        """Creates a new store and commits/closes it when done.
-
-        It should be used as::
-
-          with api.trans() as store:
-              ...
-
-        When the execution of the with statement has finished this
-        will commit the object, close the store.
-        trans.retval will be used to determine if the store
-        should be committed or rolled back (via :py:func:`~stoqlib.api.StoqAPI.finish_transaction`)
-        """
-        store = self.new_store()
-        yield store
-
-        # Editors/Wizards requires the store.retval variable to
-        # be set or it won't be committed.
-        if store.needs_retval:
-            retval = bool(store.retval)
-            if store.confirm(retval):
-                store.committed = True
-            else:
-                store.committed = False
-        # Normal transaction, just commit it
-        else:
-            store.commit()
-            store.committed = True
-        store.close()
-
     @property
     def config(self):
         return get_utility(IStoqConfig)
@@ -108,9 +76,6 @@ class StoqAPI(object):
     def user_settings(self):
         return get_settings()
 
-    def sysparam(self, store):
-        return sysparam(store)
-
     def is_developer_mode(self):
         return is_developer_mode()
 
@@ -123,7 +88,8 @@ class StoqAPI(object):
           def _run_a_dialog(self):
               model = yield run_dialog(SomeDialog, parent, store)
 
-        If the function returns a value, you need to use :py:func:`~stoqlib.api.StoqAPI.asyncReturn`, eg::
+        If the function returns a value, you need to use
+        :py:func:`~stoqlib.api.StoqAPI.asyncReturn`, eg::
 
           api.asyncReturn(model)
 
@@ -141,8 +107,8 @@ class StoqAPI(object):
         """
         return returnValue(value)
 
-    def get_l10n_field(self, store, field_name, country=None):
-        return get_l10n_field(store, field_name, country=country)
+    def get_l10n_field(self, field_name, country=None):
+        return get_l10n_field(field_name, country=country)
 
     def for_combo(self, resultset, attr=None, empty=None, sorted=True):
         """
@@ -176,7 +142,8 @@ class StoqAPI(object):
 
     def for_person_combo(self, resultset):
         """
-        This is similar to :py:func:`~stoqlib.api.StoqAPI.for_combo` but takes a class that references a :py:class:`~stoqlib.domain.person.Person`,
+        This is similar to :py:func:`~stoqlib.api.StoqAPI.for_combo` but
+        takes a class that references a :py:class:`~stoqlib.domain.person.Person`,
         such as a :py:class:`~stoqlib.domain.person.Client`,
         :py:class:`~stoqlib.domain.person.Company`,
         :py:class:`~stoqlib.domain.person.Supplier` etc.
@@ -225,15 +192,17 @@ class StoqAPI(object):
         :returns: an :py:class:`~stoqlib.domain.exampledata.ExampleCreator`
         """
         # FIXME: We need to move this into stoqlib
-        from stoq.gui.shell.shell import Shell
+        from stoq.gui.shell.bootstrap import boot_shell
         from stoq.lib.options import get_option_parser
         parser = get_option_parser()
         options = parser.parse_args(sys.argv[1:])[0]
         options.wizard = False
         options.splashscreen = False
+        options.autoreload = False
         options.login_username = u'admin'
-        shell = Shell(options, initial=False)
-        shell._bootstrap.bootstrap()
+        options.non_fatal_warnings = False
+        shell = boot_shell(options, initial=False)
+        shell._dbconn.connect()
         shell._do_login()
 
         from stoqlib.domain.exampledata import ExampleCreator
@@ -243,3 +212,4 @@ class StoqAPI(object):
         return ec
 
 api = StoqAPI()
+api.sysparam = sysparam
