@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2006-2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2006-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -22,10 +22,3 @@
 
 """Database abstraction layer
 """
-
-import os
-import sys
-
-if os.getenv('STOQLIB_USE_STORM'):
-    import stormorm
-    sys.modules['stoqlib.database.orm'] = stormorm
