@@ -29,13 +29,13 @@ tables, removing tables and configuring administration user.
 """
 
 import glob
+import logging
 import os
-import sys
+import tempfile
 
 from kiwi.component import provide_utility
 from kiwi.currency import currency
 from kiwi.environ import environ
-from kiwi.log import Logger
 
 from stoqdrivers.enum import TaxType, UnitType
 from stoqdrivers.constants import describe_constant
@@ -52,15 +52,15 @@ from stoqlib.domain.profile import ProfileSettings, UserProfile
 from stoqlib.domain.sellable import SellableTaxConstant, SellableUnit
 from stoqlib.exceptions import StoqlibError
 from stoqlib.importers.invoiceimporter import InvoiceImporter
-from stoqlib.lib.crashreport import collect_traceback
 from stoqlib.lib.message import error
-from stoqlib.lib.parameters import sysparam, ensure_system_parameters
+from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.template import render_template_string
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
-log = Logger(__name__)
-create_log = Logger('stoqlib.database.create')
+log = logging.getLogger(__name__)
+create_log = logging.getLogger('stoqlib.database.create')
 USER_ADMIN_DEFAULT_NAME = u'admin'
 
 
@@ -123,7 +123,7 @@ def create_main_branch(store, name):
     Company(person=person, store=store)
     branch = Branch(person=person, store=store)
 
-    sysparam(store).MAIN_COMPANY = branch.id
+    sysparam.set_object(store, 'MAIN_COMPANY', branch)
 
     provide_utility(ICurrentBranch, branch)
     admin = get_admin_user(store)
@@ -157,14 +157,15 @@ def register_payment_methods(store):
     pom = get_payment_operation_manager()
 
     log.info("Creating domain objects for payment methods")
-    account = sysparam(store).IMBALANCE_ACCOUNT
+    account_id = sysparam.get_object_id('IMBALANCE_ACCOUNT')
+    assert account_id
     for operation_name in pom.get_operation_names():
         operation = pom.get(operation_name)
         pm = store.find(PaymentMethod, method_name=operation_name).one()
         if pm is None:
             pm = PaymentMethod(store=store,
                                method_name=operation_name,
-                               destination_account=account,
+                               destination_account_id=account_id,
                                max_installments=operation.max_installments)
 
 
@@ -192,17 +193,24 @@ def register_accounts(store):
             account = Account(store=store, description=name)
         account.account_type = atype
 
-    sparam = sysparam(store)
-    sparam.BANKS_ACCOUNT = store.find(Account, description=_(u"Banks")).one().id
-    sparam.TILLS_ACCOUNT = store.find(Account, description=_(u"Tills")).one().id
-    sparam.IMBALANCE_ACCOUNT = store.find(Account,
-                                          description=_(u"Imbalance")).one().id
+    sysparam.set_object(
+        store,
+        'BANKS_ACCOUNT',
+        store.find(Account, description=_(u"Banks")).one())
+    sysparam.set_object(
+        store,
+        'TILLS_ACCOUNT',
+        store.find(Account, description=_(u"Tills")).one())
+    sysparam.set_object(
+        store,
+        'IMBALANCE_ACCOUNT',
+        store.find(Account, description=_(u"Imbalance")).one())
 
 
 def _ensure_card_providers():
     """ Creates a list of default card providers """
     log.info("Creating Card Providers")
-    from stoqlib.domain.payment.card import CreditProvider
+    from stoqlib.domain.payment.card import CreditProvider, CardPaymentDevice
 
     providers = [u'VISANET', u'REDECARD', u'AMEX', u'HIPERCARD',
                  u'BANRISUL', u'PAGGO', u'CREDISHOP', u'CERTIF']
@@ -217,6 +225,9 @@ def _ensure_card_providers():
                        provider_id=name,
                        open_contract_date=TransactionTimestamp(),
                        store=store)
+    devices = store.find(CardPaymentDevice)
+    if devices.is_empty():
+        CardPaymentDevice(store=store, description=_(u'Default'))
     store.commit(close=True)
 
 
@@ -229,10 +240,9 @@ def get_admin_user(store):
                       username=USER_ADMIN_DEFAULT_NAME).one()
 
 
-def ensure_sellable_constants():
+def ensure_sellable_constants(store):
     """ Create native sellable constants. """
     log.info("Creating sellable units")
-    store = new_store()
     unit_list = [(u"Kg", UnitType.WEIGHT),
                  (u"Lt", UnitType.LITERS),
                  (u"m ", UnitType.METERS)]
@@ -252,8 +262,6 @@ def ensure_sellable_constants():
                             tax_value=None,
                             store=store)
 
-    store.commit(close=True)
-
 
 def user_has_usesuper(store):
     """This method checks if the currently logged in postgres user has
@@ -299,14 +307,24 @@ def _get_latest_schema():
     return schemas[-1]
 
 
+def create_database_functions():
+    """Create some functions we define on the database
+
+    This will simply read data/sql/functions.sql and execute it
+    """
+    with tempfile.NamedTemporaryFile(suffix='stoqfunctions-') as tmp_f:
+        with open(environ.find_resource('sql', 'functions.sql')) as f:
+            tmp_f.write(render_template_string(f.read()))
+            tmp_f.flush()
+        if db_settings.execute_sql(tmp_f.name) != 0:
+            error(u'Failed to create functions')
+
+
 def create_base_schema():
     log.info('Creating base schema')
     create_log.info("SCHEMA")
 
-    # Functions
-    functions = environ.find_resource('sql', 'functions.sql')
-    if db_settings.execute_sql(functions) != 0:
-        error(u'Failed to create functions')
+    create_database_functions()
 
     # A Base schema shared between all RDBMS implementations
     schema = _get_latest_schema()
@@ -373,9 +391,9 @@ def initialize_system(password=None, testsuite=False,
         register_payment_methods(store)
         from stoqlib.domain.uiform import create_default_forms
         create_default_forms(store)
+        ensure_sellable_constants(store)
+        sysparam.ensure_system_parameters(store)
         store.commit(close=True)
-        ensure_sellable_constants()
-        ensure_system_parameters()
         _ensure_card_providers()
         create_default_profiles()
         _install_invoice_templates()
@@ -383,9 +401,9 @@ def initialize_system(password=None, testsuite=False,
         if not testsuite:
             create_default_profile_settings()
             ensure_admin_user(password)
-    except Exception, e:
+    except Exception:
+        # if not testsuite:
+        #     collect_traceback(sys.exc_info(), submit=True)
+        # raise SystemExit("Could not initialize system: %r" % (e, ))
         raise
-        if not testsuite:
-            collect_traceback(sys.exc_info(), submit=True)
-        raise SystemExit("Could not initialize system: %r" % (e, ))
     create_log("INIT DONE")
