@@ -27,6 +27,8 @@ import sys
 import platform
 import struct
 
+import psycopg2
+
 from storm.tracer import BaseStatementTracer, install_tracer
 
 try:
@@ -79,8 +81,8 @@ if has_sqlparse:
             identifiers = list(tlist.get_identifiers())
             if len(identifiers) > 1 and not tlist.within(sql.Function):
                 # This is not working in some cases
-                #first = list(identifiers[0].flatten())[0]
-                #num_offset = self._get_offset(first) - len(first.value)
+                # first = list(identifiers[0].flatten())[0]
+                # num_offset = self._get_offset(first) - len(first.value)
                 num_offset = 7
                 self.offset += num_offset
                 width = self.offset
@@ -115,11 +117,13 @@ class StoqlibDebugTracer(BaseStatementTracer):
                       reverse=7, concealed=8)
     COLORS = dict(grey=30, red=31, green=32, yellow=33, blue=34,
                   magenta=35, cyan=36, white=37)
-    RESET = '\033[0m'
+    RESET = '\033[0m'   # pylint: disable=W1401
 
     def __init__(self, stream=None):
         # This colors will be used to highlight the transaction
-        self._available_colors = ['blue', 'green', 'magenta', 'yellow', 'cyan']
+        self._available_colors = ['blue', 'green', 'magenta', 'yellow', 'cyan',
+                                  'red']
+        self._current_color = 0
         # Mapping pid > color
         self._transactions = {}
         # Mapping pid > query count
@@ -131,7 +135,7 @@ class StoqlibDebugTracer(BaseStatementTracer):
 
     def _colored(self, text, color=None, attrs=None):
         if os.getenv('ANSI_COLORS_DISABLED') is None:
-            fmt_str = '\033[%dm%s'
+            fmt_str = '\033[%dm%s'   # pylint: disable=W1401
             if color is not None:
                 text = fmt_str % (self.COLORS[color], text)
 
@@ -186,7 +190,7 @@ class StoqlibDebugTracer(BaseStatementTracer):
         self._transactions_count[pid] += 1
         count = self._transactions_count[pid]
         header_size = 9 + len(str(pid))
-        color = self._transactions.get(pid, 'red')
+        color = self._get_transaction_color(pid)
         pid = self._colored(pid, color)
 
         self._start_time = datetime.datetime.now()
@@ -195,49 +199,59 @@ class StoqlibDebugTracer(BaseStatementTracer):
         # Dont write new line, so we can print the time at the end
         self.header(pid, color, count, tail=' ')
         self.write(self.statement + '\n')
-        import time
-        time.sleep(0.1)
 
     def connection_raw_execute_success(self, transaction, raw_cursor, statement,
                                        params):
         pid = raw_cursor.connection.get_backend_pid()
         header_size = 9 + len(str(pid))
-        duration = datetime.datetime.now() - self._start_time
+        now = datetime.datetime.now()
+        duration = now - self._start_time
         seconds = duration.seconds + float(duration.microseconds) / 10 ** 6
         rows = raw_cursor.rowcount
 
-        text = '%s%s seconds | %s rows' % (' ' * header_size,
-                       self._colored(seconds, attrs=['bold']),
-                       self._colored(rows, attrs=['bold']))
+        text = '%s%s seconds | %s rows | %s' % (
+            ' ' * header_size,
+            self._colored(seconds, attrs=['bold']),
+            self._colored(rows, attrs=['bold']),
+            self._colored(now.strftime('%F %T.%f'), attrs=['bold']))
 
         if statement.startswith('INSERT') and rows == 1:
-            rowid = raw_cursor.fetchone()[0]
-            raw_cursor.scroll(-1)
-            text += ' | id: ' + self._colored(repr(rowid), attrs=['bold'])
+            try:
+                rowid = raw_cursor.fetchone()[0]
+                raw_cursor.scroll(-1)
+                text += ' | id: ' + self._colored(repr(rowid), attrs=['bold'])
+            except psycopg2.ProgrammingError:
+                text = ''
         self.write(text + '\n')
 
+    def _get_transaction_color(self, pid):
+        if pid not in self._transactions:
+            self._transactions[pid] = self._available_colors[self._current_color]
+            self._current_color += 1
+            if self._current_color == len(self._available_colors):
+                self._current_color = 0
+        return self._transactions[pid]
+
     def transaction_create(self, store):
         pid = store._connection._raw_connection.get_backend_pid()
-        self._transactions[pid] = color = self._available_colors.pop()
+        color = self._get_transaction_color(pid)
 
         self.header(pid, color, 'BEGIN')
 
     def transaction_commit(self, store):
         pid = store._connection._raw_connection.get_backend_pid()
-        color = self._transactions.get(pid, 'red')
+        color = self._get_transaction_color(pid)
         self.header(pid, color, 'COMIT')
 
     def transaction_rollback(self, store, xid=None):
         pid = store._connection._raw_connection.get_backend_pid()
-        color = self._transactions.get(pid, 'red')
+        color = self._get_transaction_color(pid)
         self.header(pid, color, 'ROLLB')
 
     def transaction_close(self, store):
         pid = store._connection._raw_connection.get_backend_pid()
-        color = self._transactions.get(pid, 'red')
-        if color != 'red':
-            self._available_colors.insert(0, color)
-            del self._transactions[pid]
+        color = self._get_transaction_color(pid)
+        del self._transactions[pid]
 
         self.header(pid, color, 'CLOSE')
 
