@@ -25,6 +25,8 @@
 """Database Interfaces: Connection, Settings etc
 """
 
+# pylint: disable=E0102,E0211,E0213
+
 from zope.interface import Attribute
 from zope.interface.interface import Interface
 
@@ -52,3 +54,14 @@ class ICurrentUser(Interface):
     profile = Attribute('A profile represents a colection of information '
                         'which represents what this user can do in the '
                         'system')
+
+
+class ISearchFilter(Interface):
+
+    def get_state():
+        """
+        Gets the state.
+        :rtype: :class:`QueryState`
+        """
+
+# pylint: enable=E0102,E0211,E0213
