@@ -26,6 +26,7 @@
 """
 
 import fnmatch
+import logging
 import os
 import re
 import shutil
@@ -34,11 +35,10 @@ import tempfile
 import traceback
 
 from kiwi.environ import environ
-from kiwi.log import Logger
 
 from stoqlib.database.runtime import (get_default_store,
                                       new_store)
-from stoqlib.database.settings import db_settings
+from stoqlib.database.settings import db_settings, check_extensions
 from stoqlib.domain.plugin import InstalledPlugin
 from stoqlib.domain.profile import update_profile_applications
 from stoqlib.exceptions import (DatabaseInconsistency, StoqlibError,
@@ -46,14 +46,13 @@ from stoqlib.exceptions import (DatabaseInconsistency, StoqlibError,
 from stoqlib.lib.crashreport import collect_traceback
 from stoqlib.lib.defaults import stoqlib_gettext
 from stoqlib.lib.message import error, info
-from stoqlib.lib.parameters import (check_parameter_presence,
-                                    ensure_system_parameters)
+from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.pluginmanager import get_plugin_manager
 
 _ = stoqlib_gettext
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 # Used by the wizard
-create_log = Logger('stoqlib.database.create')
+create_log = logging.getLogger('stoqlib.database.create')
 
 
 class Patch(object):
@@ -156,16 +155,23 @@ class SchemaMigration(object):
         if self.patch_resource is None:
             raise ValueError(
                 _("%s needs to have the patch_resource class variable set") % (
-                self.__class__.__name__))
+                    self.__class__.__name__))
         if self.patch_patterns is None:
             raise ValueError(
                 _("%s needs to have the patch_patterns class variable set") % (
-                self.__class__.__name__))
+                    self.__class__.__name__))
         self.default_store = get_default_store()
 
+        try:
+            check_extensions(store=self.default_store)
+        except ValueError:
+            error("Missing PostgreSQL extension on the server, "
+                  "please install postgresql-contrib")
+
     def _patchname_is_valid(self, filename):
         # simple checking of the patch naming convention
-        valid_patterns = ["patch-\d\d-\d\d.sql", "patch-\d\d-\d\d.py"]
+        valid_patterns = [r"patch-\d\d-\d\d.sql",
+                          r"patch-\d\d-\d\d.py"]
         for valid_pattern in valid_patterns:
             if re.match(valid_pattern, filename) is not None:
                 return True
@@ -178,7 +184,7 @@ class SchemaMigration(object):
                 if not fnmatch.fnmatch(filename, pattern):
                     continue
                 if not self._patchname_is_valid(filename):
-                    print "Invalid patch name: %s" % filename
+                    print("Invalid patch name: %s" % filename)
                     continue
                 filename = environ.get_resource_filename('stoq', self.patch_resource, filename)
                 patches.append(Patch(filename, self))
@@ -207,9 +213,8 @@ class SchemaMigration(object):
                     continue
                 patches_to_apply.append(patch)
 
-            functions = environ.get_resource_filename('stoq', 'sql', 'functions.sql')
-            if db_settings.execute_sql(functions) != 0:
-                error('Failed to create functions')
+            from stoqlib.database.admin import create_database_functions
+            create_database_functions()
 
             log.info("Applying %d patches" % (len(patches_to_apply), ))
             create_log.info("PATCHES:%d" % (len(patches_to_apply), ))
@@ -292,16 +297,16 @@ class SchemaMigration(object):
         """Updates the database schema
         """
         if self.check_uptodate():
-            print 'Database is already at the latest version %d.%d' % (
-                self.get_current_version())
+            print('Database is already at the latest version %d.%d' % (
+                self.get_current_version()))
         else:
             from_, to = self._update_schema()
             if to is None:
-                print 'Database schema is already up to date'
+                print('Database schema is already up to date')
             else:
                 f = "(%d.%d)" % from_
                 t = "(%d.%d)" % to
-                print 'Database schema updated from %s to %s' % (f, t)
+                print('Database schema updated from %s to %s' % (f, t))
 
     def get_current_version(self):
         """This method is revision for returning the database schema version
@@ -339,7 +344,7 @@ class StoqlibSchemaMigration(SchemaMigration):
     def check_uptodate(self):
         retval = super(StoqlibSchemaMigration, self).check_uptodate()
 
-        if not check_parameter_presence(self.default_store):
+        if not sysparam.check_parameter_presence():
             return False
 
         return retval
@@ -368,7 +373,7 @@ class StoqlibSchemaMigration(SchemaMigration):
             msg = _(u'Could not connect to the database using command line '
                     'tool! Aborting.') + ' '
             msg += _(u'Please, check if you can connect to the database '
-                    'using:') + ' '
+                     'using:') + ' '
             msg += _(u'psql -l -h <server> -p <port> -U <username>')
             error(msg)
             return
@@ -447,10 +452,10 @@ class StoqlibSchemaMigration(SchemaMigration):
         # profiles on the system
         store = new_store()
         update_profile_applications(store)
-        store.commit(close=True)
 
         # Updating the parameter list
-        ensure_system_parameters(update=True)
+        sysparam.ensure_system_parameters(store, update=True)
+        store.commit(close=True)
 
     def generate_sql_for_patch(self, patch):
         return self.default_store.quote_query(
@@ -500,12 +505,12 @@ def needs_schema_update():
         migration = StoqlibSchemaMigration()
     except StoqlibError:
         error(_("Update Error"),
-             _("You need to call setup() before checking the database "
-               "schema."))
+              _("You need to call setup() before checking the database "
+                "schema."))
 
     try:
         update = not (migration.check_uptodate() and migration.check_plugins())
-    except DatabaseInconsistency, e:
+    except DatabaseInconsistency as e:
         error(str(e))
 
     # If we need to update the database, we need to close the connection,
