@@ -23,13 +23,13 @@
 ##
 """ Runtime routines for applications"""
 
-import os
+import logging
 import sys
 import warnings
 import weakref
+import os
 
 from kiwi.component import get_utility, provide_utility
-from kiwi.log import Logger
 from storm import Undef
 from storm.expr import SQL, Avg
 from storm.info import get_obj_info
@@ -42,16 +42,17 @@ from stoqlib.database.interfaces import (
     ICurrentBranchStation, ICurrentUser)
 from stoqlib.database.expr import StatementTimestamp, is_sql_identifier
 from stoqlib.database.orm import ORMObject
+from stoqlib.database.properties import Identifier
 from stoqlib.database.settings import db_settings
 from stoqlib.database.viewable import Viewable
-from stoqlib.exceptions import DatabaseError, LoginError, StoqlibError
+from stoqlib.exceptions import DatabaseError, LoginError
 from stoqlib.lib.decorators import public
 from stoqlib.lib.message import error, yesno
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.net.socketutils import get_hostname
 
 _ = stoqlib_gettext
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 #: the default store, considered read-only in Stoq
 _default_store = None
@@ -110,8 +111,15 @@ class StoqlibResultSet(ResultSet):
         instance = self._viewable()
         # This will be removed later
         instance._store = self._store
+        identifiers = []
         for attr, value in zip(self._viewable.cls_attributes, values):
+            if type(value) is Identifier:
+                identifiers.append(value)
             setattr(instance, attr, value)
+        branch = getattr(instance, 'branch', None)
+        if branch:
+            for i in identifiers:
+                i.prefix = branch.acronym or ''
         return instance
 
     def _load_objects(self, result, values):
@@ -151,14 +159,15 @@ class StoqlibStore(Store):
     the store.
 
     The primary way of querying object from  a store is via the :meth:`.find`
-    method, but you can also use :meth:`.get` if you know the id of the object.
-    find returns a ResultSet, see the Storm documentation for information
-    about that.
+    method, but you can also use :meth:`.Store.get` if you know the id
+    of the object. find returns a ResultSet, see the Storm documentation for
+    information about that.
 
     Objects needs to be added to a store. This can either be done via
-    :meth:`.add` or passing in the store parameter to a ORMObject/Domain object.
+    :meth:`StoqlibStore.add` or passing in the store parameter to a
+    ORMObject/Domain object.
 
-    If you want to delete an object you use :meth:`.remove`
+    If you want to delete an object you use :meth:`StoqlibStore.remove`
 
     You normally create a store using :func:`.new_store`, it needs to be
     :meth:`close` when you're done or a database connection will be leaked.
@@ -168,10 +177,9 @@ class StoqlibStore(Store):
     `storm tutorial <https://storm.canonical.com/Tutorial>`__
 
     :attribute retval: The return value of a operation this transaction
-      is covering. Usually a domain object that was modified
-    :attribute needs_retval: If this is set to True, the retval variable
-      needs to be set to a non-zero value to be committed, see
-      stoqlib.api.trans
+      is covering. Usually a domain object that was modified. By default
+      it's ``True``, but can be set to ``False`` to do a rollback instead
+      of a commit on :meth:`stoqlib.api.StoqApi.trans`
     """
     _result_set_factory = StoqlibResultSet
 
@@ -183,8 +191,7 @@ class StoqlibStore(Store):
         :param cache: storm cache to use or ``None``
         """
         self._savepoints = []
-        self.retval = None
-        self.needs_retval = False
+        self.retval = True
         self.obsolete = False
 
         if database is None:
@@ -194,6 +201,15 @@ class StoqlibStore(Store):
         _stores[self] = None
         trace('transaction_create', self)
         self._reset_pending_objs()
+        self._setup_application_name()
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        if exc_type is None:
+            self.committed = self.confirm(commit=self.retval)
+            self.close()
 
     def find(self, cls_spec, *args, **kwargs):
         # Overwrite the default find method so we can support querying our own
@@ -202,14 +218,20 @@ class StoqlibStore(Store):
         # results will be converted in instances of the viewable
 
         viewable = None
-        if not isinstance(cls_spec, tuple) and issubclass(cls_spec, Viewable):
-            args = list(args)
-            viewable = cls_spec
-            # Get the actual class spec for the viewable
-            cls_spec = viewable.cls_spec
+        if not isinstance(cls_spec, tuple):
+            try:
+                is_viewable = issubclass(cls_spec, Viewable)
+            except TypeError:
+                is_viewable = False
 
-            if viewable.clause:
-                args.append(viewable.clause)
+            if is_viewable:
+                args = list(args)
+                viewable = cls_spec
+                # Get the actual class spec for the viewable
+                cls_spec = viewable.cls_spec
+
+                if viewable.clause:
+                    args.append(viewable.clause)
 
         # kwargs are based on the properties of the viewable. We need to convert
         # it to the properties of the real tables.
@@ -250,7 +272,7 @@ class StoqlibStore(Store):
             # not begin one explicitly
             self.execute('BEGIN TRANSACTION')
             self.execute(self.get_lock_database_query())
-        except OperationalError, e:
+        except OperationalError as e:
             raise DatabaseError("ERROR: Could not obtain lock: %s" % (e, ))
 
     def unlock_database(self):
@@ -285,6 +307,18 @@ class StoqlibStore(Store):
         cursor.close()
         return stmt
 
+    def maybe_remove(self, obj):
+        """Maybe remove an object from the database
+
+        This will depend on the parameter SYNCHRONIZED_MODE. When working with
+        synchronized databases, we should be very carefull when removing
+        objects, since they will not be removed from the remote database (at
+        least until we fix bug 5581)
+        """
+        from stoqlib.lib.parameters import sysparam
+        if not sysparam.get_bool('SYNCHRONIZED_MODE'):
+            self.remove(obj)
+
     def add_created_object(self, obj):
         """Record an object that was created in the store.
         This is an internal method that should only be called by Domain.
@@ -343,6 +377,11 @@ class StoqlibStore(Store):
         else:
             super(StoqlibStore, self).rollback()
             self._reset_pending_objs()
+            # If we rollback completely, we need to clear all savepoints
+            self._savepoints = []
+
+        # Rolling back resets the application name.
+        self._setup_application_name()
 
         # sqlobject closes the connection after a rollback
         if close:
@@ -433,6 +472,15 @@ class StoqlibStore(Store):
             if self._savepoints.pop() == name:
                 break
 
+    def savepoint_exists(self, name):
+        """Checks if the given savepoint's name exists
+
+        :param name: the name of the savepoint
+        :returns: ``True`` if the savepoint exists on this store,
+            ``False`` otherwise.
+        """
+        return name in self._savepoints
+
     def confirm(self, commit):
         """Encapsulated method for committing/aborting changes in models.
 
@@ -452,6 +500,15 @@ class StoqlibStore(Store):
     #  Private
     #
 
+    def _setup_application_name(self):
+        """Sets a friendly name for postgres connection
+
+        This name will appear when selecting from pg_stat_activity, for instance,
+        and will allow to better debug the queries (specially when there is a deadlock)
+        """
+        self.execute("SET application_name = 'stoq - %s - %s'" %
+                     (get_hostname(), os.getpid()))
+
     def _check_obsolete(self):
         if self.obsolete:
             raise InterfaceError("This transaction has already been closed")
@@ -501,6 +558,7 @@ class StoqlibStore(Store):
                     modified_obj.te_modified.user_id = user_id
                 # And also from domainv2
                 else:
+                    modified_obj.te.dirty = True
                     modified_obj.te.te_time = te_time
                     modified_obj.te.station_id = station_id
                     modified_obj.te.user_id = user_id
@@ -532,16 +590,28 @@ def get_default_store():
 
     :returns: default store
     """
-    global _default_store
     if _default_store is None:
-        _default_store = db_settings.create_store()
-        assert _default_store is not None
+        set_default_store(db_settings.create_store())
         # We intentionally leave this open, it's the default
         # store and should only be closed when we close the
         # application
     return _default_store
 
 
+def set_default_store(store):
+    """This sets a new default store and closes the
+    existing one if any.
+
+    This is only called during Startup and should not be used elsewhere
+    :param store: the new store to set
+    """
+
+    global _default_store
+    if store is None and _default_store is not None:
+        _default_store.close()
+    _default_store = store
+
+
 def new_store():
     """
     Create a new transaction.
@@ -556,54 +626,35 @@ def new_store():
 #
 # User methods
 #
-def _register_branch(caller_store, station_name):
+def _register_branch_station(caller_store, station_name):
     import gtk
     from stoqlib.lib.parameters import sysparam
 
-    if not sysparam(caller_store).DEMO_MODE:
-        if yesno(_("The computer '%s' is not registered to the Stoq "
-                   "server at %s.\n\n"
-                   "Do you want to register it "
-                   "(requires administrator access) ?") %
-                 (station_name, db_settings.address),
-                 gtk.RESPONSE_NO, _("Quit"), _("Register computer")):
+    if not sysparam.get_bool('DEMO_MODE'):
+        fmt = _(u"The computer '%s' is not registered to the Stoq "
+                u"server at %s.\n\n"
+                u"Do you want to register it "
+                u"(requires administrator access) ?")
+        if not yesno(fmt % (station_name,
+                            db_settings.address),
+                     gtk.RESPONSE_YES, _(u"Register computer"), _(u"Quit")):
             raise SystemExit
 
-        from stoqlib.gui.login import LoginHelper
+        from stoqlib.gui.utils.login import LoginHelper
         h = LoginHelper(username="admin")
         try:
             user = h.validate_user()
-        except LoginError, e:
+        except LoginError as e:
             error(str(e))
 
         if not user:
             error(_("Must login as 'admin'"))
 
-    from stoqlib.domain.person import Branch
     from stoqlib.domain.station import BranchStation
-
-    branches = caller_store.find(Branch)
-    if branches.is_empty():
-        error(_("Schema error, no branches found"))
-
-    # TODO
-    # Always select the first branch as the main branch, until we
-    # support multiple branches properly. And then, provide a way to the
-    # user choose which one will be the main branch.
-    branch = branches[0]
-
-    store = new_store()
-    try:
-        station = BranchStation.create(store,
-                                       branch=store.fetch(branch),
-                                       name=station_name)
-    except StoqlibError, e:
-        error(_("ERROR: %s") % e)
-
-    station_id = station.id
-    store.commit(close=True)
-
-    return caller_store.find(BranchStation, id=station_id).one()
+    with new_store() as store:
+        branch = sysparam.get_object(store, 'MAIN_COMPANY')
+        station = BranchStation.create(store, branch=branch, name=station_name)
+    return caller_store.fetch(station)
 
 
 def set_current_branch_station(store, station_name):
@@ -612,26 +663,19 @@ def set_current_branch_station(store, station_name):
     :param store: a store
     :param station_name: name of the station to register
     """
-
-    # This might be called early, so make sure SQLObject
-    # knows about Branch which might not have
-    # been imported yet
+    # This is called from stoq-daemon, which doesn't know about Branch yet
+    from stoqlib.lib.parameters import sysparam
     from stoqlib.domain.person import Branch
-    Branch  # pyflakes
+    Branch  # pylint: disable=W0104
 
     if station_name is None:
-        # For LTSP systems we cannot use the hostname as stoq is run
-        # on a shared serve system. Instead the ip of the client system
-        # is available in the LTSP_CLIENT environment variable
-        station_name = os.environ.get('LTSP_CLIENT_HOSTNAME', None)
-        if station_name is None:
-            station_name = get_hostname()
+        station_name = get_hostname()
 
     station_name = unicode(station_name)
     from stoqlib.domain.station import BranchStation
     station = store.find(BranchStation, name=station_name).one()
     if station is None:
-        station = _register_branch(store, station_name)
+        station = _register_branch_station(store, station_name)
 
     if not station.is_active:
         error(_("The computer <u>%s</u> is not active in Stoq") %
@@ -641,6 +685,14 @@ def set_current_branch_station(store, station_name):
 
     provide_utility(ICurrentBranchStation, station, replace=True)
 
+    main_company = sysparam.get_object(store, 'MAIN_COMPANY')
+    if not station.branch and main_company:
+        with new_store() as commit_store:
+            commit_station = commit_store.fetch(station)
+            commit_station.branch = commit_store.fetch(main_company)
+
+    # The station may still not be associated with a branch when creating an
+    # empty database
     if station.branch:
         provide_utility(ICurrentBranch, station.branch, replace=True)
 
