@@ -25,6 +25,7 @@
 
 """Settings required to access the database, hostname, username etc
 """
+import logging
 import os
 import platform
 import re
@@ -33,7 +34,6 @@ import sys
 import time
 import urllib
 
-from kiwi.log import Logger
 from storm.database import create_database
 from storm.uri import URI
 
@@ -46,18 +46,74 @@ from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 _system = platform.system()
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 DEFAULT_RDBMS = 'postgres'
 # As of 2012-03-30:
 # 604 is the number of entries that are created when you create an
 # empty database
 # 1174 when you create examples
 _ENTRIES_DELETE_THRESHOLD = 1000
+# List of PostgreSQL extensions that we need to be available on the
+# server.
+_REQUIRED_EXTENSIONS = [
+    'pg_trgm',  # gist_trgm_ops index type
+    'uuid-ossp',   # uuid data-type
+]
 
 #: We only allow alpha-numeric and underscores in database names
 DB_NAME_RE = re.compile('^[a-zA-Z0-9_]+$')
 
 
+def _fix_storm():  # pragma nocover
+    # FIXME: This is a workaround for this bug: https://bugs.launchpad.net/storm/+bug/1170063
+    # We are monkey-patching storm using the patch proposed there.
+    # Remove when the bug is fixed.
+    import psycopg2
+    # psycopg2 version comes as '2.5.3 (dt dec mx pq3 ext)' (both in debian and
+    # ubuntu). If that's not the case somehow, we will simply abort.
+    try:
+        psycopg2_version = psycopg2.__version__[:5]
+        psycopg2_version = tuple(psycopg2_version.split('.'))
+    except Exception:
+        return
+
+    # We only need to apply this if psycopg2 version is >= 2.5
+    if psycopg2_version < (2, 5):
+        return
+
+    from storm.exceptions import (Error, Warning, InternalError,
+                                  ProgrammingError, IntegrityError, DataError,
+                                  NotSupportedError, InterfaceError,
+                                  # Make pyflakes happy
+                                  DatabaseError as _DatabaseError,
+                                  OperationalError as _OperationalError)
+
+    def install_exceptions(module):
+        for exception in (Error, Warning, _DatabaseError, InternalError,
+                          _OperationalError, ProgrammingError, IntegrityError,
+                          DataError, NotSupportedError, InterfaceError):
+            module_exception = getattr(module, exception.__name__, None)
+            if module_exception is not None:
+                try:
+                    module_exception.__bases__ += (exception,)
+                except TypeError:
+                    # Since PsycoPG >= 2.5 psycopg2.Error is built-in
+                    tmp_exception = module_exception
+
+                    class PsycoPG25Error(tmp_exception):
+                        """We can not patch built-in types
+                        """
+
+                    setattr(module, module_exception.__name__, PsycoPG25Error)
+                    module_exception = getattr(module, exception.__name__)
+                    module_exception.__bases__ += (exception,)
+
+    import storm.exceptions
+    storm.exceptions.install_exceptions = install_exceptions
+
+_fix_storm()
+
+
 def validate_database_name(dbname):
     """Verifies that a database name does not contain any invalid characters.
 
@@ -92,6 +148,14 @@ def _database_drop(store, dbname, ifExists=False):
     return True
 
 
+def _extension_exists(cur, extension):
+    q = """SELECT count(*)
+             FROM pg_available_extensions
+            WHERE name = %s"""
+    cur.execute(q, (extension, ))
+    return cur.fetchone()[0] == 1
+
+
 def _create_empty_database(store, dbname, ifNotExists=False):
     if not validate_database_name(dbname):
         raise ValueError(
@@ -105,11 +169,30 @@ def _create_empty_database(store, dbname, ifNotExists=False):
     cur = raw_conn.cursor()
     cur.execute('COMMIT')
     cur.execute('CREATE DATABASE %s' % (dbname, ))
+    check_extensions(cursor=cur)
     cur.close()
     del cur, raw_conn, database
     return True
 
 
+def check_extensions(cursor=None, store=None):
+    """
+    Check if all required extensions can be installed.
+
+    :param cursor: a cursor or ``None``
+    :param store: a store or ``None``
+    """
+    if cursor is None:
+        database = store.get_database()
+        raw_conn = database.raw_connect()
+        cursor = raw_conn.cursor()
+
+    for extension in _REQUIRED_EXTENSIONS:
+        if not _extension_exists(cursor, extension):
+            raise ValueError("Database server is missing %s extension." % (
+                extension))
+
+
 def test_local_database():
     """Check and see if we postgres running locally
 
@@ -146,6 +229,32 @@ def test_local_database():
         return None
 
 
+def get_database_version(store):
+    """Gets the database version as a tuple
+
+    :param store: a store
+    :returns: the version as a 3 item tuple
+    :raises: :exc:`stoqlib.exceptions.DatabaseError` if any error ocour
+        in the process
+    """
+    full_version = store.execute('SELECT VERSION();').get_one()[0]
+    server_version = full_version.split(' ')[1].split('.')
+
+    try:
+        # We do the replace on server_version[2] because postgresql reports
+        # its version a little different on other platforms. For example, on
+        # Windows, it reports like this:
+        # "PostgreSQL 9.3.4, compiled by Visual C++ build 1600, 64-bit"
+        version_tuple = (int(server_version[0]),
+                         int(server_version[1]),
+                         int(server_version[2].replace(',', '')))
+    except ValueError:
+        raise DatabaseError(
+            "Error getting server version: %s" % (server_version, ))
+
+    return version_tuple
+
+
 class DatabaseSettings(object):
     """DatabaseSettings contains all the information required to connect to
     a database, such as hostname, username and password.
@@ -233,10 +342,10 @@ class DatabaseSettings(object):
                 uri.port = int(pair[1])
             self._log_connect(uri)
             store = StoqlibStore(create_database(uri))
-        except OperationalError, e:
+        except OperationalError as e:
             log.info('OperationalError: %s' % e)
             raise DatabaseError(e.args[0])
-        except Exception, e:
+        except Exception as e:
             value = sys.exc_info()[1]
             raise DatabaseError(
                 _("Could not connect to %s database. The error message is "
@@ -288,7 +397,7 @@ class DatabaseSettings(object):
 
         try:
             socket.getaddrinfo(self.address, None)
-        except socket.gaierror:
+        except (socket.gaierror, socket.error):
             return False
         return True
 
@@ -298,7 +407,7 @@ class DatabaseSettings(object):
         """
         try:
             super_store = self.create_super_store()
-        except OperationalError, e:
+        except OperationalError as e:
             msg = e.args[0]
             details = None
             if ';' in msg:
@@ -356,9 +465,9 @@ class DatabaseSettings(object):
                         _database_drop(super_store, dbname)
                     log.info("Dropped database %s" % (dbname, ))
                     break
-                except Exception, e:
+                except Exception as e:
+                    # time.sleep(1)
                     raise
-                    time.sleep(1)
             else:
                 if _database_exists(super_store, dbname):
                     raise e
@@ -380,16 +489,16 @@ class DatabaseSettings(object):
 
         # We are trying to delete another database. This happens when restoring a
         # backup
-        db_settings = self
-        if dbname != db_settings.dbname:
-            db_settings = db_settings.copy()
-            db_settings.dbname = dbname
+        db_settings_ = self
+        if dbname != db_settings_.dbname:
+            db_settings_ = db_settings_.copy()
+            db_settings_.dbname = dbname
 
         # There is no database. Safe to drop.
-        if not db_settings.has_database():
+        if not db_settings_.has_database():
             return False
 
-        store = db_settings.create_store()
+        store = db_settings_.create_store()
 
         # There is no transaction_entry table. Safe to drop.
         if not store.table_exists('transaction_entry'):
@@ -443,11 +552,7 @@ class DatabaseSettings(object):
                 raise SystemExit("Cannot drop a database with existing "
                                  "tables (use --force to really drop it)")
 
-        try:
-            self.drop_database(dbname)
-        except Exception, e:
-            raise e
-
+        self.drop_database(dbname)
         super_store = self.create_super_store()
         _create_empty_database(super_store, dbname)
         super_store.close()
@@ -546,8 +651,8 @@ class DatabaseSettings(object):
             args.extend(self.get_tool_args())
             args.append(self.dbname)
 
-            print 'Connecting to %s' % (
-                self.get_store_dsn(filter_password=True), )
+            print('Connecting to %s' % (
+                self.get_store_dsn(filter_password=True), ))
             proc = Process(args)
             proc.wait()
         else:
@@ -673,14 +778,10 @@ class DatabaseSettings(object):
         :param store: a store
         """
         if self.rdbms == 'postgres':
-            version = store.execute('SELECT VERSION();').get_one()[0]
-            server_version = version.split(' ', 2)[1]
-            assert server_version.count('.') == 2, version
-            parts = server_version.split(".")[:2]
             try:
-                svs = map(int, parts)
-            except ValueError:
-                log.info("Error getting server version: %s" % (server_version, ))
+                svs = get_database_version(store)
+            except DatabaseError as e:
+                log.info(str(e))
                 return
 
             # Client version
@@ -698,20 +799,21 @@ class DatabaseSettings(object):
                 line = line[:-1]
 
             parts = line.split(' ')
-            #assert len(parts) == 3, parts
+            # assert len(parts) == 3, parts
             if len(parts) != 3:
                 log.info("Error getting psql version: %s" % (line, ))
                 return
 
             client_version = parts[2]
-            #assert client_version.count('.') == 2, line
+            # assert client_version.count('.') == 2, line
             if client_version.count('.') != 2:
                 log.info("Error getting pg version: %s" % (client_version, ))
                 return
 
-            cvs = map(int, client_version.split('.'))[:2]
+            cvs = tuple(map(int, client_version.split('.'))[:3])
 
             if svs != cvs:
+                server_version = '.'.join(map(str, svs))
                 warning(_(u"Problem with PostgreSQL version"),
                         _(u"The version of the PostgreSQL database server (%s) and the "
                           "postgres client tools (%s) differ. I will let you use "
