@@ -35,7 +35,7 @@ class WillBeCommitted(Domain):
     __storm_table__ = 'will_be_committed'
     SQL_DROP = """DROP TABLE IF EXISTS will_be_committed;"""
     SQL_CREATE = """CREATE TABLE will_be_committed (
-        id serial NOT NULL PRIMARY KEY,
+        id uuid PRIMARY KEY DEFAULT uuid_generate_v1(),
         test_var text,
         te_id bigint UNIQUE REFERENCES transaction_entry(id)
         );"""
@@ -46,6 +46,10 @@ class WillBeCommitted(Domain):
         super(WillBeCommitted, self).__init__(*args, **kwargs)
         self.reset()
 
+    def __storm_loaded__(self):
+        super(WillBeCommitted, self).__storm_loaded__()
+        self.reset()
+
     def reset(self):
         self.was_created = False
         self.was_updated = False
@@ -79,6 +83,32 @@ class StoqlibTransactionTest(DomainTest):
                                     WillBeCommitted.SQL_CREATE)))
         self.store.commit()
 
+    def test_dirty_flag(self):
+        # Creating an object should set its dirty flag to True
+        store = new_store()
+        obj = WillBeCommitted(store=store)
+        obj_id = obj.id
+        store.commit()
+        self.assertTrue(obj.te.dirty)
+
+        # Reset the flag to test changing the object
+        obj.te.dirty = False
+        store.commit()
+        store.close()
+
+        # Get the same object from a new connection
+        store = new_store()
+        obj = store.get(WillBeCommitted, obj_id)
+
+        # The flag must be False
+        self.assertFalse(obj.te.dirty)
+
+        # Changing the object and commiting should update the flag
+        obj.test_var = u'asd'
+        store.commit()
+        self.assertTrue(obj.te.dirty)
+        store.close()
+
     def test_rollback_to_savepoint(self):
         obj = WillBeCommitted(store=self.store, test_var=u'XXX')
         obj2 = WillBeCommitted(store=self.store, test_var=u'foo')
