@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2006-2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2006-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,15 +23,17 @@
 ##
 """Database routines which are used by the testsuite"""
 
+# FIXME: This should be moved/merged with the normal bootstrap
+
 # This needs to before the other commits, so the externals/
 # path is properly setup.
 from stoqlib.lib.kiwilibrary import library
-library  # pyflakes
+library  # pylint: disable=W0104
 
+import logging
 import os
 
 from kiwi.component import provide_utility, utilities
-from kiwi.log import Logger
 from storm.expr import And
 from storm.tracer import install_tracer, remove_tracer_type
 
@@ -46,12 +48,11 @@ from stoqlib.importers.stoqlibexamples import create
 from stoqlib.lib.interfaces import IApplicationDescriptions, ISystemNotifier
 from stoqlib.lib.message import DefaultSystemNotifier
 from stoqlib.lib.osutils import get_username
-from stoqlib.lib.parameters import ParameterAccess
 from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.lib.settings import get_settings
 from stoqlib.net.socketutils import get_hostname
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class StoqlibTestsuiteTracer(object):
@@ -126,8 +127,8 @@ def _provide_current_station(station_name=None, branch_name=None):
     store = new_store()
     if branch_name:
         branch = store.find(Person,
-            And(Person.name == branch_name,
-                Branch.person_id == Person.id)).one()
+                            And(Person.name == branch_name,
+                                Branch.person_id == Person.id)).one()
     else:
         branches = store.find(Branch)
         if branches.count() == 0:
@@ -161,7 +162,7 @@ def _provide_app_info():
 
 
 def provide_database_settings(dbname=None, address=None, port=None, username=None,
-                              password=None, create=True):
+                              password=None, createdb=True):
     """
     Provide database settings.
     :param dbname:
@@ -196,7 +197,7 @@ def provide_database_settings(dbname=None, address=None, port=None, username=Non
     db_settings.password = password
 
     rv = False
-    if create or not db_settings.database_exists(dbname):
+    if createdb or not db_settings.database_exists(dbname):
         db_settings.clean_database(dbname, force=True)
         rv = True
 
@@ -205,7 +206,7 @@ def provide_database_settings(dbname=None, address=None, port=None, username=Non
 
 def _provide_domain_slave_mapper():
     from stoqlib.gui.interfaces import IDomainSlaveMapper
-    from stoqlib.gui.domainslavemapper import DefaultDomainSlaveMapper
+    from stoqlib.gui.slaves.domainslavemapper import DefaultDomainSlaveMapper
     provide_utility(IDomainSlaveMapper, DefaultDomainSlaveMapper(),
                     replace=True)
 
@@ -229,12 +230,20 @@ def provide_utilities(station_name, branch_name=None):
 
 def _enable_plugins():
     manager = get_plugin_manager()
-    for plugin in [u'nfe', u'ecf']:
+    for plugin in [u'ecf',
+                   u'nfe',
+                   u'optical']:
         if not manager.is_installed(plugin):
             # STOQLIB_TEST_QUICK won't let dropdb on testdb run. Just a
             # precaution to avoid trying to install it again
             manager.install_plugin(plugin)
 
+        else:
+            # Make sure that the plugin is imported so sys.path is properly
+            # setup
+            plugin = manager.get_plugin(plugin)
+            plugin  # pylint: disable=W0104
+
 
 def bootstrap_suite(address=None, dbname=None, port=5432, username=None,
                     password=u"", station_name=None, quick=False):
@@ -249,8 +258,13 @@ def bootstrap_suite(address=None, dbname=None, port=5432, username=None,
     :param quick:
     """
 
+    # This will only be required when we use uuid.UUID instances
+    # for UUIDCol
+    #import psycopg2.extras
+    #psycopg2.extras.register_uuid()
+
     empty = provide_database_settings(dbname, address, port, username, password,
-                                      create=not quick)
+                                      createdb=not quick)
 
     # Reset the user settings (loaded from ~/.stoq/settings), so that user
     # preferences don't affect the tests.
@@ -259,12 +273,9 @@ def bootstrap_suite(address=None, dbname=None, port=5432, username=None,
 
     if quick and not empty:
         provide_utilities(station_name)
+        _enable_plugins()
         return
 
-    # XXX: Why clearing_cache if initialize_system will drop the
-    # database?!
-    ParameterAccess.clear_cache()
-
     initialize_system(testsuite=True, force=True)
 
     # Commit before trying to apply patches which requires an exclusive lock
