@@ -34,18 +34,20 @@ Finally there's a :class:`AccountTransactionView` that is used by
 the financial application to efficiently display a ledger.
 """
 
+# pylint: enable=E1101
+
 import datetime
 
 from kiwi.currency import currency
 from storm.expr import And, LeftJoin, Or
 from storm.info import ClassAlias
 from storm.references import Reference
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.expr import TransactionTimestamp
 from stoqlib.database.properties import PriceCol
 from stoqlib.database.properties import IntCol, UnicodeCol
-from stoqlib.database.properties import DateTimeCol
+from stoqlib.database.properties import DateTimeCol, IdCol
 from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
@@ -72,7 +74,7 @@ class BillOption(Domain):
     #: value of the option
     value = UnicodeCol()
 
-    bank_account_id = IntCol()
+    bank_account_id = IdCol()
 
     #: the |bankaccount| this option belongs to
     bank_account = Reference(bank_account_id, 'BankAccount.id')
@@ -87,7 +89,7 @@ class BankAccount(Domain):
 
     __storm_table__ = 'bank_account'
 
-    account_id = IntCol()
+    account_id = IdCol()
 
     #: the |account| for this bank account
     account = Reference(account_id, 'Account.id')
@@ -114,6 +116,7 @@ class BankAccount(Domain):
                                bank_account=self)
 
 
+@implementer(IDescribable)
 class Account(Domain):
     """An account, a collection of |accounttransactions| that may be controlled
     by a bank.
@@ -163,9 +166,7 @@ class Account(Domain):
         (_(u"Income"), TYPE_INCOME),
         (_(u"Expense"), TYPE_EXPENSE),
         (_(u"Equity"), TYPE_EQUITY),
-        ]
-
-    implements(IDescribable)
+    ]
 
     #: name of the account
     description = UnicodeCol(default=None)
@@ -174,12 +175,12 @@ class Account(Domain):
     code = UnicodeCol(default=None)
 
     #: parent account id, can be None
-    parent_id = IntCol(default=None)
+    parent_id = IdCol(default=None)
 
     #: parent account
     parent = Reference(parent_id, 'Account.id')
 
-    station_id = IntCol(default=None)
+    station_id = IdCol(default=None)
 
     #: the |branchstation| tied
     #: to this account, mainly for TYPE_CASH accounts
@@ -214,7 +215,7 @@ class Account(Domain):
             raise TypeError("station cannot be None")
         if not isinstance(station, BranchStation):
             raise TypeError("station must be a BranchStation, not %r" %
-                    (station, ))
+                           (station, ))
         return store.find(cls, station=station).one()
 
     @classmethod
@@ -235,10 +236,9 @@ class Account(Domain):
         parts = []
         account = self
         while account:
-            if account in parts:
-                break
-            parts.append(account)
-            account = account.parent
+            if not account in parts:
+                parts.append(account)
+                account = account.parent
         return u':'.join([a.description for a in reversed(parts)])
 
     @property
@@ -248,8 +248,8 @@ class Account(Domain):
         :returns: list of |accounttransaction|
         """
         return self.store.find(AccountTransaction,
-            Or(self.id == AccountTransaction.account_id,
-               self.id == AccountTransaction.source_account_id))
+                               Or(self.id == AccountTransaction.account_id,
+                                  self.id == AccountTransaction.source_account_id))
 
     def get_total_for_interval(self, start, end):
         """Fetch total value for a given interval
@@ -267,17 +267,16 @@ class Account(Domain):
 
         return currency(self.transactions.find(And(
             AccountTransaction.date >= start,
-            AccountTransaction.date < end)).sum(AccountTransaction.value) or 0)
+            AccountTransaction.date <= end)).sum(AccountTransaction.value) or 0)
 
     def can_remove(self):
         """If the account can be removed.
         Not all accounts can be removed, some are internal to Stoq
         and cannot be removed"""
         # Can't remove accounts that are used in a parameter
-        sparam = sysparam(self.store)
-        if self in [sparam.IMBALANCE_ACCOUNT,
-                    sparam.TILLS_ACCOUNT,
-                    sparam.BANKS_ACCOUNT]:
+        if (sysparam.compare_object('IMBALANCE_ACCOUNT', self) or
+            sysparam.compare_object('TILLS_ACCOUNT', self) or
+            sysparam.compare_object('BANKS_ACCOUNT', self)):
             return False
 
         # Can't remove station accounts
@@ -299,16 +298,16 @@ class Account(Domain):
         if not self.can_remove():
             raise TypeError("Account %r cannot be removed" % (self, ))
 
-        imbalance_account = sysparam(store).IMBALANCE_ACCOUNT
+        imbalance_account_id = sysparam.get_object_id('IMBALANCE_ACCOUNT')
 
         for transaction in store.find(AccountTransaction,
                                       account=self):
-            transaction.account = imbalance_account
+            transaction.account_id = imbalance_account_id
             store.flush()
 
         for transaction in store.find(AccountTransaction,
                                       source_account=self):
-            transaction.source_account = imbalance_account
+            transaction.source_account_id = imbalance_account_id
             store.flush()
 
         bank = self.bank
@@ -317,7 +316,7 @@ class Account(Domain):
                 store.remove(option)
             store.remove(bank)
 
-        self.delete(self.id, store=store)
+        self.store.remove(self)
 
     def has_child_accounts(self):
         """If this account has child accounts
@@ -378,12 +377,12 @@ class AccountTransaction(Domain):
     #        want to store more values, so it might make sense to allow
     #        N values per transaction.
 
-    account_id = IntCol()
+    account_id = IdCol()
 
     #: destination |account|
     account = Reference(account_id, 'Account.id')
 
-    source_account_id = IntCol()
+    source_account_id = IdCol()
 
     #: source |account|
     source_account = Reference(source_account_id, 'Account.id')
@@ -400,7 +399,7 @@ class AccountTransaction(Domain):
     #: date the transaction was done
     date = DateTimeCol()
 
-    payment_id = IntCol(default=None)
+    payment_id = IdCol(default=None)
 
     #: |payment| this transaction relates to, can also be ``None``
     payment = Reference(payment_id, 'Payment.id')
@@ -426,7 +425,7 @@ class AccountTransaction(Domain):
         value = payment.paid_value
         if payment.is_outpayment():
             value = -value
-        return cls(source_account=sysparam(store).IMBALANCE_ACCOUNT,
+        return cls(source_account_id=sysparam.get_object_id('IMBALANCE_ACCOUNT'),
                    account=account or payment.method.destination_account,
                    value=value,
                    description=payment.description,
@@ -515,16 +514,16 @@ class AccountTransactionView(Viewable):
     tables = [
         AccountTransaction,
         LeftJoin(Account_Dest,
-                   AccountTransaction.account_id == Account_Dest.id),
+                 AccountTransaction.account_id == Account_Dest.id),
         LeftJoin(Account_Source,
-                   AccountTransaction.source_account_id == Account_Source.id),
+                 AccountTransaction.source_account_id == Account_Source.id),
     ]
 
     @classmethod
     def get_for_account(cls, account, store):
         """Get all transactions for this |account|, see Account.transaction"""
         return store.find(cls, Or(account.id == AccountTransaction.account_id,
-                           account.id == AccountTransaction.source_account_id))
+                                  account.id == AccountTransaction.source_account_id))
 
     def get_account_description(self, account):
         """Get description of the other |account|, eg.
