@@ -25,17 +25,20 @@
 Commission management
 """
 
+# pylint: enable=E1101
+
 from decimal import Decimal
 
-from storm.expr import Join
+from storm.expr import Join, Cast
 from storm.references import Reference
 
 from stoqlib.database.properties import PercentCol, PriceCol
-from stoqlib.database.properties import IntCol
+from stoqlib.database.properties import IntCol, IdCol
 from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
+from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.person import Person, SalesPerson
+from stoqlib.domain.person import Person, SalesPerson, Branch
 from stoqlib.domain.sale import Sale
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.translation import stoqlib_gettext
@@ -68,12 +71,12 @@ class CommissionSource(Domain):
     #: the commission value to be used in a |sale| with multiple installments
     installments_value = PercentCol()
 
-    category_id = IntCol(default=None)
+    category_id = IdCol(default=None)
 
     #: the |sellablecategory|
     category = Reference(category_id, 'SellableCategory.id')
 
-    sellable_id = IntCol(default=None)
+    sellable_id = IdCol(default=None)
 
     #: the |sellable|
     sellable = Reference(sellable_id, 'Sellable.id')
@@ -104,17 +107,12 @@ class Commission(Domain):
     #: The commission amount
     value = PriceCol(default=0)
 
-    salesperson_id = IntCol()
-
-    #: who sold the |sale| this commission applies to
-    salesperson = Reference(salesperson_id, 'SalesPerson.id')
-
-    sale_id = IntCol()
+    sale_id = IdCol()
 
     #: the |sale| this commission applies to
     sale = Reference(sale_id, 'Sale.id')
 
-    payment_id = IntCol()
+    payment_id = IdCol()
 
     #: the |payment| this commission applies to
     payment = Reference(payment_id, 'Payment.id')
@@ -203,54 +201,76 @@ class CommissionView(Viewable):
         sale and payment.
     """
 
+    #: the branch this commission was generated
+    branch = Branch
+
+    payment = Payment
+    sale = Sale
+
+    # Sale
     id = Sale.id
     identifier = Sale.identifier
+    identifier_str = Cast(Sale.identifier, 'text')
     sale_status = Sale.status
+    confirm_date = Sale.confirm_date
+
+    # Commission
     code = Commission.id
     commission_value = Commission.value
     commission_percentage = Commission.value / Payment.value * 100
-    salesperson_name = Person.name
+
+    # Payment
     payment_id = Payment.id
     payment_value = Payment.value
-    confirm_date = Sale.confirm_date
+    method_name = PaymentMethod.method_name
     paid_date = Payment.paid_date
 
+    # Salesperson
+    salesperson_id = SalesPerson.id
+    salesperson_name = Person.name
+
     tables = [
         Sale,
+        Join(Branch, Sale.branch_id == Branch.id),
         Join(Commission, Commission.sale_id == Sale.id),
-        Join(SalesPerson, SalesPerson.id == Commission.salesperson_id),
+        Join(SalesPerson, SalesPerson.id == Sale.salesperson_id),
         Join(Person, Person.id == SalesPerson.person_id),
         Join(Payment, Payment.id == Commission.payment_id),
-       ]
+        Join(PaymentMethod, Payment.method_id == PaymentMethod.id),
+    ]
 
     @property
-    def sale(self):
-        return self.store.get(Sale, self.id)
+    def method_description(self):
+        from stoqlib.domain.payment.operation import get_payment_operation
+        return get_payment_operation(self.method_name).description
 
+    # pylint: disable=E1120
     @property
-    def payment(self):
-        return self.store.get(Payment, self.payment_id)
-
     def quantity_sold(self):
-        if self.sale_returned():
+        if self.sale_returned:
             # zero means 'this sale does not changed our stock'
             return Decimal(0)
 
+        # FIXME: This is doing one extra query per row when printing the report
         return self.sale.get_items_total_quantity()
 
-    def get_payment_amount(self):
+    @property
+    def payment_amount(self):
         # the returning payment should be shown as negative one
         if self.payment.is_outpayment():
             return -self.payment_value
         return self.payment_value
 
-    def get_total_amount(self):
+    @property
+    def total_amount(self):
         # XXX: No, the sale amount does not change. But I return different
         # values based in type of the payment to guess how I might show the
         # total sale amount.
         if self.payment.is_outpayment():
             return -self.sale.total_amount
         return self.sale.total_amount
+    # pylint: enable=E1120
 
+    @property
     def sale_returned(self):
         return self.sale_status == Sale.STATUS_RETURNED
