@@ -25,15 +25,18 @@
 Domain classes related to stoqdrivers package.
 """
 
-from zope.interface import implements
+# pylint: enable=E1101
+
 from stoqdrivers.printers.cheque import ChequePrinter
 from stoqdrivers.scales.scales import Scale
 from stoqdrivers.serialbase import SerialPort
 from storm.references import Reference, ReferenceSet
+from zope.interface import implementer
 
 from stoqlib.database.properties import PriceCol
 from stoqlib.database.properties import (IntCol, BoolCol,
-                                         DateTimeCol, UnicodeCol)
+                                         DateTimeCol, UnicodeCol,
+                                         IdCol)
 from stoqlib.database.runtime import get_current_station
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IActive, IDescribable
@@ -43,8 +46,9 @@ from stoqlib.lib.translation import stoqlib_gettext
 _ = stoqlib_gettext
 
 
+@implementer(IActive)
+@implementer(IDescribable)
 class DeviceSettings(Domain):
-    implements(IActive, IDescribable)
 
     __storm_table__ = 'device_settings'
 
@@ -52,7 +56,7 @@ class DeviceSettings(Domain):
     brand = UnicodeCol()
     model = UnicodeCol()
     device_name = UnicodeCol()
-    station_id = IntCol()
+    station_id = IdCol()
     station = Reference(station_id, 'BranchStation.id')
     is_active = BoolCol(default=True)
 
@@ -147,7 +151,7 @@ class FiscalDayTax(Domain):
 
     __storm_table__ = 'fiscal_day_tax'
 
-    fiscal_day_history_id = IntCol()
+    fiscal_day_history_id = IdCol()
     fiscal_day_history = Reference(fiscal_day_history_id, 'FiscalDayHistory.id')
 
     #: four bytes, either the percental of the tax, 1800 for 18% or one of:
@@ -172,7 +176,7 @@ class FiscalDayHistory(Domain):
     __storm_table__ = 'fiscal_day_history'
 
     emission_date = DateTimeCol()
-    station_id = IntCol()
+    station_id = IdCol()
     station = Reference(station_id, 'BranchStation.id')
     serial = UnicodeCol()
     serial_id = IntCol()
