@@ -26,9 +26,10 @@
 Events used in the domain code
 """
 
+# pylint: enable=E1101
+
 from stoqlib.enums import CreatePaymentStatus
 from stoqlib.lib.event import Event
-
 from stoqlib.lib.decorators import public
 
 #
@@ -170,6 +171,41 @@ class SaleStatusChangedEvent(Event):
     """
 
 
+class SaleItemBeforeDecreaseStockEvent(Event):
+    """
+    This event is emitted when a |saleitem| is about to decrease the stock
+
+    This is usually called at the beginning of
+    :meth:`stoqlib.domain.sale.SaleItem.sell`
+
+    :param sale_item: the |saleitem| object
+    """
+
+
+class SaleItemBeforeIncreaseStockEvent(Event):
+    """
+    This event is emitted when a |saleitem| is about to increase the stock
+
+    This is usually called at the beginning of
+    :meth:`stoqlib.domain.sale.SaleItem.cancel`
+
+    :param sale_item: the |saleitem| object
+    """
+
+
+class SaleItemAfterSetBatchesEvent(Event):
+    """
+    This event is emitted after a |saleitem| set it's batches
+
+    This is called at the end of
+    :meth:`stoqlib.domain.sale.SaleItem.set_batches`
+
+    :param sale_item: the |saleitem| object
+    :param new_sale_items: a list of the new |saleitems| created
+        when setting the batches
+    """
+
+
 @public(since="1.5.0")
 class DeliveryStatusChangedEvent(Event):
     """
@@ -240,11 +276,15 @@ class CancelPendingPaymentsEvent(Event):
 
 class GerencialReportPrintEvent(Event):
     """
+    This is emitted when the user requests a gerencial report
+    for fiscal printers.
     """
 
 
 class GerencialReportCancelEvent(Event):
     """
+    This is emitted when the user cancels a gerencial report
+    for fiscal printers.
     """
 
 
