@@ -27,33 +27,35 @@
 Note that this whole module is Brazil-specific.
 """
 
-import datetime
+# pylint: enable=E1101
 
 from storm.expr import LeftJoin, Join
 from storm.references import Reference
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.expr import Date, TransactionTimestamp
-from stoqlib.database.properties import UnicodeCol, DateTimeCol, IntCol, BoolCol
+from stoqlib.database.properties import (UnicodeCol, DateTimeCol, IntCol, BoolCol,
+                                         IdCol)
 from stoqlib.database.properties import PriceCol
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable, IReversal
 from stoqlib.domain.person import Person
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.parameters import sysparam
 
 
+@implementer(IDescribable)
 class CfopData(Domain):
     """A Brazil-specific class wich defines a fiscal code of operations.
     In Brazil it means 'Codigo Fiscal de Operacoes e Prestacoes'
 
-    Canonical list of C.F.O.Ps can be found `here <http://www.fazenda.gov.br/confaz/confaz/convenios/sinief/cfop_cvsn_70_vigente.htm>`__
+    Canonical list of C.F.O.Ps can be found `here <http://tinyurl.com/mncsnlf>`__
 
     See also:
     `schema <http://doc.stoq.com.br/schema/tables/cfop_data.html>`__
     """
-    implements(IDescribable)
 
     __storm_table__ = 'cfop_data'
 
@@ -64,11 +66,15 @@ class CfopData(Domain):
     description = UnicodeCol()
 
     def get_description(self):
+        # FIXME: kgetattr tries to get this instead of self.description,
+        # making it return u" " on a new model. How to fix that properly?
+        if not self.code and not self.description:
+            return u""
         return u"%s %s" % (self.code, self.description)
 
 
+@implementer(IReversal)
 class FiscalBookEntry(Domain):
-    implements(IReversal)
 
     __storm_table__ = 'fiscal_book_entry'
 
@@ -76,16 +82,16 @@ class FiscalBookEntry(Domain):
      TYPE_SERVICE,
      TYPE_INVENTORY) = range(3)
 
-    date = DateTimeCol(default_factory=datetime.datetime.now)
+    date = DateTimeCol(default_factory=localnow)
     is_reversal = BoolCol(default=False)
     invoice_number = IntCol()
-    cfop_id = IntCol()
+    cfop_id = IdCol()
     cfop = Reference(cfop_id, 'CfopData.id')
-    branch_id = IntCol()
+    branch_id = IdCol()
     branch = Reference(branch_id, 'Branch.id')
-    drawee_id = IntCol(default=None)
+    drawee_id = IdCol(default=None)
     drawee = Reference(drawee_id, 'Person.id')
-    payment_group_id = IntCol(default=None)
+    payment_group_id = IdCol(default=None)
     payment_group = Reference(payment_group_id, 'PaymentGroup.id')
     iss_value = PriceCol(default=None)
     icms_value = PriceCol(default=None)
@@ -140,7 +146,7 @@ class FiscalBookEntry(Domain):
             FiscalBookEntry.TYPE_PRODUCT,
             group, cfop, invoice_number,
             icms_value=value, ipi_value=ipi_value,
-            )
+        )
 
     @classmethod
     def create_service_entry(cls, store, group, cfop, invoice_number, value):
@@ -161,7 +167,7 @@ class FiscalBookEntry(Domain):
             FiscalBookEntry.TYPE_SERVICE,
             group, cfop, invoice_number,
             iss_value=value,
-            )
+        )
 
     def reverse_entry(self, invoice_number,
                       iss_value=None, icms_value=None, ipi_value=None):
@@ -175,7 +181,7 @@ class FiscalBookEntry(Domain):
             iss_value=iss_value,
             icms_value=icms_value,
             ipi_value=ipi_value,
-            cfop=sysparam(store).DEFAULT_RETURN_SALES_CFOP,
+            cfop_id=sysparam.get_object_id('DEFAULT_SALES_CFOP'),
             branch=self.branch,
             invoice_number=invoice_number,
             drawee=self.drawee,
@@ -202,7 +208,7 @@ class _FiscalBookEntryView(Viewable):
         FiscalBookEntry,
         LeftJoin(Person, Person.id == FiscalBookEntry.drawee_id),
         Join(CfopData, CfopData.id == FiscalBookEntry.cfop_id)
-        ]
+    ]
 
 
 class IcmsIpiView(_FiscalBookEntryView):
