@@ -24,9 +24,12 @@
 ##
 """ Interfaces definition for all domain classes """
 
+# pylint: disable=E0102,E0211,E0213,W0404
+
 from zope.interface import Attribute, Interface
 
-# pylint: disable=E0102,E0211,E0213
+# pylint: enable=W0404
+
 
 #
 # Interfaces
@@ -75,41 +78,7 @@ class IORMObject(Interface):
     id = Attribute("Object ID")
 
     def delete(obj_id, store):
-        pass
-
-
-class IPaymentTransaction(Interface):
-    """ Interface specification for PaymentGroups. """
-
-    def confirm():
-        """Transaction is confirmed.
-        Payments might occur at this time, in case of money payment,
-        others may happen later
-        """
-
-    def pay():
-        """All payment for this transaction are paid.
-        """
-
-    def cancel():
-        """Cancels the transaction before it's completed.
-        """
-
-    def return_(renegotiation):
-        """Returns the goods purchased.
-        This means that all paid payments are paid back and
-        all pending onces are cancelled.
-        Commissions may also reversed.
-        :param renegotiation: renegotiation data
-        """
-
-    def create_commission(payment):
-        """Creates a commission for the *payment*
-
-        This will create a |commission| for the given |payment|,
-        :obj:`.sale` and :obj:`.sale.salesperson`. Note that, if the
-        payment already has a commission, nothing will be done.
-        """
+        "Delete an ORM Interface Object"
 
 
 class IReversal(Interface):
@@ -119,3 +88,5 @@ class IReversal(Interface):
         """Takes a financial entry and reverse it, creating a new instance
         with an oposite value
         """
+
+# pylint: enable=E0102,E0211,E0213
