@@ -24,22 +24,24 @@
 ##
 """Invoice domain classes; field, layout and printer
 """
-from storm.references import Reference
-from zope.interface import implements
 
-from stoqlib.database.properties import IntCol, UnicodeCol
+# pylint: enable=E1101
+
+from storm.references import Reference
+from zope.interface import implementer
+
+from stoqlib.database.properties import IntCol, UnicodeCol, IdCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
 
 
+@implementer(IDescribable)
 class InvoicePrinter(Domain):
     """An invoice printer is a representation of a physical printer
     connected to a branch station.
     It has a layout assigned which will be used to format the data sent
     to the printer
     """
-    implements(IDescribable)
-
     __storm_table__ = 'invoice_printer'
 
     #: a operating system specific identifier for the
@@ -51,11 +53,11 @@ class InvoicePrinter(Domain):
     description = UnicodeCol()
 
     #: the station this printer is connected to
-    station_id = IntCol()
+    station_id = IdCol()
     station = Reference(station_id, 'BranchStation.id')
 
     #: the layout used to format the invoices
-    layout_id = IntCol()
+    layout_id = IdCol()
     layout = Reference(layout_id, 'InvoiceLayout.id')
 
     def get_description(self):
@@ -77,11 +79,10 @@ class InvoicePrinter(Domain):
         return store.find(InvoicePrinter, station=station).one()
 
 
+@implementer(IDescribable)
 class InvoiceLayout(Domain):
     """A layout of an invoice.
     """
-    implements(IDescribable)
-
     __storm_table__ = 'invoice_layout'
 
     #: description of the layout, this is human friendly
@@ -147,5 +148,5 @@ class InvoiceField(Domain):
     field_name = UnicodeCol()
 
     #: the layout this field belongs to
-    layout_id = IntCol()
+    layout_id = IdCol()
     layout = Reference(layout_id, 'InvoiceLayout.id')
