@@ -30,23 +30,24 @@ The main class is :class:`Loan` which can hold a
 set of :class:`LoanItem`.
 """
 
-import datetime
+# pylint: enable=E1101
+
 from decimal import Decimal
 
-from kiwi.argcheck import argcheck
 from kiwi.currency import currency
 from storm.references import Reference, ReferenceSet
-from storm.store import AutoReload
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.expr import Round
-from stoqlib.database.properties import (UnicodeCol,
-                                  DateTimeCol, IntCol, PriceCol, QuantityCol)
+from stoqlib.database.properties import (UnicodeCol, DateTimeCol, IntCol,
+                                         PriceCol, QuantityCol, IdentifierCol,
+                                         IdCol)
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.domain.product import StockTransactionHistory
 from stoqlib.exceptions import DatabaseInconsistency
-from stoqlib.lib.defaults import DECIMAL_PRECISION
+from stoqlib.lib.dateutils import localnow
+from stoqlib.lib.defaults import DECIMAL_PRECISION, quantize
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -59,6 +60,9 @@ class LoanItem(Domain):
     or :obj:`~.sale_quantity` you will need to call :meth:`.sync_stock`
     to synchronize the stock (increase or decrease it).
 
+    Also note that objects of this type should never be created manually, only
+    by calling :meth:`Loan.add_sellable`
+
     See also:
     `schema <http://doc.stoq.com.br/schema/tables/loan_item.html>`__
     """
@@ -80,13 +84,21 @@ class LoanItem(Domain):
     #: a :class:`sale <stoqlib.domain.sale.Sale>`
     price = PriceCol()
 
-    sellable_id = IntCol(allow_none=False)
+    #: original price of a sellable
+    base_price = PriceCol()
+
+    sellable_id = IdCol(allow_none=False)
 
     #: :class:`sellable <stoqlib.domain.sellable.Sellable>` that is loaned
     #: cannot be *None*
     sellable = Reference(sellable_id, 'Sellable.id')
 
-    loan_id = IntCol()
+    batch_id = IdCol()
+
+    #: If the sellable is a storable, the |batch| that it was returned in
+    batch = Reference(batch_id, 'StorableBatch.id')
+
+    loan_id = IdCol()
 
     #: :class:`loan <Loan>` this item belongs to
     loan = Reference(loan_id, 'Loan.id')
@@ -129,12 +141,12 @@ class LoanItem(Domain):
         if diff_quantity > 0:
             self.storable.increase_stock(diff_quantity, self.branch,
                                          StockTransactionHistory.TYPE_RETURNED_LOAN,
-                                         self.id)
+                                         self.id, batch=self.batch)
         elif diff_quantity < 0:
             diff_quantity = - diff_quantity
             self.storable.decrease_stock(diff_quantity, self.branch,
                                          StockTransactionHistory.TYPE_LOANED,
-                                         self.id)
+                                         self.id, batch=self.batch)
 
         # Reset the values used to calculate the stock quantity, just like
         # when the object as loaded from the database again.
@@ -151,12 +163,25 @@ class LoanItem(Domain):
 
     def get_quantity_unit_string(self):
         return u"%s %s" % (self.quantity,
-                          self.sellable.get_unit_description())
+                           self.sellable.unit_description)
 
     def get_total(self):
         return currency(self.price * self.quantity)
 
+    def set_discount(self, discount):
+        """Apply *discount* on this item
 
+        Note that the discount will be applied based on :obj:`.base_price`
+        and then substitute :obj:`.price`, making any previous
+        discount/surcharge being lost
+
+        :param decimal.Decimal discount: the discount to be applied
+            as a percentage, e.g. 10.0, 22.5
+        """
+        self.price = quantize(self.base_price * (1 - discount / 100))
+
+
+@implementer(IContainer)
 class Loan(Domain):
     """
     A loan is a collection of |sellable| that is being loaned
@@ -170,8 +195,6 @@ class Loan(Domain):
     `manual <http://doc.stoq.com.br/manual/loan.html>`__
     """
 
-    implements(IContainer)
-
     __storm_table__ = 'loan'
 
     #: The request for a loan has been added to the system,
@@ -190,9 +213,9 @@ class Loan(Domain):
                 STATUS_CLOSED: _(u'Closed')}
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
 
     #: status of the loan
     status = IntCol(default=STATUS_OPEN)
@@ -201,7 +224,7 @@ class Loan(Domain):
     notes = UnicodeCol(default=u'')
 
     #: date loan was opened
-    open_date = DateTimeCol(default_factory=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=localnow)
 
     #: date loan was closed
     close_date = DateTimeCol(default=None)
@@ -213,20 +236,25 @@ class Loan(Domain):
     removed_by = UnicodeCol(default=u'')
 
     #: branch where the loan was done
-    branch_id = IntCol()
+    branch_id = IdCol()
     branch = Reference(branch_id, 'Branch.id')
 
     #: :class:`user <stoqlib.domain.person.LoginUser>` of the system
     #: that made the loan
     # FIXME: Should probably be a SalesPerson, we can find the
     #        LoginUser via te.user_id
-    responsible_id = IntCol()
+    responsible_id = IdCol()
     responsible = Reference(responsible_id, 'LoginUser.id')
 
     #: client that loaned the items
-    client_id = IntCol(default=None)
+    client_id = IdCol(default=None)
     client = Reference(client_id, 'Client.id')
 
+    client_category_id = IdCol(default=None)
+
+    #: the |clientcategory| used for price determination.
+    client_category = Reference(client_category_id, 'ClientCategory.id')
+
     #: a list of all items loaned in this loan
     loaned_items = ReferenceSet('id', 'LoanItem.loan_id')
 
@@ -244,7 +272,6 @@ class Loan(Domain):
     # IContainer implementation
     #
 
-    @argcheck(LoanItem)
     def add_item(self, loan_item):
         assert not loan_item.loan
         loan_item.loan = self
@@ -252,28 +279,99 @@ class Loan(Domain):
     def get_items(self):
         return self.store.find(LoanItem, loan=self)
 
-    @argcheck(LoanItem)
     def remove_item(self, loan_item):
-        LoanItem.delete(loan_item.id, store=self.store)
+        loan_item.loan = None
+        self.store.maybe_remove(loan_item)
 
     #
     # Public API
     #
 
-    def add_sellable(self, sellable, quantity=1, price=None):
+    def add_sellable(self, sellable, quantity=1, price=None, batch=None):
         """Adds a new sellable item to a loan
 
-        :param sellable: the sellable
+        :param sellable: the |sellable|
         :param quantity: quantity to add, defaults to 1
         :param price: optional, the price, it not set the price
           from the sellable will be used
+        :param batch: the |batch| this sellable comes from if the sellable is a
+          storable. Should be ``None`` if it is not a storable or if the storable
+          does not have batches.
         """
+        self.validate_batch(batch, sellable=sellable)
         price = price or sellable.price
+        base_price = sellable.price
         return LoanItem(store=self.store,
                         quantity=quantity,
                         loan=self,
                         sellable=sellable,
-                        price=price)
+                        batch=batch,
+                        price=price,
+                        base_price=base_price)
+
+    def get_available_discount_for_items(self, user=None, exclude_item=None):
+        """Get available discount for items in this loan
+
+        The available items discount is the total discount not used
+        by items in this sale. For instance, if we have 2 products
+        with a price of 100 and they can have 10% of discount, we have
+        20 of discount available. If one of those products price
+        is set to 98, that is, using 2 of it's discount, the available
+        discount is now 18.
+
+        :param user: passed to
+            :meth:`stoqlib.domain.sellable.Sellable.get_maximum_discount`
+            together with :obj:`.client_category` to check for the max
+            discount for sellables on this sale
+        :param exclude_item: a |saleitem| to exclude from the calculations.
+            Useful if you are trying to get some extra discount for that
+            item and you don't want it's discount to be considered here
+        :returns: the available discount
+        """
+        available_discount = currency(0)
+        used_discount = currency(0)
+
+        for item in self.get_items():
+            if item == exclude_item:
+                continue
+            # Don't put surcharges on the discount, or it can end up negative
+            if item.price > item.sellable.base_price:
+                continue
+
+            used_discount += item.sellable.base_price - item.price
+            max_discount = item.sellable.get_maximum_discount(
+                category=self.client_category, user=user) / 100
+            available_discount += item.base_price * max_discount
+
+        return available_discount - used_discount
+
+    def set_items_discount(self, discount):
+        """Apply discount on this sale's items
+
+        :param decimal.Decimal discount: the discount to be applied
+            as a percentage, e.g. 10.0, 22.5
+        """
+        new_total = currency(0)
+
+        item = None
+        candidate = None
+        for item in self.get_items():
+            item.set_discount(discount)
+            new_total += item.price * item.quantity
+            if item.quantity == 1:
+                candidate = item
+
+        # Since we apply the discount percentage above, items can generate a
+        # 3rd decimal place, that will be rounded to the 2nd, making the value
+        # differ. Find that difference and apply it to a sale item, preferable
+        # to one with a quantity of 1 since, for instance, applying +0,1 to an
+        # item with a quantity of 4 would make it's total +0,4 (+0,3 extra than
+        # we are trying to adjust here).
+        discount_value = (self.get_sale_base_subtotal() * discount) / 100
+        diff = new_total - self.get_sale_base_subtotal() + discount_value
+        if diff:
+            item = candidate or item
+            item.price -= diff
 
     #
     # Accessors
@@ -302,15 +400,12 @@ class Loan(Domain):
 
     def get_branch_name(self):
         if self.branch:
-            return self.branch.person.name
+            return self.branch.get_description()
         return u''
 
     def get_responsible_name(self):
         return self.responsible.person.name
 
-    def get_order_number_str(self):
-        return u'%05d' % self.identifier
-
     #
     # Public API
     #
@@ -323,6 +418,9 @@ class Loan(Domain):
         to do that one by one.
         """
         for loan_item in self.get_items():
+            # No need to sync stock for products that dont need.
+            if not loan_item.sellable.product.manage_stock:
+                continue
             loan_item.sync_stock()
 
     def can_close(self):
@@ -337,9 +435,21 @@ class Loan(Domain):
                 return False
         return True
 
+    def get_sale_base_subtotal(self):
+        """Get the base subtotal of items
+
+        Just a helper that, unlike :meth:`.get_sale_subtotal`, will
+        return the total based on item's base price.
+
+        :returns: the base subtotal
+        """
+        subtotal = self.get_items().sum(LoanItem.quantity *
+                                        LoanItem.base_price)
+        return currency(subtotal)
+
     def close(self):
         """Closes the loan. At this point, all the loan items have been
         returned to stock or sold."""
         assert self.can_close()
-        self.close_date = datetime.datetime.now()
+        self.close_date = localnow()
         self.status = Loan.STATUS_CLOSED
