@@ -23,27 +23,25 @@
 ##
 """Payment methods"""
 
-from decimal import Decimal
-import datetime
+# pylint: enable=E1101
+
 import operator
 
 from kiwi import ValueUnset
-from kiwi.argcheck import argcheck
 from storm.expr import And
 from storm.references import Reference
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.expr import TransactionTimestamp
-from stoqlib.database.properties import IntCol, BoolCol, UnicodeCol
+from stoqlib.database.properties import IntCol, BoolCol, UnicodeCol, IdCol
 from stoqlib.database.properties import PercentCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IActive, IDescribable
-from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.person import Branch
 from stoqlib.domain.till import Till
-from stoqlib.exceptions import DatabaseInconsistency, PaymentMethodError
-from stoqlib.lib.defaults import quantize
+from stoqlib.exceptions import (DatabaseInconsistency, PaymentMethodError,
+                                TillError)
+from stoqlib.lib.payment import generate_payments_values
 from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -60,17 +58,19 @@ class CheckData(Domain):
 
     __storm_table__ = 'check_data'
 
-    payment_id = IntCol()
+    payment_id = IdCol()
 
     #: the :class:`payment <stoqlib.domain.payment.Payment>`
     payment = Reference(payment_id, 'Payment.id')
 
-    bank_account_id = IntCol()
+    bank_account_id = IdCol()
 
     #: the :class:`bank account <stoqlib.domain.account.BankAccount>`
     bank_account = Reference(bank_account_id, 'BankAccount.id')
 
 
+@implementer(IActive)
+@implementer(IDescribable)
 class PaymentMethod(Domain):
     """A PaymentMethod controls how a payments is paid. Example of payment
     methods are::
@@ -86,8 +86,6 @@ class PaymentMethod(Domain):
     PaymentMethodOperation associated.
     """
 
-    implements(IActive, IDescribable)
-
     __storm_table__ = 'payment_method'
 
     method_name = UnicodeCol()
@@ -108,7 +106,7 @@ class PaymentMethod(Domain):
     #: payment_day? Sales after this day will be paid only in the next month.
     closing_day = IntCol(default=None)
     max_installments = IntCol(default=1)
-    destination_account_id = IntCol(default=None)
+    destination_account_id = IdCol(default=None)
     destination_account = Reference(destination_account_id, 'Account.id')
 
     #
@@ -155,45 +153,6 @@ class PaymentMethod(Domain):
         from stoqlib.domain.payment.operation import get_payment_operation
         return get_payment_operation(self.method_name)
 
-    #
-    # Private API
-    #
-
-    def _check_installments_number(self, installments_number, maximum=None):
-        if maximum is None:
-            maximum = self.max_installments
-        if installments_number > maximum:
-            raise ValueError(
-                _('The number of installments can not be greater than %d '
-                  'for payment method %r') % (maximum, self))
-
-    def _check_penalty_value(self, penalty):
-        penalty = penalty or Decimal(0)
-        if not isinstance(penalty, (int, Decimal)):
-            raise TypeError('penalty argument must be integer '
-                            'or Decimal, got %s instead'
-                            % type(penalty))
-        if not (0 <= penalty <= 100):
-            raise ValueError(_("Penalty must be "
-                               "between 0 and 100, not %s")
-                             % penalty)
-
-    def _calculate_payment_value(self, total_value, installments_number,
-                                 payment_type, penalty=None):
-        if not installments_number:
-            raise ValueError(_('The payment_qty argument must be greater '
-                               'than zero'))
-        if payment_type == Payment.TYPE_IN:
-            self._check_installments_number(installments_number)
-
-        self._check_penalty_value(penalty)
-
-        if not penalty:
-            return total_value / installments_number
-
-        penalty_rate = penalty / 100 + 1
-        return (total_value / installments_number) * penalty_rate
-
     #
     # Public API
     #
@@ -202,8 +161,6 @@ class PaymentMethod(Domain):
     #       they don't really belong to the method itself.
     #       They should either go into the group or to a separate payment
     #       factory singleton.
-    @argcheck(int, PaymentGroup, Branch, Decimal, datetime.datetime,
-              basestring, basestring, object, basestring)
     def create_payment(self, payment_type, payment_group, branch, value,
                        due_date=None, description=None, base_value=None,
                        till=ValueUnset, payment_number=None):
@@ -211,7 +168,7 @@ class PaymentMethod(Domain):
 
         :param payment_type: the kind of payment, in or out
         :param payment_group: a :class:`PaymentGroup` subclass
-        :param branch: the :class:`branch <stoqlib.domain.person.Branch>'
+        :param branch: the :class:`branch <stoqlib.domain.person.Branch>`
           associated with the payment, for incoming payments this is the
           branch receiving the payment and for outgoing payments this is the
           branch sending the payment.
@@ -252,7 +209,10 @@ class PaymentMethod(Domain):
         if till is ValueUnset:
             # We only need a till for inpayments
             if payment_type == Payment.TYPE_IN:
-                till = Till.get_current(store)
+                try:
+                    till = Till.get_current(store)
+                except TillError as err:
+                    raise PaymentMethodError(str(err))
             elif payment_type == Payment.TYPE_OUT:
                 till = None
             else:
@@ -273,7 +233,6 @@ class PaymentMethod(Domain):
         self.operation.payment_create(payment)
         return payment
 
-    @argcheck(int, PaymentGroup, Branch, Decimal, object)
     def create_payments(self, payment_type, group, branch, value, due_dates):
         """Creates new payments
         The values of the individual payments are calculated by taking
@@ -282,40 +241,42 @@ class PaymentMethod(Domain):
         sequence.
 
         :param payment_type: the kind of payment, in or out
-        :param payment_group: a :class:`PaymentGroup` subclass
-        :param branch: the :class:`branch <stoqlib.domain.person.Branch>'
-          associated with the payments, for incoming payments this is the
-          branch receiving the payment and for outgoing payments this is the
-          branch sending the payment.
-        :param value: value of payment
+        :param payment_group: a |paymentgroup|
+        :param branch: the |branch| associated with the payments, for incoming
+          payments this is the  branch receiving the payment and for outgoing
+          payments this is the branch sending the payment.
+        :param value: total value of all payments
         :param due_dates: a list of datetime objects
-        :returns: a list of :class:`payments <stoqlib.domain.payment.Payment>`
+        :returns: a list of |payments|
         """
         installments = len(due_dates)
-        penalty = Decimal(0)
-
-        normalized_value = self._calculate_payment_value(
-            value, installments, payment_type, penalty)
-
-        normalized_value = quantize(normalized_value)
-        if penalty:
-            penalty_total = normalized_value * installments - value
-        else:
-            penalty_total = Decimal(0)
+        if not installments:
+            raise ValueError(_('Need at least one installment'))
+        if payment_type == Payment.TYPE_IN:
+            if installments > self.max_installments:
+                raise ValueError(
+                    _('The number of installments can not be greater than %d '
+                      'for payment method %s') % (self.max_installments,
+                                                  self.method_name))
 
+        # Create the requested payments with the right:
+        # - due_date
+        # - description for the specific group
+        # - normalized value
         payments = []
-        payments_total = Decimal(0)
-        for i, due_date in enumerate(due_dates):
-            payment = self.create_payment(payment_type,
-                group, branch, normalized_value, due_date,
-                description=self.describe_payment(group, i + 1, installments))
+        normalized_values = generate_payments_values(value, installments)
+        for (i, due_date), normalized_value in zip(enumerate(due_dates),
+                                                   normalized_values):
+            description = self.describe_payment(group, i + 1, installments)
+            payment = self.create_payment(
+                payment_type=payment_type,
+                payment_group=group,
+                branch=branch,
+                value=normalized_value,
+                due_date=due_date,
+                description=description)
             payments.append(payment)
-            payments_total += normalized_value
 
-        # Adjust the last payment so it the total will sum up nicely.
-        difference = -(payments_total - penalty_total - value)
-        if difference:
-            payment.value += difference
         return payments
 
     def describe_payment(self, payment_group, installment=1, installments=1):
@@ -334,85 +295,9 @@ class PaymentMethod(Domain):
 
         # TRANSLATORS: This will generate something like: 1/1 Money for sale 00001
         return _(u'{installment} {method_name} for {order_description}').format(
-                 installment=u'%s/%s' % (installment, installments),
-                 method_name=self.get_description(),
-                 order_description=payment_group.get_description())
-
-    @argcheck(PaymentGroup, Branch, Decimal, datetime.datetime,
-              basestring, Decimal, object)
-    def create_inpayment(self, payment_group, branch, value, due_date=None,
-                         description=None, base_value=None, till=ValueUnset):
-        """Creates a new inpayment
-
-        :param payment_group: a :class:`PaymentGroup` subclass
-        :param branch: the :class:`branch <stoqlib.domain.person.Branch>'
-          that will receive the payment created.
-        :param value: value of payment
-        :param due_date: optional, due date of payment
-        :param description: optional, description of the payment
-        :param base_value: optional
-        :param till: optional
-        :returns: a :class:`payment <stoqlib.domain.payment.Payment>`
-        """
-        return self.create_payment(Payment.TYPE_IN, payment_group,
-                                   branch, value, due_date,
-                                   description, base_value, till)
-
-    @argcheck(PaymentGroup, Branch, Decimal, datetime.datetime,
-              basestring, Decimal, object)
-    def create_outpayment(self, payment_group, branch, value, due_date=None,
-                          description=None, base_value=None, till=ValueUnset):
-        """Creates a new outpayment
-
-        :param payment_group: a :class:`PaymentGroup` subclass
-        :param branch: the :class:`branch <stoqlib.domain.person.Branch>'
-          that will pay the payment created.
-        :param value: value of payment
-        :param due_date: optional, due date of payment
-        :param description: optional, description of the payment
-        :param base_value: optional
-        :param till: optional
-        :returns: a :class:`payment <stoqlib.domain.payment.Payment>`
-        """
-        return self.create_payment(Payment.TYPE_OUT, payment_group,
-                                   branch, value, due_date,
-                                   description, base_value, till)
-
-    @argcheck(PaymentGroup, Branch, Decimal, object)
-    def create_inpayments(self, payment_group, branch, value, due_dates):
-        """Creates a list of new inpayments, the values of the individual
-        payments are calculated by taking the value and dividing it by
-        the number of payments.
-        The number of payments is determined by the length of the due_dates
-        sequence.
-
-        :param payment_group: a :class:`PaymentGroup` subclass
-        :param branch: the :class:`branch <stoqlib.domain.person.Branch>'
-          that will receive the payments created.
-        :param value: total value of all payments
-        :param due_dates: a list of datetime objects
-        :returns: a list of :class:`payments <stoqlib.domain.payment.Payment>`
-        """
-        return self.create_payments(Payment.TYPE_IN, payment_group,
-                                    branch, value, due_dates)
-
-    @argcheck(PaymentGroup, Branch, Decimal, object)
-    def create_outpayments(self, payment_group, branch, value, due_dates):
-        """Creates a list of new outpayments, the values of the individual
-        payments are calculated by taking the value and dividing it by
-        the number of payments.
-        The number of payments is determined by the length of the due_dates
-        sequence.
-
-        :param payment_group: a :class:`PaymentGroup` subclass
-        :param branch: the :class:`branch <stoqlib.domain.person.Branch>'
-          that will pay the payments created.
-        :param value: total value of all payments
-        :param due_dates: a list of datetime objects
-        :returns: a list of :class:`payments <stoqlib.domain.payment.Payment>`
-        """
-        return self.create_payments(Payment.TYPE_OUT, payment_group,
-                                    branch, value, due_dates)
+            installment=u'%s/%s' % (installment, installments),
+            method_name=self.get_description(),
+            order_description=payment_group.get_description())
 
     @classmethod
     def get_active_methods(cls, store):
