@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2008-2012 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2008-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -29,9 +29,11 @@ for the logic needed by a payment method.
 Such as storing the kind of credit card or associate a check with a bank account.
 """
 
-from kiwi.argcheck import argcheck
+# pylint: enable=E1101
+
 from kiwi.component import get_utility, provide_utility
-from zope.interface import implements
+from stoqdrivers.enum import PaymentMethodType
+from zope.interface import implementer
 
 from stoqlib.domain.account import BankAccount
 from stoqlib.domain.payment.card import CreditProvider, CreditCardData
@@ -39,13 +41,56 @@ from stoqlib.domain.payment.method import CheckData, Payment
 from stoqlib.lib.interfaces import IPaymentOperation, IPaymentOperationManager
 from stoqlib.lib.translation import stoqlib_gettext
 
-from stoqdrivers.enum import PaymentMethodType
-
 _ = stoqlib_gettext
 
 
+def payment_operation(method_name=None, fallback=False):
+    """
+    A class decorator to register a payment operation which contains some
+    of the business logic for a certain payment method.
+
+    :param method_name: name of the method or ``None``
+    :param fallback: if ``True``, will be registered as a fallback
+    """
+    def wrapper(cls):
+        pmm = get_payment_operation_manager()
+        if fallback:
+            pmm.register_fallback(cls())
+        else:
+            pmm.register(method_name, cls())
+        return cls
+    return wrapper
+
+
+def get_payment_operation_manager():
+    """Returns the payment operation manager"""
+    pmm = get_utility(IPaymentOperationManager, None)
+
+    if not pmm:
+        from stoqlib.lib.payment import PaymentOperationManager
+        pmm = PaymentOperationManager()
+        provide_utility(IPaymentOperationManager, pmm)
+
+    return pmm
+
+
+def get_payment_operation(method_name):
+    """Returns the payment operation for method_name
+
+    :param method_name: the method name
+    """
+    pmm = get_payment_operation_manager()
+    pm = pmm.get(method_name)
+    if not pm:  # pragma: nocover
+        raise KeyError(u"There's no payment operation for method '%s'" %
+                       method_name)
+
+    return pm
+
+
+@payment_operation(u'money')
+@implementer(IPaymentOperation)
 class MoneyPaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Money')
     max_installments = 1
@@ -84,15 +129,19 @@ class MoneyPaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return True
+
+    def print_(self, payments):
         pass
 
     def require_person(self, payment_type):
         return False
 
 
+@payment_operation(u'check')
+@implementer(IPaymentOperation)
 class CheckPaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Check')
     max_installments = 12
@@ -138,7 +187,10 @@ class CheckPaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return True
+
+    def print_(self, payments):
         pass
 
     def require_person(self, payment_type):
@@ -148,15 +200,15 @@ class CheckPaymentOperation(object):
     # Public API
     #
 
-    @argcheck(Payment)
     def get_check_data_by_payment(self, payment):
         """Get an existing CheckData instance from a payment object."""
         store = payment.store
         return store.find(CheckData, payment=payment).one()
 
 
+@payment_operation(u'bill')
+@implementer(IPaymentOperation)
 class BillPaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Bill')
     max_installments = 12
@@ -180,9 +232,6 @@ class BillPaymentOperation(object):
     def creatable(self, method, payment_type, separate):
         return True
 
-    def payable(self, payment_type):
-        return True
-
     def can_cancel(self, payment):
         return True
 
@@ -197,6 +246,9 @@ class BillPaymentOperation(object):
             return False
         return True
 
+    def can_set_not_paid(self, payment):
+        return True
+
     def print_(self, payments):
         from stoqlib.reporting.boleto import BillReport
         if not BillReport.check_printable(payments):
@@ -212,8 +264,9 @@ class BillPaymentOperation(object):
         return False
 
 
+@payment_operation(u'card')
+@implementer(IPaymentOperation)
 class CardPaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Card')
     max_installments = 12
@@ -221,10 +274,8 @@ class CardPaymentOperation(object):
     CARD_METHOD_CONSTANTS = {
         CreditCardData.TYPE_CREDIT: PaymentMethodType.CREDIT_CARD,
         CreditCardData.TYPE_DEBIT: PaymentMethodType.DEBIT_CARD,
-        CreditCardData.TYPE_CREDIT_INSTALLMENTS_STORE:
-             PaymentMethodType.CREDIT_CARD,
-        CreditCardData.TYPE_CREDIT_INSTALLMENTS_PROVIDER:
-             PaymentMethodType.CREDIT_CARD,
+        CreditCardData.TYPE_CREDIT_INSTALLMENTS_STORE: PaymentMethodType.CREDIT_CARD,
+        CreditCardData.TYPE_CREDIT_INSTALLMENTS_PROVIDER: PaymentMethodType.CREDIT_CARD,
         CreditCardData.TYPE_DEBIT_PRE_DATED: PaymentMethodType.DEBIT_CARD,
     }
 
@@ -239,7 +290,7 @@ class CardPaymentOperation(object):
     def payment_delete(self, payment):
         store = payment.store
         credit_card_data = self.get_card_data_by_payment(payment)
-        CreditCardData.delete(credit_card_data.id, store=store)
+        store.remove(credit_card_data)
 
     def create_transaction(self):
         return True
@@ -266,7 +317,10 @@ class CardPaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return True
+
+    def print_(self, payments):
         pass
 
     def get_constant(self, payment):
@@ -280,15 +334,15 @@ class CardPaymentOperation(object):
     #  Public API
     #
 
-    @argcheck(Payment)
     def get_card_data_by_payment(self, payment):
         """Get an existing CreditCardData instance from a payment object."""
         store = payment.store
         return store.find(CreditCardData, payment=payment).one()
 
 
+@payment_operation(u'store_credit')
+@implementer(IPaymentOperation)
 class StoreCreditPaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Store Credit')
     max_installments = 1
@@ -335,13 +389,16 @@ class StoreCreditPaymentOperation(object):
 
         return True
 
+    def can_set_not_paid(self, payment):
+        return True
+
     def print_(self, payments):
         from stoqlib.reporting.booklet import BookletReport
         return BookletReport
 
     def get_constant(self, payment):
         # FIXME: Add another constant to stoqdrivers?
-        return PaymentMethodType.CUSTOM
+        return PaymentMethodType.MONEY
 
     def require_person(self, payment_type):
         if payment_type == Payment.TYPE_IN:
@@ -349,8 +406,71 @@ class StoreCreditPaymentOperation(object):
         return False
 
 
+@payment_operation(u'credit')
+@implementer(IPaymentOperation)
+class CreditPaymentOperation(object):
+    """This payment method is used to register deposits (inpayments) and
+    withdrawals (outpayments) in a client's credit account.
+
+    When returning a sale, the store or the client can choose whether they want
+    to return in cash or if the account is deposited as credit so the client
+    can use it in the future.
+    """
+
+    description = _(u'Credit')
+    max_installments = 1
+
+    #
+    # IPaymentOperation
+    #
+
+    def payment_create(self, payment):
+        pass
+
+    def payment_delete(self, payment):
+        pass
+
+    def create_transaction(self):
+        return False
+
+    def selectable(self, method):
+        return True
+
+    def creatable(self, method, payment_type, separate):
+        # Credit is only allowed when selling.
+        if payment_type != Payment.TYPE_IN:
+            return False
+        return True
+
+    def can_cancel(self, payment):
+        return False
+
+    def can_change_due_date(self, payment):
+        return False
+
+    def can_pay(self, payment):
+        return True
+
+    def can_print(self, payment):
+        return False
+
+    def can_set_not_paid(self, payment):
+        return False
+
+    def print_(self, payments):
+        pass
+
+    def get_constant(self, payment):
+        # FIXME: Add another constant to stoqdrivers?
+        return PaymentMethodType.MONEY
+
+    def require_person(self, payment_type):
+        return True
+
+
+@payment_operation(u'deposit')
+@implementer(IPaymentOperation)
 class DepositPaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Deposit')
     max_installments = 12
@@ -389,15 +509,19 @@ class DepositPaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return True
+
+    def print_(self, payments):
         pass
 
     def require_person(self, payment_type):
         return False
 
 
+@payment_operation(u'online')
+@implementer(IPaymentOperation)
 class OnlinePaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Online')
     max_installments = 1
@@ -437,15 +561,19 @@ class OnlinePaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return True
+
+    def print_(self, payments):
         pass
 
     def require_person(self, payment_type):
         return True
 
 
+@payment_operation(u'trade')
+@implementer(IPaymentOperation)
 class TradePaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Trade')
     max_installments = 1
@@ -482,7 +610,10 @@ class TradePaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return False
+
+    def print_(self, payments):
         pass
 
     def get_constant(self, payment):
@@ -496,8 +627,9 @@ class TradePaymentOperation(object):
 # The MultiplePaymentOperation is not a payment operation, but we need to
 # register it, so it could be activated or not. It will not create anything
 # related to payments.
+@payment_operation(u'multiple')
+@implementer(IPaymentOperation)
 class MultiplePaymentOperation(object):
-    implements(IPaymentOperation)
 
     description = _(u'Multiple')
     max_installments = 12
@@ -542,7 +674,10 @@ class MultiplePaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return False
+
+    def print_(self, payments):
         pass
 
     def get_constant(self, payment):
@@ -552,12 +687,13 @@ class MultiplePaymentOperation(object):
         return False
 
 
+@payment_operation(fallback=True)
+@implementer(IPaymentOperation)
 class InvalidPaymentOperation(object):
     """This operation will be used as a fallback for methods that wore removed
     from stoq, but may still exist in the database (they cannot be removed,
     since payments may have been created using that method).
     """
-    implements(IPaymentOperation)
 
     description = _(u'Invalid payment')
     max_installments = 1
@@ -596,49 +732,11 @@ class InvalidPaymentOperation(object):
     def can_print(self, payment):
         return False
 
-    def print_(self, payment):
+    def can_set_not_paid(self, payment):
+        return True
+
+    def print_(self, payments):
         pass
 
     def require_person(self, payment_type):
         return False
-
-
-def get_payment_operation_manager():
-    """Returns the payment operation manager"""
-    pmm = get_utility(IPaymentOperationManager, None)
-
-    if not pmm:
-        from stoqlib.lib.payment import PaymentOperationManager
-        pmm = PaymentOperationManager()
-        provide_utility(IPaymentOperationManager, pmm)
-
-        for method_name, klass in [
-            (u'money', MoneyPaymentOperation),
-            (u'check', CheckPaymentOperation),
-            (u'bill', BillPaymentOperation),
-            (u'card', CardPaymentOperation),
-            (u'store_credit', StoreCreditPaymentOperation),
-            (u'trade', TradePaymentOperation),
-            (u'multiple', MultiplePaymentOperation),
-            (u'deposit', DepositPaymentOperation),
-            (u'online', OnlinePaymentOperation),
-            ]:
-            pmm.register(method_name, klass())
-        # Also, register InvalidPaymentOperation as a fallback operation
-        pmm.register_fallback(InvalidPaymentOperation())
-
-    return pmm
-
-
-def get_payment_operation(method_name):
-    """Returns the payment operation for method_name
-
-    :param method_name: the method name
-    """
-    pmm = get_payment_operation_manager()
-    pm = pmm.get(method_name)
-    if not pm:
-        raise KeyError(u"There's no payment operation for method '%s'" %
-                       method_name)
-
-    return pm
