@@ -32,26 +32,26 @@ to or from a |branch|.
 Certain changes to a payment is saved in :class:`PaymentChangeHistory`
 """
 
-import datetime
+# pylint: enable=E1101
+
+import logging
 
 from kiwi.currency import currency
-from kiwi.log import Logger
 from storm.references import Reference, ReferenceSet
-from storm.store import AutoReload
 
 from stoqlib.database.expr import TransactionTimestamp
 from stoqlib.database.properties import (DateTimeCol, IntCol, BoolCol,
-                                         PriceCol, UnicodeCol)
+                                         PriceCol, UnicodeCol, IdentifierCol,
+                                         IdCol)
 from stoqlib.domain.account import AccountTransaction
 from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
-from stoqlib.domain.interfaces import IPaymentTransaction
 from stoqlib.exceptions import DatabaseInconsistency, StoqlibError
-from stoqlib.lib.dateutils import create_date_interval
+from stoqlib.lib.dateutils import create_date_interval, localnow, localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class Payment(Domain):
@@ -145,9 +145,9 @@ class Payment(Domain):
     payment_type = IntCol()
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
 
     #: status, see |payment| for more information.
     status = IntCol(default=STATUS_PREVIEW)
@@ -159,7 +159,7 @@ class Payment(Domain):
     #        inconsistencies
 
     #: when this payment was opened
-    open_date = DateTimeCol(default_factory=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=localnow)
 
     #: when this payment is due
     due_date = DateTimeCol()
@@ -194,7 +194,7 @@ class Payment(Domain):
     #: number of the payment
     payment_number = UnicodeCol(default=None)
 
-    branch_id = IntCol(allow_none=False)
+    branch_id = IdCol(allow_none=False)
 
     #: |branch| associated with this payment.
     #: For a :obj:`.TYPE_IN` payment, this is the branch that will receive
@@ -202,23 +202,23 @@ class Payment(Domain):
     #: will make the payment
     branch = Reference(branch_id, 'Branch.id')
 
-    method_id = IntCol()
+    method_id = IdCol()
 
     #: |paymentmethod| for this payment
     #: payment
     method = Reference(method_id, 'PaymentMethod.id')
 
-    group_id = IntCol()
+    group_id = IdCol()
 
     #: |paymentgroup| for this payment
     group = Reference(group_id, 'PaymentGroup.id')
 
-    till_id = IntCol()
+    till_id = IdCol()
 
     #: |till| that this payment belongs to
     till = Reference(till_id, 'Till.id')
 
-    category_id = IntCol()
+    category_id = IdCol()
 
     #: |paymentcategory| this payment belongs to, can be None
     category = Reference(category_id, 'PaymentCategory.id')
@@ -231,7 +231,7 @@ class Payment(Domain):
     #: this payment
     check_data = Reference('id', 'CheckData.payment_id', on_remote=True)
 
-    #: |transaction| for this payment
+    #: |accounttransaction| for this payment
     transaction = Reference('id', 'AccountTransaction.payment_id', on_remote=True)
 
     #: indicates if a bill has been received. They are usually delivered by
@@ -239,7 +239,7 @@ class Payment(Domain):
     #: been paid, just that the receiver has notified the payer somehow.
     bill_received = BoolCol(default=False)
 
-    attachment_id = IntCol()
+    attachment_id = IdCol()
 
     #: |attachment| for this payment
     attachment = Reference(attachment_id, 'Attachment.id')
@@ -252,9 +252,10 @@ class Payment(Domain):
         Domain.__init__(self, store=store, **kw)
 
     def _check_status(self, status, operation_name):
-        assert self.status == status, ('Invalid status for %s '
-                                       'operation: %s' % (operation_name,
-                                       self.statuses[self.status]))
+        fmt = 'Invalid status for %s operation: %s'
+        assert self.status == status, (
+            fmt % (operation_name,
+                   self.statuses[self.status]))
 
     #
     # ORMObject hooks
@@ -264,6 +265,8 @@ class Payment(Domain):
         # First call hooks, do this first so the hook
         # have access to everything it needs
         self.method.operation.payment_delete(self)
+        # FIXME: BUG 5581 check if it is really safe to remove the payment
+        # when using with synced databases
         self.store.remove(self)
 
     @classmethod
@@ -298,7 +301,7 @@ class Payment(Domain):
                         payment_type=payment.payment_type,
                         status=payment.status,
                         description=u'%d/%d %s' % (i + 2, n_dates,
-                                                  description),
+                                                   description),
                         value=payment.value,
                         base_value=payment.base_value,
                         due_date=date,
@@ -316,7 +319,7 @@ class Payment(Domain):
 
     @property
     def comments_number(self):
-        """The number of :class:`comments <stoqlib.domain.payment.comments.PaymentComment>` for this payment"""
+        """The number of |paymentcomments| for this payment"""
         return self.comments.count()
 
     @property
@@ -333,13 +336,15 @@ class Payment(Domain):
 
     @property
     def installment_number(self):
-        payments = self.group.get_valid_payments().order_by(Payment.id)
+        payments = self.group.get_valid_payments().order_by(
+            Payment.identifier)
         for i, payment in enumerate(payments):
             if self == payment:
                 return i + 1
 
-    def get_status_str(self):
-        """The :obj:`.status` as a translated string"""
+    @property
+    def status_str(self):
+        """The :obj:`Payment.status` as a translated string"""
         if not self.status in self.statuses:
             raise DatabaseInconsistency('Invalid status for Payment '
                                         'instance, got %d' % self.status)
@@ -353,7 +358,7 @@ class Payment(Domain):
         if self.status == Payment.STATUS_PAID:
             return 0
 
-        days_late = datetime.date.today() - self.due_date.date()
+        days_late = localtoday().date() - self.due_date.date()
         if days_late.days < 0:
             return 0
 
@@ -387,7 +392,11 @@ class Payment(Domain):
         self.paid_value = None
 
     def pay(self, paid_date=None, paid_value=None, account=None):
-        """Pay the current payment set its status as :obj:`.STATUS_PAID`"""
+        """Pay the current payment set its status as :obj:`.STATUS_PAID`
+
+        If this payment belongs to a sale, and all other payments from the sale
+        are paid then the sale will be set as paid.
+        """
         if self.status != Payment.STATUS_PENDING:
             raise ValueError(_(u"This payment is already paid."))
         self._check_status(self.STATUS_PENDING, u'pay')
@@ -404,31 +413,34 @@ class Payment(Domain):
 
         sale = self.group and self.group.sale
         if sale:
-            transaction = IPaymentTransaction(sale)
-            transaction.create_commission(self)
+            sale.create_commission(self)
+
+            # When paying payments of a sale, check if the other payments are
+            # paid. If they are, this means you can change the sale status to
+            # paid as well.
+            if sale.can_set_paid():
+                sale.set_paid()
 
         if self.value == self.paid_value:
             msg = _(u"{method} payment with value {value:.2f} was paid").format(
-                    method=self.method.method_name,
-                    value=self.value)
+                method=self.method.method_name,
+                value=self.value)
         else:
             msg = _(u"{method} payment with value original value "
                     u"{original_value:.2f} was paid with value "
-                    u"{value:.2f}").format(
-                    method=self.method.method_name,
-                    original_value=self.value,
-                    value=self.paid_value)
-        Event.log(Event.TYPE_PAYMENT, msg.capitalize())
+                    u"{value:.2f}").format(method=self.method.method_name,
+                                           original_value=self.value,
+                                           value=self.paid_value)
+        Event.log(self.store, Event.TYPE_PAYMENT, msg.capitalize())
 
     def cancel(self, change_entry=None):
         """Cancel the payment, set it's status to :obj:`.STATUS_CANCELLED`
         """
         # TODO Check for till entries here and call cancel_till_entry if
         # it's possible. Bug 2598
-        if self.status not in [Payment.STATUS_PREVIEW, Payment.STATUS_PENDING,
-                               Payment.STATUS_PAID]:
+        if not self.can_cancel():
             raise StoqlibError(_(u"Invalid status for cancel operation, "
-                                 u"got %s") % self.get_status_str())
+                                 u"got %s") % self.status_str)
 
         if self.transaction:
             self.transaction.create_reverse()
@@ -442,9 +454,9 @@ class Payment(Domain):
             change_entry.new_status = self.status
 
         msg = _(u"{method} payment with value {value:.2f} was cancelled").format(
-                method=self.method.method_name,
-                value=self.value)
-        Event.log(Event.TYPE_PAYMENT, msg.capitalize())
+            method=self.method.method_name,
+            value=self.value)
+        Event.log(self.store, Event.TYPE_PAYMENT, msg.capitalize())
 
     def change_due_date(self, new_due_date):
         """Changes the payment due date.
@@ -453,7 +465,7 @@ class Payment(Domain):
         """
         if self.status in [Payment.STATUS_PAID, Payment.STATUS_CANCELLED]:
             raise StoqlibError(_(u"Invalid status for change_due_date operation, "
-                                 u"got %s") % self.get_status_str())
+                                 u"got %s") % self.status_str)
         self.due_date = new_due_date
 
     def update_value(self, new_value):
@@ -462,6 +474,10 @@ class Payment(Domain):
         """
         self.value = new_value
 
+    def can_cancel(self):
+        return self.status in (Payment.STATUS_PREVIEW, Payment.STATUS_PENDING,
+                               Payment.STATUS_PAID)
+
     def get_payable_value(self):
         """Returns the calculated payment value with the daily interest.
 
@@ -484,11 +500,11 @@ class Payment(Domain):
         :returns: penalty
         :rtype: :class:`kiwi.currency.currency`
         """
-        if not date:
-            date = datetime.date.today()
+        if date is None:
+            date = localtoday().date()
         elif date < self.open_date.date():
             raise ValueError(_(u"Date can not be less then open date"))
-        elif date > datetime.date.today():
+        elif date > localtoday().date():
             raise ValueError(_(u"Date can not be greather then future date"))
         if not self.method.penalty:
             return currency(0)
@@ -506,11 +522,11 @@ class Payment(Domain):
         :returns: interest
         :rtype: :class:`kiwi.currency.currency`
         """
-        if not date:
-            date = datetime.date.today()
+        if date is None:
+            date = localtoday().date()
         elif date < self.open_date.date():
             raise ValueError(_(u"Date can not be less then open date"))
-        elif date > datetime.date.today():
+        elif date > localtoday().date():
             raise ValueError(_(u"Date can not be greather then future date"))
 
         if not self.method.daily_interest:
@@ -576,9 +592,6 @@ class Payment(Domain):
             return self.open_date.date().strftime('%x')
         return u""
 
-    def get_payment_number_str(self):
-        return u'%05d' % self.identifier
-
     def is_inpayment(self):
         """Find out if a payment is :obj:`incoming <.TYPE_IN>`
 
@@ -616,12 +629,12 @@ class Payment(Domain):
 
         return True
 
-    def is_money(self):
-        """Find out if the payment was made with money
+    def is_of_method(self, method_name):
+        """Find out if the payment was made with a certain method
 
-        :returns: ``True`` if it's a money payment
+        :returns: ``True`` if it's a payment of that method
         """
-        return self.method.method_name == u'money'
+        return self.method.method_name == method_name
 
 
 class PaymentChangeHistory(Domain):
@@ -636,7 +649,7 @@ class PaymentChangeHistory(Domain):
 
     __storm_table__ = 'payment_change_history'
 
-    payment_id = IntCol()
+    payment_id = IdCol()
 
     #: the changed |payment|
     payment = Reference(payment_id, 'Payment.id')
@@ -645,7 +658,7 @@ class PaymentChangeHistory(Domain):
     change_reason = UnicodeCol(default=None)
 
     #: when the changed happened
-    change_date = DateTimeCol(default_factory=datetime.datetime.now)
+    change_date = DateTimeCol(default_factory=localnow)
 
     #: the due date that was set before the changed
     last_due_date = DateTimeCol(default=None)
