@@ -23,20 +23,20 @@
 ##
 """ Domain classes for renegotiation management """
 
-import datetime
+# pylint: enable=E1101
 
 from kiwi.currency import currency
 from storm.references import Reference
-from storm.store import AutoReload
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.expr import TransactionTimestamp
-from stoqlib.database.properties import (PriceCol, UnicodeCol,
-                                  IntCol, DateTimeCol)
+from stoqlib.database.properties import (PriceCol, UnicodeCol, IdentifierCol,
+                                         IntCol, DateTimeCol, IdCol)
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.group import PaymentGroup
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -46,10 +46,10 @@ _ = stoqlib_gettext
 # Base Domain Classes
 #
 
+@implementer(IContainer)
 class PaymentRenegotiation(Domain):
     """Class for payments renegotiations
     """
-    implements(IContainer)
 
     __storm_table__ = 'payment_renegotiation'
 
@@ -62,24 +62,24 @@ class PaymentRenegotiation(Domain):
                 STATUS_RENEGOTIATED: _(u'Renegotiated')}
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
 
     status = IntCol(default=STATUS_CONFIRMED)
     notes = UnicodeCol(default=None)
-    open_date = DateTimeCol(default_factory=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=localnow)
     close_date = DateTimeCol(default=None)
     discount_value = PriceCol(default=0)
     surcharge_value = PriceCol(default=0)
     total = PriceCol(default=0)
-    responsible_id = IntCol()
+    responsible_id = IdCol()
     responsible = Reference(responsible_id, 'LoginUser.id')
-    client_id = IntCol(default=None)
+    client_id = IdCol(default=None)
     client = Reference(client_id, 'Client.id')
-    branch_id = IntCol(default=None)
+    branch_id = IdCol(default=None)
     branch = Reference(branch_id, 'Branch.id')
-    group_id = IntCol()
+    group_id = IdCol()
     group = Reference(group_id, 'PaymentGroup.id')
 
     #
@@ -128,11 +128,11 @@ class PaymentRenegotiation(Domain):
     #
 
     def add_item(self, payment):
-        #TODO:
+        # TODO:
         pass
 
     def remove_item(self, payment):
-        #TODO:
+        # TODO:
         pass
 
     def get_items(self):
