@@ -22,11 +22,14 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-from dateutil.relativedelta import relativedelta
+# pylint: enable=E1101
 
+import datetime
+
+from dateutil.relativedelta import relativedelta
 from kiwi.datatypes import converter
-from storm.expr import And, Count, Join, LeftJoin, Or, Sum, Alias, Select
+from storm.expr import (And, Count, Join, LeftJoin, Or, Sum, Alias,
+                        Select, Cast)
 from storm.info import ClassAlias
 
 from stoqlib.database.expr import Date, Field
@@ -41,9 +44,10 @@ from stoqlib.domain.payment.method import CheckData, PaymentMethod
 from stoqlib.domain.payment.operation import get_payment_operation
 from stoqlib.domain.payment.payment import Payment, PaymentChangeHistory
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Person, Branch
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sale import Sale
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -67,10 +71,15 @@ class BasePaymentView(Viewable):
     purchase = PurchaseOrder
     sale = Sale
     method = PaymentMethod
+    branch = Branch
+
+    card_data = CreditCardData
+    check_data = CheckData
 
     # Payment
     id = Payment.id
     identifier = Payment.identifier
+    identifier_str = Cast(Payment.identifier, 'text')
     description = Payment.description
     due_date = Payment.due_date
     status = Payment.status
@@ -103,9 +112,12 @@ class BasePaymentView(Viewable):
 
     _count_tables = [
         Payment,
+        Join(Branch, Payment.branch_id == Branch.id),
         LeftJoin(PaymentGroup, PaymentGroup.id == Payment.group_id),
         LeftJoin(PaymentCategory, PaymentCategory.id == Payment.category_id),
         Join(PaymentMethod, Payment.method_id == PaymentMethod.id),
+        LeftJoin(CreditCardData, Payment.id == CreditCardData.payment_id),
+        LeftJoin(CheckData, Payment.id == CheckData.payment_id),
 
         # Purchase
         LeftJoin(PaymentGroup_Purchase, PaymentGroup_Purchase.id == Payment.group_id),
@@ -118,7 +130,21 @@ class BasePaymentView(Viewable):
 
     tables = _count_tables + [
         LeftJoin(CommentsSummary, Field('_comments', 'payment_id') == Payment.id),
-        ]
+    ]
+
+    #
+    # Private
+    #
+
+    def _get_due_date_delta(self):
+        if self.status in [Payment.STATUS_PAID, Payment.STATUS_CANCELLED]:
+            return datetime.timedelta(0)
+
+        return localtoday().date() - self.due_date.date()
+
+    #
+    # Public API
+    #
 
     @classmethod
     def post_search_callback(cls, sresults):
@@ -137,24 +163,15 @@ class BasePaymentView(Viewable):
 
         return self.status == Payment.STATUS_PENDING
 
-    def get_status_str(self):
+    @property
+    def status_str(self):
         return Payment.statuses[self.status]
 
     def is_late(self):
-        if self.status in [Payment.STATUS_PAID, Payment.STATUS_CANCELLED]:
-            return False
-
-        return (datetime.date.today() - self.due_date.date()).days > 0
+        return self._get_due_date_delta().days > 0
 
     def get_days_late(self):
-        if not self.is_late():
-            return 0
-
-        days_late = datetime.date.today() - self.due_date.date()
-        if days_late.days < 0:
-            return 0
-
-        return days_late.days
+        return max(self._get_due_date_delta().days, 0)
 
     def is_paid(self):
         return self.status == Payment.STATUS_PAID
@@ -188,7 +205,7 @@ class InPaymentView(BasePaymentView):
     _count_tables = BasePaymentView._count_tables[:]
     _count_tables.append(
         LeftJoin(Person,
-                    PaymentGroup.payer_id == Person.id))
+                 PaymentGroup.payer_id == Person.id))
 
     tables = BasePaymentView.tables[:]
     tables.extend([
@@ -202,14 +219,12 @@ class InPaymentView(BasePaymentView):
     @property
     def renegotiation(self):
         if self.renegotiation_id:
-            return PaymentRenegotiation.get(self.renegotiation_id,
-                                            store=self.store)
+            return self.store.get(PaymentRenegotiation, self.renegotiation_id)
 
     @property
     def renegotiated(self):
         if self.renegotiated_id:
-            return PaymentRenegotiation.get(self.renegotiated_id,
-                                            store=self.store)
+            return self.store.get(PaymentRenegotiation, self.renegotiated_id)
 
     def get_parent(self):
         return self.sale or self.renegotiation
@@ -222,12 +237,12 @@ class InPaymentView(BasePaymentView):
           check if has late payments
         :returns: True if the person has overdue payments. False otherwise
         """
-        tolerance = sysparam(store).TOLERANCE_FOR_LATE_PAYMENTS
+        tolerance = sysparam.get_int('TOLERANCE_FOR_LATE_PAYMENTS')
 
-        query = And(cls.person_id == person.id,
-                    cls.status == Payment.STATUS_PENDING,
-                    cls.due_date < datetime.date.today() -
-                                     relativedelta(days=tolerance))
+        query = And(
+            cls.person_id == person.id,
+            cls.status == Payment.STATUS_PENDING,
+            cls.due_date < localtoday() - relativedelta(days=tolerance))
 
         late_payments = store.find(cls, query)
         if late_payments.any():
@@ -258,10 +273,15 @@ class CardPaymentView(Viewable):
     _DraweePerson = ClassAlias(Person, "drawee_person")
 
     payment = Payment
+    credit_card_data = CreditCardData
+
+    #: the branch this payment was created on
+    branch = Branch
 
     # Payment Columns
     id = Payment.id
     identifier = Payment.identifier
+    identifier_str = Cast(Payment.identifier, 'text')
     description = Payment.description
     due_date = Payment.due_date
     paid_date = Payment.paid_date
@@ -273,6 +293,7 @@ class CardPaymentView(Viewable):
     fee = CreditCardData.fee
     fee_calc = CreditCardData.fee_value
     card_type = CreditCardData.card_type
+    auth = CreditCardData.auth
 
     device_id = CardPaymentDevice.id
     device_name = CardPaymentDevice.description
@@ -287,15 +308,17 @@ class CardPaymentView(Viewable):
         Join(PaymentMethod, PaymentMethod.id == Payment.method_id),
         Join(CreditCardData, CreditCardData.payment_id == Payment.id),
         Join(CreditProvider, CreditProvider.id == CreditCardData.provider_id),
+        Join(Branch, Branch.id == Payment.branch_id),
         LeftJoin(CardPaymentDevice, CardPaymentDevice.id == CreditCardData.device_id),
         LeftJoin(PaymentGroup, PaymentGroup.id == Payment.group_id),
         LeftJoin(_DraweePerson, _DraweePerson.id == PaymentGroup.payer_id),
         LeftJoin(Sale, Sale.group_id == PaymentGroup.id),
         LeftJoin(PaymentRenegotiation,
                  PaymentRenegotiation.group_id == PaymentGroup.id),
-        ]
+    ]
 
-    def get_status_str(self):
+    @property
+    def status_str(self):
         return Payment.statuses[self.status]
 
     @property
@@ -315,6 +338,9 @@ class _BillandCheckPaymentView(Viewable):
 
     payment = Payment
 
+    #: The branch this paymet was created on
+    branch = Branch
+
     id = Payment.id
     identifier = Payment.identifier
     due_date = Payment.due_date
@@ -324,11 +350,12 @@ class _BillandCheckPaymentView(Viewable):
     payment_number = Payment.payment_number
     method_name = PaymentMethod.method_name
     bank_number = BankAccount.bank_number
-    branch = BankAccount.bank_branch
-    account = BankAccount.bank_account
+    bank_branch = BankAccount.bank_branch
+    bank_account = BankAccount.bank_account
 
     tables = [
         Payment,
+        Join(Branch, Payment.branch_id == Branch.id),
         LeftJoin(CheckData, Payment.id == CheckData.payment_id),
         Join(PaymentMethod, Payment.method_id == PaymentMethod.id),
         LeftJoin(BankAccount, BankAccount.id == CheckData.bank_account_id),
@@ -337,7 +364,8 @@ class _BillandCheckPaymentView(Viewable):
     clause = Or(PaymentMethod.method_name == u'bill',
                 PaymentMethod.method_name == u'check')
 
-    def get_status_str(self):
+    @property
+    def status_str(self):
         return Payment.statuses[self.status]
 
     @property
