@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -21,34 +21,96 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 
-""" Base classes to manage product's informations """
+"""
+Product, a physical goods that can be purchased, stored and sold.
+It's purchased by a supplier and sold to client.
+
+Imports that will be used in this doctest:
+
+    >>> from stoqlib.database.runtime import new_store, get_current_branch
+    >>> from stoqlib.domain.product import Product, ProductStockItem, Storable
+    >>> from stoqlib.domain.product import StockTransactionHistory
+
+Create a new store
+
+    >>> store = new_store()
+
+Create a branch we can use:
+
+    >>> from stoqlib.domain.exampledata import ExampleCreator
+    >>> branch = ExampleCreator.create(store, 'Branch')
+
+Create a sellable we can use:
+
+    >>> from stoqlib.domain.exampledata import ExampleCreator
+    >>> sellable = ExampleCreator.create(store, 'Sellable')
+
+The ExampleCreator already creates a Product for us. Now lets attach it a
+storable facet.
+
+    >>> product = sellable.product
+    >>> storable = Storable(product=product, store=store)
+
+The storable needs to have it's stock created, let's do so. Note that a reason
+is always required when changing the stock quantity
+
+    >>> storable.increase_stock(10, branch, StockTransactionHistory.TYPE_INITIAL, None)
+
+A stock item should now be available for the storable:
+
+    >>> stock_item = storable.get_stock_item(branch, batch=None)
+
+The branch and storable should be set properly
+
+    >>> stock_item.branch == branch
+    True
+
+    >>> stock_item.storable == storable
+    True
+
+Fetch the stock item for the current branch and verify that the
+stock_items are unique:
+
+    >>> current_branch = get_current_branch(store)
+    >>> stock_item2 = storable.get_stock_item(current_branch, batch=None)
+    >>> stock_item != stock_item2
+    True
+
+    >>> store.close()
+
+"""
+
+# pylint: enable=E1101
 
-import datetime
 from decimal import Decimal
 
 from kiwi.currency import currency
 from storm.references import Reference, ReferenceSet
-from zope.interface import implements
+from storm.expr import And, Eq, LeftJoin, Alias, Sum, Coalesce, Select
+from zope.interface import implementer
 
+from stoqlib.database.expr import Field, TransactionTimestamp
 from stoqlib.database.properties import PriceCol, DecimalCol, QuantityCol
 from stoqlib.database.properties import (UnicodeCol, DateTimeCol,
-                                  BoolCol, IntCol, PercentCol)
-from stoqlib.database.expr import TransactionTimestamp
+                                         BoolCol, IntCol, PercentCol,
+                                         IdCol)
 from stoqlib.database.runtime import get_current_user
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import (ProductCreateEvent, ProductEditEvent,
                                    ProductRemoveEvent, ProductStockUpdateEvent)
 from stoqlib.domain.interfaces import IDescribable
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Person, Branch
 from stoqlib.exceptions import StockError
-from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.lib.dateutils import localnow, localtoday
+from stoqlib.lib.translation import stoqlib_gettext, stoqlib_ngettext
 
 _ = stoqlib_gettext
 
 #
 # pyflakes
 #
-Person
+Person  # pylint: disable=W0104
 
 
 class ProductSupplierInfo(Domain):
@@ -84,12 +146,12 @@ class ProductSupplierInfo(Domain):
     #: de mercadorias e prestacao de servicos'
     icms = PercentCol(default=0)
 
-    supplier_id = IntCol()
+    supplier_id = IdCol()
 
     #: the |supplier|
     supplier = Reference(supplier_id, 'Supplier.id')
 
-    product_id = IntCol()
+    product_id = IdCol()
 
     #: the |product|
     product = Reference(product_id, 'Product.id')
@@ -106,14 +168,9 @@ class ProductSupplierInfo(Domain):
             return self.supplier.get_description()
 
     def get_lead_time_str(self):
-        if self.lead_time > 1:
-            day_str = _(u"Days")
-            lead_time = self.lead_time
-        else:
-            day_str = _(u"Day")
-            lead_time = self.lead_time or 0
-
-        return u"%d %s" % (lead_time, day_str)
+        return u"%d %s" % (
+            self.lead_time,
+            stoqlib_ngettext(_(u"Day"), _(u"Days"), self.lead_time))
 
 
 class Product(Domain):
@@ -130,13 +187,28 @@ class Product(Domain):
     A consigned product is borrowed from a |supplier|. You can also loan out
     your own products via |loan|.
 
+    If the product does not use stock managment, it will be possible to sell
+    items, even if it was never purchased.
+
     See also:
     `schema <http://doc.stoq.com.br/schema/tables/product.html>`__
     """
 
     __storm_table__ = 'product'
 
-    sellable_id = IntCol()
+    TYPE_COMMON = 0
+    TYPE_BATCH = 1
+    TYPE_WITHOUT_STOCK = 2
+    TYPE_CONSIGNED = 3
+
+    product_types = {
+        TYPE_COMMON: _("Regular product"),
+        TYPE_BATCH: _("Product with batch control"),
+        TYPE_WITHOUT_STOCK: _("Product without stock control"),
+        TYPE_CONSIGNED: _("Consigned product"),
+    }
+
+    sellable_id = IdCol()
 
     #: |sellable| for this product
     sellable = Reference(sellable_id, 'Sellable.id')
@@ -151,9 +223,29 @@ class Product(Domain):
     #: components or not.
     is_composed = BoolCol(default=False)
 
+    #: If this product will use stock management.
+    #: When this is set to ``True``, a corresponding |storable| should be created.
+    #: For ``False`` a storable will not be created and the quantity currently
+    #: in stock will not be known, e.g. |purchases| will not increase the stock
+    # quantity, and the operations that decrease stock (like a |sale| or a
+    # |loan|, will be allowed at any time.
+    manage_stock = BoolCol(default=True)
+
     #: physical location of this product, like a drawer or shelf number
     location = UnicodeCol(default=u'')
 
+    manufacturer_id = IdCol(default=None)
+
+    #: name of the manufacturer for this product, eg "General Motors"
+    manufacturer = Reference(manufacturer_id, 'ProductManufacturer.id')
+
+    #: name of the brand, eg "Chevrolet" or "Opel"
+    brand = UnicodeCol(default=u'')
+
+    #: name of the family, eg "Cobalt" or "Astra"
+    family = UnicodeCol(default=u'')
+
+    #: name of the model, eg "2.2 L Ecotec L61 I4" or "2.0 8V/ CD 2.0 Hatchback 5p Aut"
     model = UnicodeCol(default=u'')
 
     #: a number representing this part
@@ -183,16 +275,11 @@ class Product(Domain):
     #: NFE: see ncm
     genero = UnicodeCol(default=None)
 
-    manufacturer_id = IntCol(default=None)
-
-    #: name of the manufacturer for this product
-    manufacturer = Reference(manufacturer_id, 'ProductManufacturer.id')
-
-    icms_template_id = IntCol(default=None)
+    icms_template_id = IdCol(default=None)
 
     icms_template = Reference(icms_template_id, 'ProductIcmsTemplate.id')
 
-    ipi_template_id = IntCol(default=None)
+    ipi_template_id = IdCol(default=None)
 
     ipi_template = Reference(ipi_template_id, 'ProductIpiTemplate.id')
 
@@ -202,13 +289,6 @@ class Product(Domain):
     #: list of |suppliers| that sells this product
     suppliers = ReferenceSet('id', 'ProductSupplierInfo.product_id')
 
-    #
-    # General Methods
-    #
-
-    def has_quality_tests(self):
-        return not self.quality_tests.find().is_empty()
-
     @property
     def description(self):
         return self.sellable.description
@@ -217,6 +297,31 @@ class Product(Domain):
     def storable(self):
         return self.store.find(Storable, product=self).one()
 
+    @property
+    def product_type(self):
+        storable = self.storable
+
+        if not self.manage_stock:
+            assert storable is None
+            return self.TYPE_WITHOUT_STOCK
+        elif storable.is_batch:
+            return self.TYPE_BATCH
+        elif self.consignment:
+            return self.TYPE_CONSIGNED
+        else:
+            return self.TYPE_COMMON
+
+    @property
+    def product_type_str(self):
+        return self.product_types[self.product_type]
+
+    #
+    #  Public API
+    #
+
+    def has_quality_tests(self):
+        return not self.quality_tests.find().is_empty()
+
     def remove(self):
         """Deletes this product from the database.
         """
@@ -253,9 +358,15 @@ class Product(Domain):
             return False
         return True
 
-    #
-    # Acessors
-    #
+    def can_close(self):
+        """Checks if this product can be closed
+
+        Called by |sellable| to check if it can be closed or not.
+        A product can be closed if it doesn't have any stock left
+        """
+        if self.manage_stock:
+            return self.storable.get_total_balance() == 0
+        return True
 
     def get_manufacture_time(self, quantity, branch):
         """Returns the estimated time in days to manufacture a product
@@ -276,7 +387,7 @@ class Product(Domain):
             needed = quantity * i.quantity
             stock = storable.get_balance_for_branch(branch)
             # We have enought of this component items to produce.
-            if  stock >= needed:
+            if stock >= needed:
                 continue
             comp_max_time = max(comp_max_time,
                                 i.component.get_max_lead_time(needed, branch))
@@ -306,7 +417,8 @@ class Product(Domain):
 
     def get_main_supplier_name(self):
         supplier_info = self.get_main_supplier_info()
-        return supplier_info.get_name()
+        if supplier_info is not None:
+            return supplier_info.get_name()
 
     def get_main_supplier_info(self):
         """Gets a list of main suppliers for a Product, the main supplier
@@ -372,10 +484,6 @@ class Product(Domain):
                 return True
         return False
 
-    def is_being_produced(self):
-        from stoqlib.domain.production import ProductionOrderProducingView
-        return ProductionOrderProducingView.is_product_being_produced(self)
-
     #
     # Domain
     #
@@ -399,6 +507,7 @@ class Product(Domain):
         self._emitted_store_list = emitted_store_list
 
 
+@implementer(IDescribable)
 class ProductManufacturer(Domain):
     """Product manufacturer.
 
@@ -406,8 +515,6 @@ class ProductManufacturer(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/product_manufacturer.html>`__
     """
 
-    implements(IDescribable)
-
     __storm_table__ = 'product_manufacturer'
 
     #: manufacturer's name
@@ -426,7 +533,7 @@ class ProductManufacturer(Domain):
 
     def remove(self):
         """Remove this registry from the database."""
-        self.delete(self.id, self.store)
+        self.store.remove(self)
 
 
 class ProductHistory(Domain):
@@ -456,12 +563,12 @@ class ProductHistory(Domain):
     received_date = DateTimeCol(default=None)
     decreased_date = DateTimeCol(default=None)
 
-    branch_id = IntCol()
+    branch_id = IdCol()
 
     #: the |branch|
     branch = Reference(branch_id, 'Branch.id')
 
-    sellable_id = IntCol()
+    sellable_id = IdCol()
 
     #: the |sellable|
     sellable = Reference(sellable_id, 'Sellable.id')
@@ -523,7 +630,7 @@ class ProductHistory(Domain):
         """
         cls(branch=branch, sellable=consumed_item.product.sellable,
             quantity_consumed=consumed_item.consumed,
-            production_date=datetime.date.today(),
+            production_date=localtoday(),
             store=store)
 
     @classmethod
@@ -538,7 +645,7 @@ class ProductHistory(Domain):
         """
         cls(branch=branch, sellable=produced_item.product.sellable,
             quantity_produced=produced_item.produced,
-            production_date=datetime.date.today(), store=store)
+            production_date=localtoday(), store=store)
 
     @classmethod
     def add_lost_item(cls, store, branch, lost_item):
@@ -550,9 +657,12 @@ class ProductHistory(Domain):
         :param branch: the source branch
         :param lost_item: a ProductionItem or ProductionMaterial instance
         """
+        if lost_item.lost <= 0:
+            raise ValueError("lost_item must have a positive lost attribute")
+
         cls(branch=branch, sellable=lost_item.product.sellable,
             quantity_lost=lost_item.lost,
-            production_date=datetime.date.today(), store=store)
+            production_date=localtoday(), store=store)
 
     @classmethod
     def add_decreased_item(cls, store, branch, item):
@@ -566,7 +676,7 @@ class ProductHistory(Domain):
         """
         cls(branch=branch, sellable=item.sellable,
             quantity_decreased=item.quantity,
-            decreased_date=datetime.date.today(),
+            decreased_date=localtoday(),
             store=store)
 
 
@@ -587,16 +697,21 @@ class ProductStockItem(Domain):
     #: number of storables in the stock item
     quantity = QuantityCol(default=0)
 
-    branch_id = IntCol()
+    branch_id = IdCol()
 
     #: the |branch| this stock item belongs to
     branch = Reference(branch_id, 'Branch.id')
 
-    storable_id = IntCol()
+    storable_id = IdCol()
 
     #: the |storable| the stock item refers to
     storable = Reference(storable_id, 'Storable.id')
 
+    batch_id = IdCol()
+
+    #: The |batch| that the storable is in.
+    batch = Reference(batch_id, 'StorableBatch.id')
+
     def update_cost(self, new_quantity, new_cost):
         """Update the stock_item according to new quantity and cost.
 
@@ -620,11 +735,17 @@ class Storable(Domain):
 
     __storm_table__ = 'storable'
 
-    product_id = IntCol()
+    product_id = IdCol()
 
     #: the |product| the stock represents
     product = Reference(product_id, 'Product.id')
 
+    #: If this storable should have a finer grain control by batches. When this
+    #: is true, stock for this storable will also require a batch information.
+    #: This will allow us to control from what batch a sale item came from, and
+    #: it will also let us know from what purchase this batch came from.
+    is_batch = BoolCol(default=False)
+
     #: minimum quantity of stock items allowed
     minimum_quantity = QuantityCol(default=0)
 
@@ -632,10 +753,31 @@ class Storable(Domain):
     maximum_quantity = QuantityCol(default=0)
 
     #
-    # Properties
+    #  Classmethods
     #
 
-    def increase_stock(self, quantity, branch, type, object_id, unit_cost=None):
+    @classmethod
+    def get_storables_without_stock_item(cls, store, branch):
+        """Get |storables| without a |productstockitem|
+
+        This will get all storables that doesn't have a
+        |productstockitem| on the given branch.
+
+        :param store: the store used to query the storables
+        :param branch: the |branch| used to check for the stock item existence
+        :returns: a result set of |storables|
+        """
+        join = LeftJoin(ProductStockItem,
+                        And(ProductStockItem.storable_id == cls.id,
+                            ProductStockItem.branch_id == branch.id))
+        return store.using(cls, join).find(cls, Eq(ProductStockItem.id, None))
+
+    #
+    #  Public API
+    #
+
+    def increase_stock(self, quantity, branch, type, object_id, unit_cost=None,
+                       batch=None):
         """When receiving a product, update the stock reference for this new
         item on a specific |branch|.
 
@@ -645,6 +787,8 @@ class Storable(Domain):
             StockTransactionHistory.types
         :param object_id: the id of the object responsible for the transaction
         :param unit_cost: unit cost of the new stock or `None`
+        :param batch: The batch of the storable. Should be not ``None`` if
+            self.is_batch is ``True``
         """
         assert isinstance(type, int)
 
@@ -652,14 +796,13 @@ class Storable(Domain):
             raise ValueError(_(u"quantity must be a positive number"))
         if branch is None:
             raise ValueError(u"branch cannot be None")
-        stock_item = self.get_stock_item(branch)
+
+        stock_item = self.get_stock_item(branch, batch)
         # If the stock_item is missing create a new one
         if stock_item is None:
             store = self.store
-            stock_item = ProductStockItem(
-                storable=self,
-                branch=store.fetch(branch),
-                store=store)
+            stock_item = ProductStockItem(store=store, storable=self,
+                                          batch=batch, branch=store.fetch(branch))
 
         # Unit cost must be updated here as
         # 1) we need the stock item which might not exist
@@ -671,12 +814,6 @@ class Storable(Domain):
         old_quantity = stock_item.quantity
         stock_item.quantity += quantity
 
-        # If previously lacked quantity change the status of the sellable
-        if not old_quantity:
-            sellable = self.product.sellable
-            if sellable:
-                sellable.can_sell()
-
         StockTransactionHistory(product_stock_item=stock_item,
                                 quantity=quantity,
                                 stock_cost=stock_item.stock_cost,
@@ -689,7 +826,7 @@ class Storable(Domain):
                                      stock_item.quantity)
 
     def decrease_stock(self, quantity, branch, type, object_id,
-                       cost_center=None):
+                       cost_center=None, batch=None):
         """When receiving a product, update the stock reference for the sold item
         this on a specific |branch|. Returns the stock item that was
         decreased.
@@ -701,16 +838,18 @@ class Storable(Domain):
         :param object_id: the id of the object responsible for the transaction
         :param cost_center: the |costcenter| to which this stock decrease is
             related, if any
+        :param batch: The batch of the storable. Should be not ``None`` if
+            self.is_batch is ``True``
         """
         # FIXME: Put this back once 1.6 is released
-        #assert isinstance(type, int)
+        # assert isinstance(type, int)
 
         if quantity <= 0:
             raise ValueError(_(u"quantity must be a positive number"))
         if branch is None:
             raise ValueError(u"branch cannot be None")
 
-        stock_item = self.get_stock_item(branch)
+        stock_item = self.get_stock_item(branch, batch)
         if stock_item is None or quantity > stock_item.quantity:
             raise StockError(
                 _('Quantity to sell is greater than the available stock.'))
@@ -718,23 +857,14 @@ class Storable(Domain):
         old_quantity = stock_item.quantity
         stock_item.quantity -= quantity
 
-        # We emptied the entire stock in all branches, we need to change
-        # the status of the sellable to unavailable as we cannot sell
-        # it anymore
-        if not self.store.find(ProductStockItem,
-                    storable=self).sum(ProductStockItem.quantity):
-            sellable = self.product.sellable
-            if sellable:
-                sellable.set_unavailable()
-
         stock_transaction = StockTransactionHistory(
-                                product_stock_item=stock_item,
-                                quantity=-quantity,
-                                stock_cost=stock_item.stock_cost,
-                                responsible=get_current_user(self.store),
-                                type=type,
-                                object_id=object_id,
-                                store=self.store)
+            product_stock_item=stock_item,
+            quantity=-quantity,
+            stock_cost=stock_item.stock_cost,
+            responsible=get_current_user(self.store),
+            type=type,
+            object_id=object_id,
+            store=self.store)
 
         if cost_center is not None:
             cost_center.add_stock_transaction(stock_transaction)
@@ -744,20 +874,45 @@ class Storable(Domain):
 
         return stock_item
 
-    def register_initial_stock(self, quantity, branch):
+    def register_initial_stock(self, quantity, branch, unit_cost,
+                               batch_number=None):
         """Register initial stock, by increasing the amount of this storable,
-        for the given |quantity| and |branch|
+        for the given quantity and |branch|
 
         :param quantity: The inital stock quantity for this storable
         :param branch: The branch where the given quantity is avaiable for this
           storable
+        :param unit_cost: The unitary cost for the initial stock
+        :param batch_number: a batch number that will be used to
+            get or create a |batch| it will be get from the item's
+            pending quantity. Must be ``None`` if the :obj:`.is_batch`
+            is ``False``.
         """
+        if batch_number is not None:
+            batch = StorableBatch.get_or_create(
+                self.store,
+                storable=self,
+                batch_number=batch_number)
+        else:
+            batch = None
+
         self.increase_stock(quantity, branch,
                             StockTransactionHistory.TYPE_INITIAL,
-                            object_id=None)
+                            object_id=None, unit_cost=unit_cost, batch=batch)
+
+    def get_total_balance(self):
+        """Return the stock balance for the |product| in all |branches|
+
+        :returns: the amount of stock available in all |branches|
+        """
+        stock_items = self.get_stock_items()
+        return stock_items.sum(ProductStockItem.quantity) or Decimal(0)
 
     def get_balance_for_branch(self, branch):
-        """Return the stock balance for the |product| in a |branch|.
+        """Return the stock balance for the |product| in a |branch|. If this
+        storable have batches, the balance for all batches will be returned.
+
+        If you want the balance for a specific |batch|, the
 
         :param branch: the |branch| to get the stock balance for
         :returns: the amount of stock available in the |branch|
@@ -774,13 +929,125 @@ class Storable(Domain):
         """
         return self.store.find(ProductStockItem, storable=self)
 
-    def get_stock_item(self, branch):
-        """Fetch a stock item for a specific |branch|
+    def get_stock_item(self, branch, batch):
+        """Fetches the stock item for the given |branch|, |batch| and this
+        |storable|.
 
+        :param branch: the |branch| to get the stock item for
+        :param batch: the |batch| to get the stock item for
         :returns: a stock item
         """
+        self.validate_batch(batch, sellable=self.product.sellable)
+        return self.store.find(ProductStockItem, branch=branch, storable=self,
+                               batch=batch).one()
+
+    def get_available_batches(self, branch):
+        """Return all batches that have some stock left in the given branch
+
+        :param branch: the |branch| that we are getting the avaiable batches
+        :returns: all batches available for this storable in the given branch
+        """
+        tables = [StorableBatch,
+                  LeftJoin(ProductStockItem,
+                           And(ProductStockItem.storable_id == StorableBatch.storable_id,
+                               ProductStockItem.batch_id == StorableBatch.id))]
+        query = And(ProductStockItem.storable_id == self.id,
+                    ProductStockItem.branch_id == branch.id,
+                    ProductStockItem.quantity > 0)
+        return self.store.using(*tables).find(StorableBatch, query)
+
+
+# TODO: Add a reference to the batch in:
+# * References sellable:
+#     - Maybe: ProductHistory
+# * References product:
+#     - ProductionMaterial: This is not that simple and will require some
+#       refatoring in the production process
+#     - ProductionProducedItem (Maybe)
+
+@implementer(IDescribable)
+class StorableBatch(Domain):
+    """Batch information for storables.
+
+    A batch is a colection of products (storable) that were produced at the same
+    time and thus they have some common information, such as expiration date.
+
+    This information is useful since sometimes its necessary to make decisions
+    based on the batch like a special promotion for older batches (if it is
+    close to the expiration date, for instance) or if a batch is somehow
+    defective and we need to contact the clients that purchased items from this
+    batch.
+    """
+
+    __storm_table__ = 'storable_batch'
+
+    #: The sequence number for this batch. Should be unique for a given
+    #: storable
+    batch_number = UnicodeCol(allow_none=False)
+
+    #: The date this batch was created
+    create_date = DateTimeCol(default_factory=localnow)
+
+    #: An expiration date, specially for perishable products, like milk and food in
+    #: general
+    expire_date = DateTimeCol()
+
+    #: Some space for the users to add notes to this batch.
+    notes = UnicodeCol()
+
+    storable_id = IdCol(allow_none=False)
+
+    #: The storable that is in this batch
+    storable = Reference(storable_id, 'Storable.id')
+
+    #
+    #  IDescribable
+    #
+
+    def get_description(self):
+        return self.batch_number
+
+    #
+    #  Classmethods
+    #
+
+    @classmethod
+    def is_batch_number_available(cls, store, batch_number,
+                                  exclude_storable=None):
+        """Test if batch_number is available
+
+        Useful to find if a batch number is available to be used on a
+        new |batch|.
+
+        If you are increasing the stock of a storable, you probably
+        want to allow an existing batch number for it, in this case,
+        you can use exclude_storable param for that.
+
+        :param store: a store
+        :param batch_number: the batch number to check for availability
+        :param exclude_storable: if not ``None``, the |storable| to
+            exclude from the test
+        """
+        query = cls.batch_number == batch_number
+        if exclude_storable is not None:
+            query = And(query, cls.storable_id != exclude_storable.id)
+
+        return store.find(cls, query).is_empty()
+
+    #
+    #  Public API
+    #
+
+    def get_balance_for_branch(self, branch):
+        """Return the stock balance for this |batch| in a |branch|.
+
+        :param branch: the |branch| to get the stock balance for
+        :returns: the amount of stock available in the |branch|
+        """
         store = self.store
-        return store.find(ProductStockItem, branch=branch, storable=self).one()
+        stock_items = store.find(ProductStockItem, storable=self.storable,
+                                 batch=self, branch=branch)
+        return stock_items.sum(ProductStockItem.quantity) or Decimal(0)
 
 
 class StockTransactionHistory(Domain):
@@ -850,9 +1117,16 @@ class StockTransactionHistory(Domain):
     TYPE_CONSIGNMENT_RETURNED = 16
 
     #: the transaction is the utilization of a
-    #: |product|/|service| on a |workorderitem|
+    #: |product| on a |workorderitem|
     TYPE_WORK_ORDER_USED = 17
 
+    #: the transaction is the return of a |product| on a
+    #: |workorderitem| to the stock
+    TYPE_WORK_ORDER_RETURN_TO_STOCK = 18
+
+    #: the transaction is a reserved product from a sale
+    TYPE_SALE_RESERVED = 19
+
     types = {TYPE_INVENTORY_ADJUST: _(u'Adjustment for inventory %s'),
              TYPE_RETURNED_LOAN: _(u'Returned from loan %s'),
              TYPE_LOANED: _(u'Loaned for loan %s'),
@@ -872,14 +1146,16 @@ class StockTransactionHistory(Domain):
                                  u'order %s'),
              TYPE_INITIAL: _(u'Registred initial stock'),
              TYPE_IMPORTED: _(u'Imported from previous version'),
-             TYPE_CONSIGNMENT_RETURNED: _(u'Consigned product returned.'),
+             TYPE_CONSIGNMENT_RETURNED: _(u'Consigned product returned %s.'),
              TYPE_WORK_ORDER_USED: _(u'Used on work order %s.'),
+             TYPE_WORK_ORDER_RETURN_TO_STOCK: _(u'Returned to stock on work order %s.'),
+             TYPE_SALE_RESERVED: _(u'Reserved for sale %s.'),
              }
 
     #: the date and time the transaction was made
-    date = DateTimeCol(default_factory=datetime.datetime.now)
+    date = DateTimeCol(default_factory=localnow)
 
-    product_stock_item_id = IntCol()
+    product_stock_item_id = IdCol()
 
     #: the |productstockitem| used in the transaction
     product_stock_item = Reference(product_stock_item_id, 'ProductStockItem.id')
@@ -891,13 +1167,13 @@ class StockTransactionHistory(Domain):
     #: Positive value if the value was increased, negative if decreased.
     quantity = QuantityCol()
 
-    responsible_id = IntCol()
+    responsible_id = IdCol()
 
     #: the |loginuser| responsible for the transaction
     responsible = Reference(responsible_id, 'LoginUser.id')
 
     #: the id of the object who altered the stock
-    object_id = IntCol()
+    object_id = IdCol()
 
     #: the type of the transaction
     type = IntCol()
@@ -909,7 +1185,8 @@ class StockTransactionHistory(Domain):
     def get_object(self):
         if self.type in [self.TYPE_INITIAL, self.TYPE_IMPORTED]:
             return None
-        elif self.type in [self.TYPE_SELL, self.TYPE_CANCELED_SALE]:
+        elif self.type in [self.TYPE_SELL, self.TYPE_CANCELED_SALE,
+                           self.TYPE_SALE_RESERVED]:
             from stoqlib.domain.sale import SaleItem
             return self.store.get(SaleItem, self.object_id)
         elif self.type == self.TYPE_RETURNED_SALE:
@@ -943,14 +1220,12 @@ class StockTransactionHistory(Domain):
         elif self.type == self.TYPE_CONSIGNMENT_RETURNED:
             from stoqlib.domain.purchase import PurchaseItem
             return self.store.get(PurchaseItem, self.object_id)
-        elif self.type == self.TYPE_CONSIGNMENT_RETURNED:
-            from stoqlib.domain.purchase import PurchaseItem
-            return self.store.get(PurchaseItem, self.object_id)
-        elif self.type == self.TYPE_WORK_ORDER_USED:
+        elif self.type in [self.TYPE_WORK_ORDER_USED,
+                           self.TYPE_WORK_ORDER_RETURN_TO_STOCK]:
             from stoqlib.domain.workorder import WorkOrderItem
             return self.store.get(WorkOrderItem, self.object_id)
-        else:
-            raise ValueError(_('%s has invalid type: %s.') % (self, self.type))
+        else:  # pragma: nocoverage
+            raise NotImplementedError(self.type)
 
     def get_object_parent(self):
         obj = self.get_object()
@@ -961,6 +1236,7 @@ class StockTransactionHistory(Domain):
         from stoqlib.domain.loan import LoanItem
         from stoqlib.domain.production import ProductionItem
         from stoqlib.domain.production import ProductionMaterial
+        from stoqlib.domain.production import ProductionProducedItem
         from stoqlib.domain.purchase import PurchaseItem
         from stoqlib.domain.receiving import ReceivingOrderItem
         from stoqlib.domain.returnedsale import ReturnedSaleItem
@@ -975,6 +1251,8 @@ class StockTransactionHistory(Domain):
             return obj.returned_sale
         elif isinstance(obj, ProductionItem):
             return obj.order
+        elif isinstance(obj, ProductionProducedItem):
+            return obj.order
         elif isinstance(obj, ProductionMaterial):
             return obj.order
         elif isinstance(obj, ReceivingOrderItem):
@@ -988,12 +1266,11 @@ class StockTransactionHistory(Domain):
         elif isinstance(obj, InventoryItem):
             return obj.inventory
         elif isinstance(obj, PurchaseItem):
-            return obj.inventory
+            return obj.order
         elif isinstance(obj, WorkOrderItem):
             return obj.order
-        else:
-            raise TypeError(_('Object %s has invalid type (%s)') %
-                            (obj, type(obj)))
+        else:  # pragma: nocoverage
+            raise NotImplementedError(obj)
 
     def get_description(self):
         """ Based on the type of the transaction, returns the string
@@ -1001,7 +1278,11 @@ class StockTransactionHistory(Domain):
         """
         if self.type in [self.TYPE_INITIAL, self.TYPE_IMPORTED]:
             return self.types[self.type]
-        return self.types[self.type] % self.get_object_parent().identifier
+
+        object_parent = self.get_object_parent()
+        number = unicode(object_parent.identifier)
+
+        return self.types[self.type] % number
 
 
 class ProductComponent(Domain):
@@ -1014,13 +1295,14 @@ class ProductComponent(Domain):
     __storm_table__ = 'product_component'
 
     quantity = QuantityCol(default=Decimal(1))
-    product_id = IntCol()
+    product_id = IdCol()
     product = Reference(product_id, 'Product.id')
-    component_id = IntCol()
+    component_id = IdCol()
     component = Reference(component_id, 'Product.id')
     design_reference = UnicodeCol(default=u'')
 
 
+@implementer(IDescribable)
 class ProductQualityTest(Domain):
     """A quality test that a manufactured product will be submitted to.
 
@@ -1028,8 +1310,6 @@ class ProductQualityTest(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/product_quality_test.html>`__
     """
 
-    implements(IDescribable)
-
     __storm_table__ = 'product_quality_test'
 
     (TYPE_BOOLEAN,
@@ -1040,7 +1320,7 @@ class ProductQualityTest(Domain):
         TYPE_DECIMAL: _(u'Decimal'),
     }
 
-    product_id = IntCol()
+    product_id = IdCol()
     product = Reference(product_id, 'Product.id')
     test_type = IntCol(default=TYPE_BOOLEAN)
     description = UnicodeCol(default=u'')
@@ -1064,7 +1344,7 @@ class ProductQualityTest(Domain):
             return True
         elif self.success_value == u'False':
             return False
-        else:
+        else:  # pragma: nocoverage
             raise ValueError(self.success_value)
 
     def get_range_value(self):
@@ -1090,3 +1370,82 @@ class ProductQualityTest(Domain):
         if self.store.find(ProductionItemQualityResult, quality_test=self).count():
             return False
         return True
+
+
+_StockSummary = Alias(Select(
+    columns=[
+        ProductStockItem.batch_id,
+        ProductStockItem.branch_id,
+        Alias(Sum(ProductStockItem.quantity), 'stock')],
+    tables=[
+        ProductStockItem],
+    group_by=[
+        ProductStockItem.batch_id,
+        ProductStockItem.branch_id]),
+    '_stock_summary')
+
+
+class StorableBatchView(Viewable):
+    """A view for |batches|
+
+    This is used to get the most information of a |batch|
+    without doing lots of database queries.
+
+    It's bestly used with :meth:`.find_by_storable`
+    """
+
+    #: the |batch| object
+    batch = StorableBatch
+
+    #: the |branch| this batch is in
+    branch = Branch
+
+    # StorableBatch
+    id = StorableBatch.id
+    create_date = StorableBatch.create_date
+    batch_number = StorableBatch.batch_number
+    stock = Coalesce(Field('_stock_summary', 'stock'), 0)
+
+    tables = [
+        StorableBatch,
+        LeftJoin(_StockSummary,
+                 Field('_stock_summary', 'batch_id') == StorableBatch.id),
+        LeftJoin(Branch, Field('_stock_summary', 'branch_id') == Branch.id),
+    ]
+
+    @classmethod
+    def find_by_storable(cls, store, storable, branch=None):
+        """Find results for this view that for *storable*
+
+        Normally it's best to use this instead of *store.find* since
+        it'll only |batches| for the given |storable|.
+
+        :param store: the store that will be used to find the results
+        :param storable: the |storable| used to filter the results
+        :param branch: a |branch| that, if not ``None``, will be used to
+            filter the results to only get batches on that branch.
+        :returns: the matching views
+        :rtype: a sequence of :class:`StorableBatchView`
+        """
+        query = StorableBatch.storable_id == storable.id
+        if branch is not None:
+            query = And(query,
+                        Field('_stock_summary', 'branch_id') == branch.id)
+        return store.find(cls, query)
+
+    @classmethod
+    def find_available_by_storable(cls, store, storable, branch=None):
+        """Find results for this view that for *storable* that have stock
+
+        The same as :meth:`.find_by_storable`, but only results with
+        :obj:`.stock` > 0 will be fetched
+
+        :param store: the store that will be used to find the results
+        :param storable: the |storable| used to filter the results
+        :param branch: a |branch| that, if not ``None``, will be used to
+            filter the results to only get batches on that branch.
+        :returns: the matching views
+        :rtype: a sequence of :class:`StorableBatchView`
+        """
+        results = cls.find_by_storable(store, storable, branch=branch)
+        return results.find(Field('_stock_summary', 'stock') > 0)
