@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2009 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2009-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,51 +23,51 @@
 ##
 """ Base classes to manage production informations """
 
-import datetime
+# pylint: enable=E1101
+
 from decimal import Decimal
 
 from storm.expr import And, Join
 from storm.references import Reference, ReferenceSet
-from storm.store import AutoReload
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.properties import (UnicodeCol, DateTimeCol, IntCol,
-                                  QuantityCol, BoolCol)
+                                         QuantityCol, BoolCol, IdentifierCol,
+                                         IdCol)
 from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.product import ProductHistory, StockTransactionHistory
 from stoqlib.domain.interfaces import IContainer, IDescribable
+from stoqlib.lib.dateutils import localnow, localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 
 
 _ = stoqlib_gettext
 
 
+@implementer(IContainer)
+@implementer(IDescribable)
 class ProductionOrder(Domain):
     """Production Order object implementation.
-
-    :cvar ORDER_OPENED: The production order is opened, production items might
-                        have been added.
-    :cvar ORDER_WAITING: The production order is waiting some conditions to
-                         start the manufacturing process.
-    :cvar ORDER_PRODUCING: The production order have already started.
-    :cvar ORDER_CLOSED: The production have finished.
-
-    :attribute status: the production order status
-    :attribute open_date: the date when the production order was created
-    :attribute close_date: the date when the production order have been closed
-    :attribute description: the production order description
-    :attribute responsible: the person responsible for the production order
     """
-    implements(IContainer, IDescribable)
 
     __storm_table__ = 'production_order'
 
-    (ORDER_OPENED,
-     ORDER_WAITING,
-     ORDER_PRODUCING,
-     ORDER_CLOSED,
-     ORDER_QA) = range(5)
+    #: The production order is opened, production items might have been added.
+    ORDER_OPENED = 0
+
+    #: The production order is waiting some conditions to start the
+    #: manufacturing process.
+    ORDER_WAITING = 1
+
+    #: The production order have already started.
+    ORDER_PRODUCING = 2
+
+    #: The production have finished.
+    ORDER_CLOSED = 3
+
+    #: The production is in quality assurance phase.
+    ORDER_QA = 4
 
     statuses = {ORDER_OPENED: _(u'Opened'),
                 ORDER_WAITING: _(u'Waiting'),
@@ -77,18 +77,34 @@ class ProductionOrder(Domain):
                 }
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
+
+    #: the production order status
     status = IntCol(default=ORDER_OPENED)
-    open_date = DateTimeCol(default_factory=datetime.datetime.now)
-    expected_start_date = DateTimeCol(default=None)
-    start_date = DateTimeCol(default=None)
+
+    #: the date when the production order was created
+    open_date = DateTimeCol(default_factory=localnow)
+
+    #: the date when the production order have been closed
     close_date = DateTimeCol(default=None)
+
+    #: the production order description
     description = UnicodeCol(default=u'')
-    responsible_id = IntCol(default=None)
+
+    expected_start_date = DateTimeCol(default=None)
+
+    start_date = DateTimeCol(default=None)
+
+    responsible_id = IdCol(default=None)
+
+    #: the person responsible for the production order
     responsible = Reference(responsible_id, 'Employee.id')
-    branch_id = IntCol()
+
+    branch_id = IdCol()
+
+    #: branch this production belongs to
     branch = Reference(branch_id, 'Branch.id')
 
     produced_items = ReferenceSet('id', 'ProductionProducedItem.order_id')
@@ -111,7 +127,8 @@ class ProductionOrder(Domain):
             raise ValueError(_(u'Argument item must have an order attribute '
                                u'associated with the current production '
                                u'order instance.'))
-        self.store.remove(item)
+        item.order = None
+        self.store.maybe_remove(item)
 
     #
     # Public API
@@ -130,7 +147,8 @@ class ProductionOrder(Domain):
             raise ValueError(_(u'Argument item must have an order attribute '
                                u'associated with the current production '
                                u'order instance.'))
-        self.store.remove(item)
+        item.order = None
+        self.store.maybe_remove(item)
 
     def get_material_items(self):
         """Returns all the material needed by this production.
@@ -138,7 +156,7 @@ class ProductionOrder(Domain):
         :returns: a sequence of :class:`ProductionMaterial` instances.
         """
         return self.store.find(ProductionMaterial, order=self,
-                                           )
+                               )
 
     def start_production(self):
         """Start the production by allocating all the material needed.
@@ -149,24 +167,21 @@ class ProductionOrder(Domain):
         for material in self.get_material_items():
             material.allocate()
 
-        self.start_date = datetime.date.today()
+        self.start_date = localtoday()
         self.status = ProductionOrder.ORDER_PRODUCING
 
-    # FIXME: Test
     def is_completely_produced(self):
         return all(i.is_completely_produced() for i in self.get_items())
 
-    # FIXME: Test
     def is_completely_tested(self):
         # Produced items are only stored if there are quality tests for this
         # product
-        produced_items = self.produced_items
+        produced_items = list(self.produced_items)
         if not produced_items:
             return True
 
-        return all([i.test_passed for i in produced_items])
+        return all([item.test_passed for item in produced_items])
 
-    # FIXME: Test
     def try_finalize_production(self):
         """When all items are completely produced, change the status of the
         production to CLOSED.
@@ -182,7 +197,7 @@ class ProductionOrder(Domain):
             self.status = ProductionOrder.ORDER_QA
         elif is_produced and is_tested:
             # All items must be completely produced and tested
-            self.close_date = datetime.date.today()
+            self.close_date = localtoday()
             self.status = ProductionOrder.ORDER_CLOSED
 
         # If the order is closed, return the the remaining allocated material to
@@ -204,11 +219,8 @@ class ProductionOrder(Domain):
     def get_status_string(self):
         return ProductionOrder.statuses[self.status]
 
-    def get_order_number(self):
-        return u'%04d' % self.identifier
-
     def get_branch_name(self):
-        return self.branch.person.name
+        return self.branch.get_description()
 
     def get_responsible_name(self):
         if self.responsible is not None:
@@ -223,30 +235,43 @@ class ProductionOrder(Domain):
         return self.description
 
 
+@implementer(IDescribable)
 class ProductionItem(Domain):
     """Production Item object implementation.
-
-    :attribute order: The :class:`ProductionOrder` of this item.
-    :attribute product: The product that will be manufactured.
-    :attribute quantity: The product's quantity that will be manufactured.
-    :attribute produced: The product's quantity that was manufactured.
-    :attribute lost: The product's quantity that was lost.
     """
-    implements(IDescribable)
 
     __storm_table__ = 'production_item'
 
+    #: The product's quantity that will be manufactured.
     quantity = QuantityCol(default=1)
+
+    #: The product's quantity that was manufactured.
     produced = QuantityCol(default=0)
+
+    #: The product's quantity that was lost.
     lost = QuantityCol(default=0)
-    order_id = IntCol()
+
+    order_id = IdCol()
+
+    #: The :class:`ProductionOrder` of this item.
     order = Reference(order_id, 'ProductionOrder.id')
-    product_id = IntCol()
+
+    product_id = IdCol()
+
+    #: The product that will be manufactured.
     product = Reference(product_id, 'Product.id')
 
     def get_description(self):
         return self.product.sellable.get_description()
 
+    #
+    # Properties
+    #
+
+    @property
+    def unit_description(self):
+        return self.product.sellable.unit_description
+
     #
     # Private API
     #
@@ -254,15 +279,12 @@ class ProductionItem(Domain):
     def _get_material_from_component(self, component):
         store = self.store
         return store.find(ProductionMaterial, product=component.component,
-                                              order=self.order).one()
+                          order=self.order).one()
 
     #
     # Public API
     #
 
-    def get_unit_description(self):
-        return self.product.sellable.get_unit_description()
-
     def get_components(self):
         return self.product.get_components()
 
@@ -297,8 +319,7 @@ class ProductionItem(Domain):
             assert produced_by
             assert len(serials) == quantity
 
-        store = self.store
-        store.savepoint(u'before_produce')
+        self.store.savepoint(u'before_produce')
 
         for component in self.get_components():
             material = self._get_material_from_component(component)
@@ -307,7 +328,7 @@ class ProductionItem(Domain):
             try:
                 material.consume(needed_material)
             except ValueError:
-                store.rollback_to_savepoint(u'before_produce')
+                self.store.rollback_to_savepoint(u'before_produce')
                 raise
 
         if self.product.has_quality_tests():
@@ -316,7 +337,7 @@ class ProductionItem(Domain):
                                        order=self.order,
                                        product=self.product,
                                        produced_by=produced_by,
-                                       produced_date=datetime.datetime.now(),
+                                       produced_date=localnow(),
                                        serial_number=serial,
                                        entered_stock=False)
         else:
@@ -324,11 +345,11 @@ class ProductionItem(Domain):
             # right now.
             storable = self.product.storable
             storable.increase_stock(quantity, self.order.branch,
-                        StockTransactionHistory.TYPE_PRODUCTION_PRODUCED,
-                        self.id)
+                                    StockTransactionHistory.TYPE_PRODUCTION_PRODUCED,
+                                    self.id)
         self.produced += quantity
         self.order.try_finalize_production()
-        ProductHistory.add_produced_item(store, self.order.branch, self)
+        ProductHistory.add_produced_item(self.store, self.order.branch, self)
 
     def add_lost(self, quantity):
         """Adds a quantity that was lost. The maximum quantity that can be
@@ -356,37 +377,49 @@ class ProductionItem(Domain):
         ProductHistory.add_lost_item(store, self.order.branch, self)
 
 
+@implementer(IDescribable)
 class ProductionMaterial(Domain):
     """Production Material object implementation.
 
-    :attribute product: The :class:`Product` that will be consumed.
-    :attribute order: The :class:`ProductionOrder` that will consume this material.
-    :attribute needed: The quantity needed of this material.
-    :attribute consumed: The quantity already used of this material.
-    :attribute lost: The quantity lost of this material.
-    :attribute to_purchase: The quantity to purchase of this material.
-    :attribute to_make: The quantity to manufacture of this material.
-    """
-    implements(IDescribable)
+    This represents the material needed by a production. It can either be
+    consumed or lost (due to manufacturing process).
 
+    """
     __storm_table__ = 'production_material'
 
-    product_id = IntCol()
+    product_id = IdCol()
+
+    #: The |product| that will be consumed.
     product = Reference(product_id, 'Product.id')
-    order_id = IntCol()
+
+    order_id = IdCol()
+    #: The |production| that will consume this material.
     order = Reference(order_id, 'ProductionOrder.id')
+
+    # The quantity needed of this material.
     needed = QuantityCol(default=1)
+
+    #: The quantity that is actually allocated to this production. It may be
+    #: more than the quantity required (and in this case, the remaining quantity
+    #: will be returned to the stock later.
     allocated = QuantityCol(default=0)
+
+    #: The quantity already used of this material.
     consumed = QuantityCol(default=0)
+
+    #: The quantity lost of this material.
     lost = QuantityCol(default=0)
+
+    #: The quantity to purchase of this material.
     to_purchase = QuantityCol(default=0)
+
+    #: The quantity to manufacture of this material.
     to_make = QuantityCol(default=0)
 
     #
     # Public API
     #
 
-    # TESTME
     def can_add_lost(self, quantity):
         """Returns if we can loose a certain quantity of this material.
 
@@ -411,10 +444,14 @@ class ProductionMaterial(Domain):
         :param quantity: the quantity to be allocated or None to allocate the
                          maximum quantity possible.
         """
-        stock = self.get_stock_quantity()
         storable = self.product.storable
-        assert storable is not None
+        # If there is no storable for the product, than we just need to allocate
+        # what is necessary
+        if not storable:
+            self.allocated = self.needed
+            return
 
+        stock = self.get_stock_quantity()
         if quantity is None:
             required = self.needed - self.allocated
             if stock > required:
@@ -427,10 +464,9 @@ class ProductionMaterial(Domain):
         if quantity > 0:
             self.allocated += quantity
             storable.decrease_stock(quantity, self.order.branch,
-                        StockTransactionHistory.TYPE_PRODUCTION_ALLOCATED,
-                        self.id)
+                                    StockTransactionHistory.TYPE_PRODUCTION_ALLOCATED,
+                                    self.id)
 
-    # TESTME
     def return_remaining(self):
         """Returns remaining allocated material to the stock
 
@@ -443,8 +479,8 @@ class ProductionMaterial(Domain):
             return
         storable = self.product.storable
         storable.increase_stock(remaining, self.order.branch,
-                    StockTransactionHistory.TYPE_PRODUCTION_RETURNED,
-                    self.id)
+                                StockTransactionHistory.TYPE_PRODUCTION_RETURNED,
+                                self.id)
         self.allocated -= remaining
 
     def add_lost(self, quantity):
@@ -483,7 +519,7 @@ class ProductionMaterial(Domain):
             raise ValueError(_(u'Can not consume this quantity.'))
 
         required = self.consumed + self.lost + quantity
-        if required > self.allocated:
+        if required > self.allocated:  # pragma nocover
             self.allocate(required - self.allocated)
 
         self.consumed += quantity
@@ -499,8 +535,9 @@ class ProductionMaterial(Domain):
 
     # Accessors
 
-    def get_unit_description(self):
-        return self.product.sellable.get_unit_description()
+    @property
+    def unit_description(self):
+        return self.product.sellable.unit_description
 
     def get_stock_quantity(self):
         storable = self.product.storable
@@ -508,21 +545,24 @@ class ProductionMaterial(Domain):
         return storable.get_balance_for_branch(self.order.branch)
 
 
+@implementer(IDescribable)
 class ProductionService(Domain):
     """Production Service object implementation.
-
-    :attribute order: The :class:`ProductionOrder` of this service.
-    :attribute service: The service that will be used by the production.
-    :attribute quantity: The service's quantity.
     """
-    implements(IDescribable)
 
     __storm_table__ = 'production_service'
 
-    service_id = IntCol()
+    service_id = IdCol()
+
+    #: The service that will be used by the production.
     service = Reference(service_id, 'Service.id')
-    order_id = IntCol()
+
+    order_id = IdCol()
+
+    #: The :class:`ProductionOrder` of this service.
     order = Reference(order_id, 'ProductionOrder.id')
+
+    #: The service's quantity.
     quantity = QuantityCol(default=1)
 
     #
@@ -532,10 +572,11 @@ class ProductionService(Domain):
     def get_description(self):
         return self.service.sellable.get_description()
 
-    # Accessors
+    # Properties
 
-    def get_unit_description(self):
-        return self.service.sellable.get_unit_description()
+    @property
+    def unit_description(self):
+        return self.service.sellable.unit_description
 
 
 class ProductionProducedItem(Domain):
@@ -546,13 +587,13 @@ class ProductionProducedItem(Domain):
 
     __storm_table__ = 'production_produced_item'
 
-    order_id = IntCol()
+    order_id = IdCol()
     order = Reference(order_id, 'ProductionOrder.id')
     # ProductionItem already has a reference to Product, but we need it for
     # constraint checks UNIQUE(product_id, serial_number)
-    product_id = IntCol()
+    product_id = IdCol()
     product = Reference(product_id, 'Product.id')
-    produced_by_id = IntCol()
+    produced_by_id = IdCol()
     produced_by = Reference(produced_by_id, 'LoginUser.id')
     produced_date = DateTimeCol()
     serial_number = IntCol()
@@ -584,8 +625,8 @@ class ProductionProducedItem(Domain):
 
         storable = self.product.storable
         storable.increase_stock(1, self.order.branch,
-                    StockTransactionHistory.TYPE_PRODUCTION_SENT,
-                    self.id)
+                                StockTransactionHistory.TYPE_PRODUCTION_SENT,
+                                self.id)
         self.entered_stock = True
 
     def set_test_result_value(self, quality_test, value, tester):
@@ -595,15 +636,15 @@ class ProductionProducedItem(Domain):
                             produced_item=self).one()
         if not result:
             result = ProductionItemQualityResult(
-                                store=self.store,
-                                quality_test=quality_test,
-                                produced_item=self,
-                                tested_by=tester,
-                                result_value=u'')
+                store=self.store,
+                quality_test=quality_test,
+                produced_item=self,
+                tested_by=tester,
+                result_value=u'')
         else:
             result.tested_by = tester
 
-        result.tested_date = datetime.datetime.now()
+        result.tested_date = localnow()
         result.set_value(value)
         return result
 
@@ -627,19 +668,18 @@ class ProductionProducedItem(Domain):
             self.order.try_finalize_production()
 
 
+@implementer(IDescribable)
 class ProductionItemQualityResult(Domain):
     """This table stores the test results for every produced item.
     """
 
-    implements(IDescribable)
-
     __storm_table__ = 'production_item_quality_result'
 
-    produced_item_id = IntCol()
+    produced_item_id = IdCol()
     produced_item = Reference(produced_item_id, 'ProductionProducedItem.id')
-    quality_test_id = IntCol()
+    quality_test_id = IdCol()
     quality_test = Reference(quality_test_id, 'ProductQualityTest.id')
-    tested_by_id = IntCol()
+    tested_by_id = IdCol()
     tested_by = Reference(tested_by_id, 'LoginUser.id')
     tested_date = DateTimeCol(default=None)
     result_value = UnicodeCol()
@@ -687,7 +727,7 @@ class ProductionOrderProducingView(Viewable):
     tables = [
         ProductionOrder,
         Join(ProductionItem, ProductionOrder.id == ProductionItem.order_id),
-        ]
+    ]
 
     clause = (ProductionOrder.status == ProductionOrder.ORDER_PRODUCING)
 
