@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2009 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,35 +23,35 @@
 ##
 """ Purchase management """
 
+# pylint: enable=E1101
+
 from decimal import Decimal
-import datetime
 
-from kiwi.argcheck import argcheck
 from kiwi.currency import currency
 from kiwi.python import Settable
-from storm.expr import And, Count, Join, LeftJoin, Sum, Select, Alias
+from storm.expr import (Alias, And, Cast, Coalesce, Count, Eq, Join, LeftJoin,
+                        Select, Sum)
 from storm.info import ClassAlias
 from storm.references import Reference
-from storm.store import AutoReload
-from zope.interface import implements
+from zope.interface import implementer
 
-from stoqlib.database.expr import Date, Field, TransactionTimestamp
-from stoqlib.database.properties import IntCol, DateTimeCol, UnicodeCol
-from stoqlib.database.properties import PriceCol, BoolCol, QuantityCol
+from stoqlib.database.expr import Date, Field, NullIf, TransactionTimestamp
+from stoqlib.database.properties import (IntCol, DateTimeCol, UnicodeCol,
+                                         PriceCol, BoolCol, QuantityCol,
+                                         IdentifierCol, IdCol)
 from stoqlib.database.runtime import get_current_user
 from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.interfaces import (IPaymentTransaction, IContainer,
-                                       IDescribable)
-from stoqlib.domain.person import (Person, Branch,
-                                   Supplier,
-                                   Transporter,
-                                   LoginUser)
+from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.product import Product, StockTransactionHistory, Storable
+from stoqlib.domain.interfaces import IContainer, IDescribable
+from stoqlib.domain.person import (Person, Branch, Company, Supplier,
+                                   Transporter, LoginUser)
 from stoqlib.domain.sellable import Sellable, SellableUnit
 from stoqlib.exceptions import DatabaseInconsistency, StoqlibError
-from stoqlib.lib.component import Adaptable
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import format_quantity, get_formatted_price
@@ -78,12 +78,12 @@ class PurchaseItem(Domain):
     cost = PriceCol()
     expected_receival_date = DateTimeCol(default=None)
 
-    sellable_id = IntCol()
+    sellable_id = IdCol()
 
     #: the |sellable|
     sellable = Reference(sellable_id, 'Sellable.id')
 
-    order_id = IntCol()
+    order_id = IdCol()
 
     #: the |purchase|
     order = Reference(order_id, 'PurchaseOrder.id')
@@ -122,19 +122,17 @@ class PurchaseItem(Domain):
         return self.quantity_received > 0
 
     def get_pending_quantity(self):
-        if not self.has_been_received:
-            return Decimal(0)
         return self.quantity - self.quantity_received
 
     def get_quantity_as_string(self):
         unit = self.sellable.unit
         return u"%s %s" % (format_quantity(self.quantity),
-                          unit and unit.description or u"")
+                           unit and unit.description or u"")
 
     def get_quantity_received_as_string(self):
         unit = self.sellable.unit
         return u"%s %s" % (format_quantity(self.quantity_received),
-                          unit and unit.description or u"")
+                           unit and unit.description or u"")
 
     @classmethod
     def get_ordered_quantity(cls, store, sellable):
@@ -151,12 +149,24 @@ class PurchaseItem(Domain):
         ordered_items = store.find(PurchaseItem, query)
         return ordered_items.sum(PurchaseItem.quantity) or Decimal(0)
 
+    def return_consignment(self, quantity):
+        """
+        Return this as a consignment item
 
-class PurchaseOrder(Domain, Adaptable):
+        :param quantity: the quantity to return
+        """
+        storable = self.sellable.product_storable
+        assert storable
+        storable.decrease_stock(quantity=quantity,
+                                branch=self.order.branch,
+                                type=StockTransactionHistory.TYPE_CONSIGNMENT_RETURNED,
+                                object_id=self.id)
+
+
+@implementer(IContainer)
+class PurchaseOrder(Domain):
     """Purchase and order definition."""
 
-    implements(IContainer)
-
     __storm_table__ = 'purchase_order'
 
     (ORDER_CANCELLED,
@@ -180,43 +190,37 @@ class PurchaseOrder(Domain, Adaptable):
                      FREIGHT_CIF: _(u'CIF')}
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
 
     status = IntCol(default=ORDER_QUOTING)
-    open_date = DateTimeCol(default_factory=datetime.datetime.now)
+    open_date = DateTimeCol(default_factory=localnow)
     quote_deadline = DateTimeCol(default=None)
-    expected_receival_date = DateTimeCol(default_factory=datetime.datetime.now)
-    expected_pay_date = DateTimeCol(default_factory=datetime.datetime.now)
+    expected_receival_date = DateTimeCol(default_factory=localnow)
+    expected_pay_date = DateTimeCol(default_factory=localnow)
     receival_date = DateTimeCol(default=None)
     confirm_date = DateTimeCol(default=None)
     notes = UnicodeCol(default=u'')
     salesperson_name = UnicodeCol(default=u'')
     freight_type = IntCol(default=FREIGHT_FOB)
     expected_freight = PriceCol(default=0)
+
     surcharge_value = PriceCol(default=0)
     discount_value = PriceCol(default=0)
+
     consigned = BoolCol(default=False)
-    supplier_id = IntCol()
+    supplier_id = IdCol()
     supplier = Reference(supplier_id, 'Supplier.id')
-    branch_id = IntCol()
+    branch_id = IdCol()
     branch = Reference(branch_id, 'Branch.id')
-    transporter_id = IntCol(default=None)
+    transporter_id = IdCol(default=None)
     transporter = Reference(transporter_id, 'Transporter.id')
-    responsible_id = IntCol()
+    responsible_id = IdCol()
     responsible = Reference(responsible_id, 'LoginUser.id')
-    group_id = IntCol()
+    group_id = IdCol()
     group = Reference(group_id, 'PaymentGroup.id')
 
-    def __init__(self, **kwargs):
-        super(PurchaseOrder, self).__init__(**kwargs)
-        self.addFacet(IPaymentTransaction)
-
-    def __storm_loaded__(self):
-        super(PurchaseOrder, self).__storm_loaded__()
-        self.addFacet(IPaymentTransaction)
-
     #
     # IContainer Implementation
     #
@@ -224,13 +228,12 @@ class PurchaseOrder(Domain, Adaptable):
     def get_items(self):
         return self.store.find(PurchaseItem, order=self)
 
-    @argcheck(PurchaseItem)
     def remove_item(self, item):
-        store = self.store
         if item.order is not self:
             raise ValueError(_(u'Argument item must have an order attribute '
                                'associated with the current purchase instance'))
-        PurchaseItem.delete(item.id, store=store)
+        item.order = None
+        self.store.maybe_remove(item)
 
     def add_item(self, sellable, quantity=Decimal(1)):
         store = self.store
@@ -241,51 +244,45 @@ class PurchaseOrder(Domain, Adaptable):
     # Properties
     #
 
-    def _set_discount_by_percentage(self, value):
-        """Sets a discount by percentage.
+    @property
+    def discount_percentage(self):
+        """Discount by percentage.
         Note that percentage must be added as an absolute value not as a
         factor like 1.05 = 5 % of surcharge
         The correct form is 'percentage = 3' for a discount of 3 %"""
-        self.discount_value = self._get_percentage_value(value)
-
-    def _get_discount_by_percentage(self):
         discount_value = self.discount_value
         if not discount_value:
             return currency(0)
-        subtotal = self.get_purchase_subtotal()
+        subtotal = self.purchase_subtotal
         assert subtotal > 0, (u'the subtotal should not be zero '
                               u'at this point')
         total = subtotal - discount_value
         percentage = (1 - total / subtotal) * 100
         return quantize(percentage)
 
-    discount_percentage = property(_get_discount_by_percentage,
-                                   _set_discount_by_percentage)
+    @discount_percentage.setter
+    def discount_percentage(self, value):
+        self.discount_value = self._get_percentage_value(value)
 
-    def _set_surcharge_by_percentage(self, value):
-        """Sets a surcharge by percentage.
+    @property
+    def surcharge_percentage(self):
+        """Surcharge by percentage.
         Note that surcharge must be added as an absolute value not as a
         factor like 0.97 = 3 % of discount.
         The correct form is 'percentage = 3' for a surcharge of 3 %"""
-        self.surcharge_value = self._get_percentage_value(value)
-
-    def _get_surcharge_by_percentage(self):
         surcharge_value = self.surcharge_value
         if not surcharge_value:
             return currency(0)
-        subtotal = self.get_purchase_subtotal()
+        subtotal = self.purchase_subtotal
         assert subtotal > 0, (u'the subtotal should not be zero '
                               u'at this point')
         total = subtotal + surcharge_value
         percentage = ((total / subtotal) - 1) * 100
         return quantize(percentage)
 
-    surcharge_percentage = property(_get_surcharge_by_percentage,
-                                    _set_surcharge_by_percentage)
-
-    @property
-    def order_number(self):
-        return self.identifier
+    @surcharge_percentage.setter
+    def surcharge_percentage(self, value):
+        self.surcharge_value = self._get_percentage_value(value)
 
     @property
     def payments(self):
@@ -306,10 +303,25 @@ class PurchaseOrder(Domain, Adaptable):
     def _get_percentage_value(self, percentage):
         if not percentage:
             return currency(0)
-        subtotal = self.get_purchase_subtotal()
+        subtotal = self.purchase_subtotal
         percentage = Decimal(percentage)
         return subtotal * (percentage / 100)
 
+    def _payback_paid_payments(self):
+        paid_value = self.group.get_total_paid()
+
+        # If we didn't pay anything yet, there is no need to create a payback.
+        if not paid_value:
+            return
+
+        money = PaymentMethod.get_by_name(self.store, u'money')
+        payment = money.create_payment(
+            Payment.TYPE_IN, self.group, self.branch,
+            paid_value, description=_(u'%s Money Returned for Purchase %s') % (
+                u'1/1', self.identifier))
+        payment.set_pending()
+        payment.pay()
+
     #
     # Public API
     #
@@ -358,13 +370,14 @@ class PurchaseOrder(Domain, Adaptable):
 
         if self.status not in [PurchaseOrder.ORDER_PENDING,
                                PurchaseOrder.ORDER_CONSIGNED]:
-            raise ValueError(
-                _(u'Invalid order status, it should be '
-                  u'ORDER_PENDING or ORDER_CONSIGNED, got %s') % (
-                self.get_status_str(), ))
+            fmt = _(u'Invalid order status, it should be '
+                    u'ORDER_PENDING or ORDER_CONSIGNED, got %s')
+            raise ValueError(fmt % (self.status_str, ))
 
-        transaction = IPaymentTransaction(self)
-        transaction.confirm()
+        # In consigned purchases there is no payments at this point.
+        if self.status != PurchaseOrder.ORDER_CONSIGNED:
+            for payment in self.payments:
+                payment.set_pending()
 
         if self.supplier:
             self.group.recipient = self.supplier.person
@@ -373,18 +386,17 @@ class PurchaseOrder(Domain, Adaptable):
         self.status = PurchaseOrder.ORDER_CONFIRMED
         self.confirm_date = confirm_date
 
-        Event.log(Event.TYPE_ORDER,
-                _(u"Order %d, total value %2.2f, supplier '%s' "
-                  u"is now confirmed") % (
-                    self.order_number,
-                    self.get_purchase_total(),
-                    self.supplier.person.name))
+        Event.log(self.store, Event.TYPE_ORDER,
+                  _(u"Order %s, total value %2.2f, supplier '%s' "
+                    u"is now confirmed") % (self.identifier,
+                                            self.purchase_total,
+                                            self.supplier.person.name))
 
     def set_consigned(self):
         if self.status != PurchaseOrder.ORDER_PENDING:
             raise ValueError(
                 _(u'Invalid order status, it should be '
-                  u'ORDER_PENDING, got %s') % (self.get_status_str(), ))
+                  u'ORDER_PENDING, got %s') % (self.status_str, ))
 
         self.responsible = get_current_user(self.store)
         self.status = PurchaseOrder.ORDER_CONSIGNED
@@ -394,15 +406,14 @@ class PurchaseOrder(Domain, Adaptable):
         """
         if self.status != PurchaseOrder.ORDER_CONFIRMED:
             raise ValueError(_(u'Invalid status, it should be confirmed '
-                               u'got %s instead') % self.get_status_str())
+                               u'got %s instead') % self.status_str)
         self.status = self.ORDER_CLOSED
 
-        Event.log(Event.TYPE_ORDER,
-                _(u"Order %d, total value %2.2f, supplier '%s' "
-                  u"is now closed") % (
-                    self.order_number,
-                    self.get_purchase_total(),
-                    self.supplier.person.name))
+        Event.log(self.store, Event.TYPE_ORDER,
+                  _(u"Order %s, total value %2.2f, supplier '%s' "
+                    u"is now closed") % (self.identifier,
+                                         self.purchase_total,
+                                         self.supplier.person.name))
 
     def cancel(self):
         """Cancels the purchase order
@@ -410,8 +421,8 @@ class PurchaseOrder(Domain, Adaptable):
         assert self.can_cancel()
 
         # we have to cancel the payments too
-        transaction = IPaymentTransaction(self)
-        transaction.cancel()
+        self._payback_paid_payments()
+        self.group.cancel()
 
         self.status = self.ORDER_CANCELLED
 
@@ -429,7 +440,7 @@ class PurchaseOrder(Domain, Adaptable):
     def increase_quantity_received(self, purchase_item, quantity_received):
         sellable = purchase_item.sellable
         items = [item for item in self.get_items()
-                    if item.sellable.id == sellable.id]
+                 if item.sellable.id == sellable.id]
         qty = len(items)
         if not qty:
             raise ValueError(_(u'There is no purchase item for '
@@ -437,54 +448,59 @@ class PurchaseOrder(Domain, Adaptable):
 
         purchase_item.quantity_received += quantity_received
 
-    def get_status_str(self):
+    @property
+    def status_str(self):
         return PurchaseOrder.translate_status(self.status)
 
-    def get_freight_type_name(self):
+    @property
+    def freight_type_name(self):
         if not self.freight_type in self.freight_types.keys():
             raise DatabaseInconsistency(_(u'Invalid freight_type, got %d')
-                                          % self.freight_type)
+                                        % self.freight_type)
         return self.freight_types[self.freight_type]
 
-    def get_branch_name(self):
+    @property
+    def branch_name(self):
         return self.branch.get_description()
 
-    def get_supplier_name(self):
+    @property
+    def supplier_name(self):
         return self.supplier.get_description()
 
-    def get_transporter_name(self):
+    @property
+    def transporter_name(self):
         if not self.transporter:
             return u""
         return self.transporter.get_description()
 
-    def get_responsible_name(self):
+    @property
+    def responsible_name(self):
         return self.responsible.get_description()
 
-    def get_order_number_str(self):
-        # FIXME: Add branch acronim here
-        return u'%05d' % self.identifier
-
-    def get_purchase_subtotal(self):
+    @property
+    def purchase_subtotal(self):
         """Get the subtotal of the purchase.
         The sum of all the items cost * items quantity
         """
         return currency(self.get_items().sum(
             PurchaseItem.cost * PurchaseItem.quantity) or 0)
 
-    def get_purchase_total(self):
-        subtotal = self.get_purchase_subtotal()
+    @property
+    def purchase_total(self):
+        subtotal = self.purchase_subtotal
         total = subtotal - self.discount_value + self.surcharge_value
         if total < 0:
             raise ValueError(_(u'Purchase total can not be lesser than zero'))
-        #XXX: Since the purchase_total value must have two digits
+        # XXX: Since the purchase_total value must have two digits
         # (at the moment) we need to format the value to a 2-digit number and
         # then convert it to currency data type, because the subtotal value
         # may return a 3-or-more-digit value, depending on COST_PRECISION_DIGITS
         # parameters.
         return currency(get_formatted_price(total))
 
-    def get_received_total(self):
-        """Like {get_purchase_subtotal} but only takes into account the
+    @property
+    def received_total(self):
+        """Like {purchase_subtotal} but only takes into account the
         received items
         """
         return currency(self.get_items().sum(
@@ -494,7 +510,7 @@ class PurchaseOrder(Domain, Adaptable):
     def get_remaining_total(self):
         """The total value to be paid for the items not received yet
         """
-        return self.get_purchase_total() - self.get_received_total()
+        return self.purchase_total - self.received_total
 
     def get_pending_items(self):
         """
@@ -519,8 +535,11 @@ class PurchaseOrder(Domain, Adaptable):
     def get_receiving_orders(self):
         """Returns all ReceivingOrder related to this purchase order
         """
-        from stoqlib.domain.receiving import ReceivingOrder
-        return self.store.find(ReceivingOrder, purchase=self)
+        from stoqlib.domain.receiving import PurchaseReceivingMap, ReceivingOrder
+        tables = [PurchaseReceivingMap, ReceivingOrder]
+        query = And(PurchaseReceivingMap.purchase_id == self.id,
+                    PurchaseReceivingMap.receiving_id == ReceivingOrder.id)
+        return self.store.using(*tables).find(ReceivingOrder, query)
 
     def get_data_for_labels(self):
         """ This function returns some necessary data to print the purchase's
@@ -534,6 +553,21 @@ class PurchaseOrder(Domain, Adaptable):
                                   quantity=purchase_item.quantity)
             yield label_data
 
+    def has_batch_item(self):
+        """Fetch the storables from this purchase order and returns ``True`` if
+        any of them is a batch storable.
+
+        :returns: ``True`` if this purchase order has batch items, ``False`` if
+        it doesn't.
+        """
+        return not self.store.find(Storable,
+                                   And(self.id == PurchaseOrder.id,
+                                       PurchaseOrder.id == PurchaseItem.order_id,
+                                       PurchaseItem.sellable_id == Sellable.id,
+                                       Sellable.id == Product.sellable_id,
+                                       Product.id == Storable.product_id,
+                                       Eq(Storable.is_batch, True))).is_empty()
+
     #
     # Classmethods
     #
@@ -546,26 +580,25 @@ class PurchaseOrder(Domain, Adaptable):
         return cls.statuses[status]
 
 
+@implementer(IDescribable)
 class Quotation(Domain):
     __storm_table__ = 'quotation'
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
 
-    group_id = IntCol()
+    group_id = IdCol()
     group = Reference(group_id, 'QuoteGroup.id')
-    purchase_id = IntCol()
+    purchase_id = IdCol()
     purchase = Reference(purchase_id, 'PurchaseOrder.id')
-    branch_id = IntCol()
+    branch_id = IdCol()
     branch = Reference(branch_id, 'Branch.id')
 
-    implements(IDescribable)
-
     def get_description(self):
         supplier = self.purchase.supplier.person.name
-        return u"Group %04d - %s" % (self.group.identifier, supplier)
+        return u"Group %s - %s" % (self.group.identifier, supplier)
 
     #
     # Public API
@@ -586,18 +619,18 @@ class Quotation(Domain):
         return self.purchase.status == PurchaseOrder.ORDER_CANCELLED
 
 
+@implementer(IContainer)
+@implementer(IDescribable)
 class QuoteGroup(Domain):
 
-    implements(IContainer, IDescribable)
-
     __storm_table__ = 'quote_group'
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
 
-    branch_id = IntCol()
+    branch_id = IdCol()
     branch = Reference(branch_id, 'Branch.id')
 
     #
@@ -607,20 +640,19 @@ class QuoteGroup(Domain):
     def get_items(self):
         return self.store.find(Quotation, group=self)
 
-    @argcheck(Quotation)
     def remove_item(self, item):
-        store = self.store
         if item.group is not self:
             raise ValueError(_(u'You can not remove an item which does not '
                                u'belong to this group.'))
 
         order = item.purchase
-        Quotation.delete(item.id, store=store)
+        # FIXME: Bug 5581 Removing objects with synced databases is dangerous.
+        # Investigate this usage
+        self.store.remove(item)
         for order_item in order.get_items():
             order.remove_item(order_item)
-        PurchaseOrder.delete(order.id, store=store)
+        self.store.remove(order)
 
-    @argcheck(PurchaseOrder)
     def add_item(self, item):
         store = self.store
         return Quotation(purchase=item, group=self, branch=self.branch,
@@ -631,7 +663,7 @@ class QuoteGroup(Domain):
     #
 
     def get_description(self):
-        return _(u"quote number %04d") % self.identifier
+        return _(u"quote number %s") % self.identifier
 
     #
     # Public API
@@ -642,62 +674,9 @@ class QuoteGroup(Domain):
         store = self.store
         for quote in self.get_items():
             quote.close()
-            Quotation.delete(quote.id, store=store)
-
-
-class PurchaseOrderAdaptToPaymentTransaction(object):
-    implements(IPaymentTransaction)
-
-    def __init__(self, purchase):
-        self.purchase = purchase
-
-    #
-    # IPaymentTransaction implementation
-    #
-
-    def confirm(self):
-        # In consigned purchases there is no payments at this point.
-        if self.purchase.status == PurchaseOrder.ORDER_CONSIGNED:
-            return
-
-        for payment in self.purchase.payments:
-            payment.set_pending()
-
-    def pay(self):
-        for payment in self.purchase.payments:
-            payment.pay()
-
-    def cancel(self):
-        self._payback_paid_payments()
-        self.purchase.group.cancel()
-
-    def return_(self, renegotiation):
-        pass
-
-    def create_commission(self, payment):
-        pass
-
-    #
-    # Private API
-    #
-
-    def _payback_paid_payments(self):
-        paid_value = self.purchase.group.get_total_paid()
-
-        # If we didn't pay anything yet, there is no need to create a payback.
-        if not paid_value:
-            return
-
-        money = PaymentMethod.get_by_name(self.purchase.store, u'money')
-        payment = money.create_inpayment(
-            self.purchase.group, self.purchase.branch, paid_value,
-            description=_(u'%s Money Returned for Purchase %d') % (
-            u'1/1', self.purchase.identifier))
-        payment.set_pending()
-        payment.pay()
-
-
-PurchaseOrder.registerFacet(PurchaseOrderAdaptToPaymentTransaction, IPaymentTransaction)
+            # FIXME: Bug 5581 Removing objects with synced databases is
+            # dangerous. Investigate this usage
+            store.remove(quote)
 
 
 class PurchaseItemView(Viewable):
@@ -740,19 +719,21 @@ class PurchaseItemView(Viewable):
         Join(PurchaseOrder, PurchaseOrder.id == PurchaseItem.order_id),
         Join(Sellable, Sellable.id == PurchaseItem.sellable_id),
         LeftJoin(SellableUnit, SellableUnit.id == Sellable.unit_id),
-        ]
+    ]
 
-    def get_quantity_as_string(self):
+    @property
+    def quantity_as_string(self):
         return u"%s %s" % (format_quantity(self.quantity),
-                          self.unit or u"")
+                           self.unit or u"")
 
-    def get_quantity_received_as_string(self):
+    @property
+    def quantity_received_as_string(self):
         return u"%s %s" % (format_quantity(self.quantity_received),
-                          self.unit or u"")
+                           self.unit or u"")
 
     @classmethod
     def find_by_purchase(cls, store, purchase):
-        return store.find(cls, purchase_id=purchase.id).order_by(PurchaseItem.id)
+        return store.find(cls, purchase_id=purchase.id)
 
 
 #
@@ -765,9 +746,9 @@ class PurchaseItemView(Viewable):
 # columns in PurchaseOrderView is extremelly slow, as it requires sorting all
 # those columns
 _ItemSummary = Select(columns=[PurchaseItem.order_id,
-                           Alias(Sum(PurchaseItem.quantity), 'ordered_quantity'),
-                           Alias(Sum(PurchaseItem.quantity_received), 'received_quantity'),
-                           Alias(Sum(PurchaseItem.quantity *
+                               Alias(Sum(PurchaseItem.quantity), 'ordered_quantity'),
+                               Alias(Sum(PurchaseItem.quantity_received), 'received_quantity'),
+                               Alias(Sum(PurchaseItem.quantity *
                                      PurchaseItem.cost), 'subtotal')],
                       tables=[PurchaseItem],
                       group_by=[PurchaseItem.order_id])
@@ -804,9 +785,11 @@ class PurchaseOrderView(Viewable):
     Person_Responsible = ClassAlias(Person, 'person_responsible')
 
     purchase = PurchaseOrder
+    branch = Branch
 
     id = PurchaseOrder.id
     identifier = PurchaseOrder.identifier
+    identifier_str = Cast(PurchaseOrder.identifier, 'text')
     status = PurchaseOrder.status
     open_date = PurchaseOrder.open_date
     quote_deadline = PurchaseOrder.quote_deadline
@@ -814,15 +797,16 @@ class PurchaseOrderView(Viewable):
     expected_pay_date = PurchaseOrder.expected_pay_date
     receival_date = PurchaseOrder.receival_date
     confirm_date = PurchaseOrder.confirm_date
-    salesperson_name = PurchaseOrder.salesperson_name
+    salesperson_name = NullIf(PurchaseOrder.salesperson_name, u'')
     expected_freight = PurchaseOrder.expected_freight
     surcharge_value = PurchaseOrder.surcharge_value
     discount_value = PurchaseOrder.discount_value
 
+    branch_id = Branch.id
     supplier_id = Supplier.id
     supplier_name = Person_Supplier.name
-    transporter_name = Person_Transporter.name
-    branch_name = Person_Branch.name
+    transporter_name = Coalesce(Person_Transporter.name, u'')
+    branch_name = Coalesce(NullIf(Company.fancy_name, u''), Person_Branch.name)
     responsible_name = Person_Responsible.name
 
     ordered_quantity = Field('_purchase_item', 'ordered_quantity')
@@ -844,6 +828,7 @@ class PurchaseOrderView(Viewable):
         LeftJoin(Person_Supplier, Supplier.person_id == Person_Supplier.id),
         LeftJoin(Person_Transporter, Transporter.person_id == Person_Transporter.id),
         LeftJoin(Person_Branch, Branch.person_id == Person_Branch.id),
+        LeftJoin(Company, Company.person_id == Person_Branch.id),
         LeftJoin(Person_Responsible, LoginUser.person_id == Person_Responsible.id),
     ]
 
@@ -856,25 +841,11 @@ class PurchaseOrderView(Viewable):
     # Public API
     #
 
-    def get_total(self):
-        return currency(self.total)
-
-    def get_subtotal(self):
-        return currency(self.subtotal)
-
-    def get_branch_name(self):
-        return unicode(self.branch_name or u"")
-
-    def get_supplier_name(self):
-        return unicode(self.supplier_name or u"")
-
-    def get_transporter_name(self):
-        return unicode(self.transporter_name or u"")
-
     def get_open_date_as_string(self):
         return self.open_date.strftime("%x")
 
-    def get_status_str(self):
+    @property
+    def status_str(self):
         return PurchaseOrder.translate_status(self.status)
 
     @classmethod
