@@ -23,22 +23,26 @@
 ##
 """ Receiving management """
 
-import datetime
+# pylint: enable=E1101
+
 from decimal import Decimal
 
-from kiwi.argcheck import argcheck
 from kiwi.currency import currency
-from storm.references import Reference
-from storm.store import AutoReload
+from storm.expr import And
+from storm.references import Reference, ReferenceSet
 
-from stoqlib.database.properties import PriceCol, QuantityCol
-from stoqlib.database.properties import IntCol, DateTimeCol, UnicodeCol
+from stoqlib.database.properties import (PriceCol, QuantityCol, IntCol,
+                                         DateTimeCol, UnicodeCol, IdentifierCol,
+                                         IdCol)
 from stoqlib.domain.base import Domain
 from stoqlib.domain.fiscal import FiscalBookEntry
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.product import ProductHistory, StockTransactionHistory
+from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.product import (ProductHistory, StockTransactionHistory,
+                                    StorableBatch)
 from stoqlib.domain.purchase import PurchaseOrder
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
@@ -48,6 +52,9 @@ _ = stoqlib_gettext
 
 class ReceivingOrderItem(Domain):
     """This class stores information of the purchased items.
+
+    Note that objects of this type should not be created manually, only by
+    calling Receiving
     """
 
     __storm_table__ = 'receiving_order_item'
@@ -58,19 +65,35 @@ class ReceivingOrderItem(Domain):
     #: the cost for each |product| received
     cost = PriceCol()
 
-    purchase_item_id = IntCol()
+    purchase_item_id = IdCol()
 
     purchase_item = Reference(purchase_item_id, 'PurchaseItem.id')
 
-    sellable_id = IntCol()
+    # FIXME: This could be a product instead of a sellable, since we only buy
+    # products from the suppliers.
+    sellable_id = IdCol()
 
     #: the |sellable|
     sellable = Reference(sellable_id, 'Sellable.id')
 
-    receiving_order_id = IntCol()
+    batch_id = IdCol()
+
+    #: If the sellable is a storable, the |batch| that it was received in
+    batch = Reference(batch_id, 'StorableBatch.id')
+
+    receiving_order_id = IdCol()
 
     receiving_order = Reference(receiving_order_id, 'ReceivingOrder.id')
 
+    #
+    # Properties
+    #
+
+    @property
+    def unit_description(self):
+        unit = self.sellable.unit
+        return u"%s" % (unit and unit.description or u"")
+
     #
     # Accessors
     #
@@ -90,12 +113,10 @@ class ReceivingOrderItem(Domain):
 
     def get_quantity_unit_string(self):
         unit = self.sellable.unit
-        return u"%s %s" % (self.quantity,
-                          unit and unit.description or u"")
-
-    def get_unit_description(self):
-        unit = self.sellable.unit
-        return u"%s" % (unit and unit.description or u"")
+        data = u"%s %s" % (self.quantity,
+                           unit and unit.description or u"")
+        # The unit may be empty
+        return data.strip()
 
     def add_stock_items(self):
         """This is normally called from ReceivingOrder when
@@ -105,9 +126,8 @@ class ReceivingOrderItem(Domain):
         if self.quantity > self.get_remaining_quantity():
             raise ValueError(
                 u"Quantity received (%d) is greater than "
-                u"quantity ordered (%d)" % (
-                self.quantity,
-                self.get_remaining_quantity()))
+                u"quantity ordered (%d)" % (self.quantity,
+                                            self.get_remaining_quantity()))
 
         branch = self.receiving_order.branch
         storable = self.sellable.product_storable
@@ -115,7 +135,7 @@ class ReceivingOrderItem(Domain):
         if storable is not None:
             storable.increase_stock(self.quantity, branch,
                                     StockTransactionHistory.TYPE_RECEIVED_PURCHASE,
-                                    self.id, self.cost)
+                                    self.id, self.cost, batch=self.batch)
         purchase.increase_quantity_received(self.purchase_item, self.quantity)
         ProductHistory.add_received_item(store, branch, self)
 
@@ -151,15 +171,15 @@ class ReceivingOrder(Domain):
                     FREIGHT_CIF_INVOICE)
 
     #: A numeric identifier for this object. This value should be used instead of
-    #: :obj:`.id` when displaying a numerical representation of this object to
+    #: :obj:`Domain.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
-    identifier = IntCol(default=AutoReload)
+    identifier = IdentifierCol()
 
     #: status of the order
     status = IntCol(default=STATUS_PENDING)
 
     #: Date that order has been closed.
-    receival_date = DateTimeCol(default_factory=datetime.datetime.now)
+    receival_date = DateTimeCol(default_factory=localnow)
 
     #: Date that order was send to Stock application.
     confirm_date = DateTimeCol(default=None)
@@ -191,41 +211,106 @@ class ReceivingOrder(Domain):
     #: The number of the order that has been received.
     invoice_number = IntCol()
     invoice_total = PriceCol(default=None)
-    cfop_id = IntCol()
+
+    cfop_id = IdCol()
     cfop = Reference(cfop_id, 'CfopData.id')
 
-    responsible_id = IntCol()
+    responsible_id = IdCol()
     responsible = Reference(responsible_id, 'LoginUser.id')
-    supplier_id = IntCol()
+
+    supplier_id = IdCol()
     supplier = Reference(supplier_id, 'Supplier.id')
-    branch_id = IntCol()
+
+    branch_id = IdCol()
     branch = Reference(branch_id, 'Branch.id')
-    purchase_id = IntCol()
-    purchase = Reference(purchase_id, 'PurchaseOrder.id')
-    transporter_id = IntCol(default=None)
+
+    transporter_id = IdCol(default=None)
     transporter = Reference(transporter_id, 'Transporter.id')
 
+    purchase_orders = ReferenceSet('ReceivingOrder.id',
+                                   'PurchaseReceivingMap.receiving_id',
+                                   'PurchaseReceivingMap.purchase_id',
+                                   'PurchaseOrder.id')
+
     def __init__(self, store=None, **kw):
         Domain.__init__(self, store=store, **kw)
         # These miss default parameters and needs to be set before
         # cfop, which triggers an implicit flush.
         self.branch = kw.pop('branch', None)
-        self.purchase = kw.pop('purchase', None)
         self.supplier = kw.pop('supplier', None)
         if not 'cfop' in kw:
-            self.cfop = sysparam(store).DEFAULT_RECEIVING_CFOP
+            self.cfop = sysparam.get_object(store, 'DEFAULT_RECEIVING_CFOP')
+
+    #
+    #  Public API
+    #
 
     def confirm(self):
         for item in self.get_items():
             item.add_stock_items()
 
+        purchases = list(self.purchase_orders)
+        # XXX: Maybe FiscalBookEntry should not reference the payment group, but
+        # lets keep this way for now until we refactor the fiscal book related
+        # code, since it will pretty soon need a lot of changes.
+        group = purchases[0].group
         FiscalBookEntry.create_product_entry(
             self.store,
-            self.purchase.group, self.cfop, self.invoice_number,
+            group, self.cfop, self.invoice_number,
             self.icms_total, self.ipi_total)
-        self.invoice_total = self.get_total()
-        if self.purchase.can_close():
-            self.purchase.close()
+
+        self.invoice_total = self.total
+
+        for purchase in purchases:
+            if purchase.can_close():
+                purchase.close()
+
+    def add_purchase(self, order):
+        return PurchaseReceivingMap(store=self.store, purchase=order,
+                                    receiving=self)
+
+    def add_purchase_item(self, item, quantity=None, batch_number=None):
+        """Add a |purchaseitem| on this receiving order
+
+        :param item: the |purchaseitem|
+        :param decimal.Decimal quantity: the quantity of that item.
+            If ``None``, it will be get from the item's pending quantity
+        :param batch_number: a batch number that will be used to
+            get or create a |batch| it will be get from the item's
+            pending quantity or ``None`` if the item's |storable|
+            is not controlling batches.
+        :raises: :exc:`ValueError` when validating the quantity
+            and testing the item's order for equality with :obj:`.order`
+        """
+        pending_quantity = item.get_pending_quantity()
+        if quantity is None:
+            quantity = pending_quantity
+
+        if not (0 < quantity <= item.quantity):
+            raise ValueError("The quantity must be higher than 0 and lower "
+                             "than the purchase item's quantity")
+        if quantity > pending_quantity:
+            raise ValueError("The quantity must be lower than the item's "
+                             "pending quantity")
+
+        sellable = item.sellable
+        storable = sellable.product_storable
+        if batch_number is not None:
+            batch = StorableBatch.get_or_create(self.store, storable=storable,
+                                                batch_number=batch_number)
+        else:
+            batch = None
+
+        self.validate_batch(batch, sellable)
+
+        return ReceivingOrderItem(
+            store=self.store,
+            sellable=item.sellable,
+            batch=batch,
+            quantity=quantity,
+            cost=item.cost,
+            purchase_item=item,
+            receiving_order=self)
 
     def update_payments(self, create_freight_payment=False):
         """Updates the payment value of all payments realated to this
@@ -236,15 +321,17 @@ class ReceivingOrder(Domain):
         :param create_freight_payment: True if we should create a new payment
                                        with the freight value, False otherwise.
         """
-        group = self.purchase.group
-        difference = self.get_total() - self.get_products_total()
+        difference = self.total - self.products_total
         if create_freight_payment:
             difference -= self.freight_total
 
         if difference != 0:
-            payments = group.get_pending_payments()
+            # Get app pending payments for the purchases associated with this
+            # receiving, and update them.
+            payments = self.payments.find(status=Payment.STATUS_PENDING)
             payments_number = payments.count()
             if payments_number > 0:
+                # XXX: There is a potential rounding error here.
                 per_installments_value = difference / payments_number
                 for payment in payments:
                     new_value = payment.value + per_installments_value
@@ -258,17 +345,21 @@ class ReceivingOrder(Domain):
         money_method = PaymentMethod.get_by_name(store, u'money')
         # If we have a transporter, the freight payment will be for him
         # (and in another payment group).
-        if self.transporter is not None:
-            group = PaymentGroup(store=store)
-            group.recipient = self.transporter.person
+        purchases = list(self.purchase_orders)
+        if len(purchases) == 1 and self.transporter is None:
+            group = purchases[0].group
         else:
-            group = self.purchase.group
+            if self.transporter:
+                recipient = self.transporter.person
+            else:
+                recipient = self.supplier.person
+            group = PaymentGroup(store=store, recipient=recipient)
 
-        description = _(u'Freight for purchase %s') % (
-                        self.purchase.get_order_number_str(), )
-        payment = money_method.create_outpayment(
+        description = _(u'Freight for receiving %s') % (self.identifier, )
+        payment = money_method.create_payment(
+            Payment.TYPE_OUT,
             group, self.branch, self.freight_total,
-            due_date=datetime.datetime.today(),
+            due_date=localnow(),
             description=description)
         payment.set_pending()
         return payment
@@ -289,56 +380,54 @@ class ReceivingOrder(Domain):
     # Properties
     #
 
-    @property
-    def receiving_number(self):
-        return self.identifier
-
-    @property
-    def group(self):
-        return self.purchase.group
-
     @property
     def payments(self):
-        return self.group.payments
+        tables = [PurchaseReceivingMap, PurchaseOrder, Payment]
+        query = And(PurchaseReceivingMap.receiving_id == self.id,
+                    PurchaseReceivingMap.purchase_id == PurchaseOrder.id,
+                    Payment.group_id == PurchaseOrder.group_id)
+        return self.store.using(tables).find(Payment, query)
+
+    @property
+    def supplier_name(self):
+        if not self.supplier:
+            return u""
+        return self.supplier.get_description()
 
     #
     # Accessors
     #
 
-    def get_cfop_code(self):
+    @property
+    def cfop_code(self):
         return self.cfop.code.encode()
 
-    def get_transporter_name(self):
+    @property
+    def transporter_name(self):
         if not self.transporter:
             return u""
         return self.transporter.get_description()
 
-    def get_receiving_number_str(self):
-        return u"%04d" % self.identifier
-
-    def get_branch_name(self):
+    @property
+    def branch_name(self):
         return self.branch.get_description()
 
-    def get_supplier_name(self):
-        if not self.supplier:
-            return u""
-        return self.supplier.get_description()
-
-    def get_responsible_name(self):
+    @property
+    def responsible_name(self):
         return self.responsible.get_description()
 
-    def get_products_total(self):
+    @property
+    def products_total(self):
         total = sum([item.get_total() for item in self.get_items()],
-                     currency(0))
+                    currency(0))
         return currency(total)
 
-    def get_order_number(self):
-        return self.purchase.get_order_number_str()
-
-    def get_receival_date_str(self):
+    @property
+    def receival_date_str(self):
         return self.receival_date.strftime("%x")
 
-    def _get_total_surcharges(self):
+    @property
+    def total_surcharges(self):
         """Returns the sum of all surcharges (purchase & receiving)"""
         total_surcharge = 0
         if self.surcharge_value:
@@ -348,8 +437,8 @@ class ReceivingOrder(Domain):
         if self.expense_value:
             total_surcharge += self.expense_value
 
-        if self.purchase.surcharge_value:
-            total_surcharge += self.purchase.surcharge_value
+        for purchase in self.purchase_orders:
+            total_surcharge += purchase.surcharge_value
 
         if self.ipi_total:
             total_surcharge += self.ipi_total
@@ -362,110 +451,116 @@ class ReceivingOrder(Domain):
 
         return currency(total_surcharge)
 
-    def _get_total_discounts(self):
+    @property
+    def total_discounts(self):
         """Returns the sum of all discounts (purchase & receiving)"""
         total_discount = 0
         if self.discount_value:
             total_discount += self.discount_value
 
-        if self.purchase.discount_value:
-            total_discount += self.purchase.discount_value
+        for purchase in self.purchase_orders:
+            total_discount += purchase.discount_value
 
         return currency(total_discount)
 
-    def get_total(self):
+    @property
+    def total(self):
         """Fetch the total, including discount and surcharge for both the
         purchase order and the receiving order.
         """
-
-        total = self.get_products_total()
-        total -= self._get_total_discounts()
-        total += self._get_total_surcharges()
+        total = self.products_total
+        total -= self.total_discounts
+        total += self.total_surcharges
 
         return currency(total)
 
     def guess_freight_type(self):
         """Returns a freight_type based on the purchase's freight_type"""
-        if self.purchase.freight_type == PurchaseOrder.FREIGHT_FOB:
-            if self.purchase.is_paid():
+        purchases = list(self.purchase_orders)
+        assert len(purchases) == 1
+
+        purchase = purchases[0]
+        if purchase.freight_type == PurchaseOrder.FREIGHT_FOB:
+            if purchase.is_paid():
                 freight_type = ReceivingOrder.FREIGHT_FOB_PAYMENT
             else:
                 freight_type = ReceivingOrder.FREIGHT_FOB_INSTALLMENTS
-        elif self.purchase.freight_type == PurchaseOrder.FREIGHT_CIF:
-            if not self.purchase.expected_freight:
-                freight_type = ReceivingOrder.FREIGHT_CIF_UNKNOWN
-            else:
+        elif purchase.freight_type == PurchaseOrder.FREIGHT_CIF:
+            if purchase.expected_freight:
                 freight_type = ReceivingOrder.FREIGHT_CIF_INVOICE
+            else:
+                freight_type = ReceivingOrder.FREIGHT_CIF_UNKNOWN
 
         return freight_type
 
     def _get_percentage_value(self, percentage):
         if not percentage:
             return currency(0)
-        subtotal = self.get_products_total()
+        subtotal = self.products_total
         percentage = Decimal(percentage)
         return subtotal * (percentage / 100)
 
-    def _set_discount_by_percentage(self, value):
-        """Sets a discount by percentage.
-        Note that percentage must be added as an absolute value not as a
-        factor like 1.05 = 5 % of surcharge
-        The correct form is 'percentage = 3' for a discount of 3 %
-        """
-        self.discount_value = self._get_percentage_value(value)
-
-    def _get_discount_by_percentage(self):
+    @property
+    def discount_percentage(self):
         discount_value = self.discount_value
         if not discount_value:
             return currency(0)
-        subtotal = self.get_products_total()
+        subtotal = self.products_total
         assert subtotal > 0, (u'the subtotal should not be zero '
                               u'at this point')
         total = subtotal - discount_value
         percentage = (1 - total / subtotal) * 100
         return quantize(percentage)
 
-    discount_percentage = property(_get_discount_by_percentage,
-                                   _set_discount_by_percentage)
+    @discount_percentage.setter
+    def discount_percentage(self, value):
+        """Discount by percentage.
+        Note that percentage must be added as an absolute value not as a
+        factor like 1.05 = 5 % of surcharge
+        The correct form is 'percentage = 3' for a discount of 3 %
+        """
+        self.discount_value = self._get_percentage_value(value)
 
-    def _set_surcharge_by_percentage(self, value):
-        """Sets a surcharge by percentage.
+    @property
+    def surcharge_percentage(self):
+        """Surcharge by percentage.
         Note that surcharge must be added as an absolute value not as a
         factor like 0.97 = 3 % of discount.
         The correct form is 'percentage = 3' for a surcharge of 3 %
         """
-        self.surcharge_value = self._get_percentage_value(value)
-
-    def _get_surcharge_by_percentage(self):
         surcharge_value = self.surcharge_value
         if not surcharge_value:
             return currency(0)
-        subtotal = self.get_products_total()
+        subtotal = self.products_total
         assert subtotal > 0, (u'the subtotal should not be zero '
                               u'at this point')
         total = subtotal + surcharge_value
         percentage = ((total / subtotal) - 1) * 100
         return quantize(percentage)
 
-    surcharge_percentage = property(_get_surcharge_by_percentage,
-                                    _set_surcharge_by_percentage)
+    @surcharge_percentage.setter
+    def surcharge_percentage(self, value):
+        self.surcharge_value = self._get_percentage_value(value)
 
 
-@argcheck(PurchaseOrder, ReceivingOrder)
-def get_receiving_items_by_purchase_order(purchase_order, receiving_order):
-    """Returns a list of receiving items based on a list of purchase items
-    that weren't received yet.
+class PurchaseReceivingMap(Domain):
+    """This class stores a map for purchase and receivings.
 
-    :param purchase_order: a PurchaseOrder instance that holds one or more
-                           purchase items
-    :param receiving_order: a ReceivingOrder instance tied with the
-                            receiving_items that will be created
+    One purchase may be received more than once, for instance, if it was
+    shippped in more than one package.
+
+    Also, a receiving may be for different purchase orders, if more than one
+    purchase order was shipped in the same package.
     """
-    store = purchase_order.store
-    return [ReceivingOrderItem(store=store,
-                               quantity=item.get_pending_quantity(),
-                               cost=item.cost,
-                               sellable=item.sellable,
-                               purchase_item=item,
-                               receiving_order=receiving_order)
-            for item in purchase_order.get_pending_items()]
+
+    __storm_table__ = 'purchase_receiving_map'
+
+    purchase_id = IdCol()
+
+    #: The purchase that was recieved
+    purchase = Reference(purchase_id, 'PurchaseOrder.id')
+
+    receiving_id = IdCol()
+
+    #: In which receiving the purchase was received.
+    receiving = Reference(receiving_id, 'ReceivingOrder.id')
