@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2007 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -21,27 +21,37 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
-""" This module implements base classes to 'sellable objects', such a product
-or a service, implemented in your own modules.
+"""
+Domain objects related to something that can be sold, such a |product|
+or a |service|.
+
+* :class:`Sellable` contains the description, price, cost, barcode etc.
+* :class:`SellableCategory` provides a way to group sellables together, to be
+  able to consistently tax, markup and calculate |commission|.
+* :class:`SellableTaxConstant` contains the tax constant sent to an ECF printer.
+* :class:`SellableUnit` contains the unit.
+* :class:`ClientCategoryPrice` provides a price for |clients| in a |clientcategory|.
 """
 
-import datetime
+# pylint: enable=E1101
+
 from decimal import Decimal
 
 from kiwi.currency import currency
 from stoqdrivers.enum import TaxType, UnitType
-from storm.expr import And, In, Or
+from storm.expr import And, Or, In, Eq
 from storm.references import Reference, ReferenceSet
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.properties import BoolCol, PriceCol, PercentCol
-from stoqlib.database.properties import DateTimeCol, UnicodeCol, IntCol
+from stoqlib.database.properties import DateTimeCol, UnicodeCol, IntCol, IdCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import CategoryCreateEvent, CategoryEditEvent
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.domain.image import Image
-from stoqlib.exceptions import (DatabaseInconsistency, SellableError,
-                                BarcodeDoesNotExists, TaxError)
+from stoqlib.exceptions import SellableError, TaxError
+from stoqlib.lib.defaults import quantize
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.validators import is_date_in_interval
@@ -49,21 +59,26 @@ from stoqlib.lib.validators import is_date_in_interval
 _ = stoqlib_gettext
 
 # pyflakes: Sellable.has_image requires that Image is imported at least once
-Image
+Image  # pylint: disable=W0104
 
 #
 # Base Domain Classes
 #
 
 
+@implementer(IDescribable)
 class SellableUnit(Domain):
-    """ A class used to represent the sellable unit.
+    """
+    The unit of a |sellable|. For instance: ``Kg`` (kilo), ``l`` (liter) and
+    ``h`` (hour)
+    When selling a sellable in a |sale|  the quantity of a |saleitem| will
+    be entered in this unit.
 
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/sellable_unit.html>`__
     """
     __storm_table__ = 'sellable_unit'
 
-    implements(IDescribable)
-
     #: The values on the list are enums used to fill
     # ``'unit_index'`` column above. That list is useful for many things,
     # e.g. See if the user can delete the unit. It should not be possible
@@ -97,15 +112,22 @@ class SellableUnit(Domain):
         return self.description
 
 
+@implementer(IDescribable)
 class SellableTaxConstant(Domain):
     """A tax constant tied to a sellable
-    """
-    implements(IDescribable)
 
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/sellable_tax_constant.html>`__
+    """
     __storm_table__ = 'sellable_tax_constant'
 
+    #: description of this constant
     description = UnicodeCol()
+
+    #: a TaxType constant, used by ECF
     tax_type = IntCol()
+
+    #: the percentage value of the tax
     tax_value = PercentCol(default=None)
 
     _mapping = {
@@ -113,9 +135,12 @@ class SellableTaxConstant(Domain):
         int(TaxType.EXEMPTION): u'TAX_EXEMPTION',            # Isento - ICMS
         int(TaxType.SUBSTITUTION): u'TAX_SUBSTITUTION',      # Substituição tributária - ICMS
         int(TaxType.SERVICE): u'TAX_SERVICE',                # ISS
-        }
+    }
 
     def get_value(self):
+        """
+        :returns: the value to pass to ECF
+        """
         return SellableTaxConstant._mapping.get(
             self.tax_type, self.tax_value)
 
@@ -135,10 +160,20 @@ class SellableTaxConstant(Domain):
 
 
 # pylint: disable=E1101
+@implementer(IDescribable)
 class SellableCategory(Domain):
-    """ Sellable category.
+    """ A Sellable category.
 
-    This class can represents a sellable's category as well its base category.
+    A way to group several |sellables| together, like "Shoes", "Consumer goods",
+    "Services".
+
+    A category can define markup, tax and commission, the values of the category
+    will only be used when the sellable itself lacks a value.
+
+    Sellable categories can be grouped recursively.
+
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/sellable_category.html>`__
     """
     __storm_table__ = 'sellable_category'
 
@@ -152,25 +187,29 @@ class SellableCategory(Domain):
     #: belongs to this category.
     salesperson_commission = PercentCol(default=0)
 
-    category_id = IntCol(default=None)
+    category_id = IdCol(default=None)
 
     #: base category of this category, ``None`` for base categories themselves
     category = Reference(category_id, 'SellableCategory.id')
 
-    tax_constant_id = IntCol(default=None)
+    tax_constant_id = IdCol(default=None)
 
+    #: the |sellabletaxconstant| for this sellable category
     tax_constant = Reference(tax_constant_id, 'SellableTaxConstant.id')
 
+    #: the children of this category
     children = ReferenceSet('id', 'SellableCategory.category_id')
 
-    implements(IDescribable)
-
     #
     #  Properties
     #
 
     @property
     def full_description(self):
+        """The full description of the category, including its parents,
+        for instance: u"Clothes:Shoes:Black Shoe 14 SL"
+        """
+
         descriptions = [self.description]
 
         parent = self.category
@@ -186,7 +225,6 @@ class SellableCategory(Domain):
 
     def get_children_recursively(self):
         """Return all the children from this category, recursively
-
         This will return all children recursively, e.g.::
 
                       A
@@ -229,7 +267,7 @@ class SellableCategory(Domain):
             # Compare to None as markup can be '0'
             if self.suggested_markup is not None:
                 return self.suggested_markup
-            return  self.category.get_markup()
+            return self.category.get_markup()
         return self.suggested_markup
 
     def get_tax_constant(self):
@@ -276,37 +314,40 @@ class SellableCategory(Domain):
 
 
 class ClientCategoryPrice(Domain):
-    """A table that stores special prices for clients based on their
-    category.
+    """A table that stores special prices for |clients| based on their
+    |clientcategory|.
+
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/client_category_price.html>`__
     """
     __storm_table__ = 'client_category_price'
 
-    sellable_id = IntCol()
+    sellable_id = IdCol()
 
-    #: The sellable that has a special price
+    #: The |sellable| that has a special price
     sellable = Reference(sellable_id, 'Sellable.id')
 
-    category_id = IntCol()
+    category_id = IdCol()
 
-    #: The category that has the special price
+    #: The |clientcategory| that has the special price
     category = Reference(category_id, 'ClientCategory.id')
 
-    #: The price for this (sellable, category)
+    #: The price for this (|sellable|, |clientcategory|)
     price = PriceCol(default=0)
 
     #: The max discount that may be applied.
     max_discount = PercentCol(default=0)
 
-    def _get_markup(self):
+    @property
+    def markup(self):
         if self.sellable.cost == 0:
             return Decimal(0)
         return ((self.price / self.sellable.cost) - 1) * 100
 
-    def _set_markup(self, markup):
+    @markup.setter
+    def markup(self, markup):
         self.price = self.sellable._get_price_by_markup(markup)
 
-    markup = property(_get_markup, _set_markup)
-
     @property
     def category_name(self):
         return self.category.name
@@ -330,45 +371,48 @@ def _validate_barcode(sellable, attr, barcode):
     return barcode
 
 
+@implementer(IDescribable)
 class Sellable(Domain):
-    """ Sellable information of a certain item such a product
-    or a service. Note that sellable is not actually a concrete item but
-    only its reference as a sellable. Concrete items are created by
-    IContainer routines.
+    """ Sellable information of a certain item such a |product|
+    or a |service|.
+
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/sellable.html>`__
     """
     __storm_table__ = 'sellable'
 
-    implements(IDescribable)
+    #: the sellable is available and can be used on a |purchase|/|sale|
+    STATUS_AVAILABLE = 0
 
-    (STATUS_AVAILABLE,
-     STATUS_UNAVAILABLE,
-     STATUS_CLOSED,
-     STATUS_BLOCKED) = range(4)
+    #: the sellable is closed, that is, it still exists for references,
+    #: but it should not be possible to create a |purchase|/|sale| with it
+    STATUS_CLOSED = 1
 
     statuses = {STATUS_AVAILABLE: _(u'Available'),
-                STATUS_UNAVAILABLE: _(u'Unavailable'),
-                STATUS_CLOSED: _(u'Closed'),
-                STATUS_BLOCKED: _(u'Blocked')}
+                STATUS_CLOSED: _(u'Closed')}
 
-    #: an internal code identifying the sellable in Stoq
+    #: a code used internally by the shop to reference this sellable.
+    #: It is usually not printed and displayed to |clients|, barcode is for that.
+    #: It may be used as an shorter alternative to the barcode.
     code = UnicodeCol(default=u'', validator=_validate_code)
 
     #: barcode, mostly for products, usually printed and attached to the
     #: package.
     barcode = UnicodeCol(default=u'', validator=_validate_barcode)
 
-    # This default status is used when a new sellable is created,
-    # so it must be *always* UNAVAILABLE (that means no stock for it).
     #: status the sellable is in
-    status = IntCol(default=STATUS_UNAVAILABLE)
+    status = IntCol(default=STATUS_AVAILABLE)
 
-    #: cost of the sellable
+    # FIXME: This is only used for purchase orders without suppliers,
+    #        Perhaps we should update this as we purchase the product
+    #: cost of the sellable, this is not tied to a specific |supplier|,
+    #: which may have a different cost.
     cost = PriceCol(default=0)
 
-    #: price of sellable, how much the client is charged
+    #: price of sellable, how much the |client| paid.
     base_price = PriceCol(default=0)
 
-    #: full description of sallable
+    #: full description of sellable
     description = UnicodeCol(default=u'')
 
     #: maximum discount allowed
@@ -377,33 +421,48 @@ class Sellable(Domain):
     #: commission to pay after selling this sellable
     commission = PercentCol(default=0)
 
+    #: notes for the sellable
     notes = UnicodeCol(default=u'')
 
-    unit_id = IntCol(default=None)
+    unit_id = IdCol(default=None)
 
-    #: unit of the sellable, kg/l etc
+    #: the |sellableunit|, quantities of this sellable are in this unit.
     unit = Reference(unit_id, 'SellableUnit.id')
 
-    image_id = IntCol(default=None)
+    image_id = IdCol(default=None)
+
+    #: the |image|, a picture representing the sellable
     image = Reference(image_id, 'Image.id')
 
-    category_id = IntCol(default=None)
+    category_id = IdCol(default=None)
 
     #: a reference to category table
     category = Reference(category_id, 'SellableCategory.id')
-    tax_constant_id = IntCol(default=None)
+
+    tax_constant_id = IdCol(default=None)
+
+    #: the |sellabletaxconstant|, this controls how this sellable is taxed
     tax_constant = Reference(tax_constant_id, 'SellableTaxConstant.id')
 
+    #: the |product| for this sellable or ``None``
     product = Reference('id', 'Product.sellable_id', on_remote=True)
+
+    #: the |service| for this sellable or ``None``
     service = Reference('id', 'Service.sellable_id', on_remote=True)
 
-    default_sale_cfop_id = IntCol(default=None)
+    default_sale_cfop_id = IdCol(default=None)
+
+    #: the default |cfop| that will be used when selling this sellable
     default_sale_cfop = Reference(default_sale_cfop_id, 'CfopData.id')
 
     #: A special price used when we have a "on sale" state, this
     #: can be used for promotions
     on_sale_price = PriceCol(default=0)
+
+    #: When the promotional/special price starts to apply
     on_sale_start_date = DateTimeCol(default=None)
+
+    #: When the promotional/special price ends
     on_sale_end_date = DateTimeCol(default=None)
 
     def __init__(self, store=None,
@@ -443,18 +502,17 @@ class Sellable(Domain):
     def _get_price_by_markup(self, markup, cost=None):
         if cost is None:
             cost = self.cost
-        return cost + (cost * (markup / currency(100)))
-
-    def _get_status_string(self):
-        if not self.status in self.statuses:
-            raise DatabaseInconsistency(_('Invalid status for product got %d')
-                                        % self.status)
-        return self.statuses[self.status]
+        return currency(quantize(cost + (cost * (markup / currency(100)))))
 
     #
     # Properties
     #
 
+    @property
+    def status_str(self):
+        """The sellable status as a string"""
+        return self.statuses[self.status]
+
     @property
     def product_storable(self):
         """If this is a |product| and has stock, fetch the |storable| for this.
@@ -468,36 +526,47 @@ class Sellable(Domain):
                                              Product.sellable_id == self.id)).one()
 
     @property
-    def has_image(self):
-        return bool(self.image and self.image.image)
+    def unit_description(self):
+        """Returns the description of the |sellableunit| of this sellable
 
-    def _get_markup(self):
+        :returns: the unit description or an empty string if no
+          |sellableunit| was set.
+        :rtype: unicode
+        """
+        return self.unit and self.unit.description or u""
+
+    @property
+    def markup(self):
+        """Markup, the opposite of discount, a value added
+        on top of the sale. It's calculated as::
+          ((cost/price)-1)*100
+        """
         if self.cost == 0:
             return Decimal(0)
         return ((self.price / self.cost) - 1) * 100
 
-    def _set_markup(self, markup):
+    @markup.setter
+    def markup(self, markup):
         self.price = self._get_price_by_markup(markup)
 
-    #: ((cost/price)-1)*100
-    markup = property(_get_markup, _set_markup)
-
-    def _get_price(self):
+    @property
+    def price(self):
         if self.on_sale_price:
-            today = datetime.datetime.today()
+            today = localnow()
             start_date = self.on_sale_start_date
             end_date = self.on_sale_end_date
             if is_date_in_interval(today, start_date, end_date):
                 return self.on_sale_price
         return self.base_price
 
-    def _set_price(self, price):
+    @price.setter
+    def price(self, price):
         if price < 0:
             # Just a precaution for gui validation fails.
             price = 0
 
         if self.on_sale_price:
-            today = datetime.datetime.today()
+            today = localnow()
             start_date = self.on_sale_start_date
             end_date = self.on_sale_end_date
             if is_date_in_interval(today, start_date, end_date):
@@ -505,64 +574,49 @@ class Sellable(Domain):
                 return
         self.base_price = price
 
-    price = property(_get_price, _set_price)
-
     #
     #  Accessors
     #
 
-    def can_be_sold(self):
+    def is_available(self):
         """Whether the sellable is available and can be sold.
 
-        :returns: if the item can be sold
-        :rtype: boolean
+        :returns: ``True`` if the item can be sold, ``False`` otherwise.
         """
         # FIXME: Perhaps this should be done elsewhere. Johan 2008-09-26
-        if self.service == sysparam(self.store).DELIVERY_SERVICE:
+        if sysparam.compare_object('DELIVERY_SERVICE', self.service):
             return True
         return self.status == self.STATUS_AVAILABLE
 
-    def is_unavailable(self):
-        """Whether the sellable is unavailable.
+    def set_available(self):
+        """Mark the sellable as available
 
-        :returns: if the item is unavailable
-        :rtype: boolean
+        Being available means that it can be ordered or sold.
+
+        :raises: :exc:`ValueError`: if the sellable is already available
         """
-        return self.status == self.STATUS_UNAVAILABLE
-
-    def set_unavailable(self):
-        """Mark the sellable as unavailable"""
-        if self.is_unavailable():
-            raise ValueError('This sellable is already unavailable')
-        self.status = self.STATUS_UNAVAILABLE
+        if self.is_available():
+            raise ValueError('This sellable is already available')
+        self.status = self.STATUS_AVAILABLE
 
     def is_closed(self):
         """Whether the sellable is closed or not.
 
-        :returns: ``True`` if closed, False otherwise.
+        :returns: ``True`` if closed, ``False`` otherwise.
         """
         return self.status == Sellable.STATUS_CLOSED
 
     def close(self):
-        """Mark the sellable as closed"""
+        """Mark the sellable as closed
+
+        :raises: :exc:`ValueError`: if the sellable is already closed
+        """
         if self.is_closed():
             raise ValueError('This sellable is already closed')
 
         assert self.can_close()
         self.status = Sellable.STATUS_CLOSED
 
-    def cancel(self):
-        """Cancel the sellable"""
-        if self.can_be_sold():
-            raise ValueError('This sellable is already available')
-        self.status = self.STATUS_AVAILABLE
-
-    def can_sell(self):
-        """Make the object sellable"""
-        # Identical implementation to cancel(), but it has a very different
-        # use case, so we keep another method
-        self.status = self.STATUS_AVAILABLE
-
     def can_remove(self):
         """Whether we can delete this sellable from the database.
 
@@ -598,21 +652,12 @@ class Sellable(Domain):
             is not required by the system (i.e. Delivery service is
             required). ``False`` otherwise.
         """
-        if self.service:
-            return self.service.can_close()
-        return self.is_unavailable()
+        obj = self.service or self.product
+        return obj.can_close()
 
     def get_commission(self):
         return self.commission
 
-    def get_short_description(self):
-        """Returns a short description of the current sellable
-
-        :returns: description
-        :rtype: string
-        """
-        return u'%s %s' % (self.id, self.description)
-
     def get_suggested_markup(self):
         """Returns the suggested markup for the sellable
 
@@ -621,18 +666,13 @@ class Sellable(Domain):
         """
         return self.category and self.category.get_markup()
 
-    def get_unit_description(self):
-        """Returns the sellable category description
-        :returns: the category description or an empty string if no category
-        was set.
-        """
-        return self.unit and self.unit.description or u""
-
     def get_category_description(self):
         """Returns the description of this sellables category
         If it's unset, return the constant from the category, if any
 
-        :returns: sellable category description
+        :returns: sellable category description or an empty string if no
+          |sellablecategory| was set.
+        :rtype: unicode
         """
         category = self.category
         return category and category.description or u""
@@ -641,7 +681,7 @@ class Sellable(Domain):
         """Returns the |sellabletaxconstant| for this sellable.
         If it's unset, return the constant from the category, if any
 
-        :returns: the |sellabletaxconstant| or None if unset
+        :returns: the |sellabletaxconstant| or ``None`` if unset
         """
         if self.tax_constant:
             return self.tax_constant
@@ -651,17 +691,19 @@ class Sellable(Domain):
 
     def get_category_prices(self):
         """Returns all client category prices associated with this sellable.
+
+        :returns: the client category prices
         """
         return self.store.find(ClientCategoryPrice, sellable=self)
 
     def get_category_price_info(self, category):
         """Returns the :class:`ClientCategoryPrice` information for the given
-        :class:`ClientCategory` and this sellable.
+        :class:`ClientCategory` and this |sellable|.
 
-        :returns: the :class:`ClientCategoryPrice` or None
+        :returns: the :class:`ClientCategoryPrice` or ``None``
         """
         info = self.store.find(ClientCategoryPrice, sellable=self,
-                                     category=category).one()
+                               category=category).one()
         return info
 
     def get_price_for_category(self, category):
@@ -676,15 +718,28 @@ class Sellable(Domain):
             return info.price
         return self.price
 
+    def get_maximum_discount(self, category=None, user=None):
+        user_discount = user.profile.max_discount if user else 0
+        if category is not None:
+            info = self.get_category_price_info(category) or self
+        else:
+            info = self
+
+        return max(user_discount, info.max_discount)
+
     def check_code_exists(self, code):
-        """Returns ``True`` if we already have a sellable with the given code
-        in the database.
+        """Check if there is another sellable with the same code.
+
+        :returns: ``True`` if we already have a sellable with the given code
+          ``False`` otherwise.
         """
         return self.check_unique_value_exists(Sellable.code, code)
 
     def check_barcode_exists(self, barcode):
-        """Returns ``True`` if we already have a sellable with the given barcode
-        in the database.
+        """Check if there is another sellable with the same barcode.
+
+        :returns: ``True`` if we already have a sellable with the given barcode
+          ``False`` otherwise.
         """
         return self.check_unique_value_exists(Sellable.barcode, barcode)
 
@@ -694,8 +749,9 @@ class Sellable(Domain):
         This check is done because some icms taxes (such as CSOSN 101) have
         a 'valid until' field on it. If these taxes has expired, we cannot sell
         the sellable.
-        Check this method using assert inside a try clause. This method will
-        raise TaxError if there are any issues with the sellable taxes.
+        Check this method using assert inside a try clause.
+
+        :raises: :exc:`TaxError` if there are any issues with the sellable taxes.
         """
         icms_template = self.product and self.product.icms_template
         if not icms_template:
@@ -709,7 +765,7 @@ class Sellable(Domain):
                              "Tax Class.\n"
                              "If you don't know what this means, contact "
                              "the system administrator.")
-                              % icms_template.product_tax_template.name)
+                           % icms_template.product_tax_template.name)
 
     def is_valid_quantity(self, new_quantity):
         """Whether the new quantity is valid for this sellable or not.
@@ -717,6 +773,9 @@ class Sellable(Domain):
         If the new quantity is fractioned, check on this sellable unit if it
         allows fractioned quantities. If not, this new quantity cannot be used.
 
+        Note that, if the sellable lacks a unit, we will not allow
+        fractions either.
+
         :returns: ``True`` if new quantity is Ok, ``False`` otherwise.
         """
         if self.unit and not self.unit.allow_fraction:
@@ -724,23 +783,44 @@ class Sellable(Domain):
 
         return True
 
-    def is_valid_price(self, newprice, category=None):
-        """Returns True if the new price respects the maximum discount
-        configured for the sellable, otherwise returns ``False``.
+    def is_valid_price(self, newprice, category=None, user=None,
+                       extra_discount=None):
+        """Checks if *newprice* is valid for this sellable
+
+        Returns a dict indicating whether the new price is a valid price as
+        allowed by the discount by the user, by the category or by the sellable
+        maximum discount
 
         :param newprice: The new price that we are trying to sell this
-          sellable for.
-        :param category: Optionally define a category that we will get the
-          price info from.
+            sellable for
+        :param category: Optionally define a |clientcategory| that we will get
+            the price info from
+        :param user: The user role may allow a different discount percentage.
+        :param extra_discount: some extra discount for the sellable
+            to be considered for the min_price
+        :returns: A dict with the following keys:
+            * is_valid: ``True`` if the price is valid, else ``False``
+            * min_price: The minimum price for this sellable.
+            * max_discount: The maximum discount for this sellable.
         """
-        info = None
-        if category:
-            info = self.get_category_price_info(category)
-        if not info:
+        if category is not None:
+            info = self.get_category_price_info(category) or self
+        else:
             info = self
-        if newprice < info.price - (info.price * info.max_discount / 100):
-            return False
-        return True
+
+        max_discount = self.get_maximum_discount(category=category, user=user)
+        min_price = info.price * (1 - max_discount / 100)
+
+        if extra_discount is not None:
+            # The extra discount can be greater than the min_price, and
+            # a negative min_price doesn't make sense
+            min_price = max(currency(0), min_price - extra_discount)
+
+        return {
+            'is_valid': newprice >= min_price,
+            'min_price': min_price,
+            'max_discount': max_discount,
+        }
 
     #
     # IDescribable implementation
@@ -766,8 +846,9 @@ class Sellable(Domain):
     #
 
     def remove(self):
-        """Remove this sellable from the database (including the |product| or
-        |service|).
+        """
+        Remove this sellable. This will also remove the |product| or
+        |sellable| and |categoryprice|
         """
         assert self.can_remove()
 
@@ -783,24 +864,33 @@ class Sellable(Domain):
 
         self.store.remove(self)
 
-    @classmethod
-    def get_available_sellables_for_quote_query(cls, store):
-        service_sellable = sysparam(store).DELIVERY_SERVICE.sellable
-        return And(cls.id != service_sellable.id,
-                   Or(cls.status == cls.STATUS_AVAILABLE,
-                      cls.status == cls.STATUS_UNAVAILABLE))
-
     @classmethod
     def get_available_sellables_query(cls, store):
-        service = sysparam(store).DELIVERY_SERVICE
-        return And(cls.id != service.id,
+        """Get the sellables that are available and can be sold.
+
+        For instance, this will filter out the internal sellable used
+        by a |delivery|.
+
+        This is similar to `.get_available_sellables`, but it returns
+        a query instead of the actual results.
+
+        :param store: a store
+        :returns: a query expression
+        """
+
+        delivery = sysparam.get_object(store, 'DELIVERY_SERVICE')
+        return And(cls.id != delivery.sellable.id,
                    cls.status == cls.STATUS_AVAILABLE)
 
     @classmethod
     def get_available_sellables(cls, store):
-        """Returns sellable objects which can be added in a |sale|. By
-        default a delivery sellable can not be added manually by users
-        since a separate dialog is responsible for that.
+        """Get the sellables that are available and can be sold.
+
+        For instance, this will filter out the internal sellable used
+        by a |delivery|.
+
+        :param store: a store
+        :returns: a resultset with the available sellables
         """
         query = cls.get_available_sellables_query(store)
         return store.find(cls, query)
@@ -810,12 +900,19 @@ class Sellable(Domain):
                                       consigned=False):
         """Helper method for get_unblocked_sellables
 
-        When supplier is not None, you should use this query only with Viewables
-        that join with supplier, like ProductFullStockSupplierView
+        When supplier is not ```None``, you should use this query only with
+        Viewables that join with supplier, like ProductFullStockSupplierView.
+
+        :param store: a store
+        :param storable: if ``True``, we should filter only the sellables that
+          are also a |storable|.
+        :param supplier: |supplier| to filter on or ``None``
+        :param consigned: if the sellables are consigned
+
+        :returns: a query expression
         """
         from stoqlib.domain.product import Product, ProductSupplierInfo
-        query = And(Or(cls.get_available_sellables_query(store),
-                       cls.status == cls.STATUS_UNAVAILABLE),
+        query = And(cls.get_available_sellables_query(store),
                     cls.id == Product.sellable_id,
                     Product.consignment == consigned)
         if storable:
@@ -844,70 +941,30 @@ class Sellable(Domain):
           |storable|
         :param supplier: a |supplier| or ``None``, if set limit the returned
           object to this |supplier|
+
+        :rtype: queryset of sellables
         """
         query = cls.get_unblocked_sellables_query(store, storable, supplier,
                                                   consigned)
         return store.find(cls, query)
 
     @classmethod
-    def get_unavailable_sellables(cls, store):
-        """Returns sellable objects which can be added in a |sale|. By
-        default a |delivery| sellable can not be added manually by users
-        since a separate dialog is responsible for that.
-        """
-        return store.find(cls, status=cls.STATUS_UNAVAILABLE)
-
-    @classmethod
-    def _get_sellables_by_barcode(cls, store, barcode, extra_query):
-        sellable = store.find(cls,
-            And(Sellable.barcode == barcode,
-                extra_query)).one()
-        if sellable is None:
-            raise BarcodeDoesNotExists(
-                _(u"The sellable with barcode '%s' doesn't exists or is "
-                  u"not available to be sold") % barcode)
-        return sellable
-
-    @classmethod
-    def get_availables_by_barcode(cls, store, barcode):
-        """Returns a list of avaliable sellables that can be sold.
-        A sellable that can be sold can have only one possible
-        status: STATUS_AVAILABLE
-
-        :param store: a store
-        :param barcode: a string representing a sellable barcode
-        """
-        return cls._get_sellables_by_barcode(
-            store, barcode,
-            Sellable.status == Sellable.STATUS_AVAILABLE)
-
-    @classmethod
-    def get_availables_and_unavailable_by_barcode(cls, store, barcode):
-        """Returns a list of avaliable sellables and also sellables that
-        can be sold.  Here we will get sellables with the following
-        statuses: STATUS_AVAILABLE, STATUS_UNAVAILABLE
-
-        :param store: a store
-        :param barcode: a string representing a sellable barcode
-        """
-        statuses = [cls.STATUS_AVAILABLE, cls.STATUS_UNAVAILABLE]
-        return cls._get_sellables_by_barcode(store, barcode,
-                                             In(cls.status, statuses))
-
-    @classmethod
-    def get_unblocked_by_categories(cls, store, categories,
-                                    include_uncategorized=True):
+    def get_unblocked_by_categories_query(cls, store, categories,
+                                          include_uncategorized=True):
         """Returns the available sellables by a list of categories.
 
         :param store: a store
         :param categories: a list of SellableCategory instances
         :param include_uncategorized: whether or not include the sellables
             without a category
-        """
-        #FIXME: This query should be faster, waiting for #3696
 
+        :rtype: generator of sellables
+        """
+        queries = []
+        if len(categories):
+            queries.append(In(Sellable.category_id, [c.id for c in categories]))
         if include_uncategorized:
-            categories.append(None)
-        for sellable in cls.get_unblocked_sellables(store):
-            if sellable.category in categories:
-                yield sellable
+            queries.append(Eq(Sellable.category_id, None))
+
+        query = cls.get_unblocked_sellables_query(store)
+        return And(query, Or(*queries))
