@@ -23,11 +23,13 @@
 ##
 """ Base classes to manage services informations """
 
+# pylint: enable=E1101
+
 from storm.expr import Join, LeftJoin
 from storm.references import Reference
-from zope.interface import implements
+from zope.interface import implementer
 
-from stoqlib.database.properties import IntCol
+from stoqlib.database.properties import IdCol
 from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import (ServiceCreateEvent, ServiceEditEvent,
@@ -46,13 +48,12 @@ _ = stoqlib_gettext
 #
 
 
+@implementer(IDescribable)
 class Service(Domain):
     """Class responsible to store basic service informations."""
     __storm_table__ = 'service'
 
-    implements(IDescribable)
-
-    sellable_id = IntCol()
+    sellable_id = IdCol()
 
     #: The |sellable| for this service
     sellable = Reference(sellable_id, 'Sellable.id')
@@ -66,7 +67,7 @@ class Service(Domain):
     #
 
     def can_remove(self):
-        if self == sysparam(self.store).DELIVERY_SERVICE:
+        if sysparam.compare_object('DELIVERY_SERVICE', self):
             # The delivery item cannot be deleted as it's important
             # for creating deliveries.
             return False
@@ -80,7 +81,7 @@ class Service(Domain):
     def can_close(self):
         # The delivery item cannot be closed as it will be
         # used for deliveries.
-        return self != sysparam(self.store).DELIVERY_SERVICE
+        return not sysparam.compare_object('DELIVERY_SERVICE', self)
 
     #
     # IDescribable implementation
@@ -148,7 +149,7 @@ class ServiceView(Viewable):
         Join(Service, Service.sellable_id == Sellable.id),
         LeftJoin(SellableUnit, Sellable.unit_id == SellableUnit.id),
         LeftJoin(SellableCategory, SellableCategory.id == Sellable.category_id),
-        ]
+    ]
 
     def get_unit(self):
         return self.unit or u""
