@@ -23,12 +23,13 @@
 ##
 """ Station, a branch station per computer """
 
-from storm.references import Reference
-from zope.interface import implements
+# pylint: enable=E1101
 
-from stoqlib.database.properties import UnicodeCol, IntCol, BoolCol
+from storm.references import Reference
+from zope.interface import implementer
+
+from stoqlib.database.properties import UnicodeCol, BoolCol, IdCol
 from stoqlib.domain.base import Domain
-from stoqlib.domain.event import Event
 from stoqlib.domain.interfaces import IActive
 from stoqlib.exceptions import StoqlibError
 from stoqlib.lib.translation import stoqlib_gettext
@@ -36,16 +37,16 @@ from stoqlib.lib.translation import stoqlib_gettext
 _ = stoqlib_gettext
 
 
+@implementer(IActive)
 class BranchStation(Domain):
     """Defines a computer which access Stoqlib database and lives in a
     certain branch company
     """
-    implements(IActive)
     __storm_table__ = 'branch_station'
 
     name = UnicodeCol()
     is_active = BoolCol(default=False)
-    branch_id = IntCol()
+    branch_id = IdCol()
     branch = Reference(branch_id, 'Branch.id')
 
     # Public
@@ -93,18 +94,9 @@ class BranchStation(Domain):
         """
 
         if branch is None:
-            raise TypeError(u"%r must be a Branch" % (branch, ))
+            raise TypeError(u"BranchStation.get_station() requires a Branch")
         return store.find(cls, name=name, branch=branch).one()
 
-    # Events
-
-    def on_create(self):
-        # Should be done after_create()
-        return
-        Event.log(Event.TYPE_SYSTEM,
-                  _(u"Created computer '%s' for branch '%s'") % (
-                       self.name, self.branch.person.name))
-
     #
     # IActive implementation
     #
