@@ -24,14 +24,16 @@
 ##
 """ BranchSynchronization domain class """
 
+# pylint: enable=E1101
+
 from storm.references import Reference
 from storm.store import AutoReload
 
 from stoqlib.database.orm import ORMObject
-from stoqlib.database.properties import DateTimeCol, IntCol, UnicodeCol
+from stoqlib.database.properties import DateTimeCol, IntCol, UnicodeCol, IdCol
 from stoqlib.domain.person import Branch
 
-Branch # pyflakes
+Branch  # pylint: disable=W0104
 
 
 class BranchSynchronization(ORMObject):
@@ -47,7 +49,7 @@ class BranchSynchronization(ORMObject):
     #: last time updated
     sync_time = DateTimeCol(allow_none=False)
 
-    branch_id = IntCol()
+    branch_id = IdCol()
 
     #: a |branch|
     branch = Reference(branch_id, 'Branch.id')
