@@ -22,15 +22,18 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
+# pylint: enable=E1101
+
 from decimal import Decimal
 
 from storm.info import get_cls_info
 from storm.references import Reference
 
 from stoqlib.database.properties import (UnicodeCol, QuantityCol, DateTimeCol,
-                                  PriceCol, IntCol, BoolCol, PercentCol)
+                                         PriceCol, IntCol, BoolCol, PercentCol,
+                                         IdCol)
 from stoqlib.domain.base import Domain
+from stoqlib.lib.dateutils import localtoday
 
 # SIGLAS:
 # BC - Base de Calculo
@@ -121,7 +124,7 @@ class BaseIPI(BaseTax):
 class ProductIcmsTemplate(BaseICMS):
     __storm_table__ = 'product_icms_template'
 
-    product_tax_template_id = IntCol()
+    product_tax_template_id = IdCol()
     product_tax_template = Reference(product_tax_template_id, 'ProductTaxTemplate.id')
 
     # Simples Nacional
@@ -133,7 +136,7 @@ class ProductIcmsTemplate(BaseICMS):
             # If we don't have a valid_until, means p_cred_sn will never
             # expire. Therefore, p_cred_sn is valid.
             return True
-        elif self.p_cred_sn_valid_until.date() < datetime.date.today():
+        elif self.p_cred_sn_valid_until.date() < localtoday().date():
             return False
 
         return True
@@ -141,7 +144,7 @@ class ProductIcmsTemplate(BaseICMS):
 
 class ProductIpiTemplate(BaseIPI):
     __storm_table__ = 'product_ipi_template'
-    product_tax_template_id = IntCol()
+    product_tax_template_id = IdCol()
     product_tax_template = Reference(product_tax_template_id, 'ProductTaxTemplate.id')
 
 
