@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2006-2007 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2006-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -25,38 +25,22 @@
 
 import contextlib
 import datetime
+import os
 
 import mock
+import unittest
 
 from stoqlib.lib.kiwilibrary import library
-library  # pyflakes
+library  # pylint: disable=W0104
 
+import stoqlib
 from stoqlib.database.runtime import (get_current_branch,
                                       new_store,
                                       StoqlibStore)
 from stoqlib.database.testsuite import StoqlibTestsuiteTracer
+from stoqlib.domain.base import Domain
 from stoqlib.domain.exampledata import ExampleCreator
-
-try:
-    import unittest
-    unittest # pyflakes
-except:
-    import unittest
-
-
-class FakeAPITrans:
-    def __init__(self, store=None):
-        self.store = store
-
-    def __call__(self):
-        return self
-
-    def __enter__(self):
-        return self.store
-
-    def __exit__(self, *args):
-        if self.store is not None:
-            self.store.committed = True
+from stoqlib.lib.dateutils import localdate, localdatetime
 
 
 class FakeStoqConfig:
@@ -74,9 +58,6 @@ class FakeStoqConfig:
     def set_from_options(self, options):
         self.options = options
 
-    def get_password(self):
-        return u'password'
-
     def load_settings(self, settings):
         pass
 
@@ -88,12 +69,20 @@ class FakeStoqConfig:
         self.flushed = True
 
 
+class FakeStore(object):
+    def close(self):
+        pass
+
+
 class FakeDatabaseSettings:
     def __init__(self, store):
         self.store = store
         self.address = u'invalid'
+        self.dbname = u'stoq'
         self.check = False
-        self.password = u''
+        self.password = u'password'
+        self.username = u'username'
+        self.port = 12345
 
     def check_database_address(self):
         return self.check
@@ -102,13 +91,16 @@ class FakeDatabaseSettings:
         return False
 
     def get_command_line_arguments(self):
-        return []
+        return ['-d', self.dbname,
+                '-p', unicode(self.port),
+                '-u', self.username,
+                '-w', self.password]
 
     def get_default_connection(self):
-        class FakeConn:
-            def dbVersion(self):
-                return (8, 4)
-        return FakeConn()
+        return FakeStore()
+
+    def create_super_store(self):
+        return FakeStore()
 
 
 class ReadOnlyStore(StoqlibStore):
@@ -119,6 +111,7 @@ class ReadOnlyStore(StoqlibStore):
         # Intentionally *not* calling StoqlibStore.__init__ since this
         # creates an additional database connection
         self.real_store = real_store
+        self.retval = False
 
     # Store
 
@@ -136,7 +129,7 @@ class ReadOnlyStore(StoqlibStore):
     def fetch(self, obj):
         return obj
 
-    def rollback(self):
+    def rollback(self, close=True):
         pass
 
     def commit(self):
@@ -153,27 +146,26 @@ class FakeNamespace(object):
     """Commonly used mock objects goes in here"""
     def __init__(self):
         self.api = mock.Mock()
-        self.api.trans = FakeAPITrans()
+        self.api.get_current_branch = get_current_branch
         self.DatabaseSettings = FakeDatabaseSettings
         self.StoqConfig = FakeStoqConfig
         self.datetime = mock.MagicMock(datetime)
-        self.datetime.datetime.today.return_value = datetime.datetime(2012, 1, 1)
-        self.datetime.datetime.now.return_value = datetime.datetime(2012, 1, 1)
-        self.datetime.date.today.return_value = datetime.date(2012, 1, 1)
+        self.datetime.datetime.today.return_value = localdatetime(2012, 1, 1)
+        self.datetime.datetime.now.return_value = localdatetime(2012, 1, 1)
+        self.datetime.date.today.return_value = localdate(2012, 1, 1).date()
 
     def set_store(self, store):
         # Since we are per default a class attribute we need to call this
         # when we get a store
         database = mock.Mock()
         rd_store = ReadOnlyStore(database, store)
-        self.api.trans.store = rd_store
+        self.api.store = rd_store
         self.api.new_store.return_value = ReadOnlyStore(database, store)
-        self.api.trans.return_value = rd_store
         if store is not None:
             store.readonly = rd_store
 
     def set_retval(self, retval):
-        self.api.trans.store.retval = retval
+        self.api.store.retval = retval
 
 
 class DomainTest(unittest.TestCase, ExampleCreator):
@@ -201,6 +193,18 @@ class DomainTest(unittest.TestCase, ExampleCreator):
         self.store.rollback(close=False)
         self.clear()
 
+    def get_oficial_plugins_names(self):
+        """Get official plugins names
+
+        Since pluginmanager is prepared to work with plugins defined on
+        the same directory as stoq repository, this is a helper for getting
+        only the ones defined on stoq repository's themselves.
+        """
+        base_dir = os.path.dirname(os.path.dirname(stoqlib.__file__))
+        plugins_dir = os.path.join(base_dir, 'plugins')
+        return set(unicode(d) for d in os.listdir(plugins_dir) if
+                   not d.startswith('__init__'))
+
     @contextlib.contextmanager
     def count_tracer(self):
         """Count the number of statements that are executed during
@@ -212,8 +216,6 @@ class DomainTest(unittest.TestCase, ExampleCreator):
         it will clear common caches before starting, so the number in here
         will be higher than in the actual application.
         """
-        from stoqlib.lib.parameters import ParameterAccess
-        ParameterAccess.clear_cache()
         self.store.flush()
         self.store.invalidate()
 
@@ -222,6 +224,45 @@ class DomainTest(unittest.TestCase, ExampleCreator):
         yield tracer
         tracer.remove()
 
+    @contextlib.contextmanager
+    def sysparam(self, **kwargs):
+        """
+        Updates a set of system parameters within a context.
+        The values will be reverted when leaving the scope.
+        kwargs contains a dictionary of parameter name->value
+        """
+        from stoqlib.lib.parameters import sysparam
+        old_values = {}
+        for param, value in kwargs.items():
+            if type(value) is bool:
+                old_values[param] = sysparam.get_bool(param)
+                sysparam.set_bool(self.store, param, value)
+            elif type(value) is int:
+                old_values[param] = sysparam.get_int(param)
+                sysparam.set_int(self.store, param, value)
+            elif isinstance(value, Domain) or value is None:
+                old_values[param] = sysparam.get_object(self.store, param)
+                sysparam.set_object(self.store, param, value)
+            elif isinstance(value, basestring):
+                old_values[param] = sysparam.get_string(param)
+                sysparam.set_string(self.store, param, value)
+            else:
+                raise NotImplementedError(type(value))
+        try:
+            yield
+        finally:
+            for param, value in old_values.items():
+                if type(value) is bool:
+                    sysparam.set_bool(self.store, param, value)
+                elif type(value) is int:
+                    sysparam.set_int(self.store, param, value)
+                elif isinstance(value, Domain) or value is None:
+                    sysparam.set_object(self.store, param, value)
+                elif isinstance(value, basestring):
+                    sysparam.set_string(self.store, param, value)
+                else:
+                    raise NotImplementedError(type(value))
+
     def collect_sale_models(self, sale):
         models = [sale,
                   sale.group]
@@ -231,7 +272,8 @@ class DomainTest(unittest.TestCase, ExampleCreator):
                            cmp=lambda a, b: cmp(a.sellable.description,
                                                 b.sellable.description)):
             models.append(item.sellable)
-            stock_item = item.sellable.product_storable.get_stock_item(branch)
+            stock_item = item.sellable.product_storable.get_stock_item(
+                branch, batch=item.batch)
             models.append(stock_item)
             models.append(item)
         payments = list(sale.payments)
