@@ -22,7 +22,10 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+__tests__ = 'stoqlib/domain/account.py'
+
 import datetime
+from storm.exceptions import OrderLoopError
 
 from stoqlib.domain.account import (Account, AccountTransaction,
                                     AccountTransactionView,
@@ -35,11 +38,11 @@ from stoqlib.lib.parameters import sysparam
 
 class TestAccount(DomainTest):
 
-    def testAccount(self):
+    def test_account(self):
         account = self.create_account()
         self.failUnless(account)
 
-    def testAccountGetByStation(self):
+    def test_account_get_by_station(self):
         station = self.create_station()
         account = Account.get_by_station(self.store, station)
         self.failIf(account)
@@ -54,7 +57,7 @@ class TestAccount(DomainTest):
         self.assertRaises(TypeError, Account.get_by_station,
                           self.store, object())
 
-    def testAccountLongDescription(self):
+    def test_account_long_description(self):
         a1 = self.create_account()
         a1.description = u"first"
         a2 = self.create_account()
@@ -64,11 +67,17 @@ class TestAccount(DomainTest):
         a3.description = u"third"
         a3.parent = a2
 
+        # Testing Loop error
+        with self.assertRaises(OrderLoopError):
+            a1.parent = a2
+            self.assertEquals(a1.long_description, u'first')
+
+        a1.parent = None
         self.assertEquals(a1.long_description, u'first')
         self.assertEquals(a2.long_description, u'first:second')
         self.assertEquals(a3.long_description, u'first:second:third')
 
-    def testAccountTransactions(self):
+    def test_account_transactions(self):
         account = self.create_account()
         self.assertTrue(account.transactions.is_empty())
 
@@ -87,13 +96,13 @@ class TestAccount(DomainTest):
 
         self.failUnless(t2 in account.transactions)
 
-    def testAccountCanRemove(self):
+    def test_account_can_remove(self):
         account = self.create_account()
         self.failUnless(account.can_remove())
 
-        self.failIf(sysparam(self.store).TILLS_ACCOUNT.can_remove())
-        self.failIf(sysparam(self.store).IMBALANCE_ACCOUNT.can_remove())
-        self.failIf(sysparam(self.store).BANKS_ACCOUNT.can_remove())
+        self.failIf(sysparam.get_object(self.store, 'TILLS_ACCOUNT').can_remove())
+        self.failIf(sysparam.get_object(self.store, 'IMBALANCE_ACCOUNT').can_remove())
+        self.failIf(sysparam.get_object(self.store, 'BANKS_ACCOUNT').can_remove())
 
         station = self.create_station()
         account.station = station
@@ -112,11 +121,11 @@ class TestAccount(DomainTest):
 
         self.failIf(account.can_remove())
 
-    def testAccountRemove(self):
+    def test_account_remove(self):
         a1 = self.create_account()
         a2 = self.create_account()
 
-        imbalance_account = sysparam(self.store).IMBALANCE_ACCOUNT
+        imbalance_account = sysparam.get_object(self.store, 'IMBALANCE_ACCOUNT')
 
         t1 = self.create_account_transaction(a1)
         t1.source_account = a2
@@ -126,6 +135,11 @@ class TestAccount(DomainTest):
         t2.source_account = a1
         self.store.flush()
 
+        a2.parent = a1
+        with self.assertRaises(TypeError):
+            a1.remove(self.store)
+        a2.parent = None
+
         a1.station = self.create_station()
         self.assertRaises(TypeError, a1.remove)
         a1.station = None
@@ -135,7 +149,7 @@ class TestAccount(DomainTest):
         self.assertEquals(t1.account, imbalance_account)
         self.assertEquals(t2.source_account, imbalance_account)
 
-    def testAccountRemoveWithBankAccount(self):
+    def test_account_remove_with_bank_account(self):
         account = self.create_account()
         bank = self.create_bank_account(account=account)
         BillOption(option=u'foo',
@@ -144,7 +158,7 @@ class TestAccount(DomainTest):
                    store=self.store)
         account.remove(self.store)
 
-    def testHasChildAccounts(self):
+    def test_has_child_accounts(self):
         a1 = self.create_account()
         a2 = self.create_account()
 
@@ -160,7 +174,7 @@ class TestAccount(DomainTest):
         a1 = self.create_account()
         self.assertEquals(a1.long_description, IDescribable(a1).get_description())
 
-    def testGetTypeLabel(self):
+    def test_get_type_label(self):
         a = self.create_account()
         a.account_type = Account.TYPE_CASH
         self.assertEquals(a.get_type_label(True), u"Spend")
@@ -182,13 +196,13 @@ class TestAccount(DomainTest):
         self.assertEquals(Account.get_children_for(self.store, a1).one(), a2)
         a3.parent = a1
         self.assertEquals(
-            list(Account.get_children_for(self.store, a1).order_by(Account.id)),
-            [a2, a3])
+            set(Account.get_children_for(self.store, a1)),
+            set([a2, a3]))
 
     def test_get_total_for_interval(self):
         a = self.create_account()
         start = datetime.datetime(2010, 1, 1)
-        end = datetime.datetime(2011, 1, 1)
+        end = datetime.datetime(2010, 12, 31)
         self.assertEquals(a.get_total_for_interval(start, end), 0)
 
         transaction = self.create_account_transaction(a)
@@ -201,7 +215,7 @@ class TestAccount(DomainTest):
             a.get_total_for_interval(start, end), 100)
 
         transaction = self.create_account_transaction(a)
-        transaction.date = datetime.datetime(2010, 8, 1)
+        transaction.date = datetime.datetime(2010, 12, 31)
         transaction.value = 100
 
         self.assertEquals(
@@ -225,10 +239,36 @@ class TestAccount(DomainTest):
         self.assertRaises(TypeError, a.get_total_for_interval, good, bad)
         self.assertRaises(TypeError, a.get_total_for_interval, bad, good)
 
+    def test_matches(self):
+        a1 = self.create_account()
+        a2 = self.create_account()
+        a2.parent = a1
+        accounts = list(self.store.find(Account))
+        for account in accounts:
+            if a1.matches(account.id):
+                result1 = True
+            if a2.matches(account.id):
+                result2 = True
+        self.assertTrue(result1)
+        self.assertTrue(result2)
+        a3 = self.create_account()
+        result3 = a1.matches(a3.id)
+        self.assertFalse(result3)
+
 
 class TestAccountTransaction(DomainTest):
 
-    def testGetOtherAccount(self):
+    def test_create_reverse(self):
+        at = self.create_account_transaction()
+        reversed = self.store.find(AccountTransaction,
+                                   account=at.account).count()
+        self.assertEquals(reversed, 1)
+        at.create_reverse()
+        reversed = self.store.find(AccountTransaction,
+                                   account=at.account).count()
+        self.assertEquals(reversed, 2)
+
+    def test_get_other_account(self):
         a1 = self.create_account()
         a2 = self.create_account()
 
@@ -246,7 +286,11 @@ class TestAccountTransaction(DomainTest):
         self.assertEquals(t2.get_other_account(a1), a2)
         self.assertEquals(t2.get_other_account(a2), a1)
 
-    def testSetOtherAccount(self):
+        a3 = self.create_account()
+        with self.assertRaises(AssertionError):
+            t1.get_other_account(account=a3)
+
+    def test_set_other_account(self):
         a1 = self.create_account()
         a2 = self.create_account()
 
@@ -276,7 +320,12 @@ class TestAccountTransaction(DomainTest):
         self.assertEquals(t2.account, a2)
         self.assertEquals(t2.source_account, a2)
 
-    def testCreateFromPayment(self):
+        a3 = self.create_account()
+        with self.assertRaises(AssertionError):
+            t1.set_other_account(a3, a1)
+            t2.set_other_account(a3, a2)
+
+    def test_create_from_payment(self):
         sale = self.create_sale()
         self.add_product(sale)
         payment = self.add_payments(sale, method_type=u'check')[0]
@@ -289,14 +338,14 @@ class TestAccountTransaction(DomainTest):
         payment.pay()
         transaction = AccountTransaction.create_from_payment(payment)
 
-        imbalance_account = sysparam(self.store).IMBALANCE_ACCOUNT
+        imbalance_account = sysparam.get_object(self.store, 'IMBALANCE_ACCOUNT')
         self.assertEquals(transaction.source_account, imbalance_account)
         self.assertEquals(transaction.account, account)
         self.assertEquals(transaction.payment, payment)
 
 
 class TestAccountTransactionView(DomainTest):
-    def testGetForAccount(self):
+    def test_get_for_account(self):
         a = self.create_account()
         t = self.create_account_transaction(a)
         t.value = 100
@@ -310,11 +359,12 @@ class TestAccountTransactionView(DomainTest):
         self.assertEquals(v1.description, t.description)
         self.assertEquals(v1.date.replace(tzinfo=None), t.date)
 
-    def testGetAccountDescription(self):
+    def test_get_account_description(self):
         a1 = self.create_account()
         a1.description = u"Source Account"
         a2 = self.create_account()
         a2.description = u"Account"
+        a3 = self.create_account()
         t = self.create_account_transaction(a1)
         t.value = 100
         t.source_account = a1
@@ -324,8 +374,10 @@ class TestAccountTransactionView(DomainTest):
         views = AccountTransactionView.get_for_account(a1, self.store)
         self.assertEquals(views[0].get_account_description(a1), u"Account")
         self.assertEquals(views[0].get_account_description(a2), u"Source Account")
+        with self.assertRaises(AssertionError):
+            views[0].get_account_description(a3)
 
-    def testGetValue(self):
+    def test_get_value(self):
         a1 = self.create_account()
         a1.description = u"Source Account"
         a2 = self.create_account()
@@ -341,7 +393,7 @@ class TestAccountTransactionView(DomainTest):
         self.assertEquals(views[0].get_value(a1), -100)
         self.assertEquals(views[0].get_value(a2), 100)
 
-    def testTransaction(self):
+    def test_transaction(self):
         a = self.create_account()
         t = self.create_account_transaction(a)
 
