@@ -22,12 +22,14 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+__tests__ = 'stoqlib/domain/costcenter.py'
+
 from stoqlib.domain.costcenter import CostCenter, CostCenterEntry
 from stoqlib.domain.test.domaintest import DomainTest
 
 
 class TestCostCenter(DomainTest):
-    def testAddTransaction(self):
+    def test_add_transaction(self):
         cost_center = self.create_cost_center()
         stock_trans = self.create_stock_transaction_history()
         stock_trans.quantity = -1
@@ -41,7 +43,7 @@ class TestCostCenter(DomainTest):
         self.assertEquals(len(list(entry)), 1)
         self.assertEquals(entry[0].stock_transaction, stock_trans)
 
-    def testAddLonelyPayment(self):
+    def test_add_lonely_payment(self):
         cost_center = self.create_cost_center()
         payment = self.create_payment()
 
@@ -77,20 +79,27 @@ class TestCostCenter(DomainTest):
         stock_trans3 = self.create_stock_transaction_history()
 
         cost_center_entry1 = self.create_cost_center_entry(
-                                    stock_transaction=stock_trans1)
+            stock_transaction=stock_trans1)
         cost_center1 = cost_center_entry1.cost_center
         cost_center_entry2 = self.create_cost_center_entry(
-                                    cost_center1, stock_transaction=stock_trans2)
+            cost_center1, stock_transaction=stock_trans2)
 
         cost_center_entry3 = self.create_cost_center_entry(
-                                    stock_transaction=stock_trans3)
+            stock_transaction=stock_trans3)
         cost_center2 = cost_center_entry3.cost_center
 
-        self.assertEquals(list(cost_center1.get_stock_trasaction_entries()),
+        self.assertEquals(list(cost_center1.get_stock_transaction_entries()),
                           [cost_center_entry1, cost_center_entry2])
-        self.assertEquals(list(cost_center2.get_stock_trasaction_entries()),
+        self.assertEquals(list(cost_center2.get_stock_transaction_entries()),
                           [cost_center_entry3])
 
+    def test_stock_decreases(self):
+        cost_center = self.create_cost_center()
+        stock_decrease = self.create_stock_decrease()
+        stock_decrease.cost_center = cost_center
+        results = cost_center.get_stock_decreases()
+        self.assertEquals(results.one(), stock_decrease)
+
     def test_get_sales(self):
         cost_center1 = self.create_cost_center()
         cost_center2 = self.create_cost_center()
@@ -124,3 +133,9 @@ class TestCostCenter(DomainTest):
         cost_centers = CostCenter.get_active(self.store)
 
         self.assertEquals([cost_center], list(cost_centers))
+
+    def test_get_payments(self):
+        cost_center_entry = self.create_cost_center_entry()
+        payment = cost_center_entry.payment
+        results = cost_center_entry.cost_center.get_payments()
+        self.assertEquals(results.one(), payment)
