@@ -22,7 +22,6 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
 import decimal
 
 from kiwi.currency import currency
@@ -32,12 +31,16 @@ from storm.references import Reference
 from storm.variables import (BoolVariable, DateTimeVariable,
                              RawStrVariable, DecimalVariable,
                              IntVariable, UnicodeVariable)
+from stoqlib.domain.product import Storable
 
 from stoqlib.domain.base import Domain
-from stoqlib.database.properties import (UnicodeCol, IntCol,
+from stoqlib.database.properties import (UnicodeCol, IdCol,
                                          QuantityVariable, PriceVariable)
 from stoqlib.database.tables import get_table_types
+from stoqlib.domain.sellable import SellableCategory
+from stoqlib.domain.production import ProductionProducedItem
 from stoqlib.domain.test.domaintest import DomainTest
+from stoqlib.lib.dateutils import localnow
 
 
 class ORMTestError(Exception):
@@ -62,7 +65,7 @@ def orm_get_random(column):
     elif issubclass(variable, RawStrVariable):
         value = ''
     elif issubclass(variable, DateTimeVariable):
-        value = datetime.datetime.now()
+        value = localnow()
     elif issubclass(variable, IntVariable):
         value = None
     elif issubclass(variable, PriceVariable):
@@ -102,6 +105,11 @@ def orm_get_unittest_value(klass, test, tables_dict, name, column):
             # to LoginUser (e.g. WorkOrder)
             from stoqlib.database.runtime import get_current_user
             value = get_current_user(test.store)
+        elif cls.__name__ == 'StorableBatch':
+            # StorableBatch needs some very specific information, that is
+            # related to other objects. Thus, it cannot be created with random
+            # value.
+            value = None
         else:
             value = test.create_by_type(cls)
         if value is None:
@@ -122,7 +130,7 @@ def _create_domain_test():
         for column, name in orm_get_columns(klass):
             try:
                 value = orm_get_unittest_value(klass, self, tables_dict, name, column)
-            except ORMTestError, e:
+            except ORMTestError as e:
                 continue
 
             kwargs[name] = value
@@ -132,10 +140,14 @@ def _create_domain_test():
         # Sellable does not accept all arguments
         if klass.__name__ == 'Sellable':
             kwargs = {}
-
         # Payment needs a value argument
-        if klass.__name__ == 'Payment':
+        elif klass.__name__ == 'Payment':
             kwargs['value'] = 123
+        # TransferOrderItem needs a sellable that is also a storable
+        elif klass.__name__ == 'TransferOrderItem':
+            storable = self.create_storable()
+            kwargs['sellable'] = storable.product.sellable
+            kwargs['quantity'] = 1
 
         if 'id' in kwargs:
             del kwargs['id']
@@ -180,7 +192,7 @@ class _TestDomain(Domain):
     __storm_table__ = '_test_domain'
 
     test_var = UnicodeCol(default=u'')
-    test_reference_id = IntCol(default=None)
+    test_reference_id = IdCol(default=None)
     test_reference = Reference(test_reference_id, _ReferencedTestDomain.id)
 
 
@@ -206,7 +218,7 @@ class TestDomain(DomainTest):
 
         self.store.commit()
 
-    def testCloneObject(self):
+    def test_clone_object(self):
         # Create an object to test, clone() method.
         old_order = self.create_purchase_order()
         self.assertTrue(old_order.id)
@@ -218,3 +230,63 @@ class TestDomain(DomainTest):
         # Id and identifier fields from old and new object must be different.
         self.assertNotEquals(old_order.id, new_order.id)
         self.assertNotEquals(old_order.identifier, new_order.identifier)
+
+    def test_get_or_create_simple(self):
+        # This test is for a simple get_or_create (only one property)
+        cat = self.store.find(SellableCategory, description=u'foo').one()
+        self.assertEquals(cat, None)
+
+        cat_a = SellableCategory.get_or_create(self.store, description=u'foo')
+        self.assertEquals(cat_a.description, u'foo')
+
+        cat_b = SellableCategory.get_or_create(self.store, description=u'foo')
+        self.assertEquals(cat_a, cat_b)
+
+        cat_c = SellableCategory.get_or_create(self.store, description=u'bar')
+        self.assertNotEquals(cat_a, cat_c)
+
+        # Giving an invalid property should raise an error
+        self.assertRaises(AttributeError, SellableCategory.get_or_create,
+                          self.store, foo=123)
+
+    def test_get_or_create_multiple(self):
+        # This test is for  get_or_create call with more than one property
+        product = self.create_product()
+
+        # Make sure there is no item yet.
+        item = self.store.find(ProductionProducedItem, serial_number=123,
+                               product=product).one()
+        self.assertEquals(item, None)
+
+        # First call to get_or_create should create the object.
+        item_a = ProductionProducedItem.get_or_create(
+            self.store, serial_number=123, product=product)
+        # And set the properties given
+        self.assertEquals(item_a.serial_number, 123)
+        self.assertEquals(item_a.product, product)
+
+        # The second call to get_or_create should return the same object
+        item_b = ProductionProducedItem.get_or_create(
+            self.store, serial_number=123, product=product)
+        self.assertEquals(item_a, item_b)
+
+    def test_get_or_create_multiple_with_null(self):
+        # Check if get_or_creating is working properly when using references
+        # with null values.
+        item_a = ProductionProducedItem.get_or_create(
+            self.store, serial_number=456, product=None)
+
+        self.assertEquals(item_a.serial_number, 456)
+        self.assertEquals(item_a.product, None)
+
+        item_b = ProductionProducedItem.get_or_create(
+            self.store, serial_number=456, product=None)
+        self.assertEquals(item_a, item_b)
+
+    def test_validate_batch(self):
+        sellable = self.create_sellable()
+        with self.assertRaises(ValueError) as error:
+            sellable.validate_batch(batch=Storable, sellable=sellable)
+        expected = 'Batches should only be used with storables,' \
+                   ' but %r is not one' % sellable
+        self.assertEquals(str(error.exception), expected)
