@@ -22,14 +22,16 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+__tests__ = 'stoqlib/domain/payment/event.py'
+
 from stoqlib.domain.event import Event
 from stoqlib.domain.test.domaintest import DomainTest
 
 
 class TestEvent(DomainTest):
 
-    def testSystemEvent(self):
-        Event.log(Event.TYPE_SYSTEM, u"foo")
+    def test_system_event(self):
+        Event.log(self.store, Event.TYPE_SYSTEM, u"foo")
         events = list(self.store.find(Event))
         events = [event for event in events if event.description == u'foo']
         self.failUnless(events)
