@@ -22,6 +22,8 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+__tests__ = 'stoqlib/domain/payment/group.py'
+
 from decimal import Decimal
 
 from nose.exc import SkipTest
@@ -30,12 +32,12 @@ from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.commission import CommissionSource, Commission
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.stockdecrease import StockDecrease
 from stoqlib.domain.sale import Sale
+from stoqlib.domain.stockdecrease import StockDecrease
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.parameters import sysparam
 
-StockDecrease # pyflakes
+StockDecrease  # pylint: disable=W0104
 
 
 class TestPaymentGroup(DomainTest):
@@ -47,24 +49,51 @@ class TestPaymentGroup(DomainTest):
         # loop error. This is a potential problem on Stoq and we should be
         # fixed there.
         from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
-        PaymentRenegotiation # pyflakes
+        PaymentRenegotiation  # pylint: disable=W0104
 
         super(TestPaymentGroup, self).setUp()
 
     def _payComissionWhenConfirmed(self):
-        sysparam(self.store).update_parameter(
-            u"SALE_PAY_COMMISSION_WHEN_CONFIRMED",
-            u"1")
+        sysparam.set_bool(
+            self.store,
+            "SALE_PAY_COMMISSION_WHEN_CONFIRMED",
+            True)
         self.failUnless(
-            sysparam(self.store).SALE_PAY_COMMISSION_WHEN_CONFIRMED)
+            sysparam.get_bool('SALE_PAY_COMMISSION_WHEN_CONFIRMED'))
 
-    def testConfirm(self):
+    def test_remove_item(self):
+        payment = self.create_payment()
+        with self.assertRaises(AttributeError):
+            payment.group.remove_item(payment=None)
+        self.assertIsNone(payment.group.remove_item(payment=payment))
+
+    def test_installments_number(self):
+        payment = self.create_payment()
+        self.assertEquals(payment.group.installments_number, 1)
+
+    def test_get_payments_sum(self):
+        payment = self.create_payment()
+        payments = payment.group.get_valid_payments()
+        result = payment.group._get_payments_sum(payments=payments,
+                                                 attr=Payment.value)
+        self.assertEquals(result, 10)
+
+    def test_clear_unused(self):
+        payment = self.create_payment()
+        payment2 = self.create_payment(group=payment.group)
+        payment2.status = Payment.STATUS_PREVIEW
+        self.assertEquals(payment.group._get_preview_payments().count(), 2)
+        payment.group.clear_unused()
+        with self.assertRaises(AttributeError):
+            payment.group._get_preview_payments()
+
+    def test_confirm(self):
         branch = self.create_branch()
         group = self.create_payment_group()
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
-        payment1 = method.create_inpayment(group, branch, Decimal(10))
-        payment2 = method.create_inpayment(group, branch, Decimal(10))
+        payment1 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
+        payment2 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
 
         payment2.set_pending()
         self.assertEqual(payment1.status, Payment.STATUS_PREVIEW)
@@ -74,13 +103,13 @@ class TestPaymentGroup(DomainTest):
         self.assertEqual(payment1.status, Payment.STATUS_PENDING)
         self.assertEqual(payment2.status, Payment.STATUS_PENDING)
 
-    def testPay(self):
+    def test_pay(self):
         branch = self.create_branch()
         group = self.create_payment_group()
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
-        payment1 = method.create_inpayment(group, branch, Decimal(10))
-        payment2 = method.create_inpayment(group, branch, Decimal(10))
+        payment1 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
+        payment2 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
         group.confirm()
 
         self.assertEqual(payment1.status, Payment.STATUS_PENDING)
@@ -92,17 +121,17 @@ class TestPaymentGroup(DomainTest):
         self.assertEqual(payment1.status, Payment.STATUS_PAID)
         self.assertEqual(payment2.status, Payment.STATUS_PAID)
 
-    def testPayMoneyPayments(self):
+    def test_pay_money_payments(self):
         branch = self.create_branch()
         group = self.create_payment_group()
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
-        payment1 = method.create_inpayment(group, branch, Decimal(10))
-        payment2 = method.create_inpayment(group, branch, Decimal(10))
+        payment1 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
+        payment2 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
         method = PaymentMethod.get_by_name(self.store, u'money')
         method.max_installments = 2
-        payment3 = method.create_inpayment(group, branch, Decimal(10))
-        payment4 = method.create_inpayment(group, branch, Decimal(10))
+        payment3 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
+        payment4 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
         group.confirm()
 
         self.assertEqual(payment1.status, Payment.STATUS_PENDING)
@@ -112,20 +141,20 @@ class TestPaymentGroup(DomainTest):
         payment3.pay()
         self.assertEqual(payment3.status, Payment.STATUS_PAID)
 
-        group.pay_money_payments()
+        group.pay_method_payments(u'money')
         self.assertEqual(payment1.status, Payment.STATUS_PENDING)
         self.assertEqual(payment2.status, Payment.STATUS_PENDING)
         self.assertEqual(payment3.status, Payment.STATUS_PAID)
         self.assertEqual(payment4.status, Payment.STATUS_PAID)
 
-    def testCancel(self):
+    def test_cancel(self):
         branch = self.create_branch()
         group = self.create_payment_group()
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
-        payment1 = method.create_inpayment(group, branch, Decimal(10))
-        payment2 = method.create_inpayment(group, branch, Decimal(10))
-        payment3 = method.create_inpayment(group, branch, Decimal(10))
+        payment1 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
+        payment2 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
+        payment3 = method.create_payment(Payment.TYPE_IN, group, branch, Decimal(10))
         group.confirm()
 
         payment3.pay()
@@ -138,7 +167,7 @@ class TestPaymentGroup(DomainTest):
         self.assertEqual(payment2.status, Payment.STATUS_CANCELLED)
         self.assertEqual(payment3.status, Payment.STATUS_PAID)
 
-    def testInstallmentsCommissionAmount(self):
+    def test_installments_commission_amount(self):
         self._payComissionWhenConfirmed()
 
         sale = self.create_sale()
@@ -150,14 +179,14 @@ class TestPaymentGroup(DomainTest):
                          store=self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'check')
-        method.create_inpayment(sale.group, sale.branch, Decimal(100))
-        method.create_inpayment(sale.group, sale.branch, Decimal(200))
+        method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(100))
+        method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(200))
         self.assertTrue(self.store.find(Commission, sale=sale).is_empty())
         sale.confirm()
         self.assertFalse(self.store.find(Commission, sale=sale).is_empty())
 
         commissions = self.store.find(Commission,
-            sale=sale).order_by(Commission.value)
+                                      sale=sale).order_by(Commission.value)
         self.assertEquals(commissions.count(), 2)
         for c in commissions:
             self.failUnless(c.commission_type == Commission.INSTALLMENTS)
@@ -169,7 +198,7 @@ class TestPaymentGroup(DomainTest):
         # $15 * 2/3 => 10,00
         self.assertEquals(commissions[1].value, Decimal("10.00"))
 
-    def testInstallmentsCommissionAmountWithMultipleItems(self):
+    def test_installments_commission_amount_with_multiple_items(self):
         self._payComissionWhenConfirmed()
 
         sale = self.create_sale()
@@ -182,15 +211,15 @@ class TestPaymentGroup(DomainTest):
                          store=self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'check')
-        method.create_inpayment(sale.group, sale.branch, Decimal(300))
-        method.create_inpayment(sale.group, sale.branch, Decimal(450))
-        method.create_inpayment(sale.group, sale.branch, Decimal(150))
+        method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(300))
+        method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(450))
+        method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(150))
         self.assertTrue(self.store.find(Commission, sale=sale).is_empty())
 
         sale.confirm()
 
         commissions = self.store.find(Commission,
-            sale=sale).order_by(Commission.value)
+                                      sale=sale).order_by(Commission.value)
         self.assertEquals(commissions.count(), 3)
         for c in commissions:
             self.failUnless(c.commission_type == Commission.INSTALLMENTS)
@@ -205,16 +234,17 @@ class TestPaymentGroup(DomainTest):
         # 45 / 2 => 22,50
         self.assertEquals(commissions[2].value, Decimal("22.50"))
 
-    def testInstallmentsCommissionAmountWhenSaleReturn(self):
-        raise SkipTest(u"See stoqlib.domain.returnedsale.ReturnedSale.return_ "
-                       u"and bug 5215.")
+    def test_installments_commission_amount_when_sale_return(self):
+        if True:
+            raise SkipTest(u"See stoqlib.domain.returnedsale.ReturnedSale.return_ "
+                           u"and bug 5215.")
 
         self._payComissionWhenConfirmed()
         sale = self.create_sale()
         sellable = self.create_sellable()
         CommissionSource(sellable=sellable,
                          direct_value=12,
-                        installments_value=5,
+                         installments_value=5,
                          store=self.store)
 
         sale.add_sellable(sellable, quantity=3, price=300)
@@ -224,9 +254,9 @@ class TestPaymentGroup(DomainTest):
 
         sale.order()
         method = PaymentMethod.get_by_name(self.store, u'check')
-        payment1 = method.create_inpayment(sale.group, sale.branch, Decimal(300))
-        payment2 = method.create_inpayment(sale.group, sale.branch, Decimal(450))
-        payment3 = method.create_inpayment(sale.group, sale.branch, Decimal(150))
+        payment1 = method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(300))
+        payment2 = method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(450))
+        payment3 = method.create_payment(Payment.TYPE_IN, sale.group, sale.branch, Decimal(150))
         sale.confirm()
 
         # the commissions are created after the payment
@@ -244,7 +274,7 @@ class TestPaymentGroup(DomainTest):
         self.assertEqual(commissions.count(), 4)
         self.failIf(commissions[-1].value >= 0)
 
-    def testGetTotalValue(self):
+    def test_get_total_value(self):
         method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
@@ -254,13 +284,13 @@ class TestPaymentGroup(DomainTest):
         group = sale.group
         self.assertEqual(group.get_total_value(), 0)
 
-        method.create_inpayment(group, sale.branch, Decimal(100))
+        method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(100))
         self.assertEqual(group.get_total_value(), Decimal(100))
 
-        method.create_inpayment(group, sale.branch, Decimal(200))
+        method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(200))
         self.assertEqual(group.get_total_value(), Decimal(300))
 
-        method.create_outpayment(group, sale.branch, Decimal(50))
+        method.create_payment(Payment.TYPE_OUT, group, sale.branch, Decimal(50))
         self.assertEqual(group.get_total_value(), Decimal(250))
 
         # Test for a group in a purchase
@@ -270,16 +300,93 @@ class TestPaymentGroup(DomainTest):
         group = purchase.group
         self.assertEqual(group.get_total_value(), 0)
 
-        method.create_outpayment(group, purchase.branch, Decimal(100))
+        method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(100))
         self.assertEqual(group.get_total_value(), Decimal(100))
 
-        method.create_outpayment(group, purchase.branch, Decimal(200))
+        method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(200))
         self.assertEqual(group.get_total_value(), Decimal(300))
 
-        method.create_inpayment(group, purchase.branch, Decimal(50))
+        method.create_payment(Payment.TYPE_IN, group, purchase.branch, Decimal(50))
         self.assertEqual(group.get_total_value(), Decimal(250))
 
-    def testGetTotalDiscount(self):
+    def test_get_total_to_pay(self):
+        method = PaymentMethod.get_by_name(self.store, u'check')
+
+        # Test for a group in a sale
+        sale = self.create_sale()
+        group = sale.group
+        self.assertEqual(group.get_total_to_pay(), 0)
+
+        payment1 = method.create_payment(Payment.TYPE_IN, group, sale.branch,
+                                         Decimal(100))
+        payment1.set_pending()
+        self.assertEqual(group.get_total_to_pay(), Decimal(100))
+
+        payment2 = method.create_payment(Payment.TYPE_IN, group, sale.branch,
+                                         Decimal(200))
+        payment2.set_pending()
+        self.assertEqual(group.get_total_to_pay(), Decimal(300))
+
+        payment1.pay()
+        self.assertEqual(group.get_total_to_pay(), Decimal(200))
+
+        payment2.pay()
+        self.assertEqual(group.get_total_to_pay(), Decimal(0))
+
+    def test_get_total_confirmed_value(self):
+        method = PaymentMethod.get_by_name(self.store, u'check')
+
+        # Test for a group in a sale
+        # On sale's group, total value should return
+        # sum(inpayments.value) - sum(outpayments.value)
+        sale = self.create_sale()
+        group = sale.group
+        self.assertEqual(group.get_total_confirmed_value(), 0)
+
+        p = method.create_payment(
+            Payment.TYPE_IN, group, sale.branch, Decimal(100))
+        self.assertEqual(group.get_total_confirmed_value(), 0)
+        p.set_pending()
+        self.assertEqual(group.get_total_confirmed_value(), 100)
+
+        p = method.create_payment(
+            Payment.TYPE_IN, group, sale.branch, Decimal(200))
+        self.assertEqual(group.get_total_confirmed_value(), 100)
+        p.set_pending()
+        self.assertEqual(group.get_total_confirmed_value(), 300)
+
+        p = method.create_payment(
+            Payment.TYPE_OUT, group, sale.branch, Decimal(50))
+        self.assertEqual(group.get_total_confirmed_value(), 300)
+        p.set_pending()
+        self.assertEqual(group.get_total_confirmed_value(), 250)
+
+        # Test for a group in a purchase
+        # On purchase's group, total value should return
+        # sum(inpayments.value) - sum(outpayments.value)
+        purchase = self.create_purchase_order()
+        group = purchase.group
+        self.assertEqual(group.get_total_confirmed_value(), 0)
+
+        p = method.create_payment(
+            Payment.TYPE_OUT, group, purchase.branch, Decimal(100))
+        self.assertEqual(group.get_total_confirmed_value(), 0)
+        p.set_pending()
+        self.assertEqual(group.get_total_confirmed_value(), 100)
+
+        p = method.create_payment(
+            Payment.TYPE_OUT, group, purchase.branch, Decimal(200))
+        self.assertEqual(group.get_total_confirmed_value(), 100)
+        p.set_pending()
+        self.assertEqual(group.get_total_confirmed_value(), 300)
+
+        p = method.create_payment(
+            Payment.TYPE_IN, group, purchase.branch, Decimal(50))
+        self.assertEqual(group.get_total_confirmed_value(), 300)
+        p.set_pending()
+        self.assertEqual(group.get_total_confirmed_value(), 250)
+
+    def test_get_total_discount(self):
         method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
@@ -289,15 +396,15 @@ class TestPaymentGroup(DomainTest):
         group = sale.group
         self.assertEqual(group.get_total_value(), 0)
 
-        p = method.create_inpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(10))
         p.discount = Decimal(10)
         self.assertEqual(group.get_total_discount(), Decimal(10))
 
-        p = method.create_inpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(10))
         p.discount = Decimal(20)
         self.assertEqual(group.get_total_discount(), Decimal(30))
 
-        p = method.create_outpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, sale.branch, Decimal(10))
         p.discount = Decimal(10)
         self.assertEqual(group.get_total_discount(), Decimal(20))
 
@@ -308,19 +415,19 @@ class TestPaymentGroup(DomainTest):
         group = purchase.group
         self.assertEqual(group.get_total_value(), 0)
 
-        p = method.create_outpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(10))
         p.discount = Decimal(10)
         self.assertEqual(group.get_total_discount(), Decimal(10))
 
-        p = method.create_outpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(10))
         p.discount = Decimal(20)
         self.assertEqual(group.get_total_discount(), Decimal(30))
 
-        p = method.create_inpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, purchase.branch, Decimal(10))
         p.discount = Decimal(10)
         self.assertEqual(group.get_total_discount(), Decimal(20))
 
-    def testGetTotalInterest(self):
+    def test_get_total_interest(self):
         method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
@@ -330,15 +437,15 @@ class TestPaymentGroup(DomainTest):
         group = sale.group
         self.assertEqual(group.get_total_value(), 0)
 
-        p = method.create_inpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(10))
         p.interest = Decimal(10)
         self.assertEqual(group.get_total_interest(), Decimal(10))
 
-        p = method.create_inpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(10))
         p.interest = Decimal(20)
         self.assertEqual(group.get_total_interest(), Decimal(30))
 
-        p = method.create_outpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, sale.branch, Decimal(10))
         p.interest = Decimal(10)
         self.assertEqual(group.get_total_interest(), Decimal(20))
 
@@ -349,19 +456,19 @@ class TestPaymentGroup(DomainTest):
         group = purchase.group
         self.assertEqual(group.get_total_value(), 0)
 
-        p = method.create_outpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(10))
         p.interest = Decimal(10)
         self.assertEqual(group.get_total_interest(), Decimal(10))
 
-        p = method.create_outpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(10))
         p.interest = Decimal(20)
         self.assertEqual(group.get_total_interest(), Decimal(30))
 
-        p = method.create_inpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, purchase.branch, Decimal(10))
         p.interest = Decimal(10)
         self.assertEqual(group.get_total_interest(), Decimal(20))
 
-    def testGetTotalPenalty(self):
+    def test_get_total_penalty(self):
         method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
@@ -371,15 +478,15 @@ class TestPaymentGroup(DomainTest):
         group = sale.group
         self.assertEqual(group.get_total_value(), 0)
 
-        p = method.create_inpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(10))
         p.penalty = Decimal(10)
         self.assertEqual(group.get_total_penalty(), Decimal(10))
 
-        p = method.create_inpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, sale.branch, Decimal(10))
         p.penalty = Decimal(20)
         self.assertEqual(group.get_total_penalty(), Decimal(30))
 
-        p = method.create_outpayment(group, sale.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, sale.branch, Decimal(10))
         p.penalty = Decimal(10)
         self.assertEqual(group.get_total_penalty(), Decimal(20))
 
@@ -390,19 +497,19 @@ class TestPaymentGroup(DomainTest):
         group = purchase.group
         self.assertEqual(group.get_total_value(), 0)
 
-        p = method.create_outpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(10))
         p.penalty = Decimal(10)
         self.assertEqual(group.get_total_penalty(), Decimal(10))
 
-        p = method.create_outpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_OUT, group, purchase.branch, Decimal(10))
         p.penalty = Decimal(20)
         self.assertEqual(group.get_total_penalty(), Decimal(30))
 
-        p = method.create_inpayment(group, purchase.branch, Decimal(10))
+        p = method.create_payment(Payment.TYPE_IN, group, purchase.branch, Decimal(10))
         p.penalty = Decimal(10)
         self.assertEqual(group.get_total_penalty(), Decimal(20))
 
-    def testGetPaymentByMethodName(self):
+    def test_get_payment_by_method_name(self):
         group = self.create_payment_group()
 
         method = PaymentMethod.get_by_name(self.store, u'money')
@@ -435,11 +542,13 @@ class TestPaymentGroup(DomainTest):
         renegotiation = self.create_payment_renegotiation()
         group = self.create_payment_group()
         decrease = self.create_stock_decrease(group=group)
+        payment_group = self.create_payment_group()
 
         self.assertEquals(sale, sale.group.get_parent())
         self.assertEquals(purchase, purchase.group.get_parent())
         self.assertEquals(renegotiation, renegotiation.group.get_parent())
         self.assertEquals(decrease, decrease.group.get_parent())
+        self.assertEquals(None, payment_group.get_parent())
 
     def test_get_description(self):
         sale = self.create_sale()
