@@ -23,6 +23,8 @@
 ##
 """ This module tests all classes in stoq/domain/profile.py"""
 
+__tests__ = 'stoqlib/domain/profile.py'
+
 from stoqlib.domain.profile import UserProfile
 from stoqlib.domain.profile import ProfileSettings
 from stoqlib.domain.profile import update_profile_applications
@@ -77,13 +79,13 @@ class TestProfileSettings(DomainTest):
     def test_check_app_permission(self):
         profile = UserProfile(store=self.store, name=u'boss')
         profile.add_application_reference(u'test_application', True)
-        assert profile.check_app_permission(u'test_application') == True
+        assert profile.check_app_permission(u'test_application') is True
 
     def test_set_permission(self):
         profile = UserProfile(store=self.store, name=u'boss')
         profile.add_application_reference(u'app', False)
         setting = self.store.find(ProfileSettings, user_profile=profile,
-                                             app_dir_name=u'app').one()
+                                  app_dir_name=u'app').one()
         self.failIf(setting.has_permission)
         ProfileSettings.set_permission(self.store, profile, u'app', True)
         self.failUnless(setting.has_permission)
