@@ -25,26 +25,66 @@
 from decimal import Decimal
 
 from kiwi.currency import currency
+import mock
+from stoqdrivers.enum import TaxType
 
-from stoqlib.exceptions import SellableError
-from stoqlib.domain.test.domaintest import DomainTest
+from stoqlib.exceptions import SellableError, TaxError
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.product import Storable
-from stoqlib.domain.sellable import (Sellable,
-                                     SellableCategory, ClientCategoryPrice)
 from stoqlib.domain.sale import Sale
+from stoqlib.domain.sellable import (Sellable,
+                                     SellableCategory,
+                                     SellableUnit,
+                                     SellableTaxConstant,
+                                     ClientCategoryPrice)
+from stoqlib.domain.taxes import ProductTaxTemplate, ProductIcmsTemplate
+from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.domain.views import (ProductFullStockView,
                                   ProductFullWithClosedStockView,
                                   ProductClosedStockView)
+from stoqlib.lib.dateutils import localdate
 from stoqlib.lib.parameters import sysparam
 
+__tests__ = 'stoqlib/domain/sellable.py'
+
+
+class TestSellableUnit(DomainTest):
+    def test_get_description(self):
+        unit = SellableUnit(store=self.store,
+                            description=u'foo')
+        self.assertEquals(unit.get_description(), u'foo')
+
+
+class TestSellableTaxConstant(DomainTest):
+    def test_get_description(self):
+        constant = SellableTaxConstant(store=self.store,
+                                       description=u'foo')
+        self.assertEquals(constant.get_description(), u'foo')
+
+    def test_get_value(self):
+        constant = SellableTaxConstant(store=self.store,
+                                       tax_type=TaxType.NONE)
+        self.assertEquals(constant.get_value(), 'TAX_NONE')
+
+        constant = SellableTaxConstant(store=self.store,
+                                       tax_type=TaxType.EXEMPTION)
+        self.assertEquals(constant.get_value(), 'TAX_EXEMPTION')
+
+        constant = SellableTaxConstant(store=self.store,
+                                       tax_type=TaxType.SUBSTITUTION)
+        self.assertEquals(constant.get_value(), 'TAX_SUBSTITUTION')
+
+        constant = SellableTaxConstant(store=self.store,
+                                       tax_type=TaxType.SERVICE)
+        self.assertEquals(constant.get_value(), 'TAX_SERVICE')
+
 
 class TestSellableCategory(DomainTest):
     def setUp(self):
         DomainTest.setUp(self)
         self._base_category = self._create_category(u'Monitor')
 
-    def testGetDescription(self):
+    def test_get_description(self):
         category = self._create_category(u'LCD', parent=self._base_category)
         self.assertEqual(category.get_description(), u"LCD")
         self.assertEqual(category.full_description, u"Monitor:LCD")
@@ -53,7 +93,7 @@ class TestSellableCategory(DomainTest):
         self.assertEqual(sub_category.get_description(), u"29'")
         self.assertEqual(sub_category.full_description, u"Monitor:LCD:29'")
 
-    def testMarkup(self):
+    def test_markup(self):
         self._base_category.suggested_markup = currency('10')
         category1 = self._create_category(u'LCD', parent=self._base_category)
         category2 = self._create_category(u'LCD', parent=self._base_category)
@@ -67,7 +107,7 @@ class TestSellableCategory(DomainTest):
         self.assertEqual(category2.get_markup(), 0)
         self.assertEqual(category3.get_markup(), 5)
 
-    def testGetBaseCategories(self):
+    def test_get_base_categories(self):
         categories = SellableCategory.get_base_categories(self.store)
         count = categories.count()
         base_category = SellableCategory(description=u"Monitor",
@@ -80,7 +120,7 @@ class TestSellableCategory(DomainTest):
         self.failIf(category in categories)
         self.assertEqual(categories.count(), count + 1)
 
-    def testGetTaxConstant(self):
+    def test_get_tax_constant(self):
         category = self._create_category(u'LCD', parent=self._base_category)
 
         self.assertEquals(category.get_tax_constant(), None)
@@ -93,12 +133,65 @@ class TestSellableCategory(DomainTest):
         category.tax_constant = constant2
         self.assertEquals(category.get_tax_constant(), constant2)
 
+    def test_get_children_recursively(self):
+        base_category = SellableCategory(description=u"Monitor",
+                                         store=self.store)
+        category = SellableCategory(description=u"LCD Monitor",
+                                    category=base_category,
+                                    store=self.store)
+
+        self.assertEquals(category.get_children_recursively(), set())
+        self.assertEquals(base_category.get_children_recursively(), set([category]))
+
+    def test_on_create(self):
+        category = self._create_category(u'cat')
+        with mock.patch('stoqlib.domain.sellable.CategoryCreateEvent') as f:
+            category.on_create()
+
+        f.emit.assert_called_once_with(category)
+
+    def test_on_update(self):
+        category = self._create_category(u'cat')
+        with mock.patch('stoqlib.domain.sellable.CategoryEditEvent') as f:
+            category.on_update()
+
+        f.emit.assert_called_once_with(category)
+
     def _create_category(self, description, parent=None):
         return SellableCategory(description=description,
                                 category=parent,
                                 store=self.store)
 
 
+class TestClientCategoryPrice(DomainTest):
+    def test_category_name(self):
+        sellable = Sellable(category=None,
+                            cost=50,
+                            description=u"Test",
+                            price=currency(100),
+                            store=self.store)
+        sellable.max_discount = 0
+        cat = self.create_client_category(u'Cat 1')
+        cat_price = ClientCategoryPrice(sellable=sellable, category=cat,
+                                        price=150, max_discount=0,
+                                        store=self.store)
+        self.assertEquals(cat_price.category_name, u'Cat 1')
+
+    def test_markup(self):
+        sellable = Sellable(category=None,
+                            cost=0,
+                            store=self.store)
+        cat = self.create_client_category(u'Cat 1')
+        cat_price = ClientCategoryPrice(sellable=sellable, category=cat,
+                                        price=150, max_discount=0,
+                                        store=self.store)
+        self.assertEquals(cat_price.markup, 0)
+        sellable.cost = 10
+        self.assertEquals(cat_price.markup, 1400)
+
+        cat_price.markup = 10
+
+
 class TestSellable(DomainTest):
     def setUp(self):
         DomainTest.setUp(self)
@@ -109,6 +202,18 @@ class TestSellable(DomainTest):
                                           suggested_markup=10,
                                           store=self.store)
 
+    def test_get_description(self):
+        sellable = self.create_sellable()
+        sellable.category = self._category
+        self.assertEquals(sellable.get_description(), 'Description')
+        self.assertEquals(sellable.get_description(full_description=True),
+                          '[Hollywood] Description')
+
+    def test_get_category_description(self):
+        sellable = self.create_sellable()
+        sellable.category = self._category
+        self.assertEquals(sellable.get_category_description(), 'Hollywood')
+
     def test_price_based_on_category_markup(self):
         # When the price isn't defined, but the category and the cost. In this
         # case the sellable must have the price calculated applying the category's
@@ -133,19 +238,20 @@ class TestSellable(DomainTest):
         # When the price isn't defined, but the category, markup and the cost.
         # In this case the category's markup must be ignored and the price
         # calculated applying the markup specified in the sellable's cost.
-        markup = 5
         sellable = Sellable(description=u"FY123",
                             category=self._category,
                             cost=100,
                             store=self.store)
-        sellable.markup = markup
-        self.failUnless(sellable.markup == markup,
-                        (u"Expected markup: %r, got %r"
-                         % (markup, sellable.markup)))
-        price = sellable.cost * (markup / currency(100) + 1)
-        self.failUnless(sellable.price == price,
-                        (u"Expected price: %r, got %r"
-                         % (price, sellable.price)))
+        sellable.markup = 5
+        self.assertEquals(sellable.markup, 5)
+        self.assertEquals(sellable.price, 105)
+
+        sellable.cost = Decimal('100.33')
+        sellable.markup = 7
+        self.assertEquals(sellable.price, currency('107.35'))
+
+        sellable.markup = 8
+        self.assertEquals(sellable.price, currency('108.36'))
 
     def test_commission(self):
         self._category.salesperson_commission = 10
@@ -187,6 +293,98 @@ class TestSellable(DomainTest):
         self.failUnless(sellable.markup == 0,
                         u"Expected markup %r, got %r" % (0, sellable.markup))
 
+    def test_price_on_sale_price_getter(self):
+        sellable = Sellable(category=self._category,
+                            cost=50,
+                            description=u"Test",
+                            price=100,
+                            store=self.store)
+
+        self.assertEquals(sellable.price, 100)
+        sellable.on_sale_price = 80
+        self.assertEquals(sellable.price, 80)
+
+        # - Old promotion
+        sellable.on_sale_start_date = localdate(2001, 1, 1)
+        sellable.on_sale_end_date = localdate(2002, 1, 1)
+        self.assertEquals(sellable.price, 100)
+
+        # - Future promotion
+        sellable.on_sale_start_date = localdate(3001, 1, 1)
+        sellable.on_sale_end_date = localdate(3002, 1, 1)
+        self.assertEquals(sellable.price, 100)
+
+        # Current promotion
+        sellable.on_sale_start_date = localdate(2001, 1, 1)
+        sellable.on_sale_end_date = localdate(3002, 1, 1)
+        self.assertEquals(sellable.price, 80)
+
+    def test_price_on_sale_price_setter(self):
+        sellable = Sellable(category=self._category,
+                            cost=50,
+                            description=u"Test",
+                            price=100,
+                            store=self.store)
+        sellable.on_sale_price = 80
+
+        # - Old promotion
+        sellable.on_sale_start_date = localdate(2001, 1, 1)
+        sellable.on_sale_end_date = localdate(2002, 1, 1)
+        sellable.price = 10
+        self.assertEquals(sellable.base_price, 10)
+        self.assertEquals(sellable.on_sale_price, 80)
+
+        # - Future promotion
+        sellable.on_sale_start_date = localdate(3001, 1, 1)
+        sellable.on_sale_end_date = localdate(3002, 1, 1)
+        sellable.price = 10
+        self.assertEquals(sellable.base_price, 10)
+        self.assertEquals(sellable.on_sale_price, 80)
+
+        # Current promotion
+        sellable.price = 100
+        sellable.on_sale_start_date = localdate(2001, 1, 1)
+        sellable.on_sale_end_date = localdate(3002, 1, 1)
+        sellable.price = 10
+        self.assertEquals(sellable.base_price, 100)
+        self.assertEquals(sellable.on_sale_price, 10)
+
+        sellable.price = -80
+        self.assertEquals(sellable.base_price, 100)
+        self.assertEquals(sellable.on_sale_price, 0)
+
+    def test_get_available_sellables_query(self):
+        # Sellable and query without supplier
+        sellable = self.create_sellable()
+        self.create_storable(product=sellable.product,
+                             branch=self.create_branch())
+
+        self.assertIn(
+            sellable,
+            self.store.find(Sellable,
+                            Sellable.get_available_sellables_query(self.store)))
+
+        sellable.close()
+        self.assertNotIn(
+            sellable,
+            self.store.find(Sellable,
+                            Sellable.get_available_sellables_query(self.store)))
+
+        delivery_sellable = sysparam.get_object(self.store, 'DELIVERY_SERVICE').sellable
+        delivery_sellable.status = Sellable.STATUS_AVAILABLE
+        # Deliveries are treated differently, that's why they should
+        # not be present here
+        self.assertNotIn(
+            sellable,
+            self.store.find(Sellable,
+                            Sellable.get_available_sellables_query(self.store)))
+
+    def test_set_available(self):
+        sellable = self.create_sellable()
+        with self.assertRaisesRegexp(
+            ValueError, 'This sellable is already available'):
+            sellable.set_available()
+
     def test_get_unblocked_sellables(self):
         # Sellable and query without supplier
         sellable = self.create_sellable()
@@ -211,7 +409,53 @@ class TestSellable(DomainTest):
                                                      supplier=supplier)
         self.assertTrue(sellable in list(available))
 
-    def testIsValidQuantity(self):
+        # Now the sellable should appear in the results
+        storable = Storable(product=sellable.product, store=self.store)
+        available = Sellable.get_unblocked_sellables(self.store,
+                                                     storable=storable)
+        self.assertTrue(sellable in list(available))
+
+    def test_get_unblocked_by_category_query(self):
+        s1 = self.create_sellable()
+        s2 = self.create_sellable()
+        s3 = self.create_sellable()
+
+        c1 = self.create_sellable_category()
+        c2 = self.create_sellable_category()
+        s1.category = c1
+        s2.category = c2
+
+        query = Sellable.get_unblocked_by_categories_query(
+            self.store, [c1, c2], include_uncategorized=True)
+        self.assertEqual(
+            set([s1, s2, s3]),
+            set(self.store.find(Sellable, query)))
+
+        query = Sellable.get_unblocked_by_categories_query(
+            self.store, [c1], include_uncategorized=True)
+        self.assertEqual(
+            set([s1, s3]),
+            set(self.store.find(Sellable, query)))
+
+        query = Sellable.get_unblocked_by_categories_query(
+            self.store, [c1], include_uncategorized=True)
+        self.assertEqual(
+            set([s1, s3]),
+            set(self.store.find(Sellable, query)))
+
+        query = Sellable.get_unblocked_by_categories_query(
+            self.store, [c1], include_uncategorized=False)
+        self.assertEqual(
+            set([s1]),
+            set(self.store.find(Sellable, query)))
+
+        query = Sellable.get_unblocked_by_categories_query(
+            self.store, [], include_uncategorized=True)
+        self.assertEqual(
+            set([s3]),
+            set(self.store.find(Sellable, query)))
+
+    def test_is_valid_quantity(self):
         sellable = self.create_sellable()
         unit = self.create_sellable_unit()
         sellable.unit = unit
@@ -234,7 +478,14 @@ class TestSellable(DomainTest):
         self.assertFalse(sellable.is_valid_quantity(5.5))
         self.assertFalse(sellable.is_valid_quantity(Decimal('5.5')))
 
-    def testIsValidPrice(self):
+    def test_is_valid_price(self):
+
+        def isValidPriceAssert(valid_data, expected_validity, min_price,
+                               max_discount):
+            self.assertEquals(valid_data['is_valid'], expected_validity)
+            self.assertEquals(valid_data['min_price'], min_price)
+            self.assertEquals(valid_data['max_discount'], max_discount)
+
         sellable = Sellable(category=self._category, cost=50,
                             description=u"Test",
                             price=currency(100),
@@ -244,38 +495,83 @@ class TestSellable(DomainTest):
         cat_price = ClientCategoryPrice(sellable=sellable, category=cat,
                                         price=150, max_discount=0,
                                         store=self.store)
+        user = self.create_user()
+        user.profile.max_discount = 50
 
-        # without a category, and max_discount = 0
-        self.assertFalse(sellable.is_valid_price(0))
-        self.assertFalse(sellable.is_valid_price(-10))
-        self.assertFalse(sellable.is_valid_price(99))
-        self.assertTrue(sellable.is_valid_price(101))
-        self.assertTrue(sellable.is_valid_price(100))
+        # without a category, and max_discount = 0, user = None
+        valid_data = sellable.is_valid_price(-10)
+        isValidPriceAssert(valid_data, False, sellable.price, 0)
+
+        valid_data = sellable.is_valid_price(0)
+        isValidPriceAssert(valid_data, False, sellable.price, 0)
+
+        valid_data = sellable.is_valid_price(99)
+        isValidPriceAssert(valid_data, False, sellable.price, 0)
+
+        valid_data = sellable.is_valid_price(100)
+        isValidPriceAssert(valid_data, True, sellable.price, 0)
+
+        valid_data = sellable.is_valid_price(101)
+        isValidPriceAssert(valid_data, True, sellable.price, 0)
 
         # without a category, and max_discount = 10%
         sellable.max_discount = 10
-        self.assertFalse(sellable.is_valid_price(0))
-        self.assertFalse(sellable.is_valid_price(-1))
-        self.assertFalse(sellable.is_valid_price(89))
-        self.assertTrue(sellable.is_valid_price(90))
-        self.assertTrue(sellable.is_valid_price(95))
-        self.assertTrue(sellable.is_valid_price(99))
-        self.assertTrue(sellable.is_valid_price(101))
+
+        valid_data = sellable.is_valid_price(-1)
+        isValidPriceAssert(valid_data, False, currency(90), 10)
+
+        valid_data = sellable.is_valid_price(0)
+        isValidPriceAssert(valid_data, False, currency(90), 10)
+
+        valid_data = sellable.is_valid_price(89)
+        isValidPriceAssert(valid_data, False, currency(90), 10)
+
+        valid_data = sellable.is_valid_price(90)
+        isValidPriceAssert(valid_data, True, currency(90), 10)
+
+        valid_data = sellable.is_valid_price(91)
+        isValidPriceAssert(valid_data, True, currency(90), 10)
 
         # Now with a category, max_discount = 0
-        self.assertFalse(sellable.is_valid_price(0, cat))
-        self.assertFalse(sellable.is_valid_price(-10, cat))
-        self.assertFalse(sellable.is_valid_price(Decimal('149.99'), cat))
-        self.assertTrue(sellable.is_valid_price(150, cat))
-        self.assertTrue(sellable.is_valid_price(151, cat))
+        valid_data = sellable.is_valid_price(0, cat)
+        isValidPriceAssert(valid_data, False, currency(150), 0)
+
+        valid_data = sellable.is_valid_price(-10, cat)
+        isValidPriceAssert(valid_data, False, currency(150), 0)
+
+        valid_data = sellable.is_valid_price(Decimal('149.99'), cat)
+        isValidPriceAssert(valid_data, False, currency(150), 0)
+
+        valid_data = sellable.is_valid_price(150, cat)
+        isValidPriceAssert(valid_data, True, currency(150), 0)
+
+        valid_data = sellable.is_valid_price(151, cat)
+        isValidPriceAssert(valid_data, True, currency(150), 0)
 
         # Now with a category, max_discount = 10%
         cat_price.max_discount = 10
-        self.assertTrue(sellable.is_valid_price(Decimal('149.99'), cat))
-        self.assertTrue(sellable.is_valid_price(135, cat))
-        self.assertFalse(sellable.is_valid_price(134, cat))
 
-    def testGetTaxConstant(self):
+        valid_data = sellable.is_valid_price(Decimal('149.99'), cat)
+        isValidPriceAssert(valid_data, True, currency(135), 10)
+
+        valid_data = sellable.is_valid_price(135, cat)
+        isValidPriceAssert(valid_data, True, currency(135), 10)
+
+        valid_data = sellable.is_valid_price(134, cat)
+        isValidPriceAssert(valid_data, False, currency(135), 10)
+
+        # with a user
+        valid_data = sellable.is_valid_price(49, None, user)
+        isValidPriceAssert(valid_data, False, currency(50), 50)
+
+        valid_data = sellable.is_valid_price(50, None, user)
+        isValidPriceAssert(valid_data, True, currency(50), 50)
+
+        # with discount
+        valid_data = sellable.is_valid_price(50, None, user, extra_discount=10)
+        isValidPriceAssert(valid_data, True, currency(40), 50)
+
+    def test_get_tax_constant(self):
         base_category = SellableCategory(description=u"Monitor",
                                          store=self.store)
         category = SellableCategory(description=u"LCD Monitor",
@@ -299,7 +595,7 @@ class TestSellable(DomainTest):
         sellable.tax_constant = constant3
         self.assertEquals(sellable.get_tax_constant(), constant3)
 
-    def testClose(self):
+    def test_close(self):
         results_not_closed = self.store.find(ProductFullStockView)
         results_with_closed = self.store.find(ProductFullWithClosedStockView)
         results_only_closed = self.store.find(ProductClosedStockView)
@@ -316,6 +612,8 @@ class TestSellable(DomainTest):
         # ProductFullStockView and ProductFullWithClosedStock View,
         # but not on ProductClosedStockView.
         sellable = self.create_sellable()
+        branch = self.create_branch()
+        self.create_storable(product=sellable.product, branch=branch)
         results_not_closed = self.store.find(ProductFullStockView)
         results_with_closed = self.store.find(ProductFullWithClosedStockView)
         results_only_closed = self.store.find(ProductClosedStockView)
@@ -354,25 +652,35 @@ class TestSellable(DomainTest):
         # raise a ValueError.
         self.assertRaises(ValueError, sellable.close)
 
-    def testCanClose(self):
+    def test_can_close(self):
         sellable = self.create_sellable()
-        self.failUnless(sellable.can_close())
-
         branch = get_current_branch(self.store)
-        self.create_storable(sellable.product, branch, 1)
-        self.failIf(sellable.can_close())
+        storable = self.create_storable(sellable.product, branch, 0)
+        # There's a storable, but we can still close because there's no stock
+        self.assertTrue(sellable.can_close())
+
+        storable.increase_stock(1, branch, 0, None)
+        # Now that there's stock we should not be able to close anymore
+        self.assertFalse(sellable.can_close())
+
+        storable.decrease_stock(1, branch, 0, None)
+        # But decreasing the stock should make it possible to close again
+        self.assertTrue(sellable.can_close())
 
         # The delivery service cannot be closed.
-        sellable = sysparam(self.store).DELIVERY_SERVICE.sellable
+        sellable = sysparam.get_object(self.store, 'DELIVERY_SERVICE').sellable
         self.failIf(sellable.can_close())
 
-    def testCanRemove(self):
-        branch = get_current_branch(self.store)
+    def test_can_remove(self):
+        sellable = Sellable(store=self.store)
+        self.failIf(sellable.can_remove())
+
         sellable = self.create_sellable()
         storable = Storable(product=sellable.product, store=self.store)
         self.failUnless(sellable.can_remove())
 
-        storable.increase_stock(1, branch, 0, 0)
+        branch = get_current_branch(self.store)
+        storable.increase_stock(1, branch, 0, None)
         sale = self.create_sale()
         sale.status = Sale.STATUS_QUOTE
         sale.branch = branch
@@ -392,10 +700,10 @@ class TestSellable(DomainTest):
         self.assertFalse(sellable.can_remove())
 
         # The delivery service cannot be removed.
-        sellable = sysparam(self.store).DELIVERY_SERVICE.sellable
+        sellable = sysparam.get_object(self.store, 'DELIVERY_SERVICE').sellable
         self.failIf(sellable.can_remove())
 
-    def testRemove(self):
+    def test_remove(self):
         # Remove category price and sellable
         sellable = self.create_sellable()
         Storable(product=sellable.product, store=self.store)
@@ -435,7 +743,6 @@ class TestSellable(DomainTest):
         self.assertEquals(sellable.get_price_for_category(category2), 100)
 
     def test_remove_category_price(self):
-        from stoqlib.domain.sellable import ClientCategoryPrice
         category_price = self.create_client_category_price()
 
         total = self.store.find(ClientCategoryPrice).count()
@@ -458,3 +765,38 @@ class TestSellable(DomainTest):
         self.assertEquals(sellable.barcode, u'barcode')
         sellable2 = self.create_sellable(price=100)
         self.assertRaises(SellableError, setattr, sellable2, u'barcode', u'barcode')
+
+    def test_get_suggested_markup(self):
+        sellable = self.create_sellable()
+        self.assertEquals(sellable.get_suggested_markup(), None)
+
+        category = SellableCategory(description=u"LCD Monitor",
+                                    store=self.store)
+        sellable.category = category
+        self.assertEquals(sellable.get_suggested_markup(), 0)
+
+        category.suggested_markup = 10
+
+        self.assertEquals(sellable.get_suggested_markup(), 10)
+
+    def test_check_taxes_validity(self):
+        sellable = self.create_sellable()
+        sellable.check_taxes_validity()
+
+        tax = ProductTaxTemplate(store=self.store, name=u'foo')
+        sellable.product.icms_template = ProductIcmsTemplate(
+            store=self.store,
+            product_tax_template=tax)
+
+        sellable.check_taxes_validity()
+
+        sellable.product.icms_template.p_cred_sn = 10
+        sellable.product.icms_template.p_cred_sn_valid_until = localdate(2000, 1, 1)
+
+        with self.assertRaises(TaxError) as e:
+            sellable.check_taxes_validity()
+            self.assertEquals(str(e), ("You cannot sell this item before updating "
+                                       "the 'ICMS tax rate credit' field on 'foo' "
+                                       "Tax Class.\n"
+                                       "If you don't know what this means, contact "
+                                       "the system administrator."))
