@@ -21,9 +21,11 @@
 ##
 """ Domain classes to define required and visible fields """
 
+# pylint: enable=E1101
+
 from storm.references import Reference
 
-from stoqlib.database.properties import IntCol, BoolCol, UnicodeCol
+from stoqlib.database.properties import BoolCol, UnicodeCol, IdCol
 from stoqlib.domain.base import Domain
 from stoqlib.lib.translation import stoqlib_gettext, N_
 
@@ -36,7 +38,7 @@ class UIField(Domain):
     """
     __storm_table__ = 'ui_field'
 
-    ui_form_id = IntCol()
+    ui_form_id = IdCol()
     ui_form = Reference(ui_form_id, 'UIForm.id')
     field_name = UnicodeCol()
     description = UnicodeCol()
@@ -62,14 +64,13 @@ def _add_fields_to_form(store, ui_form, fields):
          visible, mandatory) in fields:
         ui_field = store.find(UIField, ui_form=ui_form,
                               field_name=field_name).one()
-        if ui_field is not None:
-            continue
-        UIField(store=store,
-                ui_form=ui_form,
-                field_name=field_name,
-                description=field_description,
-                visible=visible,
-                mandatory=mandatory)
+        if ui_field is None:
+            UIField(store=store,
+                    ui_form=ui_form,
+                    field_name=field_name,
+                    description=field_description,
+                    visible=visible,
+                    mandatory=mandatory)
 
 
 def _get_or_create_form(store, name, desc):
@@ -94,12 +95,12 @@ def create_default_forms(store):
         (u'city', N_(u'City'), True, False),
         (u'state', N_(u'State'), True, True),
         (u'country', N_(u'Country'), True, True),
-        ]
+    ]
 
     employee_fields = [
         (u'role', N_(u'Role'), True, True),
         (u'salary', N_(u'Salary'), True, True),
-        ]
+    ]
 
     product_fields = [
         (u'code', N_(u'Code'), True, False),
