@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
+
 ##
 ## Copyright (C) 2005, 2006 Async Open Source <http://www.async.com.br>
 ## All rights reserved
@@ -60,6 +61,17 @@ class NFeDanfeOrientation(enum):
      LANDSCAPE, ) = range(2)
 
 
+class ReturnPolicy(enum):
+    """Policy for returning sales.
+
+    This enum is used by the :class:`parameter
+    <stoqlib.lib.parameters.ParameterDetails>` RETURN_POLICY_ON_SALES.
+    """
+    (CLIENT_CHOICE,
+     RETURN_MONEY,
+     RETURN_CREDIT, ) = range(3)
+
+
 class LatePaymentPolicy(enum):
     """Policy for clients with late payments
 
@@ -69,3 +81,15 @@ class LatePaymentPolicy(enum):
     (ALLOW_SALES,
      DISALLOW_STORE_CREDIT,
      DISALLOW_SALES) = range(3)
+
+
+class SearchFilterPosition(enum):
+    """
+    An enum used to indicate where a search filter should be added to
+    a SearchContainer::
+
+      - TOP: top left corner
+      - BOTTOM: bottom
+    """
+    (TOP,
+     BOTTOM) = range(2)
