@@ -24,27 +24,27 @@
 """ Basic dialogs definition """
 
 import inspect
+import logging
 
 import gtk
 from gtk import keysyms
-from kiwi.log import Logger
 from kiwi.ui.dialogs import error, warning, info, yesno
 from kiwi.ui.delegates import GladeDelegate
 from kiwi.ui.views import BaseView
 from kiwi.utils import gsignal
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.lib.decorators import public
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.interfaces import ISystemNotifier
 from stoqlib.gui.base.gtkadds import change_button_appearance
 from stoqlib.gui.base.messagebar import MessageBar
-from stoqlib.gui.events import DialogCreateEvent
+from stoqlib.gui.events import DialogCreateEvent, RunDialogEvent
 
 _ = stoqlib_gettext
 _toplevel_stack = []
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 #
 # Helper classes
@@ -135,7 +135,7 @@ class BasicDialog(GladeDelegate, RunnableView):
         self.header.show()
 
         self.main = gtk.EventBox()
-        self.vbox.pack_start(self.main)
+        self.vbox.pack_start(self.main, padding=6)
         self.main.show()
 
         # FIXME
@@ -148,14 +148,14 @@ class BasicDialog(GladeDelegate, RunnableView):
         self.main_label.show()
 
         hbox1 = gtk.HBox()
-        self.vbox.pack_start(hbox1, False)
+        self.vbox.pack_start(hbox1, False, 6)
         hbox1.show()
 
         # FIXME
         # stoqlib/gui/dialogs/paymentmethod.py
         # stoqlib/gui/search/salesearch.py
         self.extra_holder = gtk.EventBox()
-        hbox1.pack_start(self.extra_holder, True, True)
+        hbox1.pack_start(self.extra_holder, True, True, 6)
         self.extra_holder.show()
 
         # FIXME
@@ -169,13 +169,13 @@ class BasicDialog(GladeDelegate, RunnableView):
         # stoqlib/gui/base/search.py
         # stoqlib/gui/slaves/productslave.py
         self.details_holder = gtk.EventBox()
-        hbox1.pack_end(self.details_holder, False, False)
+        hbox1.pack_end(self.details_holder, False, False, 6)
         self.details_holder.show()
 
         # FIXME
         # stoqlib/gui/dialogs/quotedialog.py
         self.notice = gtk.EventBox()
-        hbox1.pack_start(self.notice, False)
+        hbox1.pack_start(self.notice, False, 6)
         self.notice.show()
 
         action_area = self.toplevel.get_action_area()
@@ -183,12 +183,12 @@ class BasicDialog(GladeDelegate, RunnableView):
         action_area.set_layout(gtk.BUTTONBOX_END)
 
         self.cancel_button = gtk.Button(stock=gtk.STOCK_CANCEL)
-        action_area.pack_start(self.cancel_button, True, True)
+        action_area.pack_start(self.cancel_button, True, True, 6)
         self.cancel_button.show()
 
         self.ok_button = gtk.Button(stock=gtk.STOCK_OK)
         self.ok_button.set_use_underline(True)
-        action_area.pack_start(self.ok_button, True, True)
+        action_area.pack_start(self.ok_button, True, True, 6)
         self.ok_button.show()
 
     def _setup_keyactions(self):
@@ -206,13 +206,13 @@ class BasicDialog(GladeDelegate, RunnableView):
 
     def _add_help_button(self, section):
         def on_help__clicked(button):
-            from stoqlib.gui.help import show_section
+            from stoqlib.gui.utils.help import show_section
             show_section(section)
 
         self.action_area.set_layout(gtk.BUTTONBOX_END)
         self.help_button = gtk.Button(stock=gtk.STOCK_HELP)
         self.help_button.connect('clicked', on_help__clicked)
-        self.action_area.pack_start(self.help_button, expand=False, fill=False)
+        self.action_area.pack_start(self.help_button, False, False, 6)
         self.action_area.set_child_secondary(self.help_button, True)
         self.help_button.show()
 
@@ -253,10 +253,10 @@ class BasicDialog(GladeDelegate, RunnableView):
             icon = gtk.STOCK_OK
         change_button_appearance(self.ok_button, icon, text)
 
-    # FIXME: Remove
-    # Callsites: stoqlib/gui/dialogs/sintegradialog.py
-    def justify_label(self, just):
-        self.main_label.set_justify(just)
+    def set_cancel_label(self, text, icon=None):
+        if not icon:
+            icon = gtk.STOCK_CANCEL
+        change_button_appearance(self.cancel_button, icon, text)
 
     def set_confirm_widget(self, widget):
         """Enables widget as a confirm widget, the dialog will be closed as
@@ -278,11 +278,13 @@ class BasicDialog(GladeDelegate, RunnableView):
     def action_area(self):
         return self.get_toplevel().action_area
 
-    def set_message(self, message, message_type=gtk.MESSAGE_INFO):
+    def set_message(self, message, message_type=None):
         """Sets a message for this editor
         :param message: message to add or None to remove previous message
         :param message_type: type of message to add
         """
+        if message_type is None:
+            message_type = gtk.MESSAGE_INFO
         if self._message_bar is not None:
             self._message_bar.destroy()
             self._message_bar = None
@@ -346,6 +348,15 @@ def get_dialog(parent, dialog, *args, **kwargs):
     return dialog
 
 
+def has_modal_window():
+    """Verifies if any of the currently open windows are modal.
+
+    :returns: ``True`` if there are any modal windows open, otherwise ``False``
+    """
+    windows = _toplevel_stack
+    return any(window.get_modal() for window in windows)
+
+
 @public(since="1.5.0")
 def run_dialog(dialog, parent=None, *args, **kwargs):
     """Runs a dialog and return the return value of it.
@@ -360,11 +371,16 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
     if dialog is None:
         raise TypeError("dialog cannot be None")
 
+    dialog = RunDialogEvent.emit(dialog, parent, *args, **kwargs)
     if not issubclass(dialog, RunnableView):
         raise TypeError("dialog %r must be subclass of RunnableView" % (
             dialog, ))
 
     # FIXME: Move this into RunnableView
+
+    #XXX: When create a new Stoq window, even using the parent correctly:
+    # The called dialog will be a modal of the latest created window
+    # (not necessarily the window that called).
     parent = getattr(parent, 'main_dialog', parent)
     parent = parent or get_current_toplevel()
     if inspect.isclass(dialog):
@@ -393,19 +409,28 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
         # HINT_DIALOG
         toplevel.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_NORMAL)
 
+    log.info("%s: Opening" % dialog_name)
+
     if hasattr(parent, 'on_dialog__opened'):
         parent.on_dialog__opened(orig_dialog)
 
-    log.info("%s: Opening" % dialog_name)
+    retval = run_dialog_internal(dialog, parent, toplevel)
 
+    _pop_current_toplevel()
+
+    return retval
+
+
+# Mainly for mocking
+
+def run_dialog_internal(dialog, parent, toplevel):
     # FIXME: We should avoid calling dialog.run() here
-    # See http://stackoverflow.com/questions/3504739/twisted-gtk-should-i-run-gui-things-in-threads-or-in-the-reactor-thread
+    # See http://tinyurl.com/lj6ske4
     toplevel.run()
 
     retval = dialog.retval
     dialog.destroy()
 
-    _pop_current_toplevel()
     return retval
 
 _fullscreen = None
@@ -421,9 +446,8 @@ def pop_fullscreen(window):
     _fullscreen = None
 
 
+@implementer(ISystemNotifier)
 class DialogSystemNotifier:
-    implements(ISystemNotifier)
-
     def info(self, short, description):
         info(short, description, get_current_toplevel())
 
@@ -434,7 +458,9 @@ class DialogSystemNotifier:
     def error(self, short, description):
         error(short, description, get_current_toplevel())
 
-    def yesno(self, text, default=gtk.RESPONSE_YES, *verbs):
+    def yesno(self, text, default=None, *verbs):
+        if default is None:
+            default = gtk.RESPONSE_YES
         if len(verbs) != 2:
             raise ValueError(
                 "Button descriptions must be a tuple with 2 items")
