@@ -32,9 +32,9 @@ from stoqlib.api import api
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.exceptions import SelectionError, StoqlibError
 from stoqlib.gui.base.dialogs import run_dialog, BasicDialog
-from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.base.wizards import BaseWizard
 from stoqlib.gui.editors.baseeditor import BaseEditor
+from stoqlib.gui.search.searchslave import SearchSlave
 from stoqlib.lib.translation import stoqlib_gettext, stoqlib_ngettext
 from stoqlib.lib.message import yesno
 
@@ -49,19 +49,19 @@ class ModelListSlave(ListSlave):
     columns = None
 
     def __init__(self, parent=None, store=None,
-                 orientation=gtk.ORIENTATION_VERTICAL):
+                 orientation=None):
         """
         Create a new ModelListDialog object.
         :param store: a store connection
         """
+        if orientation is None:
+            orientation = gtk.ORIENTATION_VERTICAL
         if self.columns is None:
-            raise TypeError(
-                "%s needs to set it's columns attribute" % (
-                self.__class__.__name__, ))
+            fmt = "%s needs to set it's columns attribute"
+            raise TypeError(fmt % (self.__class__.__name__, ))
         if self.model_type is None:
-            raise TypeError(
-                "%s needs to set it's model_type attribute" % (
-                self.__class__.__name__, ))
+            fmt = "%s needs to set it's model_type attribute"
+            raise TypeError(fmt % (self.__class__.__name__, ))
 
         if not store:
             store = api.get_default_store()
@@ -201,9 +201,8 @@ class ModelListDialog(BasicDialog):
 
     def __init__(self, store=None):
         if self.list_slave_class is None:
-            raise TypeError(
-                "%s needs to set it's list_slave_class attribute" % (
-                self.__class__.__name__, ))
+            fmt = "%s needs to set it's list_slave_class attribute"
+            raise TypeError(fmt % (self.__class__.__name__, ))
         self.list_slave = self.list_slave_class(self, store=store)
 
         BasicDialog.__init__(self, title=self.title, size=self.size)
@@ -214,7 +213,7 @@ class ModelListDialog(BasicDialog):
         self.vbox.show()
 
 
-class AdditionListSlave(StoqlibSearchSlaveDelegate):
+class AdditionListSlave(SearchSlave):
     """A slave that offers a simple list and its management.
 
     This slave also has the option to display a small message right next to the
@@ -238,7 +237,7 @@ class AdditionListSlave(StoqlibSearchSlaveDelegate):
 
         :param store:         a store
         :param columns:       column definitions
-        :type columns:        sequence of :class:`kiwi.ui.widgets.list.Columns`
+        :type columns:        sequence of :class:`kiwi.ui.objectlist.Columns`
         :param editor_class:  the window that is going to be open when user
                               clicks on add_button or edit_button.
         :type: editor_class:  a :class:`stoqlib.gui.editors.BaseEditor` subclass
@@ -251,9 +250,10 @@ class AdditionListSlave(StoqlibSearchSlaveDelegate):
         :type restore_name:   basestring
         """
         columns = columns or self.get_columns()
-        StoqlibSearchSlaveDelegate.__init__(self, columns=columns,
-                                            restore_name=restore_name)
-        if not self._columns:
+        SearchSlave.__init__(self, columns=columns,
+                             restore_name=restore_name,
+                             store=store)
+        if not self.columns:
             raise StoqlibError("columns must be specified")
         self.visual_mode = visual_mode
         self.store = store
@@ -269,7 +269,7 @@ class AdditionListSlave(StoqlibSearchSlaveDelegate):
         self._update_sensitivity()
 
     def _setup_klist(self, klist_objects):
-        self.klist.set_columns(self._columns)
+        self.klist.set_columns(self.columns)
         self.klist.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.klist.add_list(klist_objects)
         if self.visual_mode:
@@ -319,7 +319,7 @@ class AdditionListSlave(StoqlibSearchSlaveDelegate):
         if qty != 1:
             raise SelectionError(
                 ("Please select only one item before choosing Edit."
-                   "\nThere are currently %d items selected") % qty)
+                 "\nThere are currently %d items selected") % qty)
         self._edit_model(objs[0])
 
     def _clear(self):
@@ -341,7 +341,7 @@ class AdditionListSlave(StoqlibSearchSlaveDelegate):
             _("Keep it"),
             _("Keep them"),
             qty)
-        if yesno(msg, gtk.RESPONSE_NO, keep_label, delete_label):
+        if not yesno(msg, gtk.RESPONSE_NO, delete_label, keep_label):
             return
         self.emit('before-delete-items', objs)
         if qty == len(self.klist):
@@ -390,6 +390,28 @@ class AdditionListSlave(StoqlibSearchSlaveDelegate):
     # Public API
     #
 
+    def add_extra_button(self, label=None, stock=None):
+        """Add an extra button on the this slave
+
+        The extra button will be appended at the end of the button box,
+        the one containing the add/edit/delete buttons
+
+        :param label: label of the button, can be ``None`` if stock is passed
+        :param stock: stock label of the button, can be ``None`` if label
+            is passed
+        :param returns: the button added
+        :rtype: gtk.Button
+        """
+        if label is None and stock is None:
+            raise TypeError("You need to provide a label or a stock argument")
+
+        button = gtk.Button(label=label, stock=stock)
+        button.set_property('can_focus', True)
+        self.button_box.pack_end(button, False, False)
+        button.show()
+
+        return button
+
     def set_message(self, message, details_callback=None):
         """Display a simple message on a label, next to the add, edit, delete buttons
         :param message: a message with properly escaped markup
@@ -400,7 +422,7 @@ class AdditionListSlave(StoqlibSearchSlaveDelegate):
             if self._callback_id:
                 self.message_details_button.disconnect(self._callback_id)
             self._callback_id = self.message_details_button.connect(
-                                                'clicked', details_callback)
+                'clicked', details_callback)
 
         self.message_label.set_markup(message)
 
