@@ -23,18 +23,19 @@
 ##
 """ Base classes for wizards """
 
+import logging
+
 import gtk
-from kiwi.log import Logger
 from kiwi.ui.delegates import GladeDelegate, GladeSlaveDelegate
 
 from stoqlib.database.runtime import StoqlibStore
 from stoqlib.gui.base.dialogs import RunnableView
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
-from stoqlib.gui.help import show_section
+from stoqlib.gui.utils.help import show_section
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
-logger = Logger(__name__)
+logger = logging.getLogger(__name__)
 
 
 class WizardStep:
@@ -91,7 +92,7 @@ class PluggableWizard(GladeDelegate):
                                gladefile=self.gladefile)
         if not isinstance(first_step, WizardStep):
             raise TypeError("first_step must be a WizardStep "
-                "instance, not %r" % (first_step, ))
+                            "instance, not %r" % (first_step, ))
 
         self.set_title(title)
         self._current = None
@@ -287,8 +288,6 @@ class BaseWizard(PluggableWizard, RunnableView):
         logger.info('Entering wizard: %s' % self.__class__.__name__)
         self.store = store
         self.model = model
-        if isinstance(self.store, StoqlibStore):
-            self.store.needs_retval = True
         self.retval = None
         size = size or self.size
         title = title or self.title
