@@ -24,18 +24,22 @@
 """ Dialog to register the initial stock of a product in a certain branch """
 
 from decimal import Decimal
-from sys import maxint as MAXINT
 
 import gtk
-
 from kiwi import ValueUnset
+from kiwi.currency import currency
 from kiwi.enums import ListType
+from kiwi.python import Settable
 from kiwi.ui.objectlist import Column
 from kiwi.ui.listdialog import ListSlave
 
 from stoqlib.api import api
+from stoqlib.domain.person import Branch
 from stoqlib.domain.product import Storable
+from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.dialogs.batchselectiondialog import BatchIncreaseSelectionDialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
+from stoqlib.lib.defaults import MAX_INT
 from stoqlib.lib.message import yesno
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -50,38 +54,47 @@ class _TemporaryStorableItem(object):
         self.barcode = sellable.barcode
         self.category_description = sellable.get_category_description()
         self.description = sellable.get_description()
-        self.initial_stock = 0
+        self.unit_cost = sellable.cost
+        self.storable = sellable.product_storable
+        self.is_batch = self.storable and self.storable.is_batch
+        self.batches = {}
+        if not self.is_batch:
+            self.initial_stock = 0
+
+    @property
+    def initial_stock(self):
+        if self.is_batch:
+            return sum(quantity for quantity in self.batches.values())
+        return self._quantity
+
+    @initial_stock.setter
+    def initial_stock(self, quantity):
+        assert not self.is_batch
+        self._quantity = quantity
 
 
 class InitialStockDialog(BaseEditor):
     gladefile = "InitialStockDialog"
-    model_type = object
-    title = _(u"Product  - Initial Stock")
-    size = (750, 450)
+    model_type = Settable
+    title = _(u"Initial Stock")
+    size = (850, 450)
     help_section = 'stock-register-initial'
+    proxy_widgets = ['branch']
 
-    def __init__(self, store, branch=None):
-        if branch is None:
-            self._branch = api.get_current_branch(store)
-        else:
-            self._branch = branch
-        BaseEditor.__init__(self, store, model=object())
+    #
+    # Private
+    #
 
-        self._setup_widgets()
+    def _refresh_storables(self):
+        self.slave.listcontainer.list.add_list(self._get_storables())
 
-    def _setup_widgets(self):
-        self.branch_label.set_markup(
-            _(u"Registering initial stock for products in <b>%s</b>") %
-            api.escape(self._branch.person.name))
-
-        self._storables = [_TemporaryStorableItem(s)
-            for s in self.store.find(Storable)
-                if s.get_stock_item(self._branch) is None]
-
-        self.slave.listcontainer.add_items(self._storables)
+    def _get_storables(self):
+        for s in Storable.get_storables_without_stock_item(self.store,
+                                                           self.model.branch):
+            yield _TemporaryStorableItem(s)
 
     def _get_columns(self):
-        adj = gtk.Adjustment(upper=MAXINT, step_incr=1)
+        adj = gtk.Adjustment(lower=0, upper=MAX_INT, step_incr=1)
         return [Column("code", title=_(u"Code"), data_type=str, sorted=True,
                        width=100),
                 Column("barcode", title=_(u"Barcode"), data_type=str,
@@ -96,7 +109,9 @@ class InitialStockDialog(BaseEditor):
                        data_type=str, visible=False),
                 Column("initial_stock", title=_(u"Initial Stock"),
                        data_type=Decimal, format_func=self._format_qty,
-                       editable=True, spin_adjustment=adj, width=115)]
+                       editable=True, spin_adjustment=adj, width=110),
+                Column("unit_cost", title=_(u"Unit Cost"), width=90,
+                       data_type=currency, editable=True, spin_adjustment=adj)]
 
     def _format_qty(self, quantity):
         if quantity is ValueUnset:
@@ -105,31 +120,55 @@ class InitialStockDialog(BaseEditor):
             return quantity
 
     def _validate_initial_stock_quantity(self, item, store):
-        positive = item.initial_stock > 0
-        if item.initial_stock is not ValueUnset and positive:
+        if ValueUnset in [item.initial_stock, item.unit_cost]:
+            return
+
+        valid_stock = item.initial_stock > 0
+        valid_cost = item.unit_cost >= 0
+        if valid_stock and valid_cost:
             storable = store.fetch(item.obj)
-            storable.register_initial_stock(item.initial_stock, self._branch)
+            if item.is_batch:
+                for batch, quantity in item.batches.items():
+                    storable.register_initial_stock(quantity,
+                                                    self.model.branch,
+                                                    item.unit_cost,
+                                                    batch_number=batch)
+            else:
+                storable.register_initial_stock(item.initial_stock,
+                                                self.model.branch,
+                                                item.unit_cost)
 
     def _add_initial_stock(self):
-        for item in self._storables:
+        for item in self.storables:
             self._validate_initial_stock_quantity(item, self.store)
 
     #
     # BaseEditorSlave
     #
 
+    def create_model(self, store):
+        return Settable(branch=api.get_current_branch(store))
+
+    def setup_proxies(self):
+        self.branch.prefill(
+            api.for_combo(Branch.get_active_branches(self.store)))
+        self.add_proxy(self.model, self.proxy_widgets)
+
     def setup_slaves(self):
         self.slave = ListSlave(self._get_columns())
         self.slave.set_list_type(ListType.READONLY)
-        self.slave.listcontainer.list.connect(
-            "cell-edited", self._on_objectlist__cell_edited)
+        self.storables = self.slave.listcontainer.list
+        self.storables.set_cell_data_func(
+            self._on_storables__cell_data_func)
         self.attach_slave("on_slave_holder", self.slave)
 
+        self._refresh_storables()
+
     def on_confirm(self):
         self._add_initial_stock()
 
     def on_cancel(self):
-        if self._storables:
+        if len(self.storables):
             msg = _('Save data before close the dialog ?')
             if yesno(msg, gtk.RESPONSE_NO, _("Save data"), _("Don't save")):
                 self._add_initial_stock()
@@ -140,15 +179,36 @@ class InitialStockDialog(BaseEditor):
     # Callbacks
     #
 
-    def _on_objectlist__cell_edited(self, objectlist, item, attr):
+    def _on_storables__cell_data_func(self, column, renderer, obj, text):
+        if not isinstance(renderer, gtk.CellRendererText):
+            return text
+
+        if column.attribute == 'initial_stock':
+            renderer.set_property('editable-set', not obj.is_batch)
+            renderer.set_property('editable', not obj.is_batch)
+
+        return text
+
+    def on_storables__row_activated(self, storables, item):
+        if item.is_batch:
+            retval = run_dialog(BatchIncreaseSelectionDialog, self,
+                                store=self.store, model=item.storable,
+                                quantity=0, original_batches=item.batches)
+            item.batches = retval or item.batches
+            self.storables.update(item)
+
+    def on_storables__cell_edited(self, storables, item, attr):
         # After filling a value, jump to the next cell or to the ok
         # button if we are at the last one
-        treeview = objectlist.get_treeview()
+        treeview = storables.get_treeview()
         rows, column = treeview.get_cursor()
         next_row = rows[0] + 1
-        nitems = len(self._storables)
+        nitems = len(self.storables)
         if next_row < nitems:
             treeview.set_cursor(next_row, column)
         else:
-            objectlist.unselect_all()
+            storables.unselect_all()
             self.main_dialog.ok_button.grab_focus()
+
+    def after_branch__content_changed(self, widget):
+        self._refresh_storables()
