@@ -27,7 +27,7 @@ from decimal import Decimal
 
 import pango
 import gtk
-from kiwi.ui.widgets.list import Column, ColoredColumn
+from kiwi.ui.objectlist import Column, ColoredColumn
 
 from stoqlib.api import api
 from stoqlib.domain.inventory import Inventory
@@ -39,7 +39,7 @@ from stoqlib.gui.editors.productioneditor import (ProductionItemProducedEditor,
                                                   ProductionMaterialLostEditor,
                                                   ProductionMaterialAllocateEditor,
                                                   )
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.reporting.production import ProductionOrderReport
 
@@ -53,7 +53,7 @@ class ProductionDetailsDialog(BaseEditor):
     size = (750, 460)
     hide_footer = True
     proxy_widgets = ('branch',
-                     'order_number',
+                     'identifier',
                      'open_date',
                      'close_date',
                      'responsible_name',
@@ -77,7 +77,7 @@ class ProductionDetailsDialog(BaseEditor):
         self.materials.add_list(self.model.get_material_items())
         self.services.add_list(self.model.get_service_items())
         self.produced_items.add_list(
-            self.model.produced_items.order_by(ProductionOrder.id))
+            self.model.produced_items.order_by(ProductionOrder.identifier))
 
         self.proxy.update_many(['close_date', 'status_string'])
 
@@ -185,10 +185,10 @@ class ProductionDetailsDialog(BaseEditor):
                                   use_data_model=True))
 
         columns.extend([
-                Column('test_passed', title=_('Tests Passed'),
+            Column('test_passed', title=_('Tests Passed'),
                        data_type=bool, visible=False),
-                Column('entered_stock', title=_('Entered Stock'),
-                       data_type=bool, visible=False)])
+            Column('entered_stock', title=_('Entered Stock'),
+                   data_type=bool, visible=False)])
         return columns
 
     #
@@ -254,11 +254,11 @@ class ProductionDetailsDialog(BaseEditor):
                                           and not self.has_open_inventory())
 
     def on_materials__selection_changed(self, widget, item):
-        self.lost_button.set_sensitive(bool(item) and
+        self.lost_button.set_sensitive(bool(item) and item.product.manage_stock and
                                        item.can_add_lost(Decimal('0.001')))
-        self.allocate_button.set_sensitive(bool(item) and
-                    self.model.status == ProductionOrder.ORDER_PRODUCING
-                    and not self.has_open_inventory())
+        self.allocate_button.set_sensitive(bool(item) and item.product.manage_stock and
+                                           self.model.status == ProductionOrder.ORDER_PRODUCING
+                                           and not self.has_open_inventory())
 
     def on_produced_items__selection_changed(self, widget, items):
         products = set()
