@@ -29,7 +29,7 @@ import datetime
 import pango
 import gtk
 from kiwi.currency import currency
-from kiwi.ui.widgets.list import Column, SummaryLabel, ColoredColumn
+from kiwi.ui.objectlist import Column, SummaryLabel, ColoredColumn
 
 from stoqlib.api import api
 from stoqlib.domain.payment.payment import Payment
@@ -42,7 +42,8 @@ from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.labeldialog import SkipLabelsEditor
 from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.gui.printing import print_labels, print_report
+from stoqlib.gui.search.searchcolumns import IdentifierColumn
+from stoqlib.gui.utils.printing import print_labels, print_report
 from stoqlib.reporting.purchase import PurchaseOrderReport, PurchaseQuoteReport
 
 _ = stoqlib_gettext
@@ -73,18 +74,18 @@ class _TemporaryReceivingDetails:
             ReceivingOrder.FREIGHT_FOB_INSTALLMENTS: PurchaseOrder.FREIGHT_FOB,
             ReceivingOrder.FREIGHT_CIF_UNKNOWN: PurchaseOrder.FREIGHT_CIF,
             ReceivingOrder.FREIGHT_CIF_INVOICE: PurchaseOrder.FREIGHT_CIF
-            }
+        }
         freight_names = PurchaseOrder.freight_types
         freight_types = []
 
         if orders.count():
             discount = surcharge = freight = subtotal = total = 0
             for order in orders:
-                discount += order._get_total_discounts()
-                surcharge += order._get_total_surcharges()
+                discount += order.total_discounts
+                surcharge += order.total_surcharges
                 freight += order.freight_total
-                subtotal += order.get_products_total()
-                total += order.get_total()
+                subtotal += order.products_total
+                total += order.total
 
                 # If first time used, append to the list of used types
                 if freight_type_map[order.freight_type] not in freight_types:
@@ -109,7 +110,7 @@ class PurchaseDetailsDialog(BaseEditor):
     size = (750, 460)
     hide_footer = True
     proxy_widgets = ('branch',
-                     'order_number',
+                     'identifier',
                      'supplier',
                      'open_date',
                      'status',
@@ -158,7 +159,7 @@ class PurchaseDetailsDialog(BaseEditor):
                                                          self.model.group)
         self.payments_info_list.add_list(changes)
 
-        if not self._receiving_orders:
+        if self._receiving_orders.is_empty():
             for widget in (self.received_freight_type_label,
                            self.received_freight_type,
                            self.received_freight_label,
@@ -175,71 +176,53 @@ class PurchaseDetailsDialog(BaseEditor):
         label.set_label(_(u'Print labels'))
 
     def _get_ordered_columns(self):
-        return [Column('description',
-                       title=_('Description'),
-                       data_type=str, expand=True, searchable=True,
+        return [Column('description', title=_('Description'), data_type=str,
+                       expand=True, searchable=True,
                        ellipsize=pango.ELLIPSIZE_END),
-                Column('quantity_as_string', title=_('Quantity'),
-                       data_type=str, width=90, editable=True,
+                Column('quantity_as_string', title=_('Qty'), data_type=str,
                        justify=gtk.JUSTIFY_RIGHT),
                 Column('cost', title=_('Cost'), data_type=currency,
-                       format_func=get_formatted_cost, width=90),
-                Column('total', title=_('Total'), data_type=currency,
-                       width=100)]
+                       format_func=get_formatted_cost),
+                Column('total', title=_('Total'), data_type=currency)]
 
     def _get_received_columns(self):
-        return [Column('description',
-                       title=_('Description'),
-                       data_type=str, expand=True, searchable=True,
+        return [Column('description', title=_('Description'), data_type=str,
+                       expand=True, searchable=True,
                        ellipsize=pango.ELLIPSIZE_END),
-                Column('quantity_received_as_string',
-                       title=_('Quantity Received'),
-                       data_type=str, width=150, editable=True,
-                       justify=gtk.JUSTIFY_RIGHT),
+                Column('quantity_received_as_string', title=_('Qty Received'),
+                       data_type=str, justify=gtk.JUSTIFY_RIGHT),
                 Column('cost', title=_('Cost'), data_type=currency,
-                       format_func=get_formatted_cost, editable=True,
-                       width=90),
-                Column('total_received', title=_('Total'),
-                       data_type=currency, width=100)]
+                       format_func=get_formatted_cost),
+                Column('total_received', title=_('Total'), data_type=currency)]
 
     def _get_payments_columns(self):
-        return [Column('identifier', "#", data_type=int, width=50,
-                       format='%04d', justify=gtk.JUSTIFY_RIGHT),
+        return [IdentifierColumn('identifier'),
                 Column('description', _("Description"), data_type=str,
-                       width=150, expand=True,
-                       ellipsize=pango.ELLIPSIZE_END),
+                       expand=True, ellipsize=pango.ELLIPSIZE_END),
                 Column('due_date', _("Due date"), sorted=True,
-                       data_type=datetime.date, width=90,
-                       justify=gtk.JUSTIFY_RIGHT),
-                Column('paid_date', _("Paid date"),
-                      data_type=datetime.date, width=90),
-                Column('status_str', _("Status"), data_type=str, width=80),
+                       data_type=datetime.date, justify=gtk.JUSTIFY_RIGHT),
+                Column('paid_date', _("Paid date"), data_type=datetime.date),
+                Column('status_str', _("Status"), data_type=str),
                 ColoredColumn('value', _("Value"), data_type=currency,
-                              width=90,
-                              justify=gtk.JUSTIFY_RIGHT,
-                              use_data_model=True,
+                              justify=gtk.JUSTIFY_RIGHT, use_data_model=True,
                               data_func=payment_value_colorize),
                 ColoredColumn('paid_value', _("Paid value"), data_type=currency,
-                              width=92,
-                              justify=gtk.JUSTIFY_RIGHT,
-                              use_data_model=True,
+                              justify=gtk.JUSTIFY_RIGHT, use_data_model=True,
                               data_func=payment_value_colorize)]
 
     def _get_payments_info_columns(self):
-        return [Column('change_date', _(u"When"),
-                        data_type=datetime.date, sorted=True, ),
-                Column('description', _(u"Payment"),
-                        data_type=str, expand=True,
-                        ellipsize=pango.ELLIPSIZE_END),
-                Column('changed_field', _(u"Changed"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
-                Column('from_value', _(u"From"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
-                Column('to_value', _(u"To"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
-                Column('reason', _(u"Reason"),
-                        data_type=str, expand=True,
-                        ellipsize=pango.ELLIPSIZE_END)]
+        return [Column('change_date', _(u"When"), data_type=datetime.date,
+                       sorted=True),
+                Column('description', _(u"Payment"), data_type=str, expand=True,
+                       ellipsize=pango.ELLIPSIZE_END),
+                Column('changed_field', _(u"Changed"), data_type=str,
+                       justify=gtk.JUSTIFY_RIGHT),
+                Column('from_value', _(u"From"), data_type=str,
+                       justify=gtk.JUSTIFY_RIGHT),
+                Column('to_value', _(u"To"), data_type=str,
+                       justify=gtk.JUSTIFY_RIGHT),
+                Column('reason', _(u"Reason"), data_type=str,
+                       ellipsize=pango.ELLIPSIZE_END)]
 
     def _export_csv(self):
         sse = SpreadSheetExporter()
