@@ -27,8 +27,7 @@
 
 import gtk
 from kiwi.currency import currency
-from kiwi.ui.objectlist import Column
-from kiwi.ui.widgets.list import SummaryLabel
+from kiwi.ui.objectlist import Column, SummaryLabel
 
 from stoqlib.api import api
 from stoqlib.domain.receiving import (ReceivingOrderItem,
@@ -38,8 +37,8 @@ from stoqlib.lib.formatters import get_formatted_cost
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.labeldialog import SkipLabelsEditor
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.gui.printing import print_labels
 from stoqlib.gui.slaves.receivingslave import ReceivingInvoiceSlave
+from stoqlib.gui.utils.printing import print_labels
 
 _ = stoqlib_gettext
 
@@ -85,7 +84,7 @@ class ReceivingOrderDetailsDialog(BaseEditor):
 
     def _get_product_columns(self):
         return [Column("sellable.code", title=_("Code"), data_type=str,
-                        justify=gtk.JUSTIFY_RIGHT, width=130),
+                       justify=gtk.JUSTIFY_RIGHT, width=130),
                 Column("sellable.description", title=_("Description"),
                        data_type=str, width=80, expand=True),
                 Column("quantity_unit_string", title=_("Quantity"),
@@ -102,8 +101,8 @@ class ReceivingOrderDetailsDialog(BaseEditor):
     #
 
     def setup_proxies(self):
-        receiving_date = self.model.get_receival_date_str()
-        branch_name = self.model.get_branch_name()
+        receiving_date = self.model.receival_date_str
+        branch_name = self.model.branch_name
         text = _('Received in <b>%s</b> for branch <b>%s</b>')
         header_text = text % (api.escape(receiving_date),
                               api.escape(branch_name))
@@ -118,4 +117,4 @@ class ReceivingOrderDetailsDialog(BaseEditor):
     def on_print_labels__clicked(self, button):
         label_data = run_dialog(SkipLabelsEditor, self, self.store)
         if label_data:
-            print_labels(label_data, self.store, self.model.purchase)
+            print_labels(label_data, self.store, receiving=self.model)
