@@ -30,14 +30,15 @@ import datetime
 import pango
 import gtk
 from kiwi.currency import currency
-from kiwi.ui.widgets.list import Column, SummaryLabel, ColoredColumn
+from kiwi.ui.objectlist import Column, SummaryLabel, ColoredColumn
 
 from stoqlib.api import api
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.defaults import payment_value_colorize
-from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.dialogs.clientdetails import ClientDetailsDialog
+from stoqlib.gui.search.searchcolumns import IdentifierColumn
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.payment.views import PaymentChangeHistoryView
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
@@ -52,10 +53,10 @@ class _RenegotiationItem(object):
         self.open_date = parent.open_date
 
         if isinstance(parent, Sale):
-            desc = _("Sale %04d") % (parent.identifier)
+            desc = _("Sale %s") % (parent.identifier)
             self.total_amount = parent.total_amount
         elif isinstance(parent, PaymentRenegotiation):
-            desc = _("Renegotiation %04d") % (parent.identifier)
+            desc = _("Renegotiation %s") % (parent.identifier)
             self.total_amount = parent.total
 
         self.description = desc
@@ -114,8 +115,7 @@ class RenegotiationDetailsDialog(BaseEditor):
         self._setup_summary_labels()
 
     def _get_payments_columns(self):
-        return [Column('identifier', "#", data_type=int, width=50,
-                       format='%04d', justify=gtk.JUSTIFY_RIGHT),
+        return [IdentifierColumn('identifier'),
                 Column('method.description', _("Type"),
                        data_type=str, width=60),
                 Column('description', _("Description"), data_type=str,
@@ -144,19 +144,19 @@ class RenegotiationDetailsDialog(BaseEditor):
 
     def _get_payments_info_columns(self):
         return [Column('change_date', _(u"When"),
-                        data_type=datetime.date, sorted=True, ),
+                       data_type=datetime.date, sorted=True, ),
                 Column('description', _(u"Payment"),
-                        data_type=str, expand=True,
-                        ellipsize=pango.ELLIPSIZE_END),
+                       data_type=str, expand=True,
+                       ellipsize=pango.ELLIPSIZE_END),
                 Column('changed_field', _(u"Changed"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
+                       data_type=str, justify=gtk.JUSTIFY_RIGHT),
                 Column('from_value', _(u"From"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
+                       data_type=str, justify=gtk.JUSTIFY_RIGHT),
                 Column('to_value', _(u"To"),
-                        data_type=str, justify=gtk.JUSTIFY_RIGHT),
+                       data_type=str, justify=gtk.JUSTIFY_RIGHT),
                 Column('reason', _(u"Reason"),
-                        data_type=str, expand=True,
-                        ellipsize=pango.ELLIPSIZE_END)]
+                       data_type=str, expand=True,
+                       ellipsize=pango.ELLIPSIZE_END)]
     #
     # BaseEditor hooks
     #
