@@ -55,11 +55,11 @@ class _SellableTaxConstantsListSlave(ModelListSlave):
         quantity = sellables.count()
         if quantity > 0:
             msg = _(u"You can't remove this tax, since %d products or "
-                    "services are taxed with '%s'.") % (
-                    quantity, model.get_description())
+                    "services are taxed with '%s'.") % (quantity,
+                                                        model.get_description())
             info(msg)
         else:
-            SellableTaxConstant.delete(model.id, store=store)
+            store.remove(model)
 
     def run_editor(self, store, model):
         if model and model.tax_type != TaxType.CUSTOM:
