@@ -36,13 +36,18 @@ class SellableImageViewer(GladeDelegate, RunnableView):
     title = _("Sellable Image Viewer")
     gladefile = "SellableImageViewer"
     position = (0, 0)
-    size = (325, 325)
 
-    def __init__(self, *args, **kwargs):
-        GladeDelegate.__init__(self, *args, **kwargs)
+    def __init__(self, size):
+        """
+        :param tuple size: the size for this viewer as (x, y)
+        """
+        self._size = size
+
+        GladeDelegate.__init__(self)
+
         self.toplevel.set_keep_above(True)
-        self.toplevel.resize(*SellableImageViewer.size)
-        self.toplevel.move(*SellableImageViewer.position)
+        self.toplevel.resize(*self._size)
+        self.toplevel.move(*self.position)
         self.sellable = None
         self.toplevel.connect("configure-event", self._on_configure)
 
@@ -52,13 +57,13 @@ class SellableImageViewer(GladeDelegate, RunnableView):
 
     def set_sellable(self, sellable):
         self.sellable = sellable
-        if not self.sellable.image:
+        if not self.sellable or not self.sellable.image:
             self.image.set_from_stock(gtk.STOCK_DIALOG_ERROR,
                                       gtk.ICON_SIZE_DIALOG)
             return
 
         pixbuf = _pixbuf_converter.from_string(sellable.image.image)
-        width, height = SellableImageViewer.size
+        width, height = self._size
         pixbuf = pixbuf.scale_simple(width, height, gtk.gdk.INTERP_BILINEAR)
         self.image.set_from_pixbuf(pixbuf)
 
@@ -67,9 +72,6 @@ class SellableImageViewer(GladeDelegate, RunnableView):
     #
 
     def _on_configure(self, window, event):
-        SellableImageViewer.position = event.x, event.y
-        if (event.width != SellableImageViewer.size[0]
-            or event.height != SellableImageViewer.size[1]):
-            SellableImageViewer.size = event.width, event.height
-            if self.sellable:
-                self.set_sellable(self.sellable)
+        self.position = event.x, event.y
+        self._size = event.width, event.height
+        self.set_sellable(self.sellable)
