@@ -48,7 +48,7 @@ class _TemporaryItem(object):
 
 # FIXME: Create a generic (spreadsheet like) table editor
 class StockCostDialog(BaseEditor):
-    gladefile = "InitialStockDialog"
+    gladefile = "StockCostDialog"
     model_type = object
     title = _(u"Product - Stock Cost")
     size = (750, 450)
@@ -64,7 +64,7 @@ class StockCostDialog(BaseEditor):
     def _setup_widgets(self):
         self.branch_label.set_markup(
             _(u"Fixing stock cost for products in <b>%s</b>") %
-            api.escape(self._branch.person.name))
+            api.escape(self._branch.get_description()))
 
         items = ProductWithStockView.find_by_branch(self.store, self._branch)
         self._storables = [_TemporaryItem(s) for s in items]
@@ -72,18 +72,20 @@ class StockCostDialog(BaseEditor):
 
     def _get_columns(self):
         return [Column("code", title=_(u"Code"), data_type=str,
-                        sorted=True, width=120),
+                       sorted=True, width=120),
                 Column("description", title=_(u"Description"),
-                        data_type=str, expand=True),
+                       data_type=str, expand=True),
                 Column("stock_cost", title=_(u"Stock Cost"), width=120,
-                        data_type=currency, format_func=get_formatted_cost,
-                        editable=True)]
+                       data_type=currency, format_func=get_formatted_cost,
+                       editable=True)]
 
     def _validate_confirm(self, item, store):
         if (item.stock_cost is not ValueUnset and
             item.stock_cost > 0):
             storable = item.obj.product.storable
-            stock_item = store.fetch(storable.get_stock_item(self._branch))
+            # TODO: add batch information here. Should we edit the the cost of
+            # each batch individually, or one cost for all the batches?
+            stock_item = store.fetch(storable.get_stock_item(self._branch, None))
             stock_item.stock_cost = item.stock_cost
             self.retval.append(item.obj.product.sellable)
 
