@@ -32,6 +32,7 @@ from kiwi.currency import currency
 
 from stoqlib.domain.stockdecrease import StockDecrease, StockDecreaseItem
 from stoqlib.gui.editors.baseeditor import BaseEditor
+from stoqlib.gui.search.searchcolumns import IdentifierColumn
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -66,8 +67,7 @@ class StockDecreaseDetailsDialog(BaseEditor):
             self.notebook.remove_page(2)
 
     def _get_payment_columns(self):
-        return [Column("identifier", title=_("#"), data_type=str,
-                       width=50, format='%04d'),
+        return [IdentifierColumn("identifier"),
                 Column("method.description", title=_("Type"),
                        data_type=str),
                 Column("description", title=_("Description"),
@@ -80,7 +80,7 @@ class StockDecreaseDetailsDialog(BaseEditor):
                        data_type=currency),
                 Column("paid_value", title=_("Paid value"),
                        data_type=currency),
-               ]
+                ]
 
     def _get_product_columns(self):
         return [Column("sellable.code", title=_("Code"), data_type=str,
@@ -88,7 +88,7 @@ class StockDecreaseDetailsDialog(BaseEditor):
                 Column("sellable.description", title=_("Description"),
                        data_type=str, expand=True),
                 Column("quantity", title=_("Quantity"),
-                        data_type=int, justify=gtk.JUSTIFY_RIGHT),
+                       data_type=int, justify=gtk.JUSTIFY_RIGHT),
                 ]
 
     #
