@@ -29,13 +29,13 @@ import datetime
 import gtk
 from kiwi.currency import currency
 from kiwi.python import Settable
-from kiwi.ui.objectlist import Column, ColoredColumn
-from kiwi.ui.widgets.list import SummaryLabel
+from kiwi.ui.objectlist import Column, ColoredColumn, SummaryLabel
 
 from stoqlib.api import api
 from stoqlib.domain.person import Supplier
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.editors.personeditor import SupplierEditor
+from stoqlib.gui.search.searchcolumns import IdentifierColumn
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.defaults import payment_value_colorize
@@ -73,7 +73,7 @@ class SupplierDetailsDialog(BaseEditor):
                 qty = purchase_item.quantity
                 cost = purchase_item.cost
                 total_value = cost * qty
-                unit = purchase_item.sellable.get_unit_description()
+                unit = purchase_item.sellable.unit_description
                 qty_str = '%s %s' % (qty, unit)
                 product_codes = [item.code for item in product_dict.values()]
                 sellable = purchase_item.sellable
@@ -88,7 +88,7 @@ class SupplierDetailsDialog(BaseEditor):
                     table = product_dict[sellable]
                     table.qty_str = '%s %s' % (table._total_qty, table.unit)
                     table.total_value = table._total_qty * table.cost
-        self.products = product_dict.values()
+        self.products = list(product_dict.values())
 
     def _setup_widgets(self):
         self.purchases_list.set_columns(self._get_purchase_columns())
@@ -105,27 +105,25 @@ class SupplierDetailsDialog(BaseEditor):
         value_format = '<b>%s</b>'
         total_label = "<b>%s</b>" % api.escape(_("Total:"))
         purchases_summary_label = SummaryLabel(klist=self.purchases_list,
-                                              column='total',
-                                              label=total_label,
-                                              value_format=value_format)
+                                               column='total',
+                                               label=total_label,
+                                               value_format=value_format)
 
         purchases_summary_label.show()
         self.purchases_vbox.pack_start(purchases_summary_label, False)
 
     def _get_purchase_columns(self):
-        return [Column("identifier", title=_("#"),
-                       data_type=int, justify=gtk.JUSTIFY_RIGHT,
-                       format='%04d', width=90, sorted=True),
+        return [IdentifierColumn("identifier", sorted=True),
                 Column("open_date", title=_("Date"), data_type=datetime.date,
                        justify=gtk.JUSTIFY_RIGHT, width=80),
                 Column("status_str", title=_("Status"), width=80,
-                      data_type=str),
+                       data_type=str),
                 Column("total", title=_("Total"), justify=gtk.JUSTIFY_RIGHT,
                        data_type=currency, width=100)]
 
     def _get_product_columns(self):
         return [Column("code", title=_("Code"), data_type=str, width=130,
-                        sorted=True),
+                       sorted=True),
                 Column("description", title=_("Description"), data_type=str,
                        expand=True, searchable=True),
                 Column("qty_str", title=_("Total quantity"),
@@ -134,9 +132,7 @@ class SupplierDetailsDialog(BaseEditor):
                        data_type=currency, justify=gtk.JUSTIFY_RIGHT, )]
 
     def _get_payments_columns(self):
-        return [Column("identifier", title=_("#"),
-                       data_type=int, justify=gtk.JUSTIFY_RIGHT,
-                       format='%04d', width=50),
+        return [IdentifierColumn("identifier"),
                 Column("method.description", title=_("Type"),
                        data_type=str, width=90),
                 Column("description", title=_("Description"),
