@@ -28,18 +28,20 @@ import datetime
 
 import gtk
 from kiwi.currency import currency
-from kiwi.ui.search import DateSearchFilter, Today
-from kiwi.ui.widgets.list import Column, ColoredColumn
+from kiwi.ui.objectlist import Column, ColoredColumn
 
 from stoqlib.api import api
 from stoqlib.domain.till import TillEntry
-from stoqlib.gui.base.search import SearchDialog
+from stoqlib.gui.search.searchdialog import SearchDialog
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.tilleditor import (CashAdvanceEditor, CashInEditor,
                                             CashOutEditor)
-from stoqlib.gui.printing import print_report
 from stoqlib.gui.stockicons import (STOQ_MONEY, STOQ_MONEY_ADD,
                                     STOQ_MONEY_REMOVE)
+from stoqlib.gui.search.searchcolumns import IdentifierColumn
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.search.searchoptions import Today
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.defaults import payment_value_colorize
 from stoqlib.reporting.till import TillHistoryReport
@@ -49,7 +51,7 @@ _ = stoqlib_gettext
 
 class TillHistoryDialog(SearchDialog):
     size = (780, -1)
-    table = TillEntry
+    search_spec = TillEntry
     selection_mode = gtk.SELECTION_MULTIPLE
     searchbar_labels = _('Till Entries matching:')
     title = _('Till history')
@@ -59,8 +61,7 @@ class TillHistoryDialog(SearchDialog):
     #
 
     def get_columns(self, *args):
-        return [Column('identifier', _('Number'), data_type=int, width=100,
-                        format='%03d', sorted=True),
+        return [IdentifierColumn('identifier', sorted=True),
                 Column('date', _('Date'), data_type=datetime.date),
                 Column('time', _('Time'), data_type=datetime.time),
                 Column('description', _('Description'), data_type=str,
@@ -109,12 +110,11 @@ class TillHistoryDialog(SearchDialog):
         button.show()
 
     def _print_button_clicked(self, button):
-        till_entries = self.results.get_selected_rows() or list(self.results)
-        print_report(TillHistoryReport, self.results, till_entries,
+        print_report(TillHistoryReport, self.results, list(self.results),
                      filters=self.search.get_search_filters())
 
     def _run_editor(self, button, editor_class):
-        with api.trans() as store:
+        with api.new_store() as store:
             run_dialog(editor_class, self, store)
         if store.committed:
             self.search.refresh()
