@@ -25,17 +25,17 @@
 import datetime
 
 import gtk
-from kiwi.datatypes import  ValidationError
+from kiwi.datatypes import ValidationError
 from kiwi.ui.widgets.combo import ProxyComboBox
 from kiwi.ui.widgets.entry import ProxyEntry
 
 from stoqlib.api import api
 from stoqlib.domain.account import (Account, BankAccount,
                                     BillOption)
-from stoqlib.gui.accounttree import AccountTree
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.utils.printing import print_report
+from stoqlib.gui.widgets.accounttree import AccountTree
 from stoqlib.lib.boleto import (get_all_banks,
                                 get_bank_info_by_number,
                                 BoletoException)
@@ -62,7 +62,7 @@ class _TemporaryBankAccount(object):
 
     @property
     def options(self):
-        return self._options.values()
+        return list(self._options.values())
 
     def set_option(self, option, value):
         self._options[option] = _Option(option, value)
@@ -112,7 +112,7 @@ class AccountEditor(BaseEditor):
         self.tree_box.pack_start(self.parent_accounts)
         self.tree_box.reorder_child(self.parent_accounts, 0)
 
-        if self.model == sysparam(self.store).IMBALANCE_ACCOUNT:
+        if sysparam.compare_object('IMBALANCE_ACCOUNT', self.model):
             self.account_type.set_sensitive(False)
 
         self.account_type.prefill(Account.account_type_descriptions)
@@ -350,7 +350,7 @@ class AccountEditor(BaseEditor):
             nosso_numero=u'624533',
             numero_documento=u'1138',
             sacado=[_(u"Drawee"), _(u"Address"), _(u"Details")],
-            cedente=_(u"Supplier"),
+            cedente=[_(u"Supplier"), _(u"Address"), _(u"Details"), ("CNPJ")],
             demonstrativo=[_(u"Demonstration")],
             instrucoes=[_(u"Instructions")],
             agencia=self.bank_model.bank_branch,
@@ -393,20 +393,20 @@ class AccountEditor(BaseEditor):
         if bank_info:
             try:
                 bank_info.validate_field(value)
-            except BoletoException, e:
+            except BoletoException as e:
                 return ValidationError(str(e))
 
     def _on_bank_account__validate(self, entry, value, bank_info):
         if bank_info:
             try:
                 bank_info.validate_field(value)
-            except BoletoException, e:
+            except BoletoException as e:
                 return ValidationError(str(e))
 
     def _on_bank_option__validate(self, entry, value, bank_info, option):
         try:
             bank_info.validate_option(option, value)
-        except BoletoException, e:
+        except BoletoException as e:
             return ValidationError(str(e))
         self.bank_model.set_option(option, value)
 
