@@ -23,21 +23,23 @@
 ##
 """ Base classes for editors """
 
+import logging
+
 import gtk
 from gtk import gdk
 from kiwi.enums import ListType
-from kiwi.log import Logger
 from kiwi.ui.delegates import GladeSlaveDelegate
 from kiwi.ui.listdialog import ListContainer
 from kiwi.ui.widgets.label import ProxyLabel
 
 from stoqlib.database.runtime import StoqlibStore
 from stoqlib.gui.base.dialogs import RunnableView, BasicDialog, run_dialog
-from stoqlib.gui.events import EditorSlaveCreateEvent
+from stoqlib.gui.events import (EditorSlaveCreateEvent, EditorSlaveConfirmEvent,
+                                EditorCreateEvent)
 from stoqlib.lib.decorators import public
 from stoqlib.lib.translation import stoqlib_gettext
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 _ = stoqlib_gettext
 
@@ -65,16 +67,26 @@ class BaseEditorSlave(GladeSlaveDelegate):
     fields = None
     proxy_widgets = ()
 
-    def __init__(self, store, model=None, visual_mode=False):
+    def __init__(self, store, model=None, visual_mode=False, edit_mode=None):
         """ A base class for editor slaves inheritance
 
         :param store: a store
         :param model: the object model tied with the proxy widgets
         :param visual_mode: does this slave must be opened in visual mode?
                             if so, all the proxy widgets will be disable
+        :param edit_mode: indicate if the slave are being edited or its a new one
+                          The editor that creates the slave should pass his
+                          property edit_mode to the slaves.
+                          If None self.edit_mode will be defined accordingly to
+                          the model
         """
         self.store = store
-        self.edit_mode = model is not None
+        # FIXME: Need to check if we need to add edit_mode parameter for all classes
+        # that inherit from BaseEditor
+        if edit_mode is not None:
+            self.edit_mode = edit_mode
+        else:
+            self.edit_mode = model is not None
         self.visual_mode = visual_mode
 
         if model:
@@ -84,23 +96,22 @@ class BaseEditorSlave(GladeSlaveDelegate):
             model = self.create_model(self.store)
 
             if model is None:
-                raise ValueError(
-                    "%s.create_model() must return a valid model, not %r" % (
-                    self.__class__.__name__, model))
+                fmt = "%s.create_model() must return a valid model, not %r"
+                raise ValueError(fmt % (self.__class__.__name__, model))
 
         log.info("%s editor using a %smodel %s" % (
             self.__class__.__name__, created, type(model).__name__))
 
         if self.model_type:
             if not isinstance(model, self.model_type):
+                fmt = '%s editor requires a model of type %s, got a %r'
                 raise TypeError(
-                    '%s editor requires a model of type %s, got a %r' % (
-                    self.__class__.__name__, self.model_type.__name__,
-                    model))
+                    fmt % (self.__class__.__name__,
+                           self.model_type.__name__,
+                           model))
         else:
-            raise ValueError("Editor %s must define a model_type "
-                             "attribute" % (
-                self.__class__.__name__, ))
+            fmt = "Editor %s must define a model_type attribute"
+            raise ValueError(fmt % (self.__class__.__name__, ))
         self.model = model
 
         GladeSlaveDelegate.__init__(self, gladefile=self.gladefile)
@@ -120,8 +131,19 @@ class BaseEditorSlave(GladeSlaveDelegate):
         for widget_name in widgets:
             widget = getattr(self, widget_name)
             if isinstance(widget, ProxyLabel):
-                continue
-            widget.set_sensitive(False)
+                pass
+            elif isinstance(widget, gtk.Entry):
+                # First, we need to be able to select text from entries
+                widget.set_editable(False)
+                # Second, make sure they don't look like they're editable,
+                # copy over the insentive style
+                style = widget.get_style()
+                widget.modify_text(
+                    gtk.STATE_NORMAL, style.text[gtk.STATE_INSENSITIVE])
+                widget.modify_base(
+                    gtk.STATE_NORMAL, style.base[gtk.STATE_INSENSITIVE])
+            else:
+                widget.set_sensitive(False)
 
         if self.fields:
             for field in self.fields.values():
@@ -157,6 +179,8 @@ class BaseEditorSlave(GladeSlaveDelegate):
         for slave in slaves:
             slave.on_confirm()
 
+        EditorSlaveConfirmEvent.emit(self, self.model, self.store, self.visual_mode)
+
         return True
 
     def cancel(self):
@@ -185,8 +209,8 @@ class BaseEditorSlave(GladeSlaveDelegate):
         :param store: a store
         """
         raise TypeError(
-                "%r needs a model, got None. Perhaps you want to "
-                "implement create_model?" % (self.__class__.__name__))
+            "%r needs a model, got None. Perhaps you want to "
+            "implement create_model?" % (self.__class__.__name__))
 
     def setup_proxies(self):
         """A subclass can override this to setup proxies
@@ -287,8 +311,6 @@ class BaseEditor(BaseEditorSlave, RunnableView):
     form_holder_name = 'toplevel'
 
     def __init__(self, store, model=None, visual_mode=False):
-        if store is not None and isinstance(store, StoqlibStore):
-            store.needs_retval = True
         self._confirm_disabled = False
 
         # FIXME:
@@ -320,6 +342,9 @@ class BaseEditor(BaseEditorSlave, RunnableView):
 
         self.register_validate_function(self._validation_function)
         self.force_validation()
+        # We need to use self.model instead of model, since BaseEditorSlave
+        # will create one if its None
+        EditorCreateEvent.emit(self, self.model, store, visual_mode)
 
     def _get_title_format(self):
         if self.visual_mode:
@@ -454,11 +479,13 @@ class BaseEditor(BaseEditorSlave, RunnableView):
         """
         self.main_dialog.set_confirm_widget(widget_name)
 
-    def set_message(self, message, message_type=gtk.MESSAGE_INFO):
+    def set_message(self, message, message_type=None):
         """Sets a message for this editor
         :param message: message to add
         :param message_type: type of message to add
         """
+        if message_type is None:
+            message_type = gtk.MESSAGE_INFO
         self.main_dialog.set_message(message, message_type)
 
     # RunnableView
