@@ -22,14 +22,13 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 from kiwi.ui.forms import ChoiceField, DateField, TextField, MultiLineField
 
 from stoqlib.api import api
 from stoqlib.domain.person import Client, CreditCheckHistory
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.fields import PersonField
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -41,14 +40,14 @@ class CreditCheckHistoryEditor(BaseEditor):
     size = (400, -1)
 
     fields = dict(
-        client=PersonField(_('Client'), proxy=True, person_type=Client,
-                           mandatory=True),
+        client_id=PersonField(_('Client'), proxy=True, person_type=Client,
+                              mandatory=True),
         identifier=TextField(_('Identifier'), proxy=True, mandatory=True),
         status=ChoiceField('Status', mandatory=True),
         check_date=DateField(_('Date'), proxy=True),
         user=ChoiceField(_('User')),
         notes=MultiLineField(_('Notes'), proxy=True),
-        )
+    )
 
     def __init__(self, store, model, client, visual_mode=None):
         self._client = client
@@ -57,18 +56,18 @@ class CreditCheckHistoryEditor(BaseEditor):
         BaseEditor.__init__(self, store, model, visual_mode)
 
         if visual_mode or client:
-            self.client_add_button.hide()
-            self.client_edit_button.hide()
+            self.client_id_add_button.hide()
+            self.client_id_edit_button.hide()
 
         if self.model.client:
             self.set_description(_('client credit check history for %s') %
-                                   self.model.client.person.name)
-            self.client.set_sensitive(False)
+                                 self.model.client.person.name)
+            self.client_id.set_sensitive(False)
         else:
             self.set_description(_('client credit check history'))
 
     def create_model(self, store):
-        return CreditCheckHistory(check_date=datetime.date.today(),
+        return CreditCheckHistory(check_date=localtoday().date(),
                                   identifier=u'',
                                   status=CreditCheckHistory.STATUS_NOT_INCLUDED,
                                   client=self._client,
