@@ -36,7 +36,7 @@ from stoqlib.domain.invoice import InvoiceLayout, InvoiceField, InvoicePrinter
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.station import BranchStation
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.gui.fieldgrid import FieldGrid
+from stoqlib.gui.widgets.fieldgrid import FieldGrid
 from stoqlib.lib.invoice import get_invoice_fields, SaleInvoice
 from stoqlib.lib.message import info
 from stoqlib.lib.translation import stoqlib_gettext as _
@@ -191,7 +191,7 @@ class InvoiceLayoutEditor(BaseEditor):
 
     def _field_removed(self, grid_field):
         invoice_field = grid_field.model
-        InvoiceField.delete(invoice_field.id, self.store)
+        self.store.remove(invoice_field)
 
     def _print_preview(self):
         # Get the last opened date
@@ -209,7 +209,7 @@ class InvoiceLayoutEditor(BaseEditor):
 
         for page in invoice_pages:
             for line in page:
-                print repr(line.tostring())
+                print(repr(line.tostring()))
 
 
 class InvoicePrinterEditor(BaseEditor):
@@ -232,11 +232,11 @@ class InvoicePrinterEditor(BaseEditor):
     def setup_proxies(self):
         stations = BranchStation.get_active_stations(self.store)
         self.station.prefill([(station.name, station)
-             for station in stations])
+                              for station in stations])
 
         layouts = self.store.find(InvoiceLayout)
         self.layout.prefill([(layout.get_description(), layout)
-             for layout in layouts.order_by(InvoiceLayout.description)])
+                             for layout in layouts.order_by(InvoiceLayout.description)])
 
         self.proxy = self.add_proxy(self.model,
                                     InvoicePrinterEditor.proxy_widgets)
