@@ -52,11 +52,14 @@ from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi import ValueUnset
 from kiwi.ui.objectlist import Column
+from kiwi.ui.forms import ChoiceField, IntegerField
 
 from stoqlib.api import api
 from stoqlib.domain.account import Account
-from stoqlib.domain.payment.card import CardPaymentDevice, CardOperationCost
-from stoqlib.domain.payment.card import CreditProvider, CreditCardData
+from stoqlib.domain.payment.card import (CreditProvider,
+                                         CreditCardData,
+                                         CardPaymentDevice,
+                                         CardOperationCost)
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.lists import ModelListSlave
@@ -264,10 +267,11 @@ class CardOperationCostEditor(BaseEditor):
             return ValidationError(_('Installments start should be lower '
                                      'or equal installments end'))
 
-        if not CardOperationCost.validate_installment_range(device=self.model.device,
-                        provider=self.model.provider, card_type=self.model.card_type,
-                        start=start, end=end, ignore=self.model.real_model.id,
-                        store=self.store):
+        if not CardOperationCost.validate_installment_range(
+                device=self.model.device,
+                provider=self.model.provider, card_type=self.model.card_type,
+                start=start, end=end, ignore=self.model.real_model.id,
+                store=self.store):
             return ValidationError(_('The installments range is conflicting '
                                      'with another configuration'))
 
@@ -285,16 +289,50 @@ class CreditProviderEditor(BaseEditor):
     """
     model_type = CreditProvider
     gladefile = 'CreditProviderEditor'
-    proxy_widgets = ['provider_id', 'short_name', 'open_contract_date']
+    proxy_widgets = ['provider_id', 'short_name',
+                     'max_installments', 'default_device', 'open_contract_date']
 
     def setup_proxies(self):
+        self._setup_widgets()
         self.proxy = self.add_proxy(self.model,
                                     CreditProviderEditor.proxy_widgets)
 
+    def _setup_widgets(self):
+        """ Populate device widgets
+        """
+        devices = CardPaymentDevice.get_devices(self.store)
+        self.default_device.prefill(api.for_combo(devices,
+                                                  empty=_(u"No device")))
+
     def create_model(self, store):
         return CreditProvider(store=store)
 
 
+class CardPaymentDetailsEditor(BaseEditor):
+    """Editor for :obj: `stoqlib.domain.payment.CreditCardData`
+    """
+    model_type = CreditCardData
+
+    fields = dict(
+        device=ChoiceField(_('Device'), proxy=True, mandatory=True),
+        provider=ChoiceField(_('Provider'), proxy=True, mandatory=True),
+        auth=IntegerField(_('Authorization'), proxy=True, mandatory=True)
+    )
+
+    def __init__(self, store, model, visual_mode=None):
+        self.fields['device'].values = api.for_combo(
+            CardPaymentDevice.get_devices(store))
+        self.fields['provider'].values = api.for_combo(
+            CreditProvider.get_card_providers(store))
+        BaseEditor.__init__(self, store, model)
+
+    def on_confirm(self):
+        self.model.update_card_data(device=self.model.device,
+                                    provider=self.model.provider,
+                                    card_type=self.model.card_type,
+                                    installments=self.model.installments)
+
+
 #
 #   Slaves
 #
@@ -353,7 +391,8 @@ class ProviderListSlave(ModelListSlave):
     columns = [
         Column('short_name', title=_('Name'),
                data_type=str, expand=True),
-        ]
+        Column('max_installments', title=_('Max Installments'), data_type=int)
+    ]
 
     def populate(self):
         providers = self.store.find(CreditProvider)
@@ -369,7 +408,7 @@ class CardDeviceListSlave(ModelListSlave):
     columns = [
         Column('description', title=_('Description'),
                data_type=str, expand=True),
-        ]
+    ]
 
     def populate(self):
         devices = CardPaymentDevice.get_devices(self.store)
@@ -391,8 +430,10 @@ class CardOperationCostListSlave(ModelListSlave):
     model_type = CardOperationCost
 
     columns = [
-        Column('description', title=_('Description'), data_type=str, expand=True),
-        Column('installment_range_as_string', title=_('Installments'), data_type=str),
+        Column('description', title=_('Description'), data_type=str,
+               expand=True),
+        Column('installment_range_as_string', title=_('Installments'),
+               data_type=str),
         Column('payment_days', title=_('Days'), data_type=int),
         # Translators: Fee is Taxa in pt_BR
         Column('fee', title=_('Fee'), data_type=Decimal,
