@@ -24,7 +24,6 @@
 """ Editors definitions for products"""
 
 from decimal import Decimal
-import sys
 
 import gtk
 from kiwi.currency import currency
@@ -43,7 +42,7 @@ from stoqlib.domain.sellable import (Sellable,
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.editors.sellableeditor import SellableEditor
-from stoqlib.lib.defaults import quantize
+from stoqlib.lib.defaults import quantize, MAX_INT
 from stoqlib.lib.message import info
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
@@ -71,12 +70,12 @@ class TemporaryProductComponent(object):
             self.code = sellable.code
             self.description = sellable.get_description()
             self.category = sellable.get_category_description()
-            self.unit = sellable.get_unit_description()
+            self.unit = sellable.unit_description
             self.production_cost = self.component.get_production_cost()
 
     def _get_product_component(self, store):
         return store.find(ProductComponent,
-            product=self.product, component=self.component).one()
+                          product=self.product, component=self.component).one()
 
     #
     # Public API
@@ -88,8 +87,9 @@ class TemporaryProductComponent(object):
     def delete_product_component(self, store):
         component = self._get_product_component(store)
         if component is not None:
-            ProductComponent.delete(component.id,
-                                    store=store)
+            # FIXME: bug 5581 Check if we can really remove this object when
+            # working with synced databases
+            store.remove(component)
 
     def add_or_update_product_component(self, store):
         component = self._get_product_component(store)
@@ -126,7 +126,7 @@ class QualityTestEditor(BaseEditor):
         self.sizegroup1.add_widget(self.decimal_value)
         self.sizegroup1.add_widget(self.boolean_value)
         self.test_type.prefill([(value, key)
-            for key, value in ProductQualityTest.types.items()])
+                                for key, value in ProductQualityTest.types.items()])
         self.boolean_value.prefill([(_('True'), True), (_(('False')), False)])
 
         # Editing values
@@ -185,11 +185,11 @@ class ProductSupplierEditor(BaseEditor):
         else:
             description = unit.description
         self.unit_label.set_text(description)
-        self.base_cost.set_digits(sysparam(self.store).COST_PRECISION_DIGITS)
+        self.base_cost.set_digits(sysparam.get_int('COST_PRECISION_DIGITS'))
         self.base_cost.set_adjustment(
-            gtk.Adjustment(lower=0, upper=sys.maxint, step_incr=1))
+            gtk.Adjustment(lower=0, upper=MAX_INT, step_incr=1))
         self.minimum_purchase.set_adjustment(
-            gtk.Adjustment(lower=0, upper=sys.maxint, step_incr=1))
+            gtk.Adjustment(lower=0, upper=MAX_INT, step_incr=1))
 
     #
     # BaseEditor hooks
@@ -225,9 +225,13 @@ class ProductSupplierEditor(BaseEditor):
             return
         d = {self.model_type.supplier_id: self.model.supplier.id,
              self.model_type.supplier_code: value}
-        if self.model.check_unique_tuple_exists(d):
-            return ValidationError(_("Product code already exists for this "
-                                     "supplier"))
+
+        supplier_info = self.model.check_unique_tuple_exists(d)
+        if supplier_info is not None:
+            desc = supplier_info.product.sellable.description
+            return ValidationError(
+                _("This code already exists for this supplier "
+                  "on product '%s'") % (desc, ))
 
 
 #
@@ -244,7 +248,7 @@ class ProductComponentEditor(BaseEditor):
     def _setup_widgets(self):
         self.component_description.set_text(self.model.description)
         self.quantity.set_adjustment(
-            gtk.Adjustment(lower=0, upper=sys.maxint, step_incr=1,
+            gtk.Adjustment(lower=0, upper=MAX_INT, step_incr=1,
                            page_incr=10))
         # set a default quantity value for new components
         if not self.model.quantity:
@@ -268,9 +272,9 @@ class ProductComponentEditor(BaseEditor):
 
     def on_quantity__validate(self, widget, value):
         if not value > 0:
-            #FIXME: value < upper bound
+            # FIXME: value < upper bound
             return ValidationError(_(u'The component quantity must be '
-                                    'greater than zero.'))
+                                     'greater than zero.'))
 
 
 class ProductEditor(SellableEditor):
@@ -278,45 +282,48 @@ class ProductEditor(SellableEditor):
     model_type = Product
     help_section = 'product'
     ui_form_name = u'product'
+    product_widgets = ['product_type_str']
+    proxy_widgets = SellableEditor.proxy_widgets + product_widgets
 
-    _model_created = False
-
-    def __init__(self, store, model=None, visual_mode=False):
+    def __init__(self, store, model=None, visual_mode=False,
+                 product_type=Product.TYPE_COMMON):
+        self._product_type = product_type
         SellableEditor.__init__(self, store, model, visual_mode=visual_mode)
         # This can't be done in setup_slaves() as we need to access
         # self.main_dialog when setting up the quality test slave
         self._add_extra_tabs()
 
-    def get_taxes(self):
-        query = (SellableTaxConstant.tax_type != int(TaxType.SERVICE))
-        constants = self.store.find(
-            SellableTaxConstant, query).order_by(SellableTaxConstant.id)
-        return [(c.description, c) for c in constants]
-
-    def update_status_unavailable_label(self):
-        text = ''
-        if self.statuses_combo.read() == Sellable.STATUS_UNAVAILABLE:
-            text = ("<b>%s</b>"
-                    % api.escape(
-                _("This status changes automatically when the\n"
-                  "product is purchased or an inicial stock is added.")))
-
-        self.status_unavailable_label.set_text(text)
-
     #
-    # BaseEditor
+    # Private
     #
 
-    def setup_slaves(self):
-        from stoqlib.gui.slaves.productslave import ProductDetailsSlave
-        details_slave = ProductDetailsSlave(self.store, self.model.sellable,
-                                            self.db_form, self.visual_mode)
-        self.add_extra_tab(_(u'Details'), details_slave)
-
     def _add_extra_tabs(self):
         for tabname, tabslave in self.get_extra_tabs():
             self.add_extra_tab(tabname, tabslave)
 
+    #
+    #  SellableEditor
+    #
+
+    def get_taxes(self):
+        query = (SellableTaxConstant.tax_type != int(TaxType.SERVICE))
+        constants = self.store.find(
+            SellableTaxConstant, query).order_by(SellableTaxConstant.description)
+        return [(c.description, c) for c in constants]
+
+    def setup_slaves(self):
+        super(ProductEditor, self).setup_slaves()
+
+        from stoqlib.gui.slaves.productslave import ProductInformationSlave
+        info_slave = ProductInformationSlave(self.store, self.model, self.db_form,
+                                             visual_mode=self.visual_mode)
+        self.add_extra_tab(_(u'Details'), info_slave)
+
+    def setup_proxies(self):
+        super(ProductEditor, self).setup_proxies()
+
+        self.add_proxy(self.model, self.product_widgets)
+
     def get_extra_tabs(self):
         from stoqlib.gui.slaves.productslave import (ProductTaxSlave,
                                                      ProductSupplierSlave)
@@ -331,25 +338,32 @@ class ProductEditor(SellableEditor):
         return extra_tabs
 
     def setup_widgets(self):
-        self.cost.set_digits(sysparam(self.store).COST_PRECISION_DIGITS)
-        self.consignment_yes_button.set_active(self.model.consignment)
-        self.consignment_yes_button.set_sensitive(self._model_created)
-        self.consignment_no_button.set_sensitive(self._model_created)
-        self.update_status_unavailable_label()
+        self.cost.set_digits(sysparam.get_int('COST_PRECISION_DIGITS'))
         self.description.grab_focus()
 
     def create_model(self, store):
         self._model_created = True
-        tax_constant = sysparam(store).DEFAULT_PRODUCT_TAX_CONSTANT
         sellable = Sellable(store=store)
-        sellable.tax_constant = tax_constant
-        sellable.unit = sysparam(self.store).SUGGESTED_UNIT
+        sellable.tax_constant_id = sysparam.get_object_id('DEFAULT_PRODUCT_TAX_CONSTANT')
+        sellable.unit_id = sysparam.get_object_id('SUGGESTED_UNIT')
         model = Product(store=store, sellable=sellable)
-        Storable(product=model, store=store)
+        if self._product_type != Product.TYPE_WITHOUT_STOCK:
+            storable = Storable(product=model, store=store)
+
+        if self._product_type == Product.TYPE_BATCH:
+            storable.is_batch = True
+        elif self._product_type == Product.TYPE_WITHOUT_STOCK:
+            model.manage_stock = False
+        elif self._product_type == Product.TYPE_CONSIGNED:
+            model.consignment = True
+
         return model
 
-    def on_consignment_yes_button__toggled(self, widget):
-        self.model.consignment = widget.get_active()
+    def on_confirm(self):
+        # The user choose not to manage stock for this product, so we must
+        # remove the storable.
+        if not self.model.manage_stock and self.model.storable:
+            self.store.remove(self.model.storable)
 
 
 class ProductionProductEditor(ProductEditor):
@@ -372,7 +386,7 @@ class ProductionProductEditor(ProductEditor):
                                                      ProductComponentSlave,
                                                      ProductQualityTestSlave)
         self.component_slave = ProductComponentSlave(self.store, self.model,
-                                                      self.visual_mode)
+                                                     self.visual_mode)
         tax_slave = ProductTaxSlave(self.store, self.model, self.visual_mode)
         quality_slave = ProductQualityTestSlave(self, self.store, self.model,
                                                 self.visual_mode)
@@ -397,13 +411,22 @@ class ProductionProductEditor(ProductEditor):
 class ProductStockEditor(BaseEditor):
     model_name = _('Product')
     model_type = Product
-    gladefile = 'HolderTemplate'
+    gladefile = 'ProductStockEditor'
 
     def setup_slaves(self):
-        from stoqlib.gui.slaves.productslave import ProductDetailsSlave
-        details_slave = ProductDetailsSlave(self.store, self.model.sellable)
-        details_slave.hide_stock_details()
-        self.attach_slave('place_holder', details_slave)
+        from stoqlib.gui.slaves.productslave import ProductInformationSlave
+        info_slave = ProductInformationSlave(self.store, self.model,
+                                             visual_mode=self.visual_mode)
+        info_slave.nfe_frame.hide()
+        self.attach_slave('information_holder', info_slave)
+
+        from stoqlib.gui.slaves.sellableslave import SellableDetailsSlave
+        details_slave = SellableDetailsSlave(self.store, self.model.sellable,
+                                             visual_mode=self.visual_mode)
+        self.attach_slave('details_holder', details_slave)
+
+        # Make everything aligned by pytting notes_lbl on the same size group
+        info_slave.left_labels_group.add_widget(details_slave.notes_lbl)
 
 
 class ProductManufacturerEditor(BaseEditor):
@@ -413,7 +436,7 @@ class ProductManufacturerEditor(BaseEditor):
 
     fields = dict(
         name=TextField(_('Name'), proxy=True, mandatory=True),
-        )
+    )
 
     def create_model(self, store):
         return ProductManufacturer(name=u'', store=store)
