@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,10 +23,7 @@
 ##
 """ Editors definitions for sellable"""
 
-import sys
-
 import gtk
-
 from kiwi.datatypes import ValidationError
 from kiwi.ui.forms import PercentageField, TextField
 from stoqdrivers.enum import TaxType, UnitType
@@ -39,15 +36,17 @@ from stoqlib.domain.sellable import (SellableCategory, Sellable,
                                      SellableTaxConstant,
                                      ClientCategoryPrice)
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.databaseform import DatabaseForm
 from stoqlib.gui.dialogs.labeldialog import PrintLabelEditor
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.editors.categoryeditor import SellableCategoryEditor
-from stoqlib.gui.printing import print_labels
 from stoqlib.gui.slaves.commissionslave import CommissionSlave
+from stoqlib.gui.utils.databaseform import DatabaseForm
+from stoqlib.gui.utils.printing import print_labels
+from stoqlib.lib.defaults import MAX_INT
 from stoqlib.lib.formatters import get_price_format_str
 from stoqlib.lib.message import yesno, warning
 from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.stringutils import next_value_for
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -71,7 +70,7 @@ class SellableTaxConstantEditor(BaseEditor):
     fields = dict(
         description=TextField(_('Name'), proxy=True, mandatory=True),
         tax_value=PercentageField(_('Value'), proxy=True, mandatory=True),
-        )
+    )
 
     #
     # BaseEditor
@@ -86,7 +85,7 @@ class SellableTaxConstantEditor(BaseEditor):
 
 class BasePriceEditor(BaseEditor):
     gladefile = 'SellablePriceEditor'
-    proxy_widgets = ('cost', 'markup', 'max_discount', 'price')
+    proxy_widgets = ['markup', 'cost', 'max_discount', 'price']
 
     def set_widget_formats(self):
         widgets = (self.markup, self.max_discount)
@@ -101,6 +100,13 @@ class BasePriceEditor(BaseEditor):
         return _('Price settings')
 
     def setup_proxies(self):
+        self._editing_price = True
+        self.markup.update(self.model.markup)
+
+        # These are used to avoid circular updates when changing price or markup
+        self._editing_price = False
+        self._editing_markup = False
+
         self.set_widget_formats()
         self.main_proxy = self.add_proxy(self.model, self.proxy_widgets)
         if self.model.markup is not None:
@@ -118,14 +124,24 @@ class BasePriceEditor(BaseEditor):
             return ValidationError(_("Price cannot be zero or negative"))
 
     def after_price__content_changed(self, entry_box):
-        self.handler_block(self.markup, 'changed')
-        self.main_proxy.update("markup")
-        self.handler_unblock(self.markup, 'changed')
+        # If markup is being edited, dont update the price, or the markup may be
+        # programatically changed (if there was any rounding involved)
+        if self._editing_markup:
+            return
+
+        self._editing_price = True
+        self.markup.update(self.model.markup)
+        self._editing_price = False
 
     def after_markup__content_changed(self, spin_button):
-        self.handler_block(self.price, 'changed')
+        # Like above, if the price is being edited, dont update the markup, or
+        # the price may change again.
+        if self._editing_price:
+            return
+
+        self._editing_markup = True
         self.main_proxy.update("price")
-        self.handler_unblock(self.price, 'changed')
+        self._editing_markup = False
 
 
 class SellablePriceEditor(BasePriceEditor):
@@ -174,23 +190,23 @@ class SellableEditor(BaseEditor):
     gladefile = 'SellableEditor'
     confirm_widgets = ['description', 'cost', 'price']
     ui_form_name = None
-    sellable_tax_widgets = ('tax_constant', 'tax_value', )
-    sellable_widgets = ('code',
+    sellable_tax_widgets = ['tax_constant', 'tax_value']
+    sellable_widgets = ['code',
                         'barcode',
                         'description',
                         'category_combo',
                         'cost',
                         'price',
-                        'statuses_combo',
+                        'status_str',
                         'default_sale_cfop',
-                        'unit_combo')
+                        'unit_combo']
     proxy_widgets = (sellable_tax_widgets + sellable_widgets)
 
     def __init__(self, store, model=None, visual_mode=False):
         from stoqlib.gui.slaves.sellableslave import CategoryPriceSlave
         is_new = not model
         self._sellable = None
-        self._demo_mode = sysparam(store).DEMO_MODE
+        self._demo_mode = sysparam.get_bool('DEMO_MODE')
         self._requires_weighing_text = (
             "<b>%s</b>" % api.escape(_("This unit type requires weighing")))
 
@@ -203,12 +219,12 @@ class SellableEditor(BaseEditor):
         if self._demo_mode:
             self._add_demo_warning()
 
-        # code suggestion
-        edit_code_product = sysparam(self.store).EDIT_CODE_PRODUCT
-        self.code.set_sensitive(not edit_code_product and not self.visual_mode)
+        # Code suggestion. We need to do this before disabling sensitivity,
+        # otherwise, the sellable will not be updated.
         if not self.code.read():
-            code = u'%d' % self._sellable.id
-            self.code.update(code)
+            self._update_default_sellable_code()
+        edit_code_product = sysparam.get_bool('EDIT_CODE_PRODUCT')
+        self.code.set_sensitive(not edit_code_product and not self.visual_mode)
 
         self.description.grab_focus()
         self.table.set_focus_chain([self.code,
@@ -217,8 +233,6 @@ class SellableEditor(BaseEditor):
                                     self.description,
                                     self.cost_hbox,
                                     self.price_hbox,
-                                    self.consignment_box,
-                                    self.statuses_combo,
                                     self.category_combo,
                                     self.tax_hbox,
                                     self.unit_combo,
@@ -235,12 +249,13 @@ class SellableEditor(BaseEditor):
 
         if not is_new and not self.visual_mode:
             # Although a sellable can be both removed/closed, we show only one,
-            # to avoid having *lots* of buttons. If it can be removed and
-            # closed, probably the user will prefer to remove
-            if self._sellable.can_remove():
-                self._add_delete_button()
-            elif self._sellable.is_closed():
+            # to avoid having *lots* of buttons. If it's closed, provide a way
+            # to reopen it, else, show a delete button if it can be removed
+            # or a close button if it can be closed
+            if self._sellable.is_closed():
                 self._add_reopen_button()
+            elif self._sellable.can_remove():
+                self._add_delete_button()
             elif self._sellable.can_close():
                 self._add_close_button()
 
@@ -251,10 +266,10 @@ class SellableEditor(BaseEditor):
         self._setup_ui_forms()
 
     def _add_demo_warning(self):
-        self.set_message(
-            _("This is a demostration mode of Stoq, you cannot create more than %d products.\n"
-              "To avoid this limitation, enable production mode.") % (
-            _DEMO_PRODUCT_LIMIT))
+        fmt = _("This is a demostration mode of Stoq, you cannot "
+                "create more than %d products.\n"
+                "To avoid this limitation, enable production mode.")
+        self.set_message(fmt % (_DEMO_PRODUCT_LIMIT))
         if self.store.find(Sellable).count() > _DEMO_PRODUCT_LIMIT:
             self.disable_ok()
 
@@ -286,6 +301,10 @@ class SellableEditor(BaseEditor):
         self._add_extra_button(label, None,
                                self._on_reopen_sellable_button__clicked)
 
+    def _update_default_sellable_code(self):
+        code = Sellable.get_max_value(self.store, Sellable.code)
+        self.code.update(next_value_for(code))
+
     def _setup_ui_forms(self):
         if not self.db_form:
             return
@@ -314,17 +333,17 @@ class SellableEditor(BaseEditor):
 
     def set_widget_formats(self):
         for widget in (self.cost, self.price):
-            widget.set_adjustment(gtk.Adjustment(lower=0, upper=sys.maxint,
+            widget.set_adjustment(gtk.Adjustment(lower=0, upper=MAX_INT,
                                                  step_incr=1))
         self.requires_weighing_label.set_size("small")
         self.requires_weighing_label.set_text("")
-        self.status_unavailable_label.set_size("small")
-        self.status_unavailable_label.set_text("")
 
     def edit_sale_price(self):
         sellable = self.model.sellable
         self.store.savepoint('before_run_editor_sellable_price')
-        result = run_dialog(SellablePriceEditor, self, self.store, sellable)
+        result = run_dialog(SellablePriceEditor,
+                            self.get_toplevel().get_toplevel(),
+                            self.store, sellable)
         if result:
             self.sellable_proxy.update('price')
         else:
@@ -371,10 +390,6 @@ class SellableEditor(BaseEditor):
         self._fill_categories()
         self.edit_category.set_sensitive(False)
 
-        self.statuses_combo.prefill(
-                    [(v, k) for k, v in Sellable.statuses.items()])
-        self.statuses_combo.set_sensitive(False)
-
         cfops = self.store.find(CfopData)
         self.default_sale_cfop.prefill(api.for_combo(cfops, empty=''))
 
@@ -404,6 +419,15 @@ class SellableEditor(BaseEditor):
 
         self.update_requires_weighing_label()
 
+    def setup_slaves(self):
+        from stoqlib.gui.slaves.sellableslave import SellableDetailsSlave
+        details_slave = SellableDetailsSlave(self.store, self.model.sellable,
+                                             visual_mode=self.visual_mode)
+        self.attach_slave('slave_holder', details_slave)
+
+        # Make everything aligned by pytting notes_lbl on the same size group
+        self.left_labels_group.add_widget(details_slave.notes_lbl)
+
     def _run_category_editor(self, category=None):
         self.store.savepoint('before_run_editor_sellable_category')
         model = run_dialog(SellableCategoryEditor, self, self.store, category)
@@ -420,27 +444,35 @@ class SellableEditor(BaseEditor):
     def _on_delete_button__clicked(self, button, parent_button_label=None):
         sellable_description = self._sellable.get_description()
         msg = (_("This will delete '%s' from the database. Are you sure?")
-                 % sellable_description)
+               % sellable_description)
         if not yesno(msg, gtk.RESPONSE_NO, _("Delete"), _("Keep")):
             return
 
         try:
             self._sellable.remove()
-        except IntegrityError, details:
+        except IntegrityError as details:
             warning(_("It was not possible to remove '%s'")
-                      % sellable_description, str(details))
+                    % sellable_description, str(details))
             return
 
-        self.confirm()
+        # We are doing this by hand instead of calling confirm/cancel because,
+        # if we call self.cancel(), the transaction will not be committed. If
+        # we call self.confirm(), it will, but some on_confirm hooks (like
+        # ProductComponentSlave's one) will try to create other objects and
+        # relate them with this product that doesn't exist anymore (we removed
+        # them above), resulting in an IntegrityError.
+        self.retval = self.model
+        self.store.retval = self.retval
+        self.main_dialog.close()
 
     def _on_close_sellable_button__clicked(self, button,
                                            parent_button_label=None):
         msg = (_("Do you really want to close '%s'?\n"
                  "Please note that when it's closed, you won't be able to "
                  "commercialize it anymore.")
-                 % self._sellable.get_description())
+               % self._sellable.get_description())
         if not yesno(msg, gtk.RESPONSE_NO,
-                      parent_button_label, _("Don't close")):
+                     parent_button_label, _("Don't close")):
             return
 
         self._sellable.close()
@@ -455,7 +487,7 @@ class SellableEditor(BaseEditor):
                      parent_button_label, _("Keep closed")):
             return
 
-        self._sellable.set_unavailable()
+        self._sellable.set_available()
         self.confirm()
 
     def on_category_combo__content_changed(self, category):
@@ -510,11 +542,21 @@ class SellableEditor(BaseEditor):
 
 def test_sellable_tax_constant():  # pragma nocover
     ec = api.prepare_test()
-    tax_constant = api.sysparam(ec.store).DEFAULT_PRODUCT_TAX_CONSTANT
+    tax_constant = api.sysparam.get_object(ec.store, 'DEFAULT_PRODUCT_TAX_CONSTANT')
     run_dialog(SellableTaxConstantEditor,
-                       parent=None, store=ec.store, model=tax_constant)
-    print tax_constant
+               parent=None, store=ec.store, model=tax_constant)
+    print(tax_constant)
+
+
+def test_price_editor():  # pragma nocover
+    from decimal import Decimal
+    ec = api.prepare_test()
+    sellable = ec.create_sellable()
+    sellable.cost = Decimal('15.55')
+    sellable.price = Decimal('21.50')
+    run_dialog(SellablePriceEditor,
+               parent=None, store=ec.store, model=sellable)
 
 
 if __name__ == '__main__':  # pragma nocover
-    test_sellable_tax_constant()
+    test_price_editor()
