@@ -23,18 +23,16 @@
 ##
 """ Service item editor implementation """
 
-import datetime
-
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 
 from stoqdrivers.enum import TaxType
 
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.parameters import sysparam
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.editors.sellableeditor import SellableEditor
-from stoqlib.gui.slaves.sellableslave import SellableDetailsSlave
 from stoqlib.domain.service import Service
 from stoqlib.domain.sellable import (Sellable,
                                      SellableTaxConstant)
@@ -73,7 +71,7 @@ class ServiceItemEditor(BaseEditor):
     #
 
     def on_estimated_fix_date__validate(self, widget, date):
-        if date < datetime.date.today():
+        if date < localtoday().date():
             return ValidationError(_("Expected receival date must be set to a future date"))
 
 
@@ -82,34 +80,27 @@ class ServiceEditor(SellableEditor):
     model_type = Service
     help_section = 'service'
 
+    #
+    #  SellableEditor
+    #
+
     def get_taxes(self):
         service_tax = SellableTaxConstant.get_by_type(TaxType.SERVICE,
                                                       self.store)
         return [(_(u'No tax'), None), (service_tax.description, service_tax)]
 
-    def setup_slaves(self):
-        details_slave = SellableDetailsSlave(self.store, self.model.sellable,
-                                             visual_mode=self.visual_mode)
-        self.attach_slave('slave_holder', details_slave)
-
     def setup_widgets(self):
+        for widget in [self.product_type_lbl, self.product_type_str]:
+            widget.hide()
         self.sellable_notebook.set_tab_label_text(self.sellable_tab,
                                                   _(u'Service'))
-        self.consignment_lbl.hide()
-        self.consignment_box.hide()
-        self.statuses_combo.set_sensitive(True)
-
-    #
-    # BaseEditor hooks
-    #
 
     def create_model(self, store):
         tax_constant = SellableTaxConstant.get_by_type(TaxType.SERVICE, self.store)
         sellable = Sellable(description=u'',
                             price=currency(0),
                             store=store)
-        sellable.status = Sellable.STATUS_AVAILABLE
         sellable.tax_constant = tax_constant
-        sellable.unit = sysparam(self.store).SUGGESTED_UNIT
+        sellable.unit_id = sysparam.get_object_id('SUGGESTED_UNIT')
         model = Service(sellable=sellable, store=store)
         return model
