@@ -23,7 +23,6 @@
 ##
 """ Editors implementation for open/close operation on till operation"""
 
-import datetime
 from datetime import timedelta
 
 from kiwi.currency import currency
@@ -44,6 +43,7 @@ from stoqlib.domain.till import Till
 from stoqlib.exceptions import DeviceError, TillError
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.slaves.tillslave import RemoveCashSlave, BaseCashSlave
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.message import warning
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
@@ -53,10 +53,10 @@ _ = stoqlib_gettext
 
 def _create_transaction(store, till_entry):
     AccountTransaction(description=till_entry.description,
-                       source_account=sysparam(store).IMBALANCE_ACCOUNT,
-                       account=sysparam(store).TILLS_ACCOUNT,
+                       source_account_id=sysparam.get_object_id('IMBALANCE_ACCOUNT'),
+                       account_id=sysparam.get_object_id('TILLS_ACCOUNT'),
                        value=till_entry.value,
-                       code=unicode(till_entry.id),
+                       code=unicode(till_entry.identifier),
                        date=TransactionTimestamp(),
                        store=store,
                        payment=till_entry.payment)
@@ -82,7 +82,7 @@ class _TillClosingModel(object):
         # ECF, but not on Stoq.
         # Return a date in the past
         if not self.till:
-            return datetime.datetime.now() - timedelta(1)
+            return localnow() - timedelta(1)
         return self.till.opening_date
 
     def get_cash_amount(self):
@@ -139,7 +139,7 @@ class TillOpeningEditor(BaseEditor):
 
         try:
             TillOpenEvent.emit(till=till)
-        except (TillError, DeviceError), e:
+        except (TillError, DeviceError) as e:
             warning(str(e))
             self.retval = False
             return
@@ -206,9 +206,9 @@ class TillClosingEditor(BaseEditor):
         self.day_history.connect('row-activated', lambda olist, row: self.confirm())
         self.day_history.add_list(self._get_day_history())
         summary_day_history = SummaryLabel(
-                klist=self.day_history,
-                column='value',
-                label='<b>%s</b>' % api.escape(_(u'Total balance:')))
+            klist=self.day_history,
+            column='value',
+            label='<b>%s</b>' % api.escape(_(u'Total balance:')))
         summary_day_history.show()
         self.day_history_box.pack_start(summary_day_history, False)
 
@@ -235,14 +235,14 @@ class TillClosingEditor(BaseEditor):
             else:
                 day_history[desc] = entry.value
 
-        for description, value in day_history.iteritems():
+        for description, value in day_history.items():
             yield Settable(description=description, value=value)
 
     def _get_columns(self):
         return [Column('description', title=_('Description'), data_type=str,
-                        width=300, sorted=True),
+                       width=300, sorted=True),
                 ColoredColumn('value', title=_('Amount'), data_type=currency,
-                               color='red', data_func=lambda x: x < 0)]
+                              color='red', data_func=lambda x: x < 0)]
 
     #
     # BaseEditorSlave
@@ -291,7 +291,7 @@ class TillClosingEditor(BaseEditor):
             try:
                 retval = TillCloseEvent.emit(till=till,
                                              previous_day=self._previous_day)
-            except (TillError, DeviceError), e:
+            except (TillError, DeviceError) as e:
                 warning(str(e))
                 return None
 
@@ -395,13 +395,13 @@ class CashAdvanceEditor(BaseEditor):
         assert till
         try:
             TillRemoveCashEvent.emit(till=till, value=value)
-        except (TillError, DeviceError, DriverError), e:
+        except (TillError, DeviceError, DriverError) as e:
             warning(str(e))
             self.retval = False
             return
         till_entry = till.add_debit_entry(
             value, (_(u'Cash advance paid to employee: %s') % (
-            self._get_employee_name(), )))
+                    self._get_employee_name(), )))
 
         TillAddTillEntryEvent.emit(till_entry, self.store)
         _create_transaction(self.store, till_entry)
@@ -454,7 +454,7 @@ class CashOutEditor(BaseEditor):
         assert till
         try:
             TillRemoveCashEvent.emit(till=till, value=value)
-        except (TillError, DeviceError, DriverError), e:
+        except (TillError, DeviceError, DriverError) as e:
             warning(str(e))
             self.retval = False
             return
@@ -505,7 +505,7 @@ class CashInEditor(BaseEditor):
         assert till
         try:
             TillAddCashEvent.emit(till=till, value=self.model.value)
-        except (TillError, DeviceError, DriverError), e:
+        except (TillError, DeviceError, DriverError) as e:
             warning(str(e))
             self.retval = False
             return
