@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2012 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2012-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -30,14 +30,16 @@ import gio
 import gobject
 import gtk
 from kiwi.ui.dialogs import selectfile
+from kiwi.ui.entry import ENTRY_MODE_DATA
 from kiwi.ui.forms import ChoiceField, Field
 import pango
 
 from stoqlib.api import api
 from stoqlib.domain.attachment import Attachment
-from stoqlib.gui.filters import get_filters_for_attachment
-from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
+from stoqlib.gui.utils.filters import get_filters_for_attachment
+from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.lib.message import yesno
 
 _ = stoqlib_gettext
 
@@ -58,6 +60,21 @@ def get_store_for_field(field):
 
 
 class DomainChoiceField(ChoiceField):
+    """Field used to select a domain object
+
+    The graphical interface for it contains::
+
+      * a combobox entry for selecting the model object
+      * an add_button, which you can click to add a new object
+        to the model. It's sensitivity is controller by :obj:`.can_add`
+      * an edit_button, which you can click to edit the selected
+        object. It's sensitivity is controlled by :obj:`.can_edit` and
+        :obj:`.can_view`.
+
+    It's supposed to be subclassed and have it's :meth:`.populate` and
+    :meth:`.run_dialog` implemented on the subclass
+
+    """
     default_overrides = dict(has_add_button=True, has_edit_button=True)
 
     #: If we have the permission to add new object of this kind
@@ -70,8 +87,26 @@ class DomainChoiceField(ChoiceField):
     #: selected object
     can_view = gobject.property(type=bool, default=True)
 
+    #: If we are using the ids to pupulate the field instead of domain
+    #: objects. This changes what gets send as argument on :meth:`.populate`
+    #: after :attr:`._run_editor` is called
+    use_ids = False
+
     # Field
 
+    def prefill(self, items, value=None):
+        self.widget.prefill(items)
+        if value is not None:
+            self.widget.select(value)
+
+        if self.use_entry:
+            # FIXME: Make sure the entry is set to data mode or else ir will
+            # allow any string to be typed when items is empty. This is because
+            # kiwi will only set data mode on the entry when it gets prefilled
+            # with a list of tuples. We should improve that code to avoid this
+            # kind of workarounds
+            self.widget.entry.set_mode(ENTRY_MODE_DATA)
+
     def attach(self):
         self.connect('notify::can-add', self._on_can_add__notify)
         self.connect('notify::can-edit', self._on_can_edit__notify)
@@ -97,8 +132,12 @@ class DomainChoiceField(ChoiceField):
         model = self.run_dialog(store, model)
         rv = store.confirm(model)
         if rv:
-            main_store = get_store_for_field(self)
-            self.populate(main_store.fetch(model))
+            if self.use_ids:
+                value = model.id
+            else:
+                main_store = get_store_for_field(self)
+                value = main_store.fetch(model)
+            self.populate(value)
         store.close()
 
     def _update_add_button_sensitivity(self):
@@ -142,11 +181,9 @@ class AddressField(DomainChoiceField):
         self.person = address.person if address else None
         store = get_store_for_field(self)
         addresses = store.find(Address,
-            person=self.person).order_by(Address.street)
+                               person=self.person).order_by(Address.street)
 
-        self.widget.prefill(api.for_combo(addresses))
-        if address:
-            self.widget.select(address)
+        self.prefill(api.for_combo(addresses), address)
 
         self.add_button.set_tooltip_text(_("Add a new address"))
         self.edit_button.set_tooltip_text(_("Edit the selected address"))
@@ -176,7 +213,7 @@ class PaymentMethodField(ChoiceField):
     #: for more information
     payment_type = gobject.property(type=object, default=None)
 
-    #: If this is being created separated from a |sale|/|purchase|
+    #: If this is being created separated from a |sale| / |purchase|
     #: See :meth:`stoqlib.lib.interfaces.IPaymentOperation.creatable`
     #: for more information
     separate = gobject.property(type=bool, default=True)
@@ -211,8 +248,7 @@ class PaymentCategoryField(DomainChoiceField):
         categories = PaymentCategory.get_by_type(store, self.category_type)
         values = api.for_combo(
             categories, empty=_('No category'), attr='name')
-        self.widget.prefill(values)
-        self.widget.select(value)
+        self.prefill(values, value)
         # FIXME: Move to noun
         self.add_button.set_tooltip_text(_("Add a new payment category"))
         self.edit_button.set_tooltip_text(_("Edit the selected payment category"))
@@ -227,6 +263,7 @@ class PaymentCategoryField(DomainChoiceField):
 class PersonField(DomainChoiceField):
     default_overrides = DomainChoiceField.default_overrides.copy()
     default_overrides.update(use_entry=True)
+    use_ids = True
 
     #: This is the type of person we will display in this field, it
     #: must be a class referencing a :py:class:`stoqlib.domain.person.Person`
@@ -234,39 +271,31 @@ class PersonField(DomainChoiceField):
 
     # Field
 
-    def populate(self, person):
+    def populate(self, person_id):
         from stoqlib.domain.person import (Client, Supplier, Transporter,
                                            SalesPerson, Branch)
         store = get_store_for_field(self)
         person_type = self.person_type
         if person_type == Supplier:
-            objects = Supplier.get_active_suppliers(store)
             self.add_button.set_tooltip_text(_("Add a new supplier"))
             self.edit_button.set_tooltip_text(_("Edit the selected supplier"))
         elif person_type == Client:
-            objects = Client.get_active_clients(store)
             self.add_button.set_tooltip_text(_("Add a new client"))
             self.edit_button.set_tooltip_text(_("Edit the selected client"))
         elif person_type == Transporter:
-            objects = Transporter.get_active_transporters(store)
             self.add_button.set_tooltip_text(_("Add a new transporter"))
             self.edit_button.set_tooltip_text(_("Edit the selected transporter"))
         elif person_type == SalesPerson:
-            objects = SalesPerson.get_active_salespersons(store)
             self.add_button.set_tooltip_text(_("Add a new sales person"))
             self.edit_button.set_tooltip_text(_("Edit the selected sales person"))
         elif person_type == Branch:
-            objects = Branch.get_active_branches(store)
             self.add_button.set_tooltip_text(_("Add a new branch"))
             self.edit_button.set_tooltip_text(_("Edit the selected branch"))
         else:
             raise AssertionError(self.person_type)
 
-        self.widget.prefill(api.for_person_combo(objects))
-
-        if person:
-            assert isinstance(person, person_type)
-            self.widget.select(person)
+        items = person_type.get_active_items(store)
+        self.prefill(items, person_id)
 
     def run_dialog(self, store, person):
         from stoqlib.domain.person import Branch, Client, Supplier, Transporter
@@ -279,29 +308,63 @@ class PersonField(DomainChoiceField):
             Client: ClientEditor,
             Supplier: SupplierEditor,
             Transporter: TransporterEditor,
-            }
+        }
         editor = editors.get(self.person_type)
-        if editor is None:
+        if editor is None:  # pragma no cover
             raise NotImplementedError(self.person_type)
 
         from stoqlib.gui.wizards.personwizard import run_person_role_dialog
         return run_person_role_dialog(editor, self.toplevel, store, person,
                                       visual_mode=not self.can_edit)
 
+    def edit_button_clicked(self, button):
+        facet_id = self.widget.get_selected()
+        store = get_store_for_field(self)
+        facet = store.get(self.person_type, facet_id)
+        self._run_editor(facet)
+
+
+class CfopField(DomainChoiceField):
+    """A domain choice field for selecting a |cfop|
+
+    More information about this class on :class:`DomainChoiceField`
+    """
+
+    default_overrides = DomainChoiceField.default_overrides.copy()
+    default_overrides.update(use_entry=True, can_edit=False)
+
+    # Field
+
+    def populate(self, cfop):
+        from stoqlib.domain.fiscal import CfopData
+        store = get_store_for_field(self)
+        cfops = store.find(CfopData)
+        self.prefill(api.for_combo(cfops), cfop)
+
+        self.add_button.set_tooltip_text(_("Add a new C.F.O.P"))
+        self.edit_button.set_tooltip_text(_("View C.F.O.P details"))
+
+    def run_dialog(self, store, cfop):
+        from stoqlib.gui.editors.fiscaleditor import CfopEditor
+        from stoqlib.gui.base.dialogs import run_dialog
+        return run_dialog(CfopEditor, self.toplevel, store, cfop,
+                          visual_mode=not self.can_edit)
+
 
 class AttachmentField(Field):
     """This field allows attaching files to models.
 
-      It has:
-      * a button, which you can click if there's an attachment. The attachment
-        will open in the default system application based on its mimetype
-      * the add_button, which you can click to add an attachment in case
-        there's none
-      * the edit_button, which you can click to change an attachment
-      * the delete_button, which you can click to delete an attachment
+      The graphical interface for it contains:
+
+        * a button, which you can click if there's an attachment. The attachment
+          will open in the default system application based on its mimetype
+        * the add_button, which you can click to add an attachment in case
+          there's none
+        * the edit_button, which you can click to change an attachment
+        * the delete_button, which you can click to delete an attachment
 
       It is the editor's responsibility to get the attachment and associate it
-      to the model. For example:
+      to the model. For example::
 
          self.model.attachment = self.fields['attachment'].attachment
     """
@@ -346,8 +409,8 @@ class AttachmentField(Field):
         if has_attachment:
             self._label.set_label(self.attachment.get_description())
             app_info = gio.app_info_get_default_for_type(
-                                                      self.attachment.mimetype,
-                                                      must_support_uris=False)
+                self.attachment.mimetype,
+                must_support_uris=False)
             if app_info:
                 gicon = app_info.get_icon()
                 self.image.set_from_gicon(gicon, gtk.ICON_SIZE_SMALL_TOOLBAR)
@@ -367,6 +430,10 @@ class AttachmentField(Field):
         self.sep.set_visible(can_open)
 
     def delete_button_clicked(self, button):
+        if not yesno(_("Are you sure you want to remove the attachment?"),
+                     gtk.RESPONSE_NO, _("Remove"), _("Don't remove")):
+            return
+
         self.attachment.blob = None
         self._update_widget()
 
