@@ -22,17 +22,19 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+# FIXME: Refactor this module and put it somewhere else (on POS app maybe?)
+
 import datetime
+import logging
 import sys
 
 import glib
 import gobject
 import gtk
-from kiwi.log import Logger
 from kiwi.utils import gsignal
 from stoqdrivers.exceptions import (DriverError, CouponOpenError,
                                     OutofPaperError, PrinterOfflineError)
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.api import api
 from stoqlib.domain.events import (CardPaymentReceiptPrepareEvent,
@@ -44,24 +46,27 @@ from stoqlib.domain.events import (CardPaymentReceiptPrepareEvent,
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.domain.till import Till
 from stoqlib.drivers.cheque import print_cheques_for_payment_group
-from stoqlib.exceptions import DeviceError, TillError
+from stoqlib.exceptions import DeviceError, TillError, SellError, ReportError
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.dialogs.quotedialog import ConfirmSaleMissingDialog
 from stoqlib.gui.editors.tilleditor import (TillOpeningEditor,
                                             TillClosingEditor,
                                             TillVerifyEditor)
 from stoqlib.gui.events import CouponCreatedEvent
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.gui.wizards.salewizard import ConfirmSaleWizard
+from stoqlib.reporting.boleto import BillReport
+from stoqlib.reporting.booklet import BookletReport
 
 
 _ = stoqlib_gettext
 
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 (CLOSE_TILL_NONE,
  CLOSE_TILL_DB,
@@ -110,14 +115,14 @@ class FiscalPrinterHelper(gobject.GObject):
         """Opens the till
         """
         if Till.get_current(self.store) is not None:
-            warning("You already have a till operation opened. "
-                    "Close the current Till and open another one.")
+            warning(_("You already have a till operation opened. "
+                      "Close the current Till and open another one."))
             return False
 
         store = api.new_store()
         try:
             model = run_dialog(TillOpeningEditor, self._parent, store)
-        except TillError, e:
+        except TillError as e:
             warning(str(e))
             model = None
 
@@ -225,7 +230,7 @@ class FiscalPrinterHelper(gobject.GObject):
         :returns: a new coupon
         """
 
-        if sysparam(self.store).DEMO_MODE:
+        if sysparam.get_bool('DEMO_MODE'):
             branch = api.get_current_branch(self.store)
             company = branch.person.company
             if company and company.cnpj not in ['24.198.774/7322-35',
@@ -238,7 +243,7 @@ class FiscalPrinterHelper(gobject.GObject):
         try:
             CouponCreatedEvent.emit(coupon)
         except (DriverError, DeviceError):
-            warning('Não foi possível abrir o cupom')
+            warning(_("It wasn't possible to open the coupon"))
             coupon = None
 
         return coupon
@@ -253,7 +258,7 @@ class FiscalPrinterHelper(gobject.GObject):
         This method will call check_till that will eventually,
         disable fiscal related interface.
         """
-        now = datetime.datetime.now()
+        now = localnow()
         tomorrow = now + datetime.timedelta(1)
 
         # Get the delta between now and tomorrow (midnight)
@@ -308,7 +313,7 @@ class FiscalPrinterHelper(gobject.GObject):
         try:
             HasOpenCouponEvent.emit()
             return True
-        except (DeviceError, DriverError), e:
+        except (DeviceError, DriverError) as e:
             warning(str(e))
             self.emit('ecf-changed', False)
             return False
@@ -317,7 +322,7 @@ class FiscalPrinterHelper(gobject.GObject):
         try:
             self._check_needs_closing()
             self.emit('ecf-changed', True)
-        except (DeviceError, DriverError), e:
+        except (DeviceError, DriverError) as e:
             warning(str(e))
             self.emit('ecf-changed', False)
 
@@ -334,14 +339,13 @@ class FiscalPrinterHelper(gobject.GObject):
         self.check_till()
 
 
+@implementer(IContainer)
 class FiscalCoupon(gobject.GObject):
     """ This class is used just to allow us cancel an item with base in a
     Sellable object. Currently, services can't be added, and they
     are just ignored -- be aware, if a coupon with only services is
     emitted, it will not be opened in fact, but just ignored.
     """
-    implements(IContainer)
-
     gsignal('open')
     gsignal('identify-customer', object)
     gsignal('customer-identified', retval=bool)
@@ -374,12 +378,12 @@ class FiscalCoupon(gobject.GObject):
         sys.excepthook = oldhook
 
         if sys.last_value is not None:
-            #import traceback
-            #print 'Exception caught in signal emission for %s::%s:' % (
+            # import traceback
+            # print 'Exception caught in signal emission for %s::%s:' % (
             #    gobject.type_name(self), signal)
-            #traceback.print_exception(sys.last_type, sys.last_value,
+            # traceback.print_exception(sys.last_type, sys.last_value,
             #                          sys.last_traceback)
-            raise sys.last_value
+            raise sys.last_value  # pylint: disable=E0702
         return retval
 
     #
@@ -406,7 +410,7 @@ class FiscalCoupon(gobject.GObject):
         return item_id
 
     def get_items(self):
-        return self._item_ids.keys()
+        return list(self._item_ids.keys())
 
     def remove_item(self, sale_item):
         if sale_item.price <= 0:
@@ -453,7 +457,7 @@ class FiscalCoupon(gobject.GObject):
                     gtk.RESPONSE_YES, _(u"Resume"), _(u"Confirm later")):
                     return False
                 return self.open()
-            except (DriverError, DeviceError), e:
+            except (DriverError, DeviceError) as e:
                 warning(_(u"It is not possible to emit the coupon"),
                         str(e))
                 return False
@@ -464,9 +468,7 @@ class FiscalCoupon(gobject.GObject):
         self.payments_setup = False
         return True
 
-    def confirm(self, sale, store, savepoint=None,
-                subtotal=None,
-                total_paid=0):
+    def confirm(self, sale, store, savepoint=None, subtotal=None):
         """Confirms a |sale| on fiscalprinter and database
 
         If the sale is confirmed, the store will be committed for you.
@@ -480,22 +482,15 @@ class FiscalCoupon(gobject.GObject):
         :param savepoint: if specified, a database savepoint name that
             will be used to rollback to if the sale was not confirmed.
         :param subtotal: the total value of all the items in the sale
-        :param total_paid: what has already been paid on this sale,
-            used when returning an item
         """
         # Actually, we are confirming the sale here, so the sale
         # confirmation process will be available to others applications
         # like Till and not only to the POS.
+        total_paid = sale.group.get_total_confirmed_value()
         model = run_dialog(ConfirmSaleWizard, self._parent, store, sale,
                            subtotal=subtotal,
                            total_paid=total_paid)
 
-        missing = sale.get_missing_items()
-        if missing:
-            run_dialog(ConfirmSaleMissingDialog, self._parent, sale, missing)
-            store.rollback(name=savepoint, close=False)
-            return False
-
         if not model:
             CancelPendingPaymentsEvent.emit()
             store.rollback(name=savepoint, close=False)
@@ -516,26 +511,49 @@ class FiscalCoupon(gobject.GObject):
             store.rollback(name=savepoint, close=False)
             return False
 
-        sale.confirm()
+        try:
+            sale.confirm()
+        except SellError as err:
+            warning(str(err))
+            store.rollback(name=savepoint, close=False)
+            return False
 
         if not self.print_receipts(sale):
-            warning('A venda foi cancelada')
+            warning(_("The sale was cancelled"))
             sale.cancel()
 
-        if sale.only_paid_with_money():
-            sale.set_paid()
-        else:
-            sale.group.pay_money_payments()
-
         print_cheques_for_payment_group(store, sale.group)
 
         # Only finish the transaction after everything passed above.
         store.confirm(model)
 
+        # Try to print only after the transaction is commited, to prevent
+        # losing data if something fails while printing
+        group = sale.group
+        booklets = list(group.get_payments_by_method_name(u'store_credit'))
+        bills = list(group.get_payments_by_method_name(u'bill'))
+
+        if (booklets and
+            yesno(_("Do you want to print the booklets for this sale?"),
+                  gtk.RESPONSE_YES, _("Print booklets"), _("Don't print"))):
+            try:
+                print_report(BookletReport, booklets)
+            except ReportError:
+                warning(_("Could not print booklets"))
+
+        if (bills and BillReport.check_printable(bills) and
+            yesno(_("Do you want to print the bills for this sale?"),
+                  gtk.RESPONSE_YES, _("Print bills"), _("Don't print"))):
+            try:
+                print_report(BillReport, bills)
+            except ReportError:
+                # TRANSLATORS: bills here refers to "boletos" in pt_BR
+                warning(_("Could not print bills"))
+
         return True
 
     def print_receipts(self, sale):
-        #supports_duplicate = self.emit('get-supports-duplicate-receipt')
+        # supports_duplicate = self.emit('get-supports-duplicate-receipt')
         # Vamos sempre imprimir sempre de uma vez, para simplificar
         supports_duplicate = False
 
@@ -566,17 +584,19 @@ class FiscalCoupon(gobject.GObject):
             else:
                 retval = self.print_payment_receipt(payment_list[0], value, receipt)
             while not retval:
-                if not yesno(_(u"Erro na impressão. Deseja tentar novamente?"),
-                         gtk.RESPONSE_YES,
-                         _("Sim"), _(u"Não")):
+                if not yesno(_(u"An error occurred while trying to print. "
+                               u"Would you like to try again?"),
+                             gtk.RESPONSE_YES,
+                             _("Try again"), _(u"Don't try again")):
                     CancelPendingPaymentsEvent.emit()
                     try:
                         GerencialReportCancelEvent.emit()
-                    except (DriverError, DeviceError), details:
+                    except (DriverError, DeviceError) as details:
                         log.info('Error canceling last receipt: %s' %
-                                    details)
-                        warning(u'Não foi possível cancelar o último'
-                                 ' comprovante')
+                                 details)
+                        warning(_(u"It wasn't possible to cancel "
+                                  u"the last receipt"))
+
                     return False
                 any_failed = True
                 _flush_interface()
@@ -604,12 +624,13 @@ class FiscalCoupon(gobject.GObject):
                 self.emit('totalize', sale)
                 self.totalized = True
                 return True
-            except (DriverError, DeviceError), details:
+            except (DriverError, DeviceError) as details:
                 log.info("It is not possible to totalize the coupon: %s"
-                            % str(details))
-                if not yesno(_(u"Erro na impressão. Deseja tentar novamente?"),
-                         gtk.RESPONSE_YES,
-                         _("Sim"), _(u"Não")):
+                         % str(details))
+                if not yesno(_(u"An error occurred while trying to print. "
+                               u"Would you like to try again?"),
+                             gtk.RESPONSE_YES,
+                             _("Try again"), _(u"Don't try again")):
                     CancelPendingPaymentsEvent.emit()
                     return False
                 _flush_interface()
@@ -620,11 +641,12 @@ class FiscalCoupon(gobject.GObject):
             try:
                 self.emit('cancel')
                 break
-            except (DriverError, DeviceError), details:
+            except (DriverError, DeviceError) as details:
                 log.info("Error canceling coupon: %s" % str(details))
-                if not yesno(_(u"Erro cancelando cupom. Deseja tentar novamente?"),
-                         gtk.RESPONSE_YES,
-                         _("Sim"), _(u"Não")):
+                if not yesno(_(u"An error occurred while trying to cancel the "
+                               u"the coupon. Would you like to try again?"),
+                             gtk.RESPONSE_YES,
+                             _("Try again"), _(u"Don't try again")):
                     return False
                 _flush_interface()
         return True
@@ -647,12 +669,13 @@ class FiscalCoupon(gobject.GObject):
                 self.emit('add-payments', sale)
                 self.payments_setup = True
                 return True
-            except (DriverError, DeviceError), details:
+            except (DriverError, DeviceError) as details:
                 log.info("It is not possible to add payments to the coupon: %s"
-                            % str(details))
-                if not yesno(_(u"Erro na impressão. Deseja tentar novamente?"),
-                         gtk.RESPONSE_YES,
-                         _("Sim"), _(u"Não")):
+                         % str(details))
+                if not yesno(_(u"An error occurred while trying to print. "
+                               u"Would you like to try again?"),
+                             gtk.RESPONSE_YES,
+                             _("Try again"), _(u"Don't try again")):
                     CancelPendingPaymentsEvent.emit()
                     return False
                 _flush_interface()
@@ -672,12 +695,13 @@ class FiscalCoupon(gobject.GObject):
                 sale.coupon_id = coupon_id
                 self.coupon_closed = True
                 return True
-            except (DeviceError, DriverError), details:
+            except (DeviceError, DriverError) as details:
                 log.info("It is not possible to close the coupon: %s"
-                            % str(details))
-                if not yesno(_(u"Erro na impressão. Deseja tentar novamente?"),
-                         gtk.RESPONSE_YES,
-                         _("Sim"), _(u"Não")):
+                         % str(details))
+                if not yesno(_(u"An error occurred while trying to print. "
+                               u"Would you like to try again?"),
+                             gtk.RESPONSE_YES,
+                             _("Try again"), _(u"Don't try again")):
                     CancelPendingPaymentsEvent.emit()
                     return False
                 _flush_interface()
@@ -691,9 +715,9 @@ class FiscalCoupon(gobject.GObject):
         try:
             self.emit('print-payment-receipt', self._coo, payment, value, receipt)
             return True
-        except (DriverError, DeviceError), details:
+        except (DriverError, DeviceError) as details:
             log.info("Error printing payment receipt: %s"
-                        % str(details))
+                     % str(details))
             return False
 
     def reprint_payment_receipt(self, receipt, close_previous=False):
@@ -703,7 +727,7 @@ class FiscalCoupon(gobject.GObject):
         try:
             GerencialReportPrintEvent.emit(receipt, close_previous)
             return True
-        except (DriverError, DeviceError), details:
+        except (DriverError, DeviceError) as details:
             log.info("Error printing gerencial report: %s"
-                        % str(details))
+                     % str(details))
             return False
