@@ -22,21 +22,19 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-
-import gtk
 import datetime
 
-from kiwi.db.query import DateQueryState, DateIntervalQueryState
-from kiwi.ui.search import DateSearchFilter
-from kiwi.ui.objectlist import SearchColumn, Column
+import gtk
 
 from stoqlib.api import api
+from stoqlib.database.queryexecuter import DateQueryState, DateIntervalQueryState
 from stoqlib.domain.person import CallsView, Client, ClientCallsView
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.search import SearchEditor
-from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.editors.callseditor import CallsEditor
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.search.searchcolumns import SearchColumn, Column
+from stoqlib.gui.search.searcheditor import SearchEditor
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.reporting.callsreport import CallsReport
 
@@ -52,7 +50,7 @@ class CallsSearch(SearchEditor):
     the column title in this search.
     """
     title = _("Calls Search")
-    search_table = CallsView
+    search_spec = CallsView
     editor_class = CallsEditor
     searching_by_date = True
     person_type = None
@@ -84,10 +82,7 @@ class CallsSearch(SearchEditor):
         return calls.call
 
     def setup_widgets(self):
-        self.csv_button = self.add_button(label=_("Export to spreadsheet..."))
-        self.csv_button.connect('clicked', self._on_export_csv_button__clicked)
-        self.csv_button.show()
-        self.csv_button.set_sensitive(False)
+        self.add_csv_button(_('Calls'), _('calls'))
 
         self.print_button = self.add_button(label=_("Print"))
         self.print_button.connect('clicked', self._on_print_button__clicked)
@@ -101,8 +96,7 @@ class CallsSearch(SearchEditor):
 
     def create_filters(self):
         self.set_text_field_columns(['description', 'message'])
-        self.set_searchbar_labels(_('matching:'))
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
 
         # Date
         date_filter = DateSearchFilter(_("Date:"))
@@ -115,15 +109,15 @@ class CallsSearch(SearchEditor):
 
     def get_columns(self):
         columns = [Column('date', title=_('Date'),
-                       data_type=datetime.date, width=150, sorted=True),
-                SearchColumn('description', title=_('Description'),
-                             data_type=str, width=150, expand=True),
-                SearchColumn('attendant', title=_('Attendant'),
-                             data_type=str, width=100, expand=True)]
+                          data_type=datetime.date, width=150, sorted=True),
+                   SearchColumn('description', title=_('Description'),
+                                data_type=str, width=150, expand=True),
+                   SearchColumn('attendant', title=_('Attendant'),
+                                data_type=str, width=100, expand=True)]
         if not self.person:
             columns.insert(1,
-                SearchColumn('name', title=self.person_name,
-                             data_type=str, width=150, expand=True))
+                           SearchColumn('name', title=self.person_name,
+                                        data_type=str, width=150, expand=True))
         return columns
 
     def executer_query(self, store):
@@ -139,7 +133,7 @@ class CallsSearch(SearchEditor):
 
         # Use the current connection ('self.store') to show inserted calls,
         # before confirm the new person.
-        return self.search_table.find_by_client_date(self.store, client, date)
+        return self.search_spec.find_by_client_date(self.store, client, date)
 
     def update_widgets(self, *args):
         call_view = self.results.get_selected()
@@ -166,15 +160,8 @@ class CallsSearch(SearchEditor):
     # Callbacks
     #
 
-    def _on_export_csv_button__clicked(self, widget):
-        sse = SpreadSheetExporter()
-        sse.export(object_list=self.results,
-                   name=_('Calls'),
-                   filename_prefix=_('calls'))
-
     def _on_results__has_rows(self, widget, has_rows):
         self.print_button.set_sensitive(has_rows)
-        self.csv_button.set_sensitive(has_rows)
 
     def _on_print_button__clicked(self, widget):
         print_report(CallsReport, self.results, list(self.results),
@@ -184,6 +171,6 @@ class CallsSearch(SearchEditor):
 
 class ClientCallsSearch(CallsSearch):
     title = _("Calls Search")
-    search_table = ClientCallsView
+    search_spec = ClientCallsView
     person_type = Client
     person_name = _('Client')
