@@ -28,11 +28,10 @@ creation and edition.
 
 from decimal import Decimal
 
-from kiwi.ui.objectlist import SearchColumn
-
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.gui.base.search import SearchEditor
 from stoqlib.gui.editors.categoryeditor import SellableCategoryEditor
+from stoqlib.gui.search.searchcolumns import SearchColumn
+from stoqlib.gui.search.searcheditor import SearchEditor
 from stoqlib.domain.views import SellableCategoryView
 
 _ = stoqlib_gettext
@@ -41,17 +40,11 @@ _ = stoqlib_gettext
 class SellableCategorySearch(SearchEditor):
     size = (750, 500)
     title = _('Sellable Category Search')
-    searchbar_label = _('Categories Matching:')
-    result_strings = _('category'), _('categories')
-    search_table = SellableCategoryView
+    search_label = _('Categories Matching:')
+    search_spec = SellableCategoryView
     tree = True
     editor_class = SellableCategoryEditor
 
-    def __init__(self, store):
-        SearchEditor.__init__(self, store)
-        self.set_searchbar_labels(self.searchbar_label)
-        self.set_result_strings(*self.result_strings)
-
     #
     #  SearchEditor
     #
@@ -70,7 +63,7 @@ class SellableCategorySearch(SearchEditor):
             SearchColumn("installments_commission",
                          _("Installments Commission (%)"),
                          data_type=Decimal, width=220),
-            ]
+        ]
 
     def get_editor_model(self, commission_source_category_view):
         """Search Editor hook"""
