@@ -24,11 +24,11 @@
 
 import datetime
 
-from kiwi.ui.objectlist import SearchColumn
 from kiwi.currency import currency
 
 from stoqlib.domain.person import ClientSalaryHistoryView
-from stoqlib.gui.base.search import SearchDialog
+from stoqlib.gui.search.searchcolumns import SearchColumn
+from stoqlib.gui.search.searchdialog import SearchDialog
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -40,7 +40,7 @@ class ClientSalaryHistorySearch(SearchDialog):
     """
 
     title = _("Salary History Search")
-    search_table = ClientSalaryHistoryView
+    search_spec = ClientSalaryHistoryView
     size = (600, 450)
 
     def __init__(self, store, client=None):
@@ -56,8 +56,7 @@ class ClientSalaryHistorySearch(SearchDialog):
 
     def create_filters(self):
         self.set_text_field_columns(['user'])
-        self.set_searchbar_labels(_('matching:'))
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
 
     def get_columns(self):
         columns = [SearchColumn('date', title=_('Date'),
@@ -70,4 +69,4 @@ class ClientSalaryHistorySearch(SearchDialog):
         return columns
 
     def executer_query(self, store):
-        return self.search_table.find_by_client(self.store, self.client)
+        return self.search_spec.find_by_client(self.store, self.client)
