@@ -25,11 +25,12 @@
 
 from decimal import Decimal
 
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.objectlist import SearchColumn, Column
+from kiwi.ui.objectlist import Column
 
 from stoqlib.domain.views import ConsignedItemAndStockView
-from stoqlib.gui.base.search import SearchDialog
+from stoqlib.enums import SearchFilterPosition
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchdialog import SearchDialog
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -38,22 +39,21 @@ _ = stoqlib_gettext
 class ConsignmentItemSearch(SearchDialog):
     title = _(u'Consignment Items Search')
     size = (-1, 450)
-    table = search_table = ConsignedItemAndStockView
+    search_spec = ConsignedItemAndStockView
 
     #
     # SearchDialog Hooks
     #
 
     def create_filters(self):
-        self.set_text_field_columns(['description'])
+        self.set_text_field_columns(['description', 'order_identifier_str'])
         # Branch
         branch_filter = self.create_branch_filter(_('In branch:'))
         self.add_filter(branch_filter, columns=['branch'],
                         position=SearchFilterPosition.TOP)
 
     def get_columns(self):
-        return [SearchColumn('order_identifier', title=_(u'Order'), data_type=int,
-                             format='%03d'),
+        return [IdentifierColumn('order_identifier', title=_(u"Order #")),
                 SearchColumn('code', title=_(u'Code'), data_type=str,
                              width=40),
                 SearchColumn('description', title=_(u'Description'),
