@@ -26,24 +26,24 @@ import datetime
 
 import gtk
 
-from kiwi.ui.objectlist import SearchColumn, Column
 
 from stoqlib.api import api
 from stoqlib.domain.person import CreditCheckHistoryView
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.search import SearchEditor
 from stoqlib.gui.editors.creditcheckhistoryeditor import CreditCheckHistoryEditor
+from stoqlib.gui.search.searchcolumns import SearchColumn, Column
+from stoqlib.gui.search.searcheditor import SearchEditor
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
 
 class CreditCheckHistorySearch(SearchEditor):
-    """
+    """A search dialog for querying the credit history for a |client|
     """
     title = _("Client Credit Check History Search")
     editor_class = CreditCheckHistoryEditor
-    search_table = CreditCheckHistoryView
+    search_spec = CreditCheckHistoryView
     size = (700, 450)
 
     def __init__(self, store, client=None, reuse_store=False):
@@ -73,8 +73,7 @@ class CreditCheckHistorySearch(SearchEditor):
             self.set_text_field_columns(['identifier'])
         else:
             self.set_text_field_columns(['identifier', 'client_name'])
-        self.set_searchbar_labels(_('matching:'))
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
 
     def get_columns(self):
         columns = [SearchColumn('check_date', title=_('Date'),
@@ -93,9 +92,9 @@ class CreditCheckHistorySearch(SearchEditor):
         return columns
 
     def executer_query(self, store):
-        results = self.search_table.find_by_client(self.store, self.client)
+        results = self.search_spec.find_by_client(self.store, self.client)
         return results.order_by(CreditCheckHistoryView.check_date,
-                                CreditCheckHistoryView.id)
+                                CreditCheckHistoryView.identifier)
 
     def update_widgets(self, *args):
         call_view = self.results.get_selected()
