@@ -29,15 +29,16 @@ import datetime
 
 import gtk
 import pango
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.objectlist import Column, SearchColumn
-from kiwi.ui.search import ComboSearchFilter
+from kiwi.ui.objectlist import Column
 
 from stoqlib.domain.sale import Delivery
 from stoqlib.domain.views import DeliveryView
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.editors.deliveryeditor import DeliveryEditor
-from stoqlib.gui.base.search import SearchEditor
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searcheditor import SearchEditor
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
 
 _ = stoqlib_gettext
 
@@ -46,9 +47,8 @@ class DeliverySearch(SearchEditor):
     """Delivery search implementation"""
 
     title = _('Delivery Search')
-    search_table = DeliveryView
+    search_spec = DeliveryView
     editor_class = DeliveryEditor
-    searchbar_result_strings = _('Delivery'), _('Deliveries')
     has_new_button = False
     size = (750, 450)
 
@@ -63,7 +63,7 @@ class DeliverySearch(SearchEditor):
 
     def create_filters(self):
         self.set_text_field_columns(['tracking_code', 'transporter_name',
-                                     'client_name'])
+                                     'client_name', 'identifier_str'])
 
         # Status
         statuses = [(desc, st) for st, desc in Delivery.statuses.items()]
@@ -77,23 +77,23 @@ class DeliverySearch(SearchEditor):
         return viewable.delivery
 
     def get_columns(self):
-        return [Column('sale_identifier', title=_('Sale #'), data_type=int,
-                       order=gtk.SORT_DESCENDING),
+        return [IdentifierColumn('sale_identifier', title=_('Sale #'),
+                                 order=gtk.SORT_DESCENDING),
                 SearchColumn('status_str', title=_('Status'), data_type=str,
                              search_attribute='status',
                              valid_values=self._get_status_values()),
                 Column('address_str', title=_('Address'), data_type=str,
-                             expand=True, ellipsize=pango.ELLIPSIZE_END),
+                       expand=True, ellipsize=pango.ELLIPSIZE_END),
                 SearchColumn('tracking_code', title=_('Tracking code'),
                              data_type=str),
                 SearchColumn('transporter_name', title=_('Transporter'),
-                       data_type=str),
+                             data_type=str),
                 SearchColumn('client_name', title=_('Client'),
-                       data_type=str),
+                             data_type=str),
                 SearchColumn('open_date', title=_('Open date'),
-                       data_type=datetime.date, visible=False),
+                             data_type=datetime.date, visible=False),
                 SearchColumn('deliver_date', title=_('Sent date'),
-                       data_type=datetime.date, visible=False),
+                             data_type=datetime.date, visible=False),
                 SearchColumn('receive_date', title=_('Received date'),
-                       data_type=datetime.date, visible=False),
+                             data_type=datetime.date, visible=False),
                 ]
