@@ -27,18 +27,18 @@ import datetime
 
 import gtk
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
 from kiwi.python import enum
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import SearchColumn
 
 from stoqlib.api import api
 from stoqlib.domain.fiscal import CfopData, IcmsIpiView, IssView
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.search import SearchEditor, SearchDialog
-from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.editors.fiscaleditor import (CfopEditor,
                                               FiscalBookEntryEditor)
+from stoqlib.gui.search.searchcolumns import SearchColumn
+from stoqlib.gui.search.searchdialog import SearchDialog
+from stoqlib.gui.search.searcheditor import SearchEditor
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -56,10 +56,9 @@ fiscal_book_entries = {FiscalBookEntryType.ICMS: _("ICMS"),
 
 class CfopSearch(SearchEditor):
     title = _("C.F.O.P. Search")
-    table = CfopData
+    search_spec = CfopData
     editor_class = CfopEditor
     size = (-1, 390)
-    searchbar_result_strings = _("C.F.O.P."), _("C.F.O.P.s")
 
     #
     # SearchDialog Hooks
@@ -78,14 +77,13 @@ class CfopSearch(SearchEditor):
 class FiscalBookEntrySearch(SearchDialog):
     title = _("Search for fiscal entries")
     size = (-1, 450)
-    search_table = IcmsIpiView
+    search_spec = IcmsIpiView
     searching_by_date = True
-    searchbar_result_strings = _("fiscal entry"), _("fiscal entries")
 
     def _setup_columns(self, column, table, col_name, summary_label_text):
         columns = self.get_columns() + [column]
         self.results.set_columns(columns)
-        self.set_table(table)
+        self.search.set_search_spec(table)
 
     def _setup_icms_columns(self):
         col = SearchColumn('icms_value',
@@ -147,12 +145,7 @@ class FiscalBookEntrySearch(SearchDialog):
         self.edit_button.show()
         self.edit_button.set_sensitive(False)
 
-        self.csv_button = self.add_button(label=_(u'Export to spreadsheet...'))
-        self.csv_button.connect('clicked', self._on_export_csv_button__clicked)
-        self.csv_button.show()
-        self.csv_button.set_sensitive(False)
-
-        self.results.connect('has_rows', self._on_results__has_rows)
+        self.add_csv_button(_('Fiscal book'), _('fiscal-book'))
 
     def update_widgets(self):
         can_edit = bool(self.results.get_selected())
@@ -162,11 +155,10 @@ class FiscalBookEntrySearch(SearchDialog):
         self.set_text_field_columns([])
 
         self.branch_filter = self.create_branch_filter(_('In branch:'))
-        self.branch_filter.select(None)
         self.add_filter(self.branch_filter, columns=['branch_id'])
 
         items = [(v, k)
-                    for k, v in fiscal_book_entries.items()]
+                 for k, v in fiscal_book_entries.items()]
         self.entry_type = ComboSearchFilter(_('Show entries of type'), items)
         self.add_filter(self.entry_type, callback=self._get_entry_type_query,
                         position=SearchFilterPosition.TOP)
@@ -184,12 +176,3 @@ class FiscalBookEntrySearch(SearchDialog):
                             store.fetch(entry.book_entry))
         store.confirm(retval)
         store.close()
-
-    def _on_export_csv_button__clicked(self, widget):
-        sse = SpreadSheetExporter()
-        sse.export(object_list=self.results,
-                   name=_('Fiscal book'),
-                   filename_prefix=_('fiscal-book'))
-
-    def _on_results__has_rows(self, widget, has_rows):
-        self.csv_button.set_sensitive(has_rows)
