@@ -28,33 +28,39 @@ from decimal import Decimal
 
 import gtk
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.objectlist import SearchColumn, Column
-from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
+from kiwi.ui.objectlist import Column
 
 from stoqlib.domain.loan import Loan
 from stoqlib.domain.views import LoanView, LoanItemView
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.search import SearchDialog
 from stoqlib.gui.dialogs.loandetails import LoanDetailsDialog
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.search.productsearch import ProductSearch
+from stoqlib.gui.search.searchcolumns import SearchColumn, IdentifierColumn
+from stoqlib.gui.search.searchdialog import SearchDialog
+from stoqlib.gui.search.searchfilters import ComboSearchFilter, DateSearchFilter
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.reporting.loanreceipt import LoanReceipt
 
 _ = stoqlib_gettext
 
 
-class LoanItemSearch(SearchDialog):
+class LoanItemSearch(ProductSearch):
     title = _(u'Loan Items Search')
-    size = (780, 450)
-    table = search_table = LoanItemView
+    search_spec = LoanItemView
+    has_print_price_button = False
+
+    def __init__(self, store, hide_footer=True, hide_toolbar=True):
+        ProductSearch.__init__(self, store, hide_footer=hide_footer,
+                               hide_toolbar=hide_toolbar)
 
     #
-    # SearchDialog Hooks
+    #  ProductSearch
     #
 
     def create_filters(self):
-        self.set_text_field_columns(['description'])
+        self.set_text_field_columns(['description', 'identifier_str'])
         # status filter
         statuses = [(desc, i) for i, desc in Loan.statuses.items()]
         statuses.insert(0, (_(u'Any'), None))
@@ -64,8 +70,7 @@ class LoanItemSearch(SearchDialog):
                         position=SearchFilterPosition.TOP)
 
     def get_columns(self):
-        return [SearchColumn('loan_identifier', title=_(u'Loan'), data_type=int,
-                             format='%03d', sorted=True),
+        return [IdentifierColumn('loan_identifier', sorted=True),
                 SearchColumn('opened', title=_(u'Open date'),
                              data_type=datetime.date, visible=False),
                 SearchColumn('closed', title=_(u'Close date'),
@@ -91,15 +96,14 @@ class LoanItemSearch(SearchDialog):
 class LoanSearch(SearchDialog):
     title = _(u"Loan Search")
     size = (750, 500)
-    search_table = LoanView
+    search_spec = LoanView
+    report_class = LoanReceipt
     selection_mode = gtk.SELECTION_MULTIPLE
-    searchbar_result_strings = _(u"loan"), _(u"loans")
     search_by_date = True
     advanced_search = False
 
     def __init__(self, store):
-        SearchDialog.__init__(self, store, self.search_table,
-                              title=self.title)
+        SearchDialog.__init__(self, store)
         self._setup_widgets()
 
     def _show_details(self, item):
@@ -124,15 +128,15 @@ class LoanSearch(SearchDialog):
         pass
 
     def create_filters(self):
-        self.set_text_field_columns(['client_name', 'removed_by'])
-        self.set_searchbar_labels(_('matching:'))
+        self.set_text_field_columns(['client_name', 'removed_by',
+                                     'identifier_str'])
 
         # Date
         self.date_filter = DateSearchFilter(_('Date:'))
         self.add_filter(self.date_filter, columns=['expire_date', 'open_date'])
 
     def get_columns(self):
-        return [Column('identifier', _('#'), data_type=int, width=50),
+        return [IdentifierColumn('identifier', title=_(u"Loan #")),
                 Column('open_date', _('Open date'),
                        data_type=datetime.date, sorted=True, width=100),
                 Column('expire_date', _('Expire date'),
@@ -143,7 +147,13 @@ class LoanSearch(SearchDialog):
                        data_type=unicode, width=120),
                 Column('removed_by', _('Removed by'), data_type=unicode,
                        width=120),
-                       ]
+                ]
+
+    def print_report(self):
+        orders = self.results.get_selected_rows()
+        if len(orders) == 1:
+            loan = self.store.get(Loan, orders[0].id)
+            print_report(self.report_class, loan)
 
     #
     # Callbacks
@@ -153,12 +163,6 @@ class LoanSearch(SearchDialog):
         item = item_view.loan
         self._show_details(item)
 
-    def on_print_button_clicked(self, button):
-        orders = self.results.get_selected_rows()
-        if len(orders) == 1:
-            loan = self.store.get(Loan, orders[0].id)
-            print_report(LoanReceipt, loan)
-
     def on_details_button_clicked(self, button):
         orders = self.results.get_selected_rows()
         if len(orders) > 1:
