@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2006-2009 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2006-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,8 @@
 ##
 """ Listing dialog for system parameters """
 
-from kiwi.argcheck import argcheck
+import decimal
+
 from kiwi.ui.objectlist import Column
 from storm.expr import And
 from zope.interface import providedBy
@@ -32,7 +33,7 @@ from stoqlib.api import api
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.domain.parameter import ParameterData
-from stoqlib.lib.parameters import sysparam, PathParameter
+from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext, dgettext
 from stoqlib.gui.base.columns import AccessorColumn
 from stoqlib.gui.base.dialogs import run_dialog
@@ -58,10 +59,7 @@ class ParameterSearch(BaseEditor):
         clause = And(
             # Do not allow this parameter to be used by general users for now
             ParameterData.field_name != u"ALLOW_TRADE_NOT_REGISTERED_SALES",
-            # FIXME: This isn't doing anything for now. Not showing
-            # on the search as it could confuse the users.
-            ParameterData.field_name != u"RETURN_MONEY_ON_SALES",
-            )
+        )
         self._parameters = self.store.find(ParameterData, clause)
         self._reset_results()
         self.edit_button.set_sensitive(False)
@@ -79,28 +77,37 @@ class ParameterSearch(BaseEditor):
                                accessor=self._get_parameter_value,
                                data_type=str, width=200)]
 
-    @argcheck(ParameterData)
     def _get_parameter_value(self, obj):
         """Given a ParameterData object, returns a string representation of
         its current value.
         """
-        constant = sysparam(self.store).get_parameter_constant(obj.field_name)
-        data = getattr(sysparam(self.store), obj.field_name)
+        detail = sysparam.get_detail_by_name(obj.field_name)
+        if detail.type == unicode:
+            data = sysparam.get_string(obj.field_name)
+        elif detail.type == bool:
+            data = sysparam.get_bool(obj.field_name)
+        elif detail.type == int:
+            data = sysparam.get_int(obj.field_name)
+        elif detail.type == decimal.Decimal:
+            data = sysparam.get_decimal(obj.field_name)
+        elif isinstance(detail.type, basestring):
+            data = sysparam.get_object(self.store, obj.field_name)
+        else:
+            raise NotImplementedError(detail.type)
+
         if isinstance(data, Domain):
             if not (IDescribable in providedBy(data)):
                 raise TypeError(u"Parameter `%s' must implement IDescribable "
-                                 "interface." % obj.field_name)
+                                "interface." % obj.field_name)
             return data.get_description()
-        elif constant.options:
-            return constant.options[int(obj.field_value)]
-        elif isinstance(data, PathParameter):
-            return data.path
+        elif detail.options:
+            return detail.options[int(obj.field_value)]
         elif isinstance(data, bool):
             return [_(u"No"), _(u"Yes")][data]
         elif obj.field_name == u'COUNTRY_SUGGESTED':
             return dgettext("iso_3166", data)
         elif isinstance(data, unicode):
-            #FIXME: workaround to handle locale specific data
+            # FIXME: workaround to handle locale specific data
             return _(data)
         return unicode(data)
 
@@ -109,7 +116,6 @@ class ParameterSearch(BaseEditor):
         parameter = store.fetch(item)
         retval = run_dialog(SystemParameterEditor, self, store, parameter)
         if store.confirm(retval):
-            sysparam(store).rebuild_cache_for(item.field_name)
             self.results.update(item)
         store.close()
 
@@ -124,7 +130,7 @@ class ParameterSearch(BaseEditor):
         for param in self._parameters:
             if (query not in param.get_group().lower() and
                 query not in param.get_short_description().lower()):
-                    self.results.remove(param)
+                self.results.remove(param)
 
     #
     # Kiwi Callbacks
