@@ -30,8 +30,9 @@ from decimal import Decimal
 import gtk
 
 from kiwi.currency import currency
-from kiwi.ui.objectlist import SearchColumn, Column
+from kiwi.ui.objectlist import Column
 
+from stoqlib.api import api
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.sale import SaleView
 from stoqlib.domain.payment.card import CardPaymentDevice
@@ -40,11 +41,14 @@ from stoqlib.domain.payment.views import (InCheckPaymentView,
                                           CardPaymentView)
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.search import SearchDialog
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchdialog import SearchDialog
+from stoqlib.gui.search.searcheditor import SearchEditor
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.dialogs.renegotiationdetails import RenegotiationDetailsDialog
 from stoqlib.gui.editors.paymenteditor import LonelyPaymentDetailsDialog
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.editors.paymentmethodeditor import CardPaymentDetailsEditor
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.reporting.payment import (BillCheckPaymentReport,
                                        CardPaymentReport)
 
@@ -57,6 +61,8 @@ class _BaseBillCheckSearch(SearchDialog):
     size = (750, 500)
     searching_by_date = True
     selection_mode = gtk.SELECTION_MULTIPLE
+    report_class = BillCheckPaymentReport
+    search_label = _(u'Bill or check number:')
 
     def _get_status_values(self):
         items = [(value, key) for key, value in
@@ -69,15 +75,21 @@ class _BaseBillCheckSearch(SearchDialog):
     #
 
     def create_filters(self):
-        self.set_text_field_columns(['payment_number', 'account'])
+        self.set_text_field_columns(['payment_number', 'bank_account'])
+        self.search.set_query(self.query_executer)
 
-        self.set_searchbar_labels(_(u'Bill or check number:'))
+    def query_executer(self, store):
+        resultset = store.find(self.search_spec)
+        if api.sysparam.get_bool('SYNCHRONIZED_MODE'):
+            current = api.get_current_branch(self.store)
+            resultset = resultset.find(Payment.branch_id == current.id)
+
+        return resultset
 
     def get_columns(self):
-        return [SearchColumn('identifier', title=_('#'), data_type=int, sorted=True,
-                             format='%04d', long_title=_('Id'), width=55),
+        return [IdentifierColumn('identifier', sorted=True),
                 Column('method_description', title=_(u'Method'),
-                             data_type=str, width=90),
+                       data_type=str, width=90),
                 SearchColumn('payment_number', title=_(u'Number'),
                              data_type=str, width=100),
                 SearchColumn('due_date', title=_('Due date'),
@@ -91,48 +103,43 @@ class _BaseBillCheckSearch(SearchDialog):
                              search_attribute='status'),
                 SearchColumn('value', title=_('Value'), data_type=currency)]
 
-    def _print_report(self):
+    def print_report(self):
         payments = self.results.get_selected_rows() or list(self.results)
-        print_report(BillCheckPaymentReport, self.results, payments,
+        print_report(self.report_class, self.results, payments,
                      filters=self.search.get_search_filters())
 
-    #
-    # Callbacks
-    #
-
-    def on_print_button_clicked(self, widget):
-        self._print_report()
-
 
 class InPaymentBillCheckSearch(_BaseBillCheckSearch):
-    table = InCheckPaymentView
+    search_spec = InCheckPaymentView
 
 
 class OutPaymentBillCheckSearch(_BaseBillCheckSearch):
-    table = OutCheckPaymentView
+    search_spec = OutCheckPaymentView
 
     def get_columns(self):
         columns = _BaseBillCheckSearch.get_columns(self)
         columns.append(
             SearchColumn('bill_received', title=_('Bill received'),
                          data_type=bool, visible=False)
-            )
+        )
         return columns
 
 
-class CardPaymentSearch(SearchDialog):
+class CardPaymentSearch(SearchEditor):
 
     title = _(u"Card Payment Search")
-    size = (750, 500)
+    size = (850, 500)
     searching_by_date = True
-    search_table = CardPaymentView
+    search_spec = CardPaymentView
+    editor_class = CardPaymentDetailsEditor
+    report_class = CardPaymentReport
+    search_label = (u'Client:')
     selection_mode = gtk.SELECTION_BROWSE
 
     def __init__(self, store):
-        SearchDialog.__init__(self, store, self.search_table,
-                              title=self.title)
+        SearchEditor.__init__(self, store)
         self.set_details_button_sensitive(False)
-        self.results.connect('selection-changed', self.on_selection_changed)
+        self.hide_new_button()
 
     def _get_status_values(self):
         values = [(v, k) for k, v in Payment.statuses.items()]
@@ -151,19 +158,24 @@ class CardPaymentSearch(SearchDialog):
     #
 
     def create_filters(self):
-        self.set_text_field_columns(['drawee_name'])
-        self.set_searchbar_labels(_(u'Client:'))
-        self.executer.set_query(self.executer_query)
+        self.set_text_field_columns(['drawee_name', 'identifier_str'])
+        self.search.set_query(self.executer_query)
 
-        #Provider
+        # Provider
         provider_filter = self.create_provider_filter(_('Provider:'))
         self.add_filter(provider_filter, columns=[])
         self.provider_filter = provider_filter
 
+    #
+    # SearchEditor Hooks
+    #
+
+    def get_editor_model(self, payment_card_view):
+        return payment_card_view.credit_card_data
+
     def get_columns(self):
         # TODO: Adicionar filtro por card_type
-        return [SearchColumn('identifier', title=_('#'), data_type=int,
-                             sorted=True, format='%04d', long_title=_('Id')),
+        return [IdentifierColumn('identifier', sorted=True),
                 SearchColumn('description', title=_(u'Description'),
                              data_type=str, expand=True),
                 SearchColumn('drawee_name', title=_(u'Drawee'), data_type=str,
@@ -183,23 +195,32 @@ class CardPaymentSearch(SearchDialog):
                              valid_values=self._get_status_values()),
                 SearchColumn('value', title=_(u'Value'), data_type=currency),
                 SearchColumn('fare', title=_(u'Fare'), data_type=currency),
-                SearchColumn('fee', title=_(u'% Fee'), data_type=Decimal),
-                SearchColumn('fee_calc', title=_(u'Fee'), data_type=currency)]
+                SearchColumn('fee', title=_(u'% Fee'), data_type=Decimal,
+                             visible=False),
+                SearchColumn('fee_calc', title=_(u'Fee'), data_type=currency),
+                SearchColumn('auth', title=_(u'Authorization'), data_type=int,
+                             visible=False)]
+
+    def row_activate(self, obj):
+        selected = self.results.get_selected()
+        self._show_details(selected)
 
     def executer_query(self, store):
         provider = self.provider_filter.get_state().value
-        return self.search_table.find_by_provider(store, provider)
+        resultset = self.search_spec.find_by_provider(store, provider)
 
-    def _print_report(self):
-        print_report(CardPaymentReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
+        if api.sysparam.get_bool('SYNCHRONIZED_MODE'):
+            current = api.get_current_branch(self.store)
+            resultset = resultset.find(Payment.branch_id == current.id)
 
-    def on_selection_changed(self, results, selected):
+        return resultset
+
+    def on_results__selection_changed(self, results, selected):
         can_details = bool(selected)
         self.set_details_button_sensitive(can_details)
 
     #
-    #Private
+    # Private
     #
 
     def _show_details(self, receivable_view):
@@ -214,12 +235,9 @@ class CardPaymentSearch(SearchDialog):
             run_dialog(LonelyPaymentDetailsDialog, self, self.store, payment)
 
     #
-    #Callbacks
+    # Callbacks
     #
 
-    def on_print_button_clicked(self, widget):
-        self._print_report()
-
     def on_details_button_clicked(self, button):
         selected = self.results.get_selected()
         self._show_details(selected)
