@@ -26,15 +26,19 @@
 import datetime
 from decimal import Decimal
 
-from kiwi.argcheck import argcheck
-from kiwi.db.query import DateQueryState, DateIntervalQueryState
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import Column, SearchColumn
+from kiwi.ui.objectlist import Column
 import pango
+from storm.expr import Eq
 
 from stoqlib.api import api
-from stoqlib.domain.person import Individual
+from stoqlib.database.queryexecuter import DateQueryState, DateIntervalQueryState
+from stoqlib.domain.person import (Individual, EmployeeRole,
+                                   Branch, BranchView,
+                                   Client, ClientView,
+                                   Employee, EmployeeView,
+                                   TransporterView,
+                                   SupplierView, UserView)
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import format_phone_number
 from stoqlib.gui.editors.personeditor import (ClientEditor, SupplierEditor,
@@ -42,16 +46,12 @@ from stoqlib.gui.editors.personeditor import (ClientEditor, SupplierEditor,
                                               TransporterEditor,
                                               EmployeeRoleEditor, BranchEditor,
                                               UserEditor)
-from stoqlib.gui.base.search import SearchEditor
+from stoqlib.gui.search.searcheditor import SearchEditor
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.clientdetails import ClientDetailsDialog
 from stoqlib.gui.dialogs.supplierdetails import SupplierDetailsDialog
-from stoqlib.domain.person import (EmployeeRole,
-                                   Branch, BranchView,
-                                   Client, ClientView,
-                                   Employee, EmployeeView,
-                                   TransporterView,
-                                   SupplierView, UserView)
+from stoqlib.gui.search.searchcolumns import SearchColumn
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 
 _ = stoqlib_gettext
@@ -60,20 +60,16 @@ _ = stoqlib_gettext
 class BasePersonSearch(SearchEditor):
     size = (-1, 500)
     title = _('Person Search')
-    table = None
+    search_spec = None
     interface = None
     editor_class = None
-    search_lbl_text = None
-    result_strings = None
 
     def __init__(self, store, title='', hide_footer=True):
         self.title = title or self.title
-        SearchEditor.__init__(self, store, self.table,
+        SearchEditor.__init__(self, store,
                               self.editor_class,
                               interface=self.interface,
                               hide_footer=hide_footer)
-        self.set_searchbar_labels(self.search_lbl_text)
-        self.set_result_strings(*self.result_strings)
 
     def run_dialog(self, editor_class, parent, *args, **kwargs):
         return run_person_role_dialog(editor_class, parent, *args, **kwargs)
@@ -82,9 +78,7 @@ class BasePersonSearch(SearchEditor):
 class EmployeeSearch(BasePersonSearch):
     title = _('Employee Search')
     editor_class = EmployeeEditor
-    table = EmployeeView
-    search_lbl_text = _('matching:')
-    result_strings = _('employee'), _('employees')
+    search_spec = EmployeeView
 
     def _get_status_values(self):
         items = [(value, key) for key, value in
@@ -125,12 +119,11 @@ class SupplierSearch(BasePersonSearch):
     title = _('Supplier Search')
     editor_class = SupplierEditor
     size = (800, 450)
-    table = SupplierView
-    search_lbl_text = _('Suppliers Matching:')
-    result_strings = _('supplier'), _('suppliers')
+    search_spec = SupplierView
+    search_label = _('Suppliers Matching:')
 
     def __init__(self, store, **kwargs):
-        self.company_doc_l10n = api.get_l10n_field(store, 'company_document')
+        self.company_doc_l10n = api.get_l10n_field('company_document')
         SearchEditor.__init__(self, store, **kwargs)
 
     #
@@ -167,13 +160,12 @@ class SupplierSearch(BasePersonSearch):
 class ClientSearch(BasePersonSearch):
     title = _('Client Search')
     editor_class = ClientEditor
-    table = ClientView
-    search_lbl_text = _('matching:')
-    result_strings = _('client'), _('clients')
+    search_spec = ClientView
+    search_label = _('matching:')
 
     def __init__(self, store, **kwargs):
-        self.company_doc_l10n = api.get_l10n_field(store, 'company_document')
-        self.person_doc_l10n = api.get_l10n_field(store, 'person_document')
+        self.company_doc_l10n = api.get_l10n_field('company_document')
+        self.person_doc_l10n = api.get_l10n_field('person_document')
         SearchEditor.__init__(self, store, **kwargs)
 
     #
@@ -218,7 +210,6 @@ class ClientSearch(BasePersonSearch):
         else:
             raise AssertionError
 
-    @argcheck(ClientView)
     def get_editor_model(self, client_view):
         return client_view.client
 
@@ -235,9 +226,8 @@ class ClientSearch(BasePersonSearch):
 class TransporterSearch(BasePersonSearch):
     title = _('Transporter Search')
     editor_class = TransporterEditor
-    table = TransporterView
-    search_lbl_text = _('matching:')
-    result_strings = _('transporter'), _('transporters')
+    search_spec = TransporterView
+    search_label = _('matching:')
 
     def create_filters(self):
         self.set_text_field_columns(['name', 'phone_number'])
@@ -265,22 +255,17 @@ class TransporterSearch(BasePersonSearch):
 class EmployeeRoleSearch(SearchEditor):
     title = _('Employee Role Search')
     editor_class = EmployeeRoleEditor
-    table = EmployeeRole
+    search_spec = EmployeeRole
+    search_label = _('Role Matching')
     size = (-1, 390)
     advanced_search = False
 
-    def __init__(self, store):
-        SearchEditor.__init__(self, store, EmployeeRoleSearch.table,
-                              EmployeeRoleSearch.editor_class)
-        self.set_result_strings(_('role'), _('roles'))
-
     #
     # SearchEditor Hooks
     #
 
     def create_filters(self):
         self.set_text_field_columns(['name'])
-        self.set_searchbar_labels(_('Role Matching'))
 
     def get_columns(self):
         return [Column('name', _('Role'), str, sorted=True, expand=True)]
@@ -289,9 +274,8 @@ class EmployeeRoleSearch(SearchEditor):
 class BranchSearch(BasePersonSearch):
     title = _('Branch Search')
     editor_class = BranchEditor
-    table = BranchView
-    search_lbl_text = _('matching')
-    result_strings = (_('branch'), _('branches'))
+    search_spec = BranchView
+    search_label = _('matching')
 
     #
     # SearchEditor Hooks
@@ -305,12 +289,15 @@ class BranchSearch(BasePersonSearch):
         status_filter = ComboSearchFilter(_('Show branches with status'),
                                           statuses)
         status_filter.select(None)
-        self.executer.add_filter_query_callback(
+        executer = self.search.get_query_executer()
+        executer.add_filter_query_callback(
             status_filter, self._get_status_query)
         self.search.add_filter(status_filter, SearchFilterPosition.TOP)
 
     def get_columns(self):
         return [SearchColumn('name', _('Name'), str, expand=True, sorted=True),
+                SearchColumn('fancy_name', _('Fancy name'), str, expand=True,
+                             visible=False),
                 SearchColumn('acronym', _('Acronym'), data_type=str,
                              visible=False),
                 SearchColumn('phone_number', _('Phone Number'), str,
@@ -328,18 +315,17 @@ class BranchSearch(BasePersonSearch):
 
     def _get_status_query(self, state):
         if state.value == Branch.STATUS_ACTIVE:
-            return Branch.is_active == True
+            return Eq(Branch.is_active, True)
         elif state.value == Branch.STATUS_INACTIVE:
-            return Branch.is_active == False
+            return Eq(Branch.is_active, False)
 
 
 class UserSearch(BasePersonSearch):
     title = _('User Search')
     editor_class = UserEditor
     size = (750, 450)
-    table = UserView
-    search_lbl_text = _('Users Matching:')
-    result_strings = _('user'), _('users')
+    search_spec = UserView
+    search_label = _('Users Matching:')
 
     #
     # SearchDialog hooks
@@ -350,7 +336,7 @@ class UserSearch(BasePersonSearch):
 
     def get_columns(self):
         return [SearchColumn('username', title=_('Login Name'), sorted=True,
-                              data_type=str, width=150, searchable=True),
+                             data_type=str, width=150, searchable=True),
                 SearchColumn('profile_name', title=_('Profile'),
                              data_type=str, width=120,
                              ellipsize=pango.ELLIPSIZE_END),
@@ -362,7 +348,7 @@ class UserSearch(BasePersonSearch):
     def on_details_button_clicked(self, *args):
         # FIXME: Person editor/slaves are depending on the store being a
         # StoqlibStore. See bug 5012
-        with api.trans() as store:
+        with api.new_store() as store:
             selected = self.results.get_selected()
             user = store.fetch(selected.user)
             run_dialog(UserEditor, self, store, user, visual_mode=True)
