@@ -23,76 +23,83 @@
 ##
 """ Search dialogs for product objects """
 
+import datetime
 from decimal import Decimal
 
 import gtk
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
-from kiwi.db.query import DateQueryState, DateIntervalQueryState
-from kiwi.ui.search import ComboSearchFilter, DateSearchFilter, Today
-from kiwi.ui.objectlist import Column, ColoredColumn, SearchColumn
+from kiwi.ui.objectlist import Column, ColoredColumn
+from storm.expr import Eq
 
 from stoqlib.api import api
+from stoqlib.database.queryexecuter import DateQueryState, DateIntervalQueryState
 from stoqlib.domain.person import Branch
-from stoqlib.domain.product import Product, ProductHistory
-from stoqlib.domain.sellable import Sellable
+from stoqlib.domain.product import (Product, ProductHistory,
+                                    StorableBatch,
+                                    ProductStockItem)
+from stoqlib.domain.sellable import SellableCategory
 from stoqlib.domain.views import (ProductQuantityView,
                                   ProductFullStockItemView, SoldItemView,
                                   ProductFullWithClosedStockView,
-                                  ProductClosedStockView)
+                                  ProductClosedStockView,
+                                  ProductBranchStockView,
+                                  ProductBatchView, ProductBrandStockView)
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.base.gtkadds import change_button_appearance
-from stoqlib.gui.base.search import (SearchDialog, SearchEditor,
-                                     SearchDialogPrintSlave)
-from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.editors.producteditor import (ProductEditor,
                                                ProductStockEditor)
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.search.searchcolumns import SearchColumn
+from stoqlib.gui.search.searchdialog import SearchDialog, SearchDialogPrintSlave
+from stoqlib.gui.search.searcheditor import SearchEditor
+from stoqlib.gui.search.searchfilters import (DateSearchFilter, ComboSearchFilter,
+                                              Today)
+from stoqlib.gui.search.sellablesearch import SellableSearch
+from stoqlib.gui.utils.printing import print_report
+from stoqlib.gui.wizards.productwizard import ProductCreateWizard
 from stoqlib.lib.defaults import sort_sellable_code
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import format_quantity, get_formatted_cost
 from stoqlib.reporting.product import (ProductReport, ProductQuantityReport,
                                        ProductClosedStockReport,
                                        ProductPriceReport, ProductStockReport,
-                                       ProductsSoldReport)
+                                       ProductsSoldReport, ProductBrandReport)
 
 _ = stoqlib_gettext
 
 
-class ProductSearch(SearchEditor):
+class ProductSearch(SellableSearch):
     title = _('Product Search')
     table = Product
-    size = (775, 450)
-    search_table = ProductFullWithClosedStockView
+    search_spec = ProductFullWithClosedStockView
     editor_class = ProductEditor
+    report_class = ProductReport
+    has_branch_filter = True
+    has_status_filter = True
+    has_print_price_button = True
+    csv_data = (_("Product"), _("product"))
     footer_ok_label = _('Add products')
-    searchbar_result_strings = (_('product'), _('products'))
 
     def __init__(self, store, hide_footer=True, hide_toolbar=False,
-                 selection_mode=gtk.SELECTION_BROWSE,
-                 hide_cost_column=False, use_product_statuses=None,
-                 hide_price_column=False):
+                 hide_cost_column=False, hide_price_column=False,
+                 double_click_confirm=False):
         """
-        Create a new ProductSearch object.
         :param store: a store
         :param hide_footer: do I have to hide the dialog footer?
         :param hide_toolbar: do I have to hide the dialog toolbar?
-        :param selection_mode: the kiwi list selection mode
         :param hide_cost_column: if it's True, no need to show the
                                  column 'cost'
-        :param use_product_statuses: a list instance that, if provided, will
-                                     overwrite the statuses list defined in
-                                     get_filter_slave method
         :param hide_price_column: if it's True no need to show the
                                   column 'price'
         """
-        self.use_product_statuses = use_product_statuses
         self.hide_cost_column = hide_cost_column
         self.hide_price_column = hide_price_column
-        SearchEditor.__init__(self, store, hide_footer=hide_footer,
-                              hide_toolbar=hide_toolbar,
-                              selection_mode=selection_mode)
-        self.set_searchbar_labels(_('matching'))
-        self._setup_print_slave()
+        SellableSearch.__init__(self, store, hide_footer=hide_footer,
+                                hide_toolbar=hide_toolbar,
+                                double_click_confirm=double_click_confirm)
+        if self.has_print_price_button:
+            self._setup_print_slave()
+        else:
+            self._print_slave = None
 
     def _setup_print_slave(self):
         self._print_slave = SearchDialogPrintSlave()
@@ -101,75 +108,64 @@ class ProductSearch(SearchEditor):
         self.attach_slave('print_holder', self._print_slave)
         self._print_slave.connect('print', self.on_print_price_button_clicked)
         self._print_slave.print_price_button.set_sensitive(False)
-        self.results.connect('has-rows', self._has_rows)
-
-    def on_print_button_clicked(self, button):
-        print_report(ProductReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
 
     def on_print_price_button_clicked(self, button):
         print_report(ProductPriceReport, list(self.results),
                      filters=self.search.get_search_filters(),
                      branch_name=self.branch_filter.combo.get_active_text())
 
-    def _has_rows(self, results, obj):
-        SearchEditor._has_rows(self, results, obj)
-        self._print_slave.print_price_button.set_sensitive(obj)
-
     #
-    # SearchDialog Hooks
+    #  ProductSearch
     #
 
     def setup_widgets(self):
-        self.csv_button = self.add_button(label=_('Export to spreadsheet...'))
-        self.csv_button.connect('clicked', self._on_export_csv_button__clicked)
-        self.csv_button.show()
-        self.csv_button.set_sensitive(False)
+        super(ProductSearch, self).setup_widgets()
 
-        self.results.connect('has_rows', self._on_results__has_rows)
+        if self.csv_data is not None:
+            self.add_csv_button(*self.csv_data)
 
     def create_filters(self):
-        self.set_text_field_columns(['description', 'barcode',
-                                     'category_description'])
-        self.executer.set_query(self.executer_query)
+        super(ProductSearch, self).create_filters()
 
-        # Branch
-        branch_filter = self.create_branch_filter(_('In branch:'))
-        branch_filter.select(None)
-        self.add_filter(branch_filter, columns=[])
-        self.branch_filter = branch_filter
+        if self.has_branch_filter:
+            branch_filter = self.create_branch_filter(_('In branch:'))
+            self.add_filter(branch_filter, columns=[])
+            self.branch_filter = branch_filter
+        else:
+            self.branch_filter = None
 
-        # Status
-        statuses = [(desc, id) for id, desc in Sellable.statuses.items()]
-        statuses.insert(0, (_('Any'), None))
-        status_filter = ComboSearchFilter(_('with status:'), statuses)
-        status_filter.select(None)
-        self.add_filter(status_filter, columns=['status'],
-                        position=SearchFilterPosition.TOP)
-        self.status_filter = status_filter
+        if self.has_status_filter:
+            status_filter = self.create_sellable_filter()
+            self.add_filter(status_filter, columns=['status'],
+                            position=SearchFilterPosition.TOP)
+            self.status_filter = status_filter
+        else:
+            self.status_filter = None
 
-    #
-    # SearchEditor Hooks
-    #
+    def get_editor_class_for_object(self, obj):
+        if obj is None:
+            return ProductCreateWizard
+
+        return self.editor_class
 
     def get_editor_model(self, product_full_stock_view):
         return product_full_stock_view.product
 
     def get_columns(self):
         cols = [SearchColumn('code', title=_('Code'), data_type=str,
-                              sort_func=sort_sellable_code,
-                              sorted=True),
+                             sort_func=sort_sellable_code,
+                             sorted=True),
                 SearchColumn('barcode', title=_('Barcode'), data_type=str),
                 SearchColumn('category_description', title=_(u'Category'),
                              data_type=str, width=120),
                 SearchColumn('description', title=_(u'Description'),
                              expand=True, data_type=str),
-                SearchColumn('manufacturer', title=_('Manufacturer'), data_type=str,
-                             visible=False),
+                SearchColumn('manufacturer', title=_('Manufacturer'),
+                             data_type=str, visible=False),
                 SearchColumn('model', title=_('Model'), data_type=str,
                              visible=False),
                 SearchColumn('location', title=_('Location'), data_type=str,
-                              visible=False)]
+                             visible=False)]
         # The price/cost columns must be controlled by hide_cost_column and
         # hide_price_column. Since the product search will be available across
         # the applications, it's important to restrict such columns depending
@@ -178,10 +174,10 @@ class ProductSearch(SearchEditor):
             cols.append(SearchColumn('cost', _('Cost'), data_type=currency,
                                      format_func=get_formatted_cost, width=90))
         if not self.hide_price_column:
-            cols.append(Column('price', title=_('Price'),
+            cols.append(SearchColumn('price', title=_('Price'),
                                      data_type=currency, width=90))
 
-        cols.append(Column('stock', title=_('Stock'),
+        cols.append(SearchColumn('stock', title=_('Stock'),
                                  format_func=format_quantity,
                                  data_type=Decimal, width=80))
         return cols
@@ -192,21 +188,16 @@ class ProductSearch(SearchEditor):
             branch = None
         else:
             branch = store.get(Branch, branch_id)
-        results = self.search_table.find_by_branch(store, branch)
-        return results.find(Product.is_composed == False)
+        results = self.search_spec.find_by_branch(store, branch)
+        return results.find(Eq(Product.is_composed, False))
 
     #
     # Callbacks
     #
 
-    def _on_export_csv_button__clicked(self, widget):
-        sse = SpreadSheetExporter()
-        sse.export(object_list=self.results,
-                   name=_('Product'),
-                   filename_prefix=_('product'))
-
-    def _on_results__has_rows(self, widget, has_rows):
-        self.csv_button.set_sensitive(has_rows)
+    def on_results__has_rows(self, results, obj):
+        if self._print_slave is not None:
+            self._print_slave.print_price_button.set_sensitive(obj)
 
 
 def format_data(data):
@@ -216,20 +207,22 @@ def format_data(data):
     return format_quantity(data)
 
 
-class ProductSearchQuantity(SearchDialog):
+class ProductSearchQuantity(ProductSearch):
     title = _('Product History Search')
-    size = (775, 450)
-    table = search_table = ProductQuantityView
+    table = search_spec = ProductQuantityView
+    report_class = ProductQuantityReport
+    csv_data = None
     advanced_search = False
+    has_print_price_button = False
     show_production_columns = False
 
-    #
-    # SearchDialog Hooks
-    #
+    def __init__(self, store, hide_footer=True, hide_toolbar=True):
+        ProductSearch.__init__(self, store, hide_footer=hide_footer,
+                               hide_toolbar=hide_toolbar)
 
-    def on_print_button_clicked(self, button):
-        print_report(ProductQuantityReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
+    #
+    #  ProductSearch
+    #
 
     def create_filters(self):
         self.set_text_field_columns(['description'])
@@ -248,12 +241,9 @@ class ProductSearchQuantity(SearchDialog):
         self.branch_filter = self.create_branch_filter(_('In branch:'))
         self.add_filter(self.branch_filter, columns=['branch'],
                         position=SearchFilterPosition.TOP)
-        # remove 'Any' option from branch_filter
-        self.branch_filter.combo.remove_text(0)
-
-    #
-    # SearchEditor Hooks
-    #
+        if not api.sysparam.get_bool('SYNCHRONIZED_MODE'):
+            # remove 'Any' option from branch_filter
+            self.branch_filter.combo.remove_text(0)
 
     def get_columns(self):
         return [Column('code', title=_('Code'), data_type=str,
@@ -284,23 +274,25 @@ class ProductSearchQuantity(SearchDialog):
                        visible=self.show_production_columns, )]
 
 
-class ProductsSoldSearch(SearchDialog):
+class ProductsSoldSearch(ProductSearch):
     title = _('Products Sold Search')
-    size = (775, 450)
-    table = search_table = SoldItemView
+    table = search_spec = SoldItemView
+    report_class = ProductsSoldReport
+    csv_data = None
+    has_print_price_button = False
     advanced_search = False
 
-    def on_print_button_clicked(self, button):
-        print_report(ProductsSoldReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
+    def __init__(self, store, hide_footer=True, hide_toolbar=True):
+        ProductSearch.__init__(self, store, hide_footer=hide_footer,
+                               hide_toolbar=hide_toolbar)
 
     #
-    # SearchDialog Hooks
+    #  ProductSearch
     #
 
     def create_filters(self):
         self.set_text_field_columns(['description'])
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
 
         # Date
         date_filter = DateSearchFilter(_('Date:'))
@@ -310,7 +302,6 @@ class ProductsSoldSearch(SearchDialog):
 
         # Branch
         branch_filter = self.create_branch_filter(_('In branch:'))
-        branch_filter.select(None)
         self.add_filter(branch_filter, columns=[],
                         position=SearchFilterPosition.TOP)
         self.branch_filter = branch_filter
@@ -332,76 +323,58 @@ class ProductsSoldSearch(SearchDialog):
             date = (date.start, date.end)
 
         return self.table.find_by_branch_date(store, branch, date)
-    #
-    # SearchEditor Hooks
-    #
 
     def get_columns(self):
         return [Column('code', title=_('Code'), data_type=str,
-                       sorted=True, width=130),
-                Column('description', title=_('Description'), data_type=str,
-                       width=300),
+                       sorted=True),
+                Column('description', title=_('Description'),
+                       data_type=str, expand=True),
                 Column('quantity', title=_('Sold'),
                        format_func=format_data,
                        data_type=Decimal),
                 Column('average_cost', title=_('Avg. Cost'),
-                       data_type=currency),
-               ]
+                       data_type=currency), ]
 
 
-class ProductStockSearch(SearchEditor):
+class ProductStockSearch(ProductSearch):
     title = _('Product Stock Search')
-    size = (800, 450)
     # FIXME: This search needs another viewable, since ProductFullStockView
     # cannot filter the branch of the purchase, when counting the number of
     # purchased orders by branch
-    table = search_table = ProductFullStockItemView
+    table = search_spec = ProductFullStockItemView
     editor_class = ProductStockEditor
+    report_class = ProductStockReport
+    csv_data = None
+    has_print_price_button = False
     has_new_button = False
-    searchbar_result_strings = (_('product'), _('products'))
+    has_status_filter = False
     advanced_search = True
 
     #
-    # SearchDialog Hooks
+    #  ProductSearch
     #
 
     def setup_widgets(self):
+        super(ProductStockSearch, self).setup_widgets()
+
         difference_label = gtk.Label()
         difference_label.set_markup(
             "<small><b>%s</b></small>"
             % api.escape(_(u"The DIFFERENCE column is equal to "
                            "IN STOCK minus MINIMUM columns")))
         difference_label.show()
-        self.search.search.pack_end(difference_label, False, False, 6)
-
-    def create_filters(self):
-        self.set_text_field_columns(['description', 'category_description'])
-        self.executer.set_query(self.executer_query)
-
-        branch_filter = self.create_branch_filter(_('In branch:'))
-        branch_filter.select(api.get_current_branch(self.store).id)
-        self.add_filter(branch_filter, columns=[])
-        self.branch_filter = branch_filter
-
-    def on_print_button_clicked(self, widget):
-        print_report(ProductStockReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
-
-    #
-    # SearchEditor Hooks
-    #
-
-    def get_editor_model(self, model):
-        return model.product
+        self.search.vbox.pack_end(difference_label, False, False, 6)
 
     def get_columns(self):
         return [SearchColumn('code', title=_('Code'), data_type=str,
                              sort_func=sort_sellable_code),
                 SearchColumn('category_description', title=_('Category'),
                              data_type=str, width=100),
-                SearchColumn('description', title=_('Description'), data_type=str,
+                SearchColumn('description', title=_('Description'),
+                             data_type=str,
                              expand=True, sorted=True),
-                SearchColumn('manufacturer', title=_('Manufacturer'), data_type=str,
+                SearchColumn('manufacturer', title=_('Manufacturer'),
+                             data_type=str,
                              visible=False),
                 SearchColumn('model', title=_('Model'), data_type=str,
                              visible=False),
@@ -412,10 +385,11 @@ class ProductStockSearch(SearchEditor):
                              data_type=Decimal),
                 SearchColumn('minimum_quantity', title=_('Minimum'),
                              format_func=format_data, data_type=Decimal),
-                Column('stock', title=_('In Stock'),
-                       format_func=format_data, data_type=Decimal),
-                Column('to_receive_quantity', title=_('To Receive'),
-                       format_func=format_data, data_type=Decimal),
+                SearchColumn('stock', title=_('In Stock'),
+                             format_func=format_data, data_type=Decimal),
+                SearchColumn('to_receive_quantity', title=_('To Receive'),
+                             format_func=format_data,
+                             data_type=Decimal),
                 ColoredColumn('difference', title=_('Difference'), color='red',
                               format_func=format_data, data_type=Decimal,
                               data_func=lambda x: x <= Decimal(0))]
@@ -433,39 +407,172 @@ class ProductClosedStockSearch(ProductSearch):
     """A SearchEditor for Closed Products"""
 
     title = _('Closed Product Stock Search')
-    table = search_table = ProductClosedStockView
+    table = search_spec = ProductClosedStockView
+    report_class = ProductClosedStockReport
+    has_status_filter = False
+    has_print_price_button = False
     has_new_button = False
 
     def __init__(self, store, hide_footer=True, hide_toolbar=True,
-                 selection_mode=gtk.SELECTION_BROWSE,
-                 hide_cost_column=True, use_product_statuses=None,
-                 hide_price_column=True):
+                 hide_cost_column=True, hide_price_column=True):
         ProductSearch.__init__(self, store, hide_footer, hide_toolbar,
-                               selection_mode, hide_cost_column,
-                               use_product_statuses, hide_price_column)
+                               hide_cost_column=hide_cost_column,
+                               hide_price_column=hide_price_column)
+
+
+class ProductBatchSearch(ProductSearch):
+    title = _('Batch Search')
+    table = StorableBatch
+    search_spec = ProductBatchView
+    has_print_price_button = False
+    csv_data = (_('Batch'), _('batch'))
+
+    def __init__(self, store, hide_footer=True, hide_toolbar=True):
+        ProductSearch.__init__(self, store, hide_footer=hide_footer,
+                               hide_toolbar=hide_toolbar)
+
+    #
+    #  ProductSearch
+    #
+
+    def setup_widgets(self):
+        super(ProductBatchSearch, self).setup_widgets()
+        self.search.set_summary_label('quantity', label=(u'Total:'),
+                                      format='<b>%s</b>')
 
     def create_filters(self):
-        self.set_text_field_columns(['description', 'barcode',
-                                     'category_description'])
-        self.executer.set_query(self.executer_query)
+        self.set_text_field_columns(['description', 'batch_number'])
 
         # Branch
         branch_filter = self.create_branch_filter(_('In branch:'))
-        branch_filter.select(None)
-        self.add_filter(branch_filter, columns=[])
+        self.add_filter(branch_filter, columns=[ProductStockItem.branch_id])
         self.branch_filter = branch_filter
 
-    def _setup_print_slave(self):
-        pass
+        # Dont set a limit here, otherwise it might break the summary
+        executer = self.search.get_query_executer()
+        executer.set_limit(-1)
 
-    def _has_rows(self, results, obj):
-        SearchEditor._has_rows(self, results, obj)
+    def get_columns(self):
+        cols = [SearchColumn('category', title=_('Category'), data_type=str),
+                SearchColumn('description', title=_('Description'), data_type=str,
+                             sorted=True, expand=True),
+                SearchColumn('manufacturer', title=_('Manufacturer'),
+                             data_type=str, visible=False),
+                SearchColumn('model', title=_('Model'),
+                             data_type=str, visible=False),
+                SearchColumn('batch_number', title=_('Batch'), data_type=str),
+                SearchColumn('batch_date', title=_('Date'),
+                             data_type=datetime.date),
+                SearchColumn('quantity', title=_('Qty'), data_type=Decimal)]
+        return cols
+
+
+class ProductBrandSearch(SearchEditor):
+    title = _('Brand Search')
+    table = Product
+    size = (775, 450)
+    search_spec = ProductBrandStockView
+    editor_class = ProductEditor
+    report_class = ProductBrandReport
+
+    def __init__(self, store):
+        SearchEditor.__init__(self, store, hide_footer=True,
+                              hide_toolbar=True)
 
     #
     # SearchDialog Hooks
     #
 
-    def on_print_button_clicked(self, widget):
-        print_report(ProductClosedStockReport, self.results,
-                     filters=self.search.get_search_filters(),
-                     branch_name=self.branch_filter.combo.get_active_text())
+    def setup_widgets(self):
+        self.add_csv_button(_('Brands'), _('brands'))
+
+        self.search.set_summary_label('quantity', label=_(u'Total:'),
+                                      format='<b>%s</b>')
+
+    def create_filters(self):
+        self.set_text_field_columns(['brand'])
+        self.search.set_query(self.executer_query)
+
+        # Branch
+        branch_filter = self.create_branch_filter(_('In branch:'))
+        self.add_filter(branch_filter, columns=[])
+        self.branch_filter = branch_filter
+
+        # Category
+        categories = self.store.find(SellableCategory)
+        items = api.for_combo(categories, attr='full_description')
+        items.insert(0, (_('Any'), None))
+        category_filter = ComboSearchFilter(_('Category'), items)
+        self.add_filter(category_filter, position=SearchFilterPosition.TOP)
+        self.category_filter = category_filter
+
+    #
+    # SearchEditor Hooks
+    #
+
+    def get_columns(self):
+        cols = [SearchColumn('brand', title=_('Brand'), data_type=str,
+                             sorted=True, expand=True),
+                Column('quantity', title=_('Quantity'), data_type=Decimal)]
+        return cols
+
+    def executer_query(self, store):
+        branch_id = self.branch_filter.get_state().value
+        if branch_id is None:
+            branch = None
+        else:
+            branch = store.get(Branch, branch_id)
+
+        category_description = self.category_filter.get_state().value
+        if category_description:
+            category = category_description
+        else:
+            category = None
+
+        return self.search_spec.find_by_branch_category(store, branch, category)
+
+
+class ProductBranchSearch(SearchDialog):
+    """Show products in stock on all branchs
+    """
+    title = _('Product Branch Search')
+    size = (600, 500)
+    search_spec = ProductBranchStockView
+    advanced_search = False
+
+    def __init__(self, store, storable):
+        self._storable = storable
+        dialog_title = _("Stock of %s") % storable.product.description
+        SearchDialog.__init__(self, store, title=dialog_title)
+        self.search.refresh()
+
+    #
+    # SearchDialog Hooks
+    #
+
+    def create_filters(self):
+        self.set_text_field_columns(['branch_name'])
+        self.search.set_query(self.executer_query)
+
+    #
+    # SearchEditor Hooks
+    #
+
+    def get_columns(self):
+        return [Column('branch_name', title=_('Branch'), data_type=str,
+                       expand=True),
+                Column('stock', title=_('In Stock'), data_type=Decimal,
+                       format_func=format_data)]
+
+    def executer_query(self, store):
+        return self.search_spec.find_by_storable(store, self._storable)
+
+
+def test():  # pragma: no cover
+    from stoqlib.gui.base.dialogs import run_dialog
+    ec = api.prepare_test()
+    run_dialog(ProductSearch, None, ec.store)
+
+
+if __name__ == '__main__':
+    test()
