@@ -28,14 +28,13 @@ import datetime
 
 import gtk
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.objectlist import SearchColumn
 
 from stoqlib.domain.views import PurchaseReceivingView
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.gui.base.search import SearchDialog
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchdialog import SearchDialog
 from stoqlib.gui.dialogs.receivingdialog import ReceivingOrderDetailsDialog
-from stoqlib.gui.printing import print_report
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.reporting.purchasereceival import PurchaseReceivalReport
 
@@ -45,13 +44,12 @@ _ = stoqlib_gettext
 class PurchaseReceivingSearch(SearchDialog):
     title = _('Purchase Receiving Search')
     size = (750, 500)
-    table = PurchaseReceivingView
+    search_spec = PurchaseReceivingView
+    report_class = PurchaseReceivalReport
     selection_mode = gtk.SELECTION_MULTIPLE
-    searchbar_result_strings = _('receiving order'), _('receiving orders')
 
     def __init__(self, store):
-        SearchDialog.__init__(self, store, self.search_table,
-                              title=self.title)
+        SearchDialog.__init__(self, store)
         self._setup_widgets()
 
     def _show_receiving_order(self, receiving_order_view):
@@ -63,9 +61,9 @@ class PurchaseReceivingSearch(SearchDialog):
     #
 
     def create_filters(self):
-        self.set_searchbar_labels(_('matching:'))
         self.set_text_field_columns(['supplier_name', 'responsible_name',
-                                     'purchase_responsible_name'])
+                                     'purchase_responsible_name',
+                                     'purchase_identifier_str'])
 
         # Branch
         branch_filter = self.create_branch_filter(_("In branch:"))
@@ -73,8 +71,7 @@ class PurchaseReceivingSearch(SearchDialog):
                         position=SearchFilterPosition.TOP)
 
     def get_columns(self):
-        return [SearchColumn('purchase_identifier', _('Purchase order #'),
-                             data_type=int, width=120),
+        return [IdentifierColumn('purchase_identifier', _('Purchase #')),
                 SearchColumn('receival_date', _('Receival date'),
                              data_type=datetime.date, sorted=True, width=110),
                 SearchColumn('supplier_name', _('Supplier'), data_type=str,
@@ -103,13 +100,9 @@ class PurchaseReceivingSearch(SearchDialog):
     def on_row_activated(self, klist, receiving_order):
         self._show_receiving_order(receiving_order)
 
-    def on_print_button_clicked(self, button):
-        print_report(PurchaseReceivalReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
-
     def on_details_button_clicked(self, button):
         items = self.results.get_selected_rows()
-        if  not len(items) == 1:
+        if not len(items) == 1:
             raise ValueError("You should have only one item selected at "
                              "this point ")
         selected = items[0]
