@@ -31,21 +31,24 @@ from decimal import Decimal
 import pango
 import gtk
 from kiwi.currency import currency
-from kiwi.db.query import DateQueryState, DateIntervalQueryState
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
-from kiwi.ui.objectlist import SearchColumn, Column
+from kiwi.ui.objectlist import Column
 
-from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.formatters import format_quantity
-from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.search import SearchDialog
-from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
-from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
-from stoqlib.gui.printing import print_report
+from stoqlib.api import api
+from stoqlib.database.queryexecuter import DateQueryState, DateIntervalQueryState
 from stoqlib.domain.person import Branch
 from stoqlib.domain.sale import Sale, SaleView, SalePaymentMethodView
-from stoqlib.domain.views import SoldItemsByBranchView
+from stoqlib.domain.till import Till
+from stoqlib.domain.views import SoldItemsByBranchView, ReservedProductView
+from stoqlib.domain.workorder import WorkOrder
+from stoqlib.enums import SearchFilterPosition
+from stoqlib.exceptions import TillError
+from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchfilters import ComboSearchFilter, DateSearchFilter
+from stoqlib.gui.search.searchdialog import SearchDialog
+from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.lib.formatters import format_quantity
 from stoqlib.gui.slaves.saleslave import SaleListToolbar
 from stoqlib.reporting.sale import SoldItemsByBranchReport
 
@@ -55,7 +58,7 @@ _ = stoqlib_gettext
 class _BaseSaleSearch(SearchDialog):
     title = _("Search for Sales")
     size = (-1, 450)
-    search_table = SaleView
+    search_spec = SaleView
     searching_by_date = True
 
     #
@@ -63,17 +66,25 @@ class _BaseSaleSearch(SearchDialog):
     #
 
     def create_filters(self):
-        self.set_text_field_columns(['client_name', 'salesperson_name'])
-        self.set_searchbar_labels(_('matching:'))
+        self.set_text_field_columns(['client_name', 'salesperson_name',
+                                     'identifier_str'])
         items = [(value, key) for key, value in Sale.statuses.items()]
         items.insert(0, (_('Any'), None))
 
         status_filter = ComboSearchFilter(_('Show sales with status'), items)
         self.add_filter(status_filter, SearchFilterPosition.TOP, ['status'])
 
+        self.search.set_query(self.executer_query)
+
+    def executer_query(self, store):
+        if api.sysparam.get_bool('SYNCHRONIZED_MODE'):
+            current = api.get_current_branch(self.store)
+            return self.store.find(self.search_spec, Branch.id == current.id)
+        return self.store.find(self.search_spec)
+
     def get_columns(self):
-        return [SearchColumn('identifier', title=_('#'), width=50, data_type=int,
-                             sorted=True, order=gtk.SORT_DESCENDING),
+        return [IdentifierColumn('identifier', sorted=True,
+                                 order=gtk.SORT_DESCENDING),
                 SearchColumn('open_date', title=_('Date Started'), width=110,
                              data_type=datetime.date, justify=gtk.JUSTIFY_RIGHT),
                 SearchColumn('client_name', title=_('Client'),
@@ -110,12 +121,19 @@ class SaleWithToolbarSearch(_BaseSaleSearch):
     #
 
     def _update_widgets(self, sale_view):
-        if sale_view is None:
-            return
+        sale = sale_view and sale_view.sale
+        try:
+            till = Till.get_current(self.store)
+        except TillError:
+            till = None
+
+        can_edit = bool(sale and sale.can_edit())
+        # We need an open till to return sales
+        if sale and till:
+            can_return = sale.can_return() or sale.can_cancel()
+        else:
+            can_return = False
 
-        sale = sale_view.sale
-        can_edit = sale.can_edit()
-        can_return = sale.can_return() or sale.can_cancel()
         self._sale_toolbar.return_sale_button.set_sensitive(can_return)
         self._sale_toolbar.edit_button.set_sensitive(can_edit)
 
@@ -147,19 +165,23 @@ class SaleSearch(_BaseSaleSearch):
 
 class SalesByPaymentMethodSearch(SaleWithToolbarSearch):
     title = _(u'Search for Sales by Payment Method')
-    search_table = SalePaymentMethodView
+    search_spec = SalePaymentMethodView
+    search_label = _('Items matching:')
     size = (800, 450)
 
     def _get_branch_values(self):
-        items = [(b.person.name, b.id) for b
-                    in Branch.get_active_branches(self.store)]
-        items.insert(0, (_('Any'), None))
+        if api.sysparam.get_bool('SYNCHRONIZED_MODE'):
+            current = api.get_current_branch(self.store)
+            items = [(current.get_description(), current.id)]
+        else:
+            items = [(b.get_description(), b.id) for b
+                     in Branch.get_active_branches(self.store)]
+            items.insert(0, (_('Any'), None))
         return items
 
     def create_filters(self):
         self.set_text_field_columns(['client_name', 'salesperson_name'])
-        self.set_searchbar_labels(_('Items matching:'))
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
 
         payment_filter = self.create_payment_filter(_('Payment Method:'))
         self.add_filter(payment_filter, columns=[])
@@ -167,35 +189,40 @@ class SalesByPaymentMethodSearch(SaleWithToolbarSearch):
 
     def executer_query(self, store):
         method = self.payment_filter.get_state().value
-        return self.search_table.find_by_payment_method(store, method)
+        resultset = self.search_spec.find_by_payment_method(store, method)
+        if api.sysparam.get_bool('SYNCHRONIZED_MODE'):
+            current = api.get_current_branch(self.store)
+            resultset = resultset.find(Branch.id == current.id)
+        return resultset
 
     def get_columns(self):
         columns = SaleWithToolbarSearch.get_columns(self)
         branch_column = SearchColumn('branch_name', title=_('Branch'), width=110,
-                                 data_type=str, search_attribute='branch_id',
-                                 valid_values=self._get_branch_values())
+                                     data_type=str, search_attribute='branch_id',
+                                     valid_values=self._get_branch_values())
         columns.insert(3, branch_column)
         return columns
 
 
 class SoldItemsByBranchSearch(SearchDialog):
     title = _(u'Sold Items by Branch')
-    search_table = SoldItemsByBranchView
+    report_class = SoldItemsByBranchReport
+    search_spec = SoldItemsByBranchView
     searching_by_date = True
+    search_label = _('Items matching:')
     size = (800, 450)
 
     def setup_widgets(self):
-        self.csv_button = self.add_button(label=_('Export to spreadsheet...'))
-        self.csv_button.connect('clicked', self._on_export_csv_button__clicked)
-        self.csv_button.show()
-        self.csv_button.set_sensitive(False)
+        self.add_csv_button(_('Sales'), _('sales'))
 
-        self.results.connect('has_rows', self._on_results__has_rows)
+        self.search.set_summary_label('total', label=_(u'Total:'),
+                                      format='<b>%s</b>')
 
     def create_filters(self):
         self.set_text_field_columns(['description'])
-        self.set_searchbar_labels(_('Items matching:'))
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
+        executer = self.search.get_query_executer()
+        executer.set_limit(-1)
 
         # Date
         date_filter = DateSearchFilter(_('Date:'))
@@ -204,7 +231,6 @@ class SoldItemsByBranchSearch(SearchDialog):
 
         # Branch
         branch_filter = self.create_branch_filter(_('In Branch:'))
-        branch_filter.select(None)
         self.add_filter(branch_filter, columns=[])
         self.branch_filter = branch_filter
 
@@ -220,7 +246,7 @@ class SoldItemsByBranchSearch(SearchDialog):
                 Column('quantity', title=_('Quantity'), data_type=Decimal,
                        format_func=format_quantity, width=100),
                 Column('total', title=_('Total'), data_type=currency, width=80)
-               ]
+                ]
 
     def executer_query(self, store):
         branch_id = self.branch_filter.get_state().value
@@ -235,24 +261,64 @@ class SoldItemsByBranchSearch(SearchDialog):
         elif isinstance(date, DateIntervalQueryState):
             date = (date.start, date.end)
 
-        return self.search_table.find_by_branch_date(store, branch, date)
+        return self.search_spec.find_by_branch_date(store, branch, date)
 
-    def _print_report(self):
-        print_report(SoldItemsByBranchReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
 
-    #
-    # Callbacks
-    #
+class ReservedProductSearch(SearchDialog):
+    title = _(u'Reserved Product Search')
+    search_spec = ReservedProductView
+    size = (850, 450)
 
-    def on_print_button_clicked(self, widget):
-        self._print_report()
+    def setup_widgets(self):
+        self.search.set_summary_label('quantity_decreased', label=_(u'Total:'),
+                                      format='<b>%s</b>')
 
-    def _on_export_csv_button__clicked(self, widget):
-        sse = SpreadSheetExporter()
-        sse.export(object_list=self.results,
-                   name=_('Sales'),
-                   filename_prefix=_('sales'))
+    def create_filters(self):
+        self.set_text_field_columns(['description', 'salesperson_name',
+                                     'client_name'])
+        # Branch
+        self.branch_filter = self.create_branch_filter(_('In Branch:'))
+        self.add_filter(self.branch_filter, columns=['branch_id'])
 
-    def _on_results__has_rows(self, widget, has_rows):
-        self.csv_button.set_sensitive(has_rows)
+    def get_columns(self):
+        return [IdentifierColumn('identifier', title=_('Sale #'),
+                                 sorted=True, order=gtk.SORT_DESCENDING),
+                SearchColumn('status_str', title=_('Status'),
+                             search_attribute='status',
+                             valid_values=self._get_status_values(), data_type=str),
+                SearchColumn('product_code', title=_('Code'), data_type=str),
+                SearchColumn('product_category', title=_('Category'), data_type=str),
+                SearchColumn('description', title=_('Product'), data_type=str,
+                             expand=True),
+                SearchColumn('manufacturer_name', title=_('Manufacturer'),
+                             data_type=str, expand=True, visible=False),
+                SearchColumn('salesperson_name', title=_('Sales Person'),
+                             data_type=str, visible=False),
+                SearchColumn('client_name', title=_('Client'), data_type=str,
+                             visible=False),
+                SearchColumn('open_date', title=_('Open Date'),
+                             data_type=datetime.date),
+                SearchColumn('price', title=_('Price'), data_type=currency,
+                             width=100),
+                SearchColumn('quantity_decreased', title=_('Reserved'), data_type=Decimal,
+                             format_func=format_quantity, width=100),
+                IdentifierColumn('wo_identifier', title=_('Work Order'),
+                                 visible=False, justify=gtk.JUSTIFY_RIGHT),
+                SearchColumn('wo_status_str', title=_('WO Status'), data_type=str,
+                             search_attribute='wo_status', visible=False,
+                             valid_values=self._get_wo_status_values()),
+                SearchColumn('wo_estimated_finish', title=_('Estimated finish'),
+                             data_type=datetime.date, visible=False),
+                SearchColumn('wo_finish', title=_('WO Finish'),
+                             data_type=datetime.date, visible=False)]
+
+    def _get_status_values(self):
+        items = [(value, key) for key, value in Sale.statuses.items()
+                 if key in [Sale.STATUS_ORDERED, Sale.STATUS_QUOTE]]
+        items.insert(0, (_('Any'), None))
+        return items
+
+    def _get_wo_status_values(self):
+        items = [(value, key) for key, value in WorkOrder.statuses.items()]
+        items.insert(0, (_('Any'), None))
+        return items
