@@ -26,12 +26,13 @@
 from decimal import Decimal
 
 from kiwi.currency import currency
-from kiwi.db.query import DateQueryState, DateIntervalQueryState
-from kiwi.ui.search import DateSearchFilter
-from kiwi.ui.objectlist import SearchColumn, Column
 
-from stoqlib.domain.sale import SalesPersonSalesView
-from stoqlib.gui.base.search import SearchDialog
+from stoqlib.api import api
+from stoqlib.database.queryexecuter import DateQueryState, DateIntervalQueryState
+from stoqlib.domain.sale import SalesPersonSalesView, Sale
+from stoqlib.gui.search.searchcolumns import SearchColumn, Column
+from stoqlib.gui.search.searchdialog import SearchDialog
+from stoqlib.gui.search.searchfilters import DateSearchFilter
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -39,7 +40,7 @@ _ = stoqlib_gettext
 
 class SalesPersonSalesSearch(SearchDialog):
     title = _("Salesperson Total Sales")
-    search_table = SalesPersonSalesView
+    search_spec = SalesPersonSalesView
     size = (600, 450)
 
     #
@@ -48,8 +49,7 @@ class SalesPersonSalesSearch(SearchDialog):
 
     def create_filters(self):
         self.set_text_field_columns(['name'])
-        self.set_searchbar_labels(_('matching:'))
-        self.executer.set_query(self.executer_query)
+        self.search.set_query(self.executer_query)
 
         date_filter = DateSearchFilter(_('Date:'))
         self.search.add_filter(date_filter)
@@ -63,7 +63,10 @@ class SalesPersonSalesSearch(SearchDialog):
                 Column('total_sales', title=_('Total sales'),
                        data_type=Decimal),
                 Column('total_amount', title=_('Total amount'),
-                       data_type=currency), ]
+                       data_type=currency),
+                # Column('paid_value', title=_('Paid'),
+                #        data_type=currency, visible=True),
+                ]
 
     def setup_widgets(self):
         self.search.set_summary_label('total_amount', label=_(u'Total:'),
@@ -76,4 +79,8 @@ class SalesPersonSalesSearch(SearchDialog):
         elif isinstance(date, DateIntervalQueryState):
             date = (date.start, date.end)
 
-        return self.search_table.find_by_date(store, date)
+        resultset = self.search_spec.find_by_date(store, date)
+        if api.sysparam.get_bool('SYNCHRONIZED_MODE'):
+            branch = api.get_current_branch(store)
+            resultset = resultset.find(Sale.branch_id == branch.id)
+        return resultset
