@@ -23,12 +23,12 @@
 ##
 """ Search dialog for station objects """
 
-from kiwi.enums import SearchFilterPosition
 from kiwi.ui.objectlist import Column
 
 from stoqlib.domain.station import BranchStation
+from stoqlib.enums import SearchFilterPosition
 from stoqlib.gui.base.columns import AccessorColumn
-from stoqlib.gui.base.search import SearchEditor
+from stoqlib.gui.search.searcheditor import SearchEditor
 from stoqlib.gui.editors.stationeditor import StationEditor
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -37,9 +37,8 @@ _ = stoqlib_gettext
 
 class StationSearch(SearchEditor):
     title = _("Computer Search")
-    table = BranchStation
+    search_spec = BranchStation
     editor_class = StationEditor
-    searchbar_result_strings = _("Computer"), _("Computers")
     size = (-1, 450)
     advanced_search = False
 
