@@ -26,11 +26,12 @@
 creation and edition.
 """
 
-from kiwi.ui.objectlist import SearchColumn, Column
+from kiwi.ui.objectlist import Column
 
-from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.gui.base.search import SearchEditor
 from stoqlib.domain.taxes import ProductTaxTemplate
+from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.gui.search.searchcolumns import SearchColumn
+from stoqlib.gui.search.searcheditor import SearchEditor
 from stoqlib.gui.slaves.taxslave import ICMSTemplateSlave, IPITemplateSlave
 from stoqlib.gui.editors.taxclasseditor import ProductTaxTemplateEditor
 
@@ -45,27 +46,21 @@ TYPE_SLAVES = {
 class TaxTemplatesSearch(SearchEditor):
     size = (500, 350)
     title = _('Tax Classes Search')
-
-    searchbar_label = _('Class Matching:')
-    result_strings = _('class'), _('classes')
-    search_table = ProductTaxTemplate
+    search_label = _('Class Matching:')
+    search_spec = ProductTaxTemplate
     editor_class = ProductTaxTemplateEditor
 
-    def __init__(self, store):
-        SearchEditor.__init__(self, store)
-        self.set_searchbar_labels(self.searchbar_label)
-        self.set_result_strings(*self.result_strings)
-
     def create_filters(self):
         self.set_text_field_columns(['name'])
-        self.executer.add_query_callback(self._get_query)
+        executer = self.search.get_query_executer()
+        executer.add_query_callback(self._get_query)
 
     def get_columns(self):
         return [
             SearchColumn("name", _("Class name"), data_type=str,
                          sorted=True, expand=True),
             Column("tax_type_str", _("Type"), data_type=str, width=80),
-            ]
+        ]
 
     def get_editor_model(self, view_item):
         return view_item
@@ -75,5 +70,5 @@ class TaxTemplatesSearch(SearchEditor):
     #
 
     def _get_query(self, states):
-        #return SellableCategory.category_id != None
+        # return Ne(SellableCategory.category_id, None)
         return None
