@@ -28,10 +28,7 @@ import datetime
 
 import gtk
 from kiwi.currency import currency
-from kiwi.enums import SearchFilterPosition
-from kiwi.ui.search import ComboSearchFilter
-from kiwi.ui.objectlist import SearchColumn
-from storm.expr import Join
+from storm.expr import Join, Cast
 
 from stoqlib.api import api
 from stoqlib.database.viewable import Viewable
@@ -42,7 +39,10 @@ from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.station import BranchStation
 from stoqlib.domain.till import Till
-from stoqlib.gui.base.search import SearchDialog
+from stoqlib.enums import SearchFilterPosition
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchdialog import SearchDialog
+from stoqlib.gui.search.searchfilters import ComboSearchFilter
 from stoqlib.lib.translation import stoqlib_gettext
 
 
@@ -60,6 +60,7 @@ class TillFiscalOperationsView(Viewable):
 
     id = Payment.id
     identifier = Payment.identifier
+    identifier_str = Cast(Payment.identifier, 'text')
     date = Payment.open_date
     description = Payment.description
     value = Payment.value
@@ -77,28 +78,27 @@ class TillFiscalOperationsView(Viewable):
         Join(PaymentGroup, PaymentGroup.id == Payment.group_id),
         Join(Sale, Sale.group_id == PaymentGroup.id),
         Join(CfopData, CfopData.id == Sale.cfop_id),
-        ]
+    ]
 
 
 class TillFiscalOperationsSearch(SearchDialog):
     title = _(u"Till Fiscal Operations")
-    table = TillFiscalOperationsView
+    search_spec = TillFiscalOperationsView
     size = (750, 500)
     searching_by_date = True
-    searchbar_labels = _(u"matching:"),
-    searchbar_result_strings = _(u"fiscal operation"), _(u"fiscal operations")
 
     #
     # SearchDialog Hooks
     #
 
     def create_filters(self):
-        self.set_text_field_columns(['description'])
-        self.executer.add_query_callback(self._get_query)
+        self.set_text_field_columns(['description', 'identifier_str'])
+        executer = self.search.get_query_executer()
+        executer.add_query_callback(self._get_query)
 
         # Status
         items = [(v, k) for k, v in Till.statuses.items()
-                    if k != Till.STATUS_PENDING]
+                 if k != Till.STATUS_PENDING]
         items.insert(0, (_(u'Any'), None))
         status_filter = ComboSearchFilter(_(u'Show entries of type'), items)
         status_filter.select(Till.STATUS_OPEN)
@@ -107,9 +107,7 @@ class TillFiscalOperationsSearch(SearchDialog):
                         columns=['status'])
 
     def get_columns(self, *args):
-        return [SearchColumn('identifier', title=_('#'), width=60,
-                             justify=gtk.JUSTIFY_RIGHT, format="%05d",
-                             data_type=int, sorted=True),
+        return [IdentifierColumn('identifier', sorted=True),
                 SearchColumn('date', title=_('Date'), width=100,
                              data_type=datetime.date, justify=gtk.JUSTIFY_RIGHT),
                 SearchColumn('description', title=_('Description'),
@@ -127,4 +125,4 @@ class TillFiscalOperationsSearch(SearchDialog):
 
     def _get_query(self, state):
         branch = api.get_current_branch(self.store)
-        return self.search_table.branch_id == branch.id
+        return self.search_spec.branch_id == branch.id
