@@ -22,14 +22,11 @@
 ##  Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from kiwi.argcheck import argcheck
 from kiwi.datatypes import ValidationError
 from kiwi.python import AttributeForwarder
 
 from stoqlib.api import api
-from stoqlib.database.runtime import StoqlibStore
 from stoqlib.domain.address import Address, CityLocation
-from stoqlib.domain.person import Person
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
 from stoqlib.lib.countries import get_countries
 from stoqlib.lib.translation import stoqlib_gettext
@@ -90,9 +87,9 @@ class CityLocationMixin(object):
     #
 
     def _cache_l10n_fields(self):
-        self._city_l10n = api.get_l10n_field(self.store, 'city',
+        self._city_l10n = api.get_l10n_field('city',
                                              self.model.country)
-        self._state_l10n = api.get_l10n_field(self.store, 'state',
+        self._state_l10n = api.get_l10n_field('state',
                                               self.model.country)
 
     def _prefill_states(self):
@@ -107,7 +104,7 @@ class CityLocationMixin(object):
         if len(completion.get_model()) and not force:
             return
 
-        self.city.prefill([]) # mimic missing .clear method
+        self.city.prefill([])  # mimic missing .clear method
         cities = CityLocation.get_cities_by(self.store,
                                             state=self.model.state,
                                             country=self.model.country)
@@ -129,7 +126,7 @@ class CityLocationMixin(object):
         self.city.validate(force=True)
 
     def on_city__validate(self, entry, city):
-        if sysparam(self.store).ALLOW_REGISTER_NEW_LOCATIONS:
+        if sysparam.get_bool('ALLOW_REGISTER_NEW_LOCATIONS'):
             return
 
         if self.city.is_focus() and not self._confirming:
@@ -172,10 +169,13 @@ class _AddressModel(AttributeForwarder):
         'is_main_address',
         'is_valid_model',
         'city_location',
-        ]
+    ]
 
-    @argcheck(Address, StoqlibStore)
     def __init__(self, target, store):
+        """
+        :param target: an address
+        :param store: a store
+        """
         AttributeForwarder.__init__(self, target)
         self.store = store
         self.city = target.city_location.city
@@ -212,9 +212,8 @@ class AddressSlave(BaseEditorSlave, CityLocationMixin):
         'city',
         'state',
         'country',
-        ]
+    ]
 
-    @argcheck(object, Person, Address, bool, bool, object)
     def __init__(self, store, person, model=None, is_main_address=True,
                  visual_mode=False, db_form=None):
         self.person = person
@@ -253,6 +252,9 @@ class AddressSlave(BaseEditorSlave, CityLocationMixin):
     def setup_proxies(self):
         CityLocationMixin.setup_proxies(self)
 
+        # FIXME: Implement l10n here
+        self.postal_code.set_mask('00000-000')
+
         if self.db_form:
             self._update_forms()
         self.proxy = self.add_proxy(self.model,
@@ -262,10 +264,9 @@ class AddressSlave(BaseEditorSlave, CityLocationMixin):
         # to get the label name based on SUGGESTED_COUNTRY and not on the
         # country on model.
         for field, label in [
-            ('state', self.state_lbl),
-            ('city', self.city_lbl),
-            ]:
-            l10n_field = api.get_l10n_field(self.store, field)
+                ('state', self.state_lbl),
+                ('city', self.city_lbl)]:
+            l10n_field = api.get_l10n_field(field)
             label.set_text(l10n_field.label + ':')
 
         # Enable if we already have a number or if we are adding a new address.
