@@ -28,7 +28,7 @@ import datetime
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.ui.delegates import GladeSlaveDelegate
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.account import BankAccount
@@ -37,6 +37,7 @@ from stoqlib.domain.person import (Branch, WorkPermitData, EmployeeRole,
                                    Employee, SalesPerson)
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
+from stoqlib.lib.dateutils import localnow
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.parameters import sysparam
 
@@ -110,7 +111,7 @@ class EmployeeStatusSlave(BaseEditorSlave):
 
     def setup_proxies(self):
         items = [(v, c)
-                    for c, v in self.model_type.statuses.items()]
+                 for c, v in self.model_type.statuses.items()]
         self.statuses_combo.prefill(items)
         self.proxy = self.add_proxy(self.model,
                                     EmployeeStatusSlave.proxy_widgets)
@@ -144,10 +145,8 @@ class EmployeeRoleSlave(BaseEditorSlave):
             return None
 
     def _is_default_salesperson_role(self):
-        if (sysparam(self.store).DEFAULT_SALESPERSON_ROLE ==
-            self.model.role):
-            return True
-        return False
+        return sysparam.compare_object('DEFAULT_SALESPERSON_ROLE',
+                                       self.model.role)
 
     def on_confirm(self):
         if self._is_default_salesperson_role():
@@ -169,12 +168,12 @@ class EmployeeRoleSlave(BaseEditorSlave):
             self.employee.role = self.model.role
             if self.current_role_history:
                 self.current_role_history.salary = old_salary
-                self.current_role_history.ended = datetime.datetime.now()
+                self.current_role_history.ended = localnow()
                 self.current_role_history.is_active = False
         else:
             # XXX This will prevent problems when you can't update
             # the connection.
-            self.model_type.delete(self.model.id, store=self.store)
+            self.store.remove(self.model)
 
     #
     # BaseEditorSlave Hooks
@@ -203,7 +202,7 @@ class EmployeeRoleSlave(BaseEditorSlave):
         from stoqlib.gui.editors.personeditor import EmployeeRoleEditor
         self.store.savepoint('before_run_editor_employee_role')
         model = run_dialog(EmployeeRoleEditor, self, self.store,
-                            self.model.role)
+                           self.model.role)
         if model:
             self._setup_entry_completion()
             self.proxy.update('role')
@@ -240,7 +239,7 @@ class EmployeeRoleHistorySlave(GladeSlaveDelegate):
 
     def _get_objects(self):
         return [result for result in self.employee.get_role_history()
-                           if not result.is_active]
+                if not result.is_active]
 
     def _get_columns(self):
         return [Column('began', _('Began'), data_type=datetime.date,
