@@ -35,7 +35,7 @@ from kiwi.utils import gsignal
 
 from stoqlib.domain.image import Image
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
-from stoqlib.gui.filters import get_filters_for_images
+from stoqlib.gui.utils.filters import get_filters_for_images
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -94,7 +94,7 @@ class ImageSlave(BaseEditorSlave):
             # If image came without a thumbnail, generate one for it
             w, h = (Image.THUMBNAIL_SIZE_WIDTH, Image.THUMBNAIL_SIZE_HEIGHT)
             self._thumbnail = self._image.scale_simple(w, h,
-                                                   gtk.gdk.INTERP_BILINEAR)
+                                                       gtk.gdk.INTERP_BILINEAR)
             self._image_model.thumbnail = (
                 _pixbuf_converter.as_string(self._thumbnail))
 
@@ -132,7 +132,7 @@ class ImageSlave(BaseEditorSlave):
 
     def _save_image(self, filename=None):
         if not filename:
-            name = '%s-%d.png' % ('stoq-image', self._image_model.id)
+            name = '%s-%s.png' % ('stoq-image', self._image_model.id)
             with tempfile.NamedTemporaryFile(suffix=name, delete=False) as f:
                 filename = f.name
 
