@@ -24,12 +24,13 @@
 ##
 """ Payment confirm slave """
 
+# FIXME: Move this module to stoqlib.gui.editors. There are no slaves here
+
 import datetime
 import os
 
 import gio
 import glib
-
 from kiwi import ValueUnset
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
@@ -45,7 +46,8 @@ from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.gui.filters import get_filters_for_attachment
+from stoqlib.gui.utils.filters import get_filters_for_attachment
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -55,7 +57,7 @@ _ = stoqlib_gettext
 class _ConfirmationModel(object):
     def __init__(self, payments):
         self.payments = payments
-        self.close_date = datetime.date.today()
+        self.close_date = localtoday().date()
 
     def get_interest(self):
         return currency(sum(p.interest or 0 for p in self.payments))
@@ -113,7 +115,7 @@ class _SaleConfirmationModel(_ConfirmationModel):
 
     def get_calculated_interest(self, pay_penalty):
         return currency(sum(p.get_interest(self.close_date,
-                                   pay_penalty=self.pay_penalty)
+                                           pay_penalty=self.pay_penalty)
                             for p in self.payments))
 
     def get_calculated_penalty(self):
@@ -140,7 +142,7 @@ class _SaleConfirmationModel(_ConfirmationModel):
             penalty = currency(0)
         super(_SaleConfirmationModel, self).set_penalty(penalty)
 
-    def get_order_number(self):
+    def get_order_id(self):
         return self._sale.id
 
     def get_identifier(self):
@@ -150,11 +152,6 @@ class _SaleConfirmationModel(_ConfirmationModel):
         if self._sale.client:
             return self._sale.client.person.name
 
-    def confirm(self):
-        paid = [p.is_paid() for p in self._sale.payments]
-        if all(paid):
-            self._sale.set_paid()
-
 
 class _PurchaseConfirmationModel(_ConfirmationModel):
     def __init__(self, payments, group):
@@ -165,7 +162,7 @@ class _PurchaseConfirmationModel(_ConfirmationModel):
         self._purchase = purchase
         self.open_date = purchase.open_date.date()
 
-    def get_order_number(self):
+    def get_order_id(self):
         return self._purchase.id
 
     def get_identifier(self):
@@ -184,7 +181,7 @@ class _LonelyConfirmationModel(_ConfirmationModel):
         _ConfirmationModel.__init__(self, payments)
         self.open_date = self._payment.open_date.date()
 
-    def get_order_number(self):
+    def get_order_id(self):
         return -1
 
     def get_identifier(self):
@@ -199,7 +196,7 @@ class _LonelyConfirmationModel(_ConfirmationModel):
 
     def get_calculated_interest(self, pay_penalty):
         return currency(sum(p.get_interest(self.close_date,
-                                   pay_penalty=self.pay_penalty)
+                                           pay_penalty=self.pay_penalty)
                             for p in self.payments))
 
     def get_penalty(self):
@@ -224,6 +221,7 @@ class _LonelyConfirmationModel(_ConfirmationModel):
         return currency(self._payment.paid_value)
 
 
+# FIXME: Not a slave: s/Slave/Editor/
 class _PaymentConfirmSlave(BaseEditor):
     """This slave is responsible for confirming a list of payments and
     applying the necessary interests and fines.
@@ -231,7 +229,7 @@ class _PaymentConfirmSlave(BaseEditor):
     """
     gladefile = 'PaymentConfirmSlave'
     model_type = _ConfirmationModel
-    size = (690, 420)
+    size = (690, 450)
     title = _("Confirm payment")
     proxy_widgets = ('identifier',
                      'installment_value',
@@ -245,11 +243,15 @@ class _PaymentConfirmSlave(BaseEditor):
                      'close_date',
                      'cost_center')
 
-    def __init__(self, store, payments):
+    def __init__(self, store, payments, show_till_info=True):
         """ Creates a new _PaymentConfirmSlave
+
         :param store: a store
         :param payments: a list of payments
+        :param show_till_info: if we should show an info message
+            explaining that this operation wont generate a till entry.
         """
+        self._show_till_info = show_till_info
         self._payments = payments
         self._proxy = None
 
@@ -271,8 +273,8 @@ class _PaymentConfirmSlave(BaseEditor):
     # Private
 
     def _get_columns(self):
-        return [Column('identifier', _('#'), data_type=int, visible=False,
-                       sorted=True),
+        return [Column('identifier', _('#'), data_type=int, width=60,
+                       visible=False, format_func=str, sorted=True),
                 Column('description', _("Description"), data_type=str),
                 Column('due_date', _("Due"), data_type=datetime.date),
                 Column('paid_date', _("Paid date"), data_type=datetime.date),
@@ -302,12 +304,17 @@ class _PaymentConfirmSlave(BaseEditor):
             self._setup_attachment_chooser()
 
         if isinstance(self.model, _LonelyConfirmationModel):
-            self.order_label.hide()
+            self.identifier_lbl.hide()
             self.person_label.hide()
             self.identifier.hide()
             self.person_name.hide()
             self.details_button.hide()
 
+        if (self._show_till_info and
+                any([p.method.method_name == u'money' for
+                     p in self._payments])):
+            self.set_message(self.get_till_info_msg())
+
     def _update_interest(self, pay_interest, pay_penalty):
         self.interest.set_sensitive(pay_interest)
         if pay_interest:
@@ -330,7 +337,7 @@ class _PaymentConfirmSlave(BaseEditor):
 
     def _update_total_value(self):
         total = self.model.get_penalty() + self.model.get_interest() - \
-                self.model.get_discount()
+            self.model.get_discount()
         value = total / self.installments_number
         for payment in self._payments:
             payment.paid_value = payment.value + value
@@ -355,7 +362,7 @@ class _PaymentConfirmSlave(BaseEditor):
 
     def _setup_attachment_chooser(self):
         self.attachment_chooser.connect('file-set',
-                                      self._on_attachment_chooser__file_set)
+                                        self._on_attachment_chooser__file_set)
 
         # If payment already had an attachment attached, changes the
         # FileChooser label to that file's name.
@@ -405,15 +412,18 @@ class _PaymentConfirmSlave(BaseEditor):
                         account=self.account.get_selected())
         self.model.confirm()
 
+    def get_till_info_msg(self):
+        raise NotImplementedError
+
     #
     # Callbacks
     #
 
     def on_close_date__validate(self, widget, date):
-        if sysparam(self.store).ALLOW_OUTDATED_OPERATIONS:
+        if sysparam.get_bool('ALLOW_OUTDATED_OPERATIONS'):
             return
 
-        if date > datetime.date.today() or date < self.model.open_date:
+        if date > localtoday().date() or date < self.model.open_date:
             return ValidationError(_("Paid date must be between "
                                      "%s and today") % (self.model.open_date, ))
 
@@ -463,8 +473,16 @@ class _PaymentConfirmSlave(BaseEditor):
         self.run_details_dialog()
 
 
+# FIXME: Not a slave: s/Slave/Editor/
 class SalePaymentConfirmSlave(_PaymentConfirmSlave):
     model_type = _ConfirmationModel
+    help_section = "account-receivable-receive"
+
+    def get_till_info_msg(self):
+        # TRANSLATORS: 'cash addition' is 'suprimento' in pt_BR
+        return _("Note that this operation will not generate a till entry for "
+                 "the money payment(s). \nIf you are adding money on the "
+                 "till, do a cash addition in the Till applications too.")
 
     def create_model(self, store):
         group = self._payments[0].group
@@ -474,7 +492,7 @@ class SalePaymentConfirmSlave(_PaymentConfirmSlave):
             return _LonelyConfirmationModel(self._payments)
 
     def run_details_dialog(self):
-        sale_id = self.model.get_order_number()
+        sale_id = self.model.get_order_id()
         sale_view = self.store.find(SaleView, id=sale_id).one()
         run_dialog(SaleDetailsDialog, self, self.store, sale_view)
 
@@ -484,8 +502,10 @@ class SalePaymentConfirmSlave(_PaymentConfirmSlave):
         self._proxy.update('total_value')
 
 
+# FIXME: Not a slave: s/Slave/Editor/
 class PurchasePaymentConfirmSlave(_PaymentConfirmSlave):
     model_type = _ConfirmationModel
+    help_section = "account-payable-pay"
 
     def _setup_widgets(self):
         _PaymentConfirmSlave._setup_widgets(self)
@@ -497,6 +517,12 @@ class PurchasePaymentConfirmSlave(_PaymentConfirmSlave):
         self.pay_interest.set_active(True)
         self._fill_cost_center_combo()
 
+    def get_till_info_msg(self):
+        # TRANSLATORS: 'cash removal' is 'sangria' in pt_BR
+        return _("Note that this operation will not generate a till entry for "
+                 "the money payment(s). \nIf you are removing money from the "
+                 "till, do a cash removal in the Till application too.")
+
     def create_model(self, store):
         group = self._payments[0].group
         if group and group.purchase:
