@@ -23,22 +23,20 @@
 ##
 """ Slaves for products """
 
-import sys
-
-import gtk
-
 from decimal import Decimal
 
+import gtk
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.enums import ListType
-from kiwi.ui.widgets.list import Column, SummaryLabel
+from kiwi.ui.objectlist import Column, SummaryLabel
 
 from stoqlib.api import api
 from stoqlib.domain.person import Supplier
 from stoqlib.domain.product import (ProductSupplierInfo, ProductComponent,
                                     ProductQualityTest, Product,
                                     ProductManufacturer)
+from stoqlib.domain.production import ProductionOrderProducingView
 from stoqlib.domain.taxes import ProductTaxTemplate
 from stoqlib.domain.views import ProductFullStockView
 from stoqlib.gui.base.dialogs import run_dialog
@@ -49,8 +47,7 @@ from stoqlib.gui.editors.producteditor import (TemporaryProductComponent,
                                                ProductComponentEditor,
                                                QualityTestEditor,
                                                ProductSupplierEditor)
-from stoqlib.gui.slaves.sellableslave import SellableDetailsSlave
-from stoqlib.lib.defaults import quantize
+from stoqlib.lib.defaults import quantize, MAX_INT
 from stoqlib.lib.formatters import get_formatted_cost
 from stoqlib.lib.message import info, yesno, warning
 from stoqlib.lib.parameters import sysparam
@@ -64,10 +61,10 @@ class ProductInformationSlave(BaseEditorSlave):
     model_type = Product
     proxy_widgets = ['location', 'part_number', 'manufacturer', 'width',
                      'height', 'depth', 'weight', 'ncm', 'ex_tipi', 'genero',
-                     'product_model']
+                     'product_model', 'brand', 'family']
     storable_widgets = ['minimum_quantity', 'maximum_quantity']
 
-    def __init__(self, store, model, db_form, visual_mode=False):
+    def __init__(self, store, model, db_form=None, visual_mode=False):
         self.db_form = db_form
         BaseEditorSlave.__init__(self, store, model, visual_mode)
 
@@ -92,7 +89,7 @@ class ProductInformationSlave(BaseEditorSlave):
         for widget in [self.minimum_quantity, self.maximum_quantity,
                        self.width, self.height, self.depth, self.weight]:
             widget.set_adjustment(
-                gtk.Adjustment(lower=0, upper=sys.maxint, step_incr=1))
+                gtk.Adjustment(lower=0, upper=MAX_INT, step_incr=1))
 
         if not self.db_form:
             return
@@ -116,7 +113,7 @@ class ProductInformationSlave(BaseEditorSlave):
         if (not self.minimum_quantity.get_visible() and
             not self.maximum_quantity.get_visible() and
             not self.location.get_visible()):
-            self.stock_lbl.hide()
+            self.storable_frame.hide()
 
         # Mercosul
         self.db_form.update_widget(self.ncm, other=self.ncm_lbl)
@@ -126,7 +123,7 @@ class ProductInformationSlave(BaseEditorSlave):
         if (not self.ncm.get_visible() and
             not self.ex_tipi.get_visible() and
             not self.genero.get_visible()):
-            self.mercosul_lbl.hide()
+            self.nfe_frame.hide()
 
     def setup_proxies(self):
         self._setup_widgets()
@@ -137,6 +134,9 @@ class ProductInformationSlave(BaseEditorSlave):
         if storable is not None:
             self.storable_proxy = self.add_proxy(
                 storable, ProductInformationSlave.storable_widgets)
+        else:
+            self.minimum_quantity.set_sensitive(False)
+            self.maximum_quantity.set_sensitive(False)
 
     def update_visual_mode(self):
         self.minimum_quantity.set_sensitive(False)
@@ -154,6 +154,10 @@ class ProductInformationSlave(BaseEditorSlave):
         self.manufacturer.hide()
         self.model_lbl.hide()
         self.product_model.hide()
+        self.brand_lbl.hide()
+        self.brand.hide()
+        self.family_lbl.hide()
+        self.family.hide()
 
     #
     # Kiwi Callbacks
@@ -196,7 +200,7 @@ class ProductInformationSlave(BaseEditorSlave):
         maximum = self.maximum_quantity.read()
         if maximum and value > maximum:
             return ValidationError(_(u'Minimum must be lower than the '
-                                      'maximum value.'))
+                                     'maximum value.'))
 
     def on_maximum_quantity__validate(self, widget, value):
         if not value:
@@ -207,18 +211,7 @@ class ProductInformationSlave(BaseEditorSlave):
         minimum = self.minimum_quantity.read()
         if minimum and minimum > value:
             return ValidationError(_(u'Maximum must be greater than the '
-                                      'minimum value.'))
-
-
-class ProductDetailsSlave(SellableDetailsSlave):
-
-    def setup_slaves(self):
-        self.info_slave = ProductInformationSlave(self.store, self.model.product,
-                                                  self.db_form, self.visual_mode)
-        self.attach_slave('details_holder', self.info_slave)
-
-    def hide_stock_details(self):
-        self.info_slave.hide_stock_details()
+                                     'minimum value.'))
 
 
 class ProductTaxSlave(BaseEditorSlave):
@@ -233,7 +226,7 @@ class ProductTaxSlave(BaseEditorSlave):
     def _fill_combo(self, combo, type):
         types = [(None, None)]
         types.extend([(t.name, t.get_tax_model()) for t in
-                        self.store.find(ProductTaxTemplate, tax_type=type)])
+                      self.store.find(ProductTaxTemplate, tax_type=type)])
         combo.prefill(types)
 
     def _setup_widgets(self):
@@ -258,19 +251,19 @@ class ProductComponentSlave(BaseEditorSlave):
 
     def _get_columns(self):
         return [Column('code', title=_(u'Code'), data_type=int,
-                        expander=True, sorted=True),
+                       expander=True, sorted=True),
                 Column('quantity', title=_(u'Quantity'),
-                        data_type=Decimal),
+                       data_type=Decimal),
                 Column('unit', title=_(u'Unit'), data_type=str),
                 Column('description', title=_(u'Description'),
-                        data_type=str, expand=True),
+                       data_type=str, expand=True),
                 Column('category', title=_(u'Category'), data_type=str),
                 # Translators: Ref. is for Reference (as in design reference)
                 Column('design_reference', title=_(u'Ref.'), data_type=str),
                 Column('production_cost', title=_(u'Production Cost'),
-                        format_func=get_formatted_cost, data_type=currency),
+                       format_func=get_formatted_cost, data_type=currency),
                 Column('total_production_cost', title=_(u'Total'),
-                        format_func=get_formatted_cost, data_type=currency),
+                       format_func=get_formatted_cost, data_type=currency),
                 ]
 
     def _setup_widgets(self):
@@ -333,7 +326,7 @@ class ProductComponentSlave(BaseEditorSlave):
             self.edit_button.set_sensitive(False)
             self.remove_button.set_sensitive(False)
             self.info_label.set_text(_(u"This product is being produced. "
-                                      "Can't change components."))
+                                       "Can't change components."))
 
     def _populate_component_tree(self):
         self._add_to_component_tree()
@@ -385,7 +378,7 @@ class ProductComponentSlave(BaseEditorSlave):
             product_desc = self._product.sellable.get_description()
             component_desc = product_component.description
             info(_(u'You can not add this product as component, since '
-                    '%s is composed by %s' % (component_desc, product_desc)))
+                   '%s is composed by %s' % (component_desc, product_desc)))
             return
 
         toplevel = self.get_toplevel().get_toplevel()
@@ -425,7 +418,7 @@ class ProductComponentSlave(BaseEditorSlave):
         root_component = self.component_tree.get_root(component)
 
         msg = _("This will remove the component \"%s\". Are you sure?") % (
-                root_component.description)
+            root_component.description)
         if not yesno(msg, gtk.RESPONSE_NO,
                      _("Remove component"),
                      _("Keep component")):
@@ -436,7 +429,8 @@ class ProductComponentSlave(BaseEditorSlave):
         self._update_widgets()
 
     def _validate_components(self):
-        return not self.model.product.is_being_produced()
+        return not ProductionOrderProducingView.is_product_being_produced(
+            self.model.product)
 
     #
     # BaseEditorSlave
@@ -520,7 +514,7 @@ class ProductQualityTestSlave(ModelListSlave):
                data_type=str, expand=True),
         Column('type_str', title=_(u'Type'), data_type=str),
         Column('success_value_str', title=_(u'Success Value'), data_type=str),
-        ]
+    ]
 
     def __init__(self, parent, store, product, visual_mode=False):
         self._product = product
@@ -548,7 +542,7 @@ class ProductQualityTestSlave(ModelListSlave):
         # removed
         if not item.can_remove():
             warning(_(u'You can not remove this test, since it\'s already '
-                            'been used.'))
+                      'been used.'))
             return False
 
         return ModelListSlave.remove_item(self, item)
@@ -565,7 +559,7 @@ class ProductSupplierSlave(BaseRelationshipEditorSlave):
         self._product = product
         BaseRelationshipEditorSlave.__init__(self, store, visual_mode=visual_mode)
 
-        suggested = sysparam(store).SUGGESTED_SUPPLIER
+        suggested = sysparam.get_object(store, 'SUGGESTED_SUPPLIER')
         if suggested is not None:
             self.target_combo.select(suggested)
 
@@ -578,14 +572,14 @@ class ProductSupplierSlave(BaseRelationshipEditorSlave):
 
     def get_columns(self):
         return [Column('name', title=_(u'Supplier'),
-                        data_type=str, expand=True, sorted=True),
+                       data_type=str, expand=True, sorted=True),
                 Column('supplier_code', title=_(u'Product Code'),
-                        data_type=str),
+                       data_type=str),
                 Column('lead_time_str', title=_(u'Lead time'), data_type=str),
                 Column('minimum_purchase', title=_(u'Minimum Purchase'),
-                        data_type=Decimal),
+                       data_type=Decimal),
                 Column('base_cost', title=_(u'Cost'), data_type=currency,
-                        format_func=get_formatted_cost)]
+                       format_func=get_formatted_cost)]
 
     def create_model(self):
         product = self._product
@@ -594,7 +588,7 @@ class ProductSupplierSlave(BaseRelationshipEditorSlave):
         if product.is_supplied_by(supplier):
             product_desc = self._product.sellable.get_description()
             info(_(u'%s is already supplied by %s') % (product_desc,
-                                                      supplier.person.name))
+                                                       supplier.person.name))
             return
 
         model = ProductSupplierInfo(product=product,
