@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005, 2009 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005, 2014 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -52,7 +52,6 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
                      'cfop',
                      'branch',
                      'supplier_label',
-                     'order_number',
                      'total',
                      'invoice_number',
                      'icms_total',
@@ -62,6 +61,10 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
 
     gsignal('activate')
 
+    def __init__(self, store, model, visual_mode=False):
+        self.purchases = list(model.purchase_orders)
+        BaseEditorSlave.__init__(self, store, model, visual_mode)
+
     #
     # BaseEditorSlave hooks
     #
@@ -74,8 +77,10 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
         freight_items = [(value, key) for (key, value) in
                          ReceivingOrder.freight_types.items()]
 
-        # If the purchase's installments are paid, we cannot modify them.
-        if (self.model.purchase.is_paid() and not self.visual_mode):
+        # If there is at least one purchase with pending payments, than we can
+        # change those.
+        can_change_installments = any(not p.is_paid() for p in self.model.payments)
+        if not can_change_installments and not self.visual_mode:
             ro = ReceivingOrder
             freight_items.remove((ro.freight_types[ro.FREIGHT_FOB_INSTALLMENTS],
                                   ro.FREIGHT_FOB_INSTALLMENTS))
@@ -91,14 +96,13 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
 
     def _setup_widgets(self):
         self.total.set_bold(True)
+        idents = sorted(p.identifier for p in self.purchases)
+        identifier = ', '.join(str(i) for i in idents)
+        self.identifier.set_text(identifier)
 
-        purchase = self.model.purchase
-        if not purchase:
-            for widget in (self.purchase_number_label,
-                           self.purchase_supplier_label,
-                           self.order_number, self.supplier_label):
-                widget.hide()
-        elif purchase and purchase.is_paid():
+        # TODO: Testar isso quando compras > 1
+        if len(self.purchases) == 1 and self.purchases[0].is_paid():
+            # This widgets would make the value of the installments change.
             for widget in (self.ipi, self.discount_value, self.icms_total,
                            self.secure_value, self.expense_value):
                 widget.set_sensitive(False)
@@ -127,27 +131,26 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
         will be created for freight. If not, it'll be included on installments.
         """
         freight_type = self.freight_combo.read()
-        if freight_type == self.model.FREIGHT_FOB_PAYMENT:
-            return True
-        return False
+        return freight_type == self.model.FREIGHT_FOB_PAYMENT
 
     #
     # BaseEditorSlave hooks
     #
 
     def update_visual_mode(self):
-        self.notes_button.hide()
+        self.observations_button.hide()
         self.freight_combo.set_sensitive(False)
 
     def setup_proxies(self):
+        self.proxy = None
         self._setup_widgets()
         self.proxy = self.add_proxy(self.model,
                                     ReceivingInvoiceSlave.proxy_widgets)
 
-        self.model.invoice_total = self.model.get_products_total()
+        self.model.invoice_total = self.model.products_total
 
-        purchase = self.model.purchase
-        if purchase:
+        if len(self.purchases) == 1:
+            purchase = self.purchases[0]
             if not self.visual_mode:
                 # These values are duplicates from the purchase. If we are
                 # visualising the order, the value should be it's own, not the
@@ -191,11 +194,14 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
     on_secure_value__validate = _positive_validator
     on_expense_value__validate = _positive_validator
 
-    def on_notes_button__clicked(self, *args):
+    def on_observations_button__clicked(self, *args):
         run_dialog(NoteEditor, self, self.store, self.model, 'notes',
                    title=_('Additional Information'))
 
     def on_invoice_number__validate(self, widget, value):
+        if self.visual_mode:
+            return
+
         if not 0 < value <= 999999999:
             return ValidationError(
                 _("Invoice number must be between 1 and 999999999"))
@@ -225,9 +231,10 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
                 if (not self.model.freight_total and
                     value in ReceivingOrder.FOB_FREIGHTS):
                     # Restore the freight value to the purchase expected one.
-                    self.freight.update(self.model.purchase.expected_freight)
+                    self.freight.update(self.purchases[0].expected_freight)
 
-        self.proxy.update('total')
+        if self.proxy is not None:
+            self.proxy.update('total')
 
     def after_freight__content_changed(self, widget):
         try:
@@ -237,7 +244,9 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
 
         if value is ValueUnset:
             self.model.freight_total = 0
-        self.proxy.update('total')
+
+        if self.proxy is not None:
+            self.proxy.update('total')
 
     def after_ipi__content_changed(self, widget):
         try:
@@ -247,7 +256,9 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
 
         if value is ValueUnset:
             self.model.ipi_total = 0
-        self.proxy.update('total')
+
+        if self.proxy is not None:
+            self.proxy.update('total')
 
     def after_discount_value__content_changed(self, widget):
         try:
@@ -257,14 +268,16 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
 
         if value is ValueUnset:
             self.model.discount_value = 0
-        self.proxy.update('total')
+
+        if self.proxy is not None:
+            self.proxy.update('total')
 
     def after_discount_value__validate(self, widget, value):
         if value < 0:
             return ValidationError(_("Discount must be greater than zero"))
-        if value > self.model.get_total():
+        if value > self.model.total:
             return ValidationError(_("Discount must be less "
-                                     "than %s") % (self.model.get_total(),))
+                                     "than %s") % (self.model.total,))
 
     def after_secure_value__content_changed(self, widget):
         try:
@@ -274,7 +287,9 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
 
         if value is ValueUnset:
             self.model.secure_value = 0
-        self.proxy.update('total')
+
+        if self.proxy is not None:
+            self.proxy.update('total')
 
     def after_expense_value__content_changed(self, widget):
         try:
@@ -284,4 +299,6 @@ class ReceivingInvoiceSlave(BaseEditorSlave):
 
         if value is ValueUnset:
             self.model.expense_value = 0
-        self.proxy.update('total')
+
+        if self.proxy is not None:
+            self.proxy.update('total')
