@@ -24,22 +24,24 @@
 """ Slaves for sale management """
 
 import gtk
-from kiwi.utils import gsignal
-from kiwi.decorators import signal_block
 from kiwi.datatypes import ValidationError
+from kiwi.decorators import signal_block
 from kiwi.ui.delegates import GladeSlaveDelegate
+from kiwi.utils import gsignal
 
 from stoqlib.api import api
 from stoqlib.domain.events import ECFIsLastSaleEvent
-from stoqlib.domain.sale import Sale
 from stoqlib.domain.inventory import Inventory
+from stoqlib.domain.sale import Sale
+from stoqlib.domain.workorder import WorkOrder
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.editors.baseeditor import BaseEditorSlave
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
+from stoqlib.gui.editors.baseeditor import BaseEditorSlave
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.gui.wizards.salequotewizard import SaleQuoteWizard
-from stoqlib.gui.printing import print_report
-from stoqlib.lib.message import yesno, info
+from stoqlib.gui.wizards.workorderquotewizard import WorkOrderQuoteWizard
 from stoqlib.lib.formatters import get_price_format_str
+from stoqlib.lib.message import yesno, info, warning
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.reporting.sale import SalesReport
@@ -59,7 +61,7 @@ class SaleDiscountSlave(BaseEditorSlave):
         self._proxy = None
         self.model = model
         self.model_type = model_type
-        self.default_max_discount = sysparam(store).MAX_SALE_DISCOUNT
+        self.default_max_discount = sysparam.get_decimal('MAX_SALE_DISCOUNT')
         self.max_discount = self.default_max_discount
         BaseEditorSlave.__init__(self, store, model, visual_mode=visual_mode)
 
@@ -103,15 +105,15 @@ class SaleDiscountSlave(BaseEditorSlave):
         if value >= 100:
             self.model.discount_percentage = 0
             return ValidationError(_(u'%s can not be greater or equal '
-                                      'to 100%%.') % type_text)
+                                     'to 100%%.') % type_text)
         if value > self.max_discount:
             self.model.discount_percentage = 0
             return ValidationError(_("%s can not be greater then %d%%")
-                                     % (type_text, self.max_discount))
+                                   % (type_text, self.max_discount))
         if value < 0:
             self.model.discount_percentage = 0
             return ValidationError(_("%s can not be less then 0")
-                                    % type_text)
+                                   % type_text)
 
         # Avoid unecessary updates if the discount didnt change
         if self.model.discount_value != old_discount:
@@ -198,7 +200,15 @@ class SaleListToolbar(GladeSlaveDelegate):
             sale_view = self.sales.get_selected()
         store = api.new_store()
         sale = store.fetch(sale_view.sale)
-        model = run_dialog(SaleQuoteWizard, self.parent, store, sale)
+
+        # If we have work orders on the sale (the sale is a pre-sale), we need
+        # to run WorkOrderQuoteWizard instead of SaleQuoteWizard
+        has_workorders = not WorkOrder.find_by_sale(store, sale).is_empty()
+        if has_workorders:
+            wizard = WorkOrderQuoteWizard
+        else:
+            wizard = SaleQuoteWizard
+        model = run_dialog(wizard, self.parent, store, sale)
         retval = store.confirm(model)
         store.close()
 
@@ -217,7 +227,7 @@ class SaleListToolbar(GladeSlaveDelegate):
 
     def return_sale(self):
         assert not Inventory.has_open(self.store,
-                            api.get_current_branch(self.store))
+                                      api.get_current_branch(self.store))
         sale_view = self.sales.get_selected()
         store = api.new_store()
         retval = return_sale(self.get_parent(),
@@ -281,6 +291,13 @@ def return_sale(parent, sale, store):
         return
 
     if sale.can_return():
+        need_document = not sysparam.get_bool('ACCEPT_SALE_RETURN_WITHOUT_DOCUMENT')
+        if need_document and not sale.get_client_document():
+            warning(_('It is not possible to accept a returned sale from clients '
+                      'without document. Please edit the client document or change '
+                      'the sale client'))
+            return
+
         returned_sale = sale.create_sale_return_adapter()
         retval = run_dialog(SaleReturnWizard, parent, store, returned_sale)
     elif sale.can_cancel():
