@@ -32,6 +32,7 @@ from stoqlib.domain.person import ClientCategory
 from stoqlib.domain.sellable import ClientCategoryPrice, Sellable
 from stoqlib.gui.editors.baseeditor import (BaseRelationshipEditorSlave,
                                             BaseEditorSlave)
+from stoqlib.gui.editors.sellableeditor import CategoryPriceEditor
 from stoqlib.gui.slaves.imageslaveslave import ImageSlave
 from stoqlib.lib.formatters import get_formatted_cost
 from stoqlib.lib.message import info
@@ -75,13 +76,11 @@ class SellableDetailsSlave(BaseEditorSlave):
 
     def _on_image_slave__image_changed(self, slave, image):
         if image:
-            image.description = ('%s #%d' %
-                                 (self.model.get_description(), self.model.id))
+            image.description = self.model.get_description()
         self.model.image = image
 
 
 class CategoryPriceSlave(BaseRelationshipEditorSlave):
-    from stoqlib.gui.editors.sellableeditor import CategoryPriceEditor
     """A slave for changing the suppliers for a product.
     """
     target_name = _(u'Category')
@@ -108,8 +107,7 @@ class CategoryPriceSlave(BaseRelationshipEditorSlave):
                 Column('price', title=_(u'Price'), data_type=currency,
                        format_func=get_formatted_cost, width=150),
                 Column('markup', title=_(u'Markup'), data_type=str,
-                       width=100, format_func=self._format_markup),
-                        ]
+                       width=100, format_func=self._format_markup)]
 
     def create_model(self):
         sellable = self._sellable
@@ -118,7 +116,7 @@ class CategoryPriceSlave(BaseRelationshipEditorSlave):
         if sellable.get_category_price_info(category):
             product_desc = sellable.get_description()
             info(_(u'%s already have a price for category %s') % (product_desc,
-                                                      category.get_description()))
+                                                                  category.get_description()))
             return
 
         model = ClientCategoryPrice(sellable=sellable,
