@@ -33,6 +33,7 @@ from kiwi.datatypes import ValidationError
 from stoqlib.api import api
 from stoqlib.domain.taxes import (SaleItemIcms, ProductIcmsTemplate,
                                   SaleItemIpi, ProductIpiTemplate)
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
 
@@ -121,14 +122,14 @@ class BaseICMSSlave(BaseTaxSlave):
                    bool_widgets + date_widgets)
 
     simples_widgets = ['orig', 'csosn', 'mod_bc_st', 'p_mva_st', 'p_red_bc_st',
-              'p_icms_st', 'v_bc_st', 'v_icms_st', 'p_cred_sn',
-              'p_cred_sn_valid_until' 'v_cred_icms_sn', 'v_bc_st_ret',
-              'v_icms_st_ret'],
+                       'p_icms_st', 'v_bc_st', 'v_icms_st', 'p_cred_sn',
+                       'p_cred_sn_valid_until' 'v_cred_icms_sn', 'v_bc_st_ret',
+                       'v_icms_st_ret'],
 
     normal_widgets = ['orig', 'cst', 'mod_bc_st', 'p_mva_st', 'p_red_bc_st',
-             'p_icms_st', 'v_bc_st', 'v_icms_st', 'bc_st_include_ipi',
-             'mod_bc', 'p_icms', 'v_bc', 'v_icms', 'bc_include_ipi',
-             'bc_st_include_ipi']
+                      'p_icms_st', 'v_bc_st', 'v_icms_st', 'bc_st_include_ipi',
+                      'mod_bc', 'p_icms', 'v_bc', 'v_icms', 'bc_include_ipi',
+                      'bc_st_include_ipi']
 
     tooltips = {
         'p_icms': u'Aliquota do imposto',
@@ -159,17 +160,37 @@ class BaseICMSSlave(BaseTaxSlave):
             (u'103 - Isenção do ICMS para faixa de receita bruta', 103),
             (u'201 - Tributada com permissão de crédito e com cobrança do ICMS por ST', 201),
             (u'202 - Tributada sem permissão de crédito e com cobrança do ICMS por ST', 202),
-            (u'203 - Isenção do ICMS para faixa de receita bruta e com cobrança do ICMS por ST', 203),
+            (u'203 - Isenção do ICMS para faixa de receita bruta e com cobrança do ICMS por ST',
+             203),
             (u'300 - Imune', 300),
             (u'400 - Não tributada', 400),
             (u'500 - ICMS cobrado anteriormente por ST ou por antecipação', 500),
+            (u'900 - Outros', 900),
         ),
 
+        # http://www.fazenda.gov.br/confaz/confaz/ajustes/2012/AJ_020_12.htm
+        # http://www.fazenda.gov.br/confaz/confaz/ajustes/2013/AJ_015_13.htm
+        # http://www.fazenda.gov.br/confaz/confaz/Convenios/ICMS/2013/CV038_13.htm
         'orig': (
             (None, None),
-            (u'0 - Nacional', 0),
-            (u'1 - Estrangeira - importação direta', 1),
-            (u'2 - Estrangeira - adquirida no mercado interno', 2),
+            (u'0 - Nacional, '
+             u'exceto as indicadas nos códigos 3, 4, 5 e 8', 0),
+            (u'1 - Estrangeira - Importação direta, '
+             u'exceto a indicada no código 6', 1),
+            (u'2 - Estrangeira - Adquirida no mercado interno, '
+             u'exceto a indicada no código 7', 2),
+            (u'3 - Nacional, mercadoria ou bem com Conteúdo de '
+             u'Importação superior a 40% e inferior ou igual a 70%', 3),
+            (u'4 - Nacional, cuja produção tenha sido feita em '
+             u'conformidade com os processos produtivos básicos', 4),
+            (u'5 - Nacional, mercadoria ou bem com Conteúdo de '
+             u'Importação inferior ou igual a 40%', 5),
+            (u'6 - Estrangeira - Importação direta, '
+             u'sem similar nacional, constante na CAMEX', 6),
+            (u'7 - Estrangeira - Adquirida no mercado interno, '
+             u'sem similar nacional, constante na CAMEX', 7),
+            (u'8 - Nacional, mercadoria ou bem com Conteúdo de Importação '
+             u'superior a 70%', 8),
         ),
         'mod_bc': (
             (None, None),
@@ -199,9 +220,9 @@ class BaseICMSSlave(BaseTaxSlave):
              'v_icms', 'bc_include_ipi'],
         30: ['orig', 'cst', 'mod_bc_st', 'p_mva_st', 'p_red_bc_st',
              'p_icms_st', 'v_bc_st', 'v_icms_st', 'bc_st_include_ipi'],
-        40: ['orig', 'cst'], #
-        41: ['orig', 'cst'], # Same tag
-        50: ['orig', 'cst'], #
+        40: ['orig', 'cst'],
+        41: ['orig', 'cst'],  # Same tag
+        50: ['orig', 'cst'],
         51: ['orig', 'cst', 'mod_bc', 'p_red_bc', 'p_icms', 'v_bc',
              'v_icms', 'bc_st_include_ipi'],
         60: ['orig', 'cst', 'v_bc_st', 'v_icms_st'],
@@ -222,6 +243,9 @@ class BaseICMSSlave(BaseTaxSlave):
         300: ['orig', 'csosn'],
         400: ['orig', 'csosn'],
         500: ['orig', 'csosn', 'v_bc_st_ret', 'v_icms_st_ret'],
+        900: ['orig', 'csosn', 'mod_bc', 'v_bc', 'p_red_bc', 'p_icms', 'v_icms',
+              'mod_bc_st', 'p_mva_st', 'p_red_bc_st', 'v_bc_st', 'p_icms_st',
+              'v_icms_st', 'p_cred_sn', 'v_cred_icms_sn']
     }
 
     def setup_proxies(self):
@@ -244,7 +268,7 @@ class BaseICMSSlave(BaseTaxSlave):
         if (self.p_cred_sn.get_value()
             and not self.p_cred_sn_valid_until.get_date()):
                 # Set the default expire date to the last day of current month.
-            default_expire_date = (datetime.date.today() +
+            default_expire_date = (localtoday().date() +
                                    relativedelta(day=1, months=+1, days=-1))
             self.p_cred_sn_valid_until.set_date(default_expire_date)
 
