@@ -22,7 +22,7 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.person import (Branch, UserBranchAccess)
@@ -54,7 +54,7 @@ class UserBranchAccessSlave(BaseRelationshipEditorSlave):
 
         if UserBranchAccess.has_access(self._store, user, branch):
             info(_(u'%s is already associated with %s.') %
-                 (user.person.name, branch.person.company.fancy_name))
+                 (user.person.name, branch.get_description()))
             return
 
         return UserBranchAccess(store=self._store,
@@ -62,8 +62,8 @@ class UserBranchAccessSlave(BaseRelationshipEditorSlave):
                                 branch=branch)
 
     def get_columns(self):
-        return [Column('branch.person.company.fancy_name', title=_('Branch Name'),
-                        data_type=str, expand=True), ]
+        return [Column('branch.description', title=_('Branch Name'),
+                       data_type=str, expand=True), ]
 
     def get_targets(self):
         branches = Branch.get_active_branches(self._store)
