@@ -117,10 +117,10 @@ class PasswordEditorSlave(BaseEditorSlave):
     def on_password__validate(self, entry, password):
         if len(password) < MINIMUM_PASSWORD_CHAR_LEN:
             return ValidationError(_
-                (u"Passwords must have at least %d characters")
-                % MINIMUM_PASSWORD_CHAR_LEN)
+                                  (u"Passwords must have at least %d characters")
+                                   % MINIMUM_PASSWORD_CHAR_LEN)
         if ((self.model.confirm_password and self._confirm_password) and
-               password != self.confirm_password.get_text()):
+            password != self.confirm_password.get_text()):
             return ValidationError(_(u"Passwords don't matches"))
 
     def on_password__content_changed(self, entry):
@@ -130,7 +130,7 @@ class PasswordEditorSlave(BaseEditorSlave):
         if len(password) < MINIMUM_PASSWORD_CHAR_LEN:
             return ValidationError(
                 _(u"Passwords must have at least %d characters")
-                 % MINIMUM_PASSWORD_CHAR_LEN)
+                % MINIMUM_PASSWORD_CHAR_LEN)
         if password != self.password.get_text():
             return ValidationError(_(u"Passwords don't matches"))
 
@@ -294,4 +294,5 @@ class UserDetailsSlave(BaseEditorSlave):
             return ValidationError('Username already exist')
 
     def on_change_password_button__clicked(self, button):
-        run_dialog(PasswordEditor, self, self.store, self.model)
+        parent = self.get_toplevel().get_toplevel()
+        run_dialog(PasswordEditor, parent, self.store, self.model)
