@@ -23,21 +23,23 @@
 ##
 
 import datetime
+import mock
 import unittest
+from stoqlib.gui.editors.accounteditor import AccountEditor
 
 from stoqlib.gui.editors.accounttransactioneditor import AccountTransactionEditor
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestAccountTransactionEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         account = self.create_account()
         editor = AccountTransactionEditor(self.store, None, account)
 
         editor.date.update(datetime.date.today())
         self.check_editor(editor, 'editor-transaction-create')
 
-    def testShow(self):
+    def test_show(self):
         account = self.create_account()
         transaction = self.create_account_transaction(account)
         editor = AccountTransactionEditor(self.store, transaction, account)
@@ -61,6 +63,22 @@ class TestAccountTransactionEditor(GUITest):
         self.check_editor(editor, 'editor-transaction-confirm',
                           [editor.retval, account])
 
+    @mock.patch('stoqlib.gui.editors.accounttransactioneditor.api.new_store')
+    @mock.patch('stoqlib.gui.editors.accounttransactioneditor.run_dialog')
+    def test_add_account(self, run_dialog, new_store):
+        new_account = self.create_account()
+        new_store.return_value = self.store
+        run_dialog.return_value = new_account
+        editor = AccountTransactionEditor(self.store, None, new_account)
+        parent_account = editor._get_account()
+
+        with mock.patch.object(self.store, 'commit'):
+            with mock.patch.object(self.store, 'close'):
+                self.click(editor.add_account)
+                run_dialog.assert_called_once_with(AccountEditor, editor,
+                                                   self.store,
+                                                   parent_account=parent_account)
+
 
 if __name__ == '__main__':
     from stoqlib.api import api
