@@ -22,24 +22,24 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
 import unittest
 
 from stoqlib.domain.person import Calls
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.gui.editors.callseditor import CallsEditor
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestCallsEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         person = self.create_person()
         editor = CallsEditor(self.store, None, person, None)
         self.assertTrue(isinstance(editor.model, Calls))
-        editor.date.update(datetime.date.today())
+        editor.date.update(localtoday().date())
 
         self.check_editor(editor, 'editor-calls-create')
 
-    def testShow(self):
+    def test_show(self):
         person = self.create_person()
         calls = self.create_call()
         calls.person = person
