@@ -26,12 +26,12 @@ import mock
 
 from stoqlib.gui.editors.callseditor import CallsEditor
 from stoqlib.gui.search.callsearch import CallsSearch
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestCallsSearch(GUITest):
 
-    def testShow(self):
+    def test_show(self):
         # 2 calls, different persons
         call1 = self.create_call()
         self.create_call(attendant=call1.attendant)
@@ -40,7 +40,7 @@ class TestCallsSearch(GUITest):
         search.search.refresh()
         self.check_search(search, 'calls-show')
 
-    def testWithPerson(self):
+    def test_with_person(self):
         # 2 calls, different persons
         call1 = self.create_call()
         self.create_call(attendant=call1.attendant)
@@ -49,16 +49,16 @@ class TestCallsSearch(GUITest):
         search.search.refresh()
         self.check_search(search, 'calls-show-person')
 
-    def testActions(self):
+    def test_actions(self):
         # 2 calls, different persons
         call1 = self.create_call()
         self.create_call(attendant=call1.attendant)
 
         search = CallsSearch(self.store, date=call1.date,
                              reuse_store=True)
-        self.assertNotSensitive(search, ['csv_button', 'print_button'])
+        self.assertNotSensitive(search, ['print_button'])
         search.search.refresh()
-        self.assertSensitive(search, ['csv_button', 'print_button'])
+        self.assertSensitive(search, ['print_button'])
 
         self.assertNotSensitive(search._toolbar, ['edit_button'])
         selected = search.results[0]
@@ -69,10 +69,6 @@ class TestCallsSearch(GUITest):
             self.click(search.print_button)
             self.assertEquals(print_report.call_count, 1)
 
-        with mock.patch('stoqlib.gui.search.callsearch.SpreadSheetExporter.export') as export:
-            self.click(search.csv_button)
-            self.assertEquals(export.call_count, 1)
-
         with mock.patch('stoqlib.gui.search.callsearch.run_dialog') as run_dialog:
             self.click(search._toolbar.edit_button)
             self.assertEquals(run_dialog.call_count, 1)
