@@ -23,12 +23,12 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.tilleditor import CashOutEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestCashOutEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         till = self.create_till()
         till.open_till()
         editor = CashOutEditor(self.store)
