@@ -23,12 +23,12 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.sellableeditor import CategoryPriceEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestCategoryPriceEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         model = self.create_client_category_price()
         editor = CategoryPriceEditor(self.store, model)
         self.check_editor(editor, 'editor-categorypriceeditor-show')
