@@ -23,11 +23,11 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.fiscaleditor import CfopEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestCfopEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = CfopEditor(self.store)
         self.check_editor(editor, 'editor-cfop-create')
