@@ -22,20 +22,24 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from stoqlib.gui.slaves.clientslave import ClientStatusSlave
-from stoqlib.gui.uitestutils import GUITest
+from decimal import Decimal
+import mock
+
+from stoqlib.gui.dialogs.creditdialog import CreditInfoListDialog
+from stoqlib.gui.search.clientsalaryhistorysearch import ClientSalaryHistorySearch
+from stoqlib.gui.slaves.clientslave import ClientCreditSlave, ClientStatusSlave
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.reporting.clientcredit import ClientCreditReport
 
 _ = stoqlib_gettext
 
 
 class TestClientSlave(GUITest):
-    def testShow(self):
+    def test_show(self):
         # this is necessary so previous tests will not interfere in here
-        sysparam(self.store).update_parameter(
-            u"CREDIT_LIMIT_SALARY_PERCENT",
-            u"0")
+        sysparam.set_decimal(self.store, "CREDIT_LIMIT_SALARY_PERCENT", Decimal(0))
 
         client = self.create_client()
         client.salary = 100
@@ -43,27 +47,23 @@ class TestClientSlave(GUITest):
         self.check_slave(slave, 'slave-clientstatus-show')
 
     def test_credit_limit_active(self):
-        sysparam(self.store).update_parameter(
-            u"CREDIT_LIMIT_SALARY_PERCENT",
-            u"10")
+        sysparam.set_decimal(self.store, "CREDIT_LIMIT_SALARY_PERCENT", Decimal(10))
 
         client = self.create_client()
-        slave = ClientStatusSlave(self.store, client)
+        slave = ClientCreditSlave(self.store, client)
 
         # if CREDIT_LIMIT_SALARY_PERCENT is higher than 0, credit limit
         # should not be editable
         self.assertNotSensitive(slave, ['credit_limit'])
 
         # if salary percent is 0 credit limit should be editable
-        sysparam(self.store).update_parameter(
-            u"CREDIT_LIMIT_SALARY_PERCENT",
-            u"0")
-        slave = ClientStatusSlave(self.store, client)
+        sysparam.set_decimal(self.store, "CREDIT_LIMIT_SALARY_PERCENT", Decimal(0))
+        slave = ClientCreditSlave(self.store, client)
         self.assertSensitive(slave, ['credit_limit'])
 
     def test_credit_limit_validate(self):
         client = self.create_client()
-        slave = ClientStatusSlave(self.store, client)
+        slave = ClientCreditSlave(self.store, client)
 
         # checks a valid credit limit
         self.assertEquals(None, slave.credit_limit.emit('validate', 10))
@@ -74,13 +74,11 @@ class TestClientSlave(GUITest):
                           str(slave.credit_limit.emit('validate', -10)))
 
     def test_credit_limit_update(self):
-        sysparam(self.store).update_parameter(
-            u"CREDIT_LIMIT_SALARY_PERCENT",
-            u"10")
+        sysparam.set_decimal(self.store, "CREDIT_LIMIT_SALARY_PERCENT", Decimal(10))
 
         client = self.create_client()
         client.salary = 50
-        slave = ClientStatusSlave(self.store, client)
+        slave = ClientCreditSlave(self.store, client)
         slave.salary.emit('changed')
         self.assertEquals(slave.credit_limit.read(), 5)
 
@@ -90,9 +88,7 @@ class TestClientSlave(GUITest):
         slave.salary.emit('changed')
         self.assertEquals(slave.credit_limit.read(), 10)
 
-        sysparam(self.store).update_parameter(
-            u"CREDIT_LIMIT_SALARY_PERCENT",
-            u"0")
+        sysparam.set_decimal(self.store, "CREDIT_LIMIT_SALARY_PERCENT", Decimal(0))
 
         # checks if credit limit does not update (correct behavior)
         # when salary percent is 0 and salary changes
@@ -108,7 +104,7 @@ class TestClientSlave(GUITest):
 
     def test_salary_validate(self):
         client = self.create_client()
-        slave = ClientStatusSlave(self.store, client)
+        slave = ClientCreditSlave(self.store, client)
 
         # checks a valid salary
         self.assertEquals(None, slave.salary.emit('validate', 10))
@@ -116,3 +112,32 @@ class TestClientSlave(GUITest):
         # checks invalid salary
         self.assertEquals("Salary can't be lower than 0.",
                           str(slave.salary.emit('validate', -10)))
+
+    @mock.patch('stoqlib.gui.slaves.clientslave.run_dialog')
+    def test_salary_history(self, run_dialog):
+        client = self.create_client()
+        slave = ClientCreditSlave(self.store, client)
+
+        self.click(slave.salary_history_button)
+        run_dialog.assert_called_once_with(ClientSalaryHistorySearch,
+                                           slave.get_toplevel().get_toplevel(),
+                                           self.store, client=client)
+
+    @mock.patch('stoqlib.gui.slaves.clientslave.run_dialog')
+    def test_credit_transactions(self, run_dialog):
+        client = self.create_client()
+        slave = ClientCreditSlave(self.store, client)
+
+        self.click(slave.credit_transactions_button)
+        run_dialog.assert_called_once_with(CreditInfoListDialog,
+                                           slave.get_toplevel().get_toplevel(),
+                                           self.store, client, reuse_store=True)
+
+    @mock.patch('stoqlib.gui.slaves.clientslave.print_report')
+    def test_print_credit_letter(self, print_report):
+        client = self.create_client()
+        slave = ClientCreditSlave(self.store, client)
+
+        self.click(slave.print_credit_letter)
+
+        print_report.assert_called_once_with(ClientCreditReport, client)
