@@ -23,18 +23,19 @@
 
 import datetime
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.domain.person import ClientSalaryHistory, LoginUser
 from stoqlib.gui.search.clientsalaryhistorysearch import (
-                                                    ClientSalaryHistorySearch)
+    ClientSalaryHistorySearch)
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestClientSalaryHistorySearch(GUITest):
-    def testSearch(self):
+    def test_search(self):
         client = self.create_client()
 
-        user_a = self.store.find(LoginUser, id=1).one()
-        user_b = self.store.find(LoginUser, id=2).one()
+        users = self.store.find(LoginUser).order_by(LoginUser.username)
+        user_a = users[0]
+        user_b = users[1]
 
         ClientSalaryHistory(date=datetime.datetime(2012, 1, 1),
                             new_salary=1000,
