@@ -22,29 +22,29 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 from stoqlib.api import api
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.domain.commission import Commission
 from stoqlib.domain.person import Person
 from stoqlib.gui.search.commissionsearch import CommissionSearch
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.lib.dateutils import localdatetime, localdate
 
 
 class TestCommissionSearch(GUITest):
-    def testSearch(self):
+    def test_search(self):
         self.clean_domain([Commission])
 
         person = self.store.find(Person, name=u'Deivis Alexandre Junior').one()
         salesperson = person.salesperson
         sale = self.create_sale()
         sale.identifier = 74521
-        sale.open_date = datetime.datetime(2012, 1, 1)
-        sale.confirm_date = datetime.datetime(2012, 1, 10)
+        sale.open_date = localdatetime(2012, 1, 1)
+        sale.confirm_date = localdatetime(2012, 1, 10)
+        sale.salesperson = salesperson
         payment = self.create_payment()
-        payment.paid_date = datetime.datetime(2012, 1, 15)
-        Commission(salesperson=salesperson,
-                   sale=sale,
+        payment.paid_date = localdatetime(2012, 1, 15)
+        Commission(sale=sale,
                    payment=payment,
                    store=self.store)
 
@@ -52,19 +52,23 @@ class TestCommissionSearch(GUITest):
         salesperson = person.salesperson
         sale = self.create_sale()
         sale.identifier = 85412
-        sale.open_date = datetime.datetime(2012, 2, 2)
-        sale.confirm_date = datetime.datetime(2012, 2, 10)
+        sale.open_date = localdatetime(2012, 2, 2)
+        sale.confirm_date = localdatetime(2012, 2, 10)
+        sale.salesperson = salesperson
         payment = self.create_payment()
-        payment.paid_date = datetime.datetime(2012, 2, 15)
-        Commission(salesperson=salesperson,
-                   sale=sale,
+        payment.paid_date = localdatetime(2012, 2, 15)
+        Commission(sale=sale,
                    payment=payment,
                    store=self.store)
 
         # First check for columns getting the confirm date of the sale
-        api.sysparam(self.store).update_parameter(
-            u'SALE_PAY_COMMISSION_WHEN_CONFIRMED', u'1')
+        api.sysparam.set_bool(self.store,
+                              'SALE_PAY_COMMISSION_WHEN_CONFIRMED',
+                              True)
         search = CommissionSearch(self.store)
+        search._date_filter.select(data=DateSearchFilter.Type.USER_INTERVAL)
+        search._date_filter.start_date.update(localdate(2010, 1, 1))
+        search._date_filter.end_date.update(localdate(2012, 2, 15))
 
         search.search.refresh()
         self.check_search(search, 'commission-confirmed-no-filter')
@@ -74,15 +78,20 @@ class TestCommissionSearch(GUITest):
         self.check_search(search, 'commission-confirmed-string-filter')
 
         search.set_searchbar_search_string('')
-        search._salesperson_filter.set_state('Maria Aparecida Ardana')
+        search._salesperson_filter.set_state(salesperson.id)
         search.search.refresh()
         self.check_search(search, 'commission-confirmed-salesperson-filter')
 
         # Then check for columns getting the paid date of the payment
-        api.sysparam(self.store).update_parameter(
-            u'SALE_PAY_COMMISSION_WHEN_CONFIRMED', u'0')
+        api.sysparam.set_bool(self.store,
+                              'SALE_PAY_COMMISSION_WHEN_CONFIRMED',
+                              False)
         search = CommissionSearch(self.store)
 
+        search._date_filter.select(data=DateSearchFilter.Type.USER_INTERVAL)
+        search._date_filter.start_date.update(localdate(2010, 1, 1))
+        search._date_filter.end_date.update(localdate(2012, 2, 15))
+
         search.search.refresh()
         self.check_search(search, 'commission-paid-no-filter')
 
@@ -91,6 +100,6 @@ class TestCommissionSearch(GUITest):
         self.check_search(search, 'commission-paid-string-filter')
 
         search.set_searchbar_search_string('')
-        search._salesperson_filter.set_state('Maria Aparecida Ardana')
+        search._salesperson_filter.set_state(salesperson.id)
         search.search.refresh()
         self.check_search(search, 'commission-paid-salesperson-filter')
