@@ -22,12 +22,12 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.contacteditor import ContactInfoEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestContactEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         person = self.create_person()
         editor = ContactInfoEditor(self.store, person=person)
         self.check_editor(editor, 'editor-contacteditor-create')
