@@ -22,11 +22,11 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.dialogs.crashreportdialog import CrashReportDialog
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestCrashReportDialog(GUITest):
-    def testShow(self):
+    def test_show(self):
         dialog = CrashReportDialog(None)
         self.check_dialog(dialog._dialog, 'dialog-crash-report')
