@@ -24,9 +24,9 @@
 
 
 from stoqlib.domain.sale import Delivery
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.deliveryeditor import (DeliveryEditor,
                                                 CreateDeliveryEditor)
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestDeliveryEditor(GUITest):
@@ -45,12 +45,12 @@ class TestDeliveryEditor(GUITest):
 
         return delivery
 
-    def testShow(self):
+    def test_show(self):
         delivery = self._create_delivery()
         editor = DeliveryEditor(self.store, delivery)
         self.check_editor(editor, 'editor-delivery-show')
 
-    def testStateChanging(self):
+    def test_state_changing(self):
         delivery = self._create_delivery()
         editor = DeliveryEditor(self.store, delivery)
 
@@ -58,7 +58,7 @@ class TestDeliveryEditor(GUITest):
         # transporter and address
         self.assertEqual(delivery.status, Delivery.STATUS_INITIAL)
         self.assertSensitive(editor,
-                             ['transporter', 'address',
+                             ['transporter_id', 'address',
                               'was_received_check', 'was_delivered_check'])
         self.assertNotSensitive(editor,
                                 ['deliver_date', 'tracking_code',
@@ -74,7 +74,7 @@ class TestDeliveryEditor(GUITest):
                              ['was_received_check', 'deliver_date', 'tracking_code',
                               'was_received_check', 'was_delivered_check'])
         self.assertNotSensitive(editor,
-                                ['transporter', 'address', 'receive_date'])
+                                ['transporter_id', 'address', 'receive_date'])
 
         # Received state. Like sent above, but in addition, should
         # not be possible to unmark was_delivered_check
@@ -85,18 +85,53 @@ class TestDeliveryEditor(GUITest):
                               'receive_date', 'tracking_code',
                               'was_received_check'])
         self.assertNotSensitive(editor,
-                                ['transporter', 'address',
+                                ['transporter_id', 'address',
                                  'was_delivered_check'])
 
 
 class TestCreateDeliveryEditor(GUITest):
-    def testCreate(self):
+    def _create_sale_items(self):
         sale = self.create_sale()
         sale_items = []
         for i in range(5):
             sale_item = self.create_sale_item(sale=sale)
             sale_item.sellable.description = u"Delivery item %s" % (i + 1)
             sale_items.append(sale_item)
+        return sale_items
 
+    def test_create(self):
+        sale_items = self._create_sale_items()
         editor = CreateDeliveryEditor(self.store, sale_items=sale_items)
         self.check_editor(editor, 'editor-createdelivery-create')
+
+    def test_on_client_changed(self):
+        client1 = self.create_client(name=u"Client01")
+        address1 = self.create_address(person=client1.person)
+        client2 = self.create_client(name=u"Client02")
+        addres2 = self.create_address(person=client2.person)
+        addres2.street = u"Mainstreet02"
+        sale_items = self._create_sale_items()
+        editor = CreateDeliveryEditor(self.store, sale_items=sale_items)
+
+        # No client
+        no_client = editor.client_id.get_selected_data()
+        self.assertEqual(no_client, None)
+        no_address = editor.address.get_selected_data()
+        self.assertEqual(no_address, None)
+        self.check_editor(editor, 'editor-createdelivery-noclient')
+
+        # Select a client
+        editor.client_id.select(client1.id)
+        first_client = editor.client_id.get_selected_data()
+        self.assertEqual(first_client, client1.id)
+        first_address = editor.address.get_selected_data()
+        self.assertEqual(first_address, address1)
+        self.check_editor(editor, 'editor-createdelivery-client')
+
+        # Change client
+        editor.client_id.select(client2.id)
+        new_client = editor.client_id.get_selected_data()
+        self.assertNotEquals(first_client, new_client)
+        new_address = editor.address.get_selected_data()
+        self.assertNotEquals(first_address, new_address)
+        self.check_editor(editor, 'editor-createdelivery-clientchanged')
