@@ -22,14 +22,15 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 import mock
 
+from stoqlib.api import api
 from stoqlib.domain.fiscal import FiscalBookEntry
 from stoqlib.gui.search.fiscalsearch import (CfopSearch,
-                                             FiscalBookEntrySearch)
-from stoqlib.gui.uitestutils import GUITest
+                                             FiscalBookEntrySearch,
+                                             FiscalBookEntryType)
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -42,44 +43,38 @@ class TestFiscalBookSearch(GUITest):
         search.results.select(search.results[0])
         return search
 
-    def testShow(self):
-        for i in self.store.find(FiscalBookEntry):
-            i.date = datetime.date.today()
-
+    def test_show(self):
+        entries = []
+        for entry in self.store.find(FiscalBookEntry).order_by(FiscalBookEntry.date):
+            entry.date = localtoday().date()
+            entries.append(entry)
         search = self._show_search()
         self.check_search(search, 'fiscal-book-icms-filter')
 
-        search.entry_type.set_state(1)
+        search.entry_type.set_state(FiscalBookEntryType.IPI)
         search.search.refresh()
         self.check_search(search, 'fiscal-book-ipi-filter')
 
-        search.entry_type.set_state(2)
+        search.entry_type.set_state(FiscalBookEntryType.ISS)
         search.search.refresh()
         self.check_search(search, 'fiscal-book-iss-filter')
 
-        search.entry_type.set_state(0)
-        search.branch_filter.set_state(2)
+        search.entry_type.set_state(FiscalBookEntryType.ICMS)
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
         search.search.refresh()
         self.check_search(search, 'fiscal-book-branch-filter')
 
-    @mock.patch('stoqlib.gui.search.fiscalsearch.SpreadSheetExporter.export')
     @mock.patch('stoqlib.gui.search.fiscalsearch.run_dialog')
-    def testButtons(self, run_dialog, export):
+    def test_buttons(self, run_dialog):
         search = self._show_search()
 
         self.assertSensitive(search, ['edit_button'])
         self.click(search.edit_button)
         self.assertEquals(run_dialog.call_count, 1)
 
-        self.assertSensitive(search, ['csv_button'])
-        self.click(search.csv_button)
-        export.assert_called_once_with(object_list=search.results,
-                                       name=_('Fiscal book'),
-                                       filename_prefix=_('fiscal-book'))
-
 
 class TestCfopSearch(GUITest):
-    def testShow(self):
+    def test_show(self):
         search = CfopSearch(self.store)
         search.search.refresh()
         self.check_search(search, 'cfop-show')
