@@ -25,11 +25,11 @@
 import mock
 
 from stoqlib.gui.dialogs.importerdialog import ImporterDialog
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestImporterDialog(GUITest):
-    @mock.patch('stoqlib.gui.dialogs.importerdialog.ProcessView.execute_command')
+    @mock.patch('stoqlib.gui.dialogs.progressbardialog.ProcessView.execute_command')
     def test_show(self, execute_command):
         dialog = ImporterDialog('format', 'filename')
         self.check_dialog(dialog, 'dialog-importer-show')
