@@ -24,12 +24,12 @@
 
 
 from stoqlib.domain.purchase import PurchaseOrder
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.purchaseeditor import InConsignmentItemEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestInConsignmentItemEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         item = self.create_purchase_order_item()
         item.order.status = PurchaseOrder.ORDER_CONSIGNED
         editor = InConsignmentItemEditor(self.store, item)
