@@ -23,11 +23,11 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.invoiceeditor import InvoiceLayoutEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestInvoiceLayoutEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = InvoiceLayoutEditor(self.store)
         self.check_editor(editor, 'editor-invoicelayout-create')
