@@ -26,22 +26,21 @@
 
 import gtk
 from kiwi.python import Settable
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 import mock
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.properties import UnicodeCol
 from stoqlib.database.runtime import StoqlibStore
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
-from stoqlib.gui.base.lists import ModelListSlave
-from stoqlib.gui.uitestutils import GUITest
-from stoqlib.gui.base.lists import SimpleListDialog
+from stoqlib.gui.base.lists import ModelListSlave, SimpleListDialog
+from stoqlib.gui.test.uitestutils import GUITest
 
 
+@implementer(IDescribable)
 class _TestModel(Domain):
     __storm_table__ = '_test_model'
-    implements(IDescribable)
 
     unicode_var = UnicodeCol()
 
@@ -64,7 +63,7 @@ class TestModelListSlave(GUITest):
         self.store.execute("""
             DROP TABLE IF EXISTS _test_model;
             CREATE TABLE _test_model (
-                id serial NOT NULL PRIMARY KEY,
+                id uuid PRIMARY KEY DEFAULT uuid_generate_v1(),
                 te_id bigint UNIQUE REFERENCES transaction_entry(id),
 
                 unicode_var text
@@ -73,10 +72,10 @@ class TestModelListSlave(GUITest):
         self.models = set([
             _TestModel(store=self.store, unicode_var=u'XXX'),
             _TestModel(store=self.store, unicode_var=u'YYY'),
-            ])
+        ])
         self.store.commit(close=False)
 
-    def testPopulate(self):
+    def test_populate(self):
         list_slave = _ModelListSlave(store=self.store)
         # Make sure the list was populated right
         self.assertEqual(set(list_slave.listcontainer.list), self.models)
@@ -86,7 +85,7 @@ class TestModelListSlave(GUITest):
         self.assertEqual(StoqlibStore.of(list_slave.populate()[0]), self.store)
 
     @mock.patch('kiwi.ui.listdialog.yesno')
-    def testRemoveItem(self, yesno):
+    def test_remove_item(self, yesno):
         yesno.return_value = gtk.RESPONSE_OK
 
         list_slave = _ModelListSlave(store=self.store)
@@ -114,7 +113,7 @@ class TestModelListSlave(GUITest):
         self.assertEqual(StoqlibStore.of(list_slave.populate()[0]), self.store)
 
     @mock.patch('kiwi.ui.listdialog.yesno')
-    def testRemoveItemReuseStore(self, yesno):
+    def test_remove_item_reuse_store(self, yesno):
         yesno.return_value = gtk.RESPONSE_OK
 
         list_slave = _ModelListSlave(store=self.store)
@@ -150,20 +149,20 @@ class TestSimpleListDialog(GUITest):
             objs.append(Settable(
                 id=i,
                 desc="Object %d" % i,
-                ))
+            ))
 
         columns = [
             Column('id', title='#', data_type=int),
             Column('desc', title='Description', data_type=str, expand=True),
-            ]
+        ]
 
         return SimpleListDialog(columns=columns, objects=objs)
 
-    def testDialog(self):
+    def test_dialog(self):
         dialog = self._create_dialog()
         self.check_dialog(dialog, 'dialog-simple-list')
 
-    def testConfirm(self):
+    def test_confirm(self):
         dialog = self._create_dialog()
         with mock.patch.object(dialog, 'close') as close:
             self.click(dialog.ok_button)
