@@ -22,16 +22,14 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 import mock
 
-from kiwi.ui.search import DateSearchFilter
-
 from stoqlib.domain.loan import Loan
+from stoqlib.lib.dateutils import localdate, localdatetime
 from stoqlib.gui.dialogs.loandetails import LoanDetailsDialog
 from stoqlib.gui.search.loansearch import LoanSearch
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.reporting.loanreceipt import LoanReceipt
 
 
@@ -47,15 +45,15 @@ class TestLoanSearch(GUITest):
         loan = self.create_loan(client=client)
         self.create_loan_item(loan=loan)
         loan.identifier = 54952
-        loan.open_date = datetime.datetime(2012, 1, 1)
+        loan.open_date = localdatetime(2012, 1, 1)
 
         client = self.create_client(name=u'Carmen Sandiego')
         loan = self.create_loan(client=client)
         self.create_loan_item(loan=loan)
         loan.identifier = 45978
-        loan.open_date = datetime.datetime(2012, 2, 2)
+        loan.open_date = localdatetime(2012, 2, 2)
 
-    def testSearch(self):
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -67,13 +65,13 @@ class TestLoanSearch(GUITest):
 
         search.set_searchbar_search_string('')
         search.date_filter.select(DateSearchFilter.Type.USER_DAY)
-        search.date_filter.start_date.update(datetime.date(2012, 2, 2))
+        search.date_filter.start_date.update(localdate(2012, 2, 2).date())
         search.search.refresh()
         self.check_search(search, 'loan-date-filter')
 
     @mock.patch('stoqlib.gui.search.loansearch.run_dialog')
     @mock.patch('stoqlib.gui.search.loansearch.print_report')
-    def testButtons(self, print_report, run_dialog):
+    def test_buttons(self, print_report, run_dialog):
         self._create_domain()
         search = self._show_search()
 
