@@ -27,15 +27,17 @@ from decimal import Decimal
 import unittest
 
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
 from stoqlib.gui.slaves.paymentslave import (BillMethodSlave, CheckMethodSlave,
                                              CardMethodSlave)
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
+from stoqlib.lib.dateutils import localdate
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.parameters import sysparam
 
 
 class TestBillPaymentSlaves(GUITest):
-    def testCreate(self):
+    def test_create(self):
         wizard = PurchaseWizard(self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
@@ -45,8 +47,8 @@ class TestBillPaymentSlaves(GUITest):
                                 Decimal(200))
         self.check_slave(slave, 'slave-bill-method')
 
-    def testInstallments(self):
-        sysparam(self.store).update_parameter(u'ALLOW_OUTDATED_OPERATIONS', u'1')
+    def test_installments(self):
+        sysparam.set_bool(self.store, 'ALLOW_OUTDATED_OPERATIONS', True)
         wizard = PurchaseWizard(self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
@@ -54,20 +56,20 @@ class TestBillPaymentSlaves(GUITest):
         order.identifier = 12345
 
         slave = BillMethodSlave(wizard, None, self.store, order, method,
-                                Decimal(200), datetime.date(2012, 01, 01))
+                                Decimal(200), localdate(2012, 01, 01).date())
         self.check_slave(slave, 'slave-bill-method-1-installments')
 
         slave.installments_number.update(2)
         self.check_slave(slave, 'slave-bill-method-2-installments')
 
-    def testOutdated(self):
-        sysparam(self.store).update_parameter(u'ALLOW_OUTDATED_OPERATIONS', u'0')
+    def test_outdated(self):
+        sysparam.set_bool(self.store, 'ALLOW_OUTDATED_OPERATIONS', False)
         wizard = PurchaseWizard(self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'bill')
         order = self.create_purchase_order()
 
-        today = datetime.date.today()
+        today = localtoday().date()
         slave = BillMethodSlave(wizard, None, self.store, order, method,
                                 Decimal(200), today)
         self.assertValid(slave, ['first_duedate'])
@@ -77,7 +79,9 @@ class TestBillPaymentSlaves(GUITest):
 
 
 class TestCheckPaymentSlaves(GUITest):
-    def testCreate(self):
+    def test_create(self):
+        sysparam.set_bool(self.store, 'MANDATORY_CHECK_NUMBER', True)
+
         wizard = PurchaseWizard(self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'check')
@@ -87,30 +91,56 @@ class TestCheckPaymentSlaves(GUITest):
                                  Decimal(200))
         self.check_slave(slave, 'slave-check-method')
 
+    def test_check_payment_mandatory_check_number(self):
+        sysparam.set_bool(self.store, 'MANDATORY_CHECK_NUMBER', True)
+
+        wizard = PurchaseWizard(self.store)
+
+        method = PaymentMethod.get_by_name(self.store, u'check')
+        order = self.create_purchase_order()
+        order.identifier = 123456
+        CheckMethodSlave(wizard, None, self.store, order, method, Decimal(200))
+
+        self.assertNotSensitive(wizard, ['next_button'])
+
+    def test_check_payment(self):
+        sysparam.set_bool(self.store, 'MANDATORY_CHECK_NUMBER', False)
+
+        wizard = PurchaseWizard(self.store)
+
+        method = PaymentMethod.get_by_name(self.store, u'check')
+        order = self.create_purchase_order()
+        order.identifier = 1234567
+        CheckMethodSlave(wizard, None, self.store, order, method, Decimal(200))
+
+        self.assertSensitive(wizard, ['next_button'])
+
 
 class TestCardPaymentSlaves(GUITest):
-    def testCreate(self):
+    def test_create(self):
         wizard = PurchaseWizard(self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'card')
         order = self.create_purchase_order()
         slave = CardMethodSlave(wizard, None, self.store, order, method,
-                                 Decimal(200))
+                                Decimal(200))
         self.check_slave(slave, 'slave-card-method')
 
-    def testInstallments(self):
+    def test_installments(self):
         wizard = PurchaseWizard(self.store)
 
         method = PaymentMethod.get_by_name(self.store, u'card')
         order = self.create_purchase_order()
         slave = CardMethodSlave(wizard, None, self.store, order, method,
-                                 Decimal(200))
+                                Decimal(200))
 
         # Select a option for multiple installments
         for radio in slave.types_box.get_children():
             if radio.get_label() == 'Credit Card Installments Store':
+                radio.set_active(True)
                 break
-        radio.set_active(True)
+        else:
+            raise AssertionError
 
         self.check_slave(slave, 'slave-card-installments-store')
 
