@@ -28,11 +28,11 @@ import mock
 
 from stoqlib.domain.payment.card import CreditProvider
 from stoqlib.domain.sale import SaleView
-from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.dialogs.renegotiationdetails import RenegotiationDetailsDialog
+from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.editors.paymenteditor import LonelyPaymentDetailsDialog
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.search.paymentsearch import CardPaymentSearch
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.reporting.payment import CardPaymentReport
 
 
@@ -69,7 +69,7 @@ class TestPaymentSearch(GUITest):
                                        provider_id=u'VISANET')
         pay.identifier = 88888
 
-    def testCardPaymentSearch(self):
+    def test_card_payment_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -88,9 +88,9 @@ class TestPaymentSearch(GUITest):
         search.search.refresh()
         self.check_search(search, 'card-payment-provider-filter')
 
-    @mock.patch('stoqlib.gui.search.paymentsearch.print_report')
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
     @mock.patch('stoqlib.gui.search.paymentsearch.run_dialog')
-    def testButtons(self, run_dialog, print_report):
+    def test_buttons(self, run_dialog, print_report):
         self._create_domain()
         search = self._show_search()
 
@@ -121,5 +121,5 @@ class TestPaymentSearch(GUITest):
         self.assertSensitive(search._details_slave, ['print_button'])
         self.click(search._details_slave.print_button)
         print_report.assert_called_once_with(CardPaymentReport, search.results,
-                                    list(search.results),
-                                    filters=search.search.get_search_filters())
+                                             list(search.results),
+                                             filters=search.search.get_search_filters())
