@@ -22,19 +22,19 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.gui.uitestutils import GUITest
-from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.editors.paymentseditor import SalePaymentsEditor
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.lib.dateutils import localdate
+from stoqlib.lib.translation import stoqlib_gettext
 
+# FIXME: We should not translate anything on tests
 _ = stoqlib_gettext
 
 
 class TestPaymentEditor(GUITest):
     def _create_sale(self):
-        date = datetime.date(2001, 1, 1)
+        date = localdate(2001, 1, 1).date()
         sale = self.create_sale()
         sale.identifier = 9431
         sellable = self.create_sellable(price=10)
@@ -43,12 +43,12 @@ class TestPaymentEditor(GUITest):
 
         return sale
 
-    def testSaleEditorShow(self):
+    def test_sale_editor_show(self):
         sale = self._create_sale()
         editor = SalePaymentsEditor(self.store, sale)
         self.check_editor(editor, 'editor-payment-installments')
 
-    def testSaleEditorRemovePreviewPayment(self):
+    def test_sale_editor_remove_preview_payment(self):
         sale = self._create_sale()
         editor = SalePaymentsEditor(self.store, sale)
 
@@ -60,7 +60,7 @@ class TestPaymentEditor(GUITest):
         self.click(editor.slave.remove_button)
         self.assertEquals(len(editor.slave.payments), 0)
 
-    def testSaleEditorRemovePendingPayment(self):
+    def test_sale_editor_remove_pending_payment(self):
         sale = self._create_sale()
         editor = SalePaymentsEditor(self.store, sale)
 
