@@ -30,8 +30,8 @@ from stoqlib.gui.editors.personeditor import (BranchEditor, ClientEditor,
                                               TransporterEditor, UserEditor)
 from stoqlib.gui.search.callsearch import CallsSearch
 from stoqlib.gui.search.creditcheckhistorysearch import CreditCheckHistorySearch
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.wizards.personwizard import PersonRoleWizard
-from stoqlib.gui.uitestutils import GUITest
 
 
 class TestPersonRoleWizard(GUITest):
@@ -46,7 +46,7 @@ class TestPersonRoleWizard(GUITest):
             (person_slave.calls_button, CallsSearch),
             (person_slave.contact_info_button, ContactInfoListDialog),
             (person_slave.credit_check_history_button, CreditCheckHistorySearch),
-            ]
+        ]
 
         for button, dialog in buttons_dialogs:
             run_dialog.reset_mock()
@@ -79,20 +79,16 @@ class TestPersonRoleWizard(GUITest):
 
     def test_employee(self):
         employee = self.create_employee()
-        employee.person.phone_number = u'12345678'
+        employee.person.individual.cpf = u'954.181.357-75'
         employee.person.name = u'employee name'
 
         wizard = PersonRoleWizard(self.store, EmployeeEditor)
 
         step = wizard.get_current_step()
-        step.phone_number.update(employee.person.phone_number)
+        step.person_document.update(employee.person.individual.cpf)
         self.check_wizard(wizard, 'wizard-employee-person-role-type-step')
         self.click(wizard.next_button)
 
-        step = wizard.get_current_step()
-        self.check_wizard(wizard, 'wizard-employee-existing-person-step')
-        self.click(wizard.next_button)
-
         step = wizard.get_current_step()
         self.assertNotSensitive(wizard, ['next_button'])
 
