@@ -27,7 +27,7 @@ import mock
 import gtk
 
 from stoqlib.gui.dialogs.pluginsdialog import PluginManagerDialog
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestPluginManagerDialog(GUITest):
@@ -36,6 +36,16 @@ class TestPluginManagerDialog(GUITest):
         yesno.return_value = True
 
         dialog = PluginManagerDialog(self.store)
+        oficial_plugins = self.get_oficial_plugins_names()
+        # Only list the oficial plugins (the ones on this repository), since
+        # plugins on the same checkout dir will be identified too
+        # and listed here, making the test fail with a false positive
+        for item in dialog.klist[:]:
+            if item.name not in oficial_plugins:
+                dialog.klist.remove(item)
+
+        # Make sure all oficial plugins and only them are on the list
+        self.assertEqual(set(i.name for i in dialog.klist), oficial_plugins)
         dialog.klist.select(dialog.klist[0])
         self.check_dialog(dialog, 'dialog-plugin-manager-confirm')
 
