@@ -26,43 +26,42 @@ import mock
 
 from decimal import Decimal
 from stoqlib.database.runtime import get_current_branch
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.producteditor import (ProductEditor,
                                                ProductionProductEditor)
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.slaves.productslave import ProductComponentSlave
 from stoqlib.lib.parameters import sysparam
 
 
+# TODO: Test product editor for products without storable
 class TestProductEditor(GUITest):
     def tearDown(self):
-        sysparam(self.store).update_parameter(
-            u'COST_PRECISION_DIGITS', u'2')
+        sysparam.set_int(self.store, 'COST_PRECISION_DIGITS', 2)
         GUITest.tearDown(self)
 
-    def testCreate(self):
+    def test_create(self):
         editor = ProductEditor(self.store)
         editor.code.update("12345")
         self.check_editor(editor, 'editor-product-create')
 
-    def testShow(self):
-        product = self.create_product()
+    def test_show(self):
+        product = self.create_product(storable=True)
         editor = ProductEditor(self.store, product)
         editor.code.update("12345")
         self.check_editor(editor, 'editor-product-show')
 
-    def testVisualMode(self):
-        product = self.create_product()
+    def test_visual_mode(self):
+        product = self.create_product(storable=True)
         editor = ProductEditor(self.store, product, visual_mode=True)
         editor.code.update("12412")
         self.assertNotSensitive(editor, ['add_category', 'sale_price_button'])
         self.check_editor(editor, 'editor-product-visual-mode')
 
-    def testCostPrecisionDigits(self):
+    def test_cost_precision_digits(self):
         # Set a number of digts greated than 2
-        sysparam(self.store).update_parameter(
-            u'COST_PRECISION_DIGITS', u'5')
+        sysparam.set_int(self.store, 'COST_PRECISION_DIGITS', 5)
 
-        product = self.create_product()
+        product = self.create_product(storable=True)
         product.sellable.cost = Decimal('1.23456')
         editor = ProductEditor(self.store, product)
         editor.code.update("12345")
@@ -71,13 +70,13 @@ class TestProductEditor(GUITest):
 
 
 class TestProductProductionEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = ProductionProductEditor(self.store)
         editor.code.update("12345")
         self.check_editor(editor, 'editor-product-prod-create')
 
-    def testShow(self):
-        component = self.create_product_component()
+    def test_show(self):
+        component = self.create_product_component(storable=True)
         component.component.sellable.code = u'4567'
         editor = ProductionProductEditor(
             self.store, component.product)
@@ -85,7 +84,7 @@ class TestProductProductionEditor(GUITest):
         self.check_editor(editor, 'editor-product-prod-show')
 
     def test_confirm(self):
-        component = self.create_product_component()
+        component = self.create_product_component(storable=True)
         component.component.sellable.code = u'4567'
         component.product.sellable.code = u'6789'
         editor = ProductionProductEditor(self.store, component.product)
@@ -95,7 +94,7 @@ class TestProductProductionEditor(GUITest):
                           [editor.retval])
 
     @mock.patch('stoqlib.gui.slaves.productslave.run_dialog')
-    def testEditComponent(self, run_dialog):
+    def test_edit_component(self, run_dialog):
         run_dialog.return_value = None
         component = self.create_product_component()
         component.component.sellable.code = u'4567'
@@ -114,7 +113,7 @@ class TestProductProductionEditor(GUITest):
         self.check_editor(editor, 'editor-product-prod-edit')
 
     @mock.patch('stoqlib.gui.slaves.productslave.info')
-    def testEditComponentEditComposed(self, info):
+    def test_edit_component_edit_composed(self, info):
         component = self.create_product_component()
         component.component.sellable.code = u'4567'
         branch = get_current_branch(self.store)
@@ -133,7 +132,7 @@ class TestProductProductionEditor(GUITest):
 
 
 class TestProductComponentSlave(GUITest):
-    def testShow(self):
+    def test_show(self):
         component = self.create_product_component()
         slave = ProductComponentSlave(self.store, component.product)
         self.check_slave(slave, 'slave-production-component-show')
