@@ -23,13 +23,13 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.productioneditor import ProductionItemEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductionItemEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         production_item = self.create_production_item()
         editor = ProductionItemEditor(self.store, production_item)
-        editor.order_number.set_label("12345")
+        editor.identifier.set_label("12345")
         self.check_editor(editor, 'editor-productionitem-show')
