@@ -23,13 +23,13 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.productioneditor import ProductionItemProducedEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductionItemProducedEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         production_item = self.create_production_item()
         editor = ProductionItemProducedEditor(self.store, production_item)
-        editor.order_number.set_text("12345")
+        editor.identifier.set_text("12345")
         self.check_editor(editor, 'editor-productionitemproduced-show')
