@@ -23,13 +23,13 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.productioneditor import ProductionMaterialEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductionMaterialEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         material = self.create_production_material()
         editor = ProductionMaterialEditor(self.store, material)
-        editor.order_number.update("12345")
+        editor.identifier.update("12345")
         self.check_editor(editor, 'editor-productionmaterial-show')
