@@ -23,13 +23,13 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.producteditor import ProductionProductEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductionProductEditor(GUITest):
-    def testShow(self):
-        product = self.create_product()
+    def test_show(self):
+        product = self.create_product(storable=True)
         editor = ProductionProductEditor(self.store, product)
         editor.code.update("12345")
         self.check_editor(editor, 'editor-productionproduct-show')
