@@ -27,7 +27,7 @@ import mock
 
 from stoqlib.domain.production import ProductionMaterial, ProductionOrder
 from stoqlib.gui.dialogs.productionquotedialog import ProductionQuoteDialog
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -72,8 +72,8 @@ class TestProductionQuoteDialog(GUITest):
                 self.click(dialog.main_dialog.ok_button)
 
         info.assert_called_once_with(_(u'The quote group was succesfully '
-                                        'created and it is available '
-                                        'in the Purchase application.'))
+                                       'created and it is available '
+                                       'in the Purchase application.'))
 
         quotation = dialog.retval.get_items()[0]
         order = quotation.purchase
