@@ -25,8 +25,8 @@
 import datetime
 
 import mock
-from kiwi.ui.search import Any, DateSearchFilter
 
+from stoqlib.api import api
 from stoqlib.gui.search.productionsearch import (ProductionProductSearch,
                                                  ProductionItemsSearch,
                                                  ProductionHistorySearch)
@@ -34,12 +34,14 @@ from stoqlib.domain.person import Branch
 from stoqlib.domain.product import ProductStockItem, ProductHistory
 from stoqlib.domain.production import ProductionOrder
 from stoqlib.domain.sellable import Sellable
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.search.searchoptions import Any
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.reporting.production import ProductionItemReport
 
 
 class TestProductionProductSearch(GUITest):
-    def testSearch(self):
+    def test_search(self):
         branches = self.store.find(Branch)
 
         product = self.create_product()
@@ -50,7 +52,7 @@ class TestProductionProductSearch(GUITest):
                          store=self.store)
         product.sellable.code = u'65432'
         product.sellable.description = u'Camiseta'
-        product.sellable.status = Sellable.STATUS_AVAILABLE
+        product.is_composed = True
         self.create_product_component(product=product)
 
         product = self.create_product()
@@ -61,7 +63,7 @@ class TestProductionProductSearch(GUITest):
                          store=self.store)
         product.sellable.code = u'54321'
         product.sellable.description = u'Luva'
-        product.sellable.status = Sellable.STATUS_UNAVAILABLE
+        product.sellable.status = Sellable.STATUS_CLOSED
         self.create_product_component(product=product)
 
         search = ProductionProductSearch(self.store)
@@ -74,7 +76,7 @@ class TestProductionProductSearch(GUITest):
         self.check_search(search, 'production-product-string-filter')
 
         search.set_searchbar_search_string('')
-        search.branch_filter.set_state(2)
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
         search.search.refresh()
         self.check_search(search, 'production-product-branch-filter')
 
@@ -103,7 +105,7 @@ class TestProductionItemsSearch(GUITest):
         item.order.identifier = 45978
         item.product.sellable.description = u'Botas'
 
-    def testSearch(self):
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -118,8 +120,8 @@ class TestProductionItemsSearch(GUITest):
         search.search.refresh()
         self.check_search(search, 'production-items-status-filter')
 
-    @mock.patch('stoqlib.gui.search.productionsearch.print_report')
-    def testPrintButton(self, print_report):
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
         self._create_domain()
         search = self._show_search()
 
@@ -127,16 +129,15 @@ class TestProductionItemsSearch(GUITest):
 
         self.click(search._details_slave.print_button)
         args, kwargs = print_report.call_args
-        print_report.assert_called_once_with(ProductionItemReport,
-                      search.results,
-                      list(search.results),
-                      filters=search.search.get_search_filters())
+        print_report.assert_called_once_with(
+            ProductionItemReport, search.results, list(search.results),
+            filters=search.search.get_search_filters())
 
 
 class TestProductionHistorySearch(GUITest):
     def _show_search(self):
         search = ProductionHistorySearch(self.store)
-        search.branch_filter.set_state(1)
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
         search.date_filter.select(Any)
         search.search.refresh()
         search.results.select(search.results[0])
@@ -174,7 +175,7 @@ class TestProductionHistorySearch(GUITest):
                        production_date=datetime.date(2012, 4, 4),
                        store=self.store)
 
-    def testSearch(self):
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -196,8 +197,8 @@ class TestProductionHistorySearch(GUITest):
         search.search.refresh()
         self.check_search(search, 'production-history-date-day-filter')
 
-    @mock.patch('stoqlib.gui.search.productionsearch.print_report')
-    def testPrintButton(self, print_report):
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
         self._create_domain()
         search = self._show_search()
 
@@ -206,6 +207,6 @@ class TestProductionHistorySearch(GUITest):
 
         self.click(details_slave.print_button)
         print_report.assert_called_once_with(ProductionItemReport,
-                                    search.results,
-                                    list(search.results),
-                                    filters=search.search.get_search_filters())
+                                             search.results,
+                                             list(search.results),
+                                             filters=search.search.get_search_filters())
