@@ -23,13 +23,13 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.productioneditor import ProductionServiceEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductionServiceEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         service = self.create_production_service()
         editor = ProductionServiceEditor(self.store, service)
-        editor.order_number.set_label("12345")
+        editor.identifier.set_label("12345")
         self.check_editor(editor, 'editor-productionservice-show')
