@@ -23,16 +23,16 @@
 ##
 
 from stoqlib.domain.production import ProductionOrder
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.wizards.productionwizard import (OpenProductionOrderStep,
-                                              ProductionServiceStep,
-                                              ProductionItemStep,
-                                              FinishOpenProductionOrderStep,
-                                              ProductionWizard)
-from stoqlib.gui.uitestutils import GUITest
+                                                  ProductionServiceStep,
+                                                  ProductionItemStep,
+                                                  FinishOpenProductionOrderStep,
+                                                  ProductionWizard)
 
 
 class TestProductionWizard(GUITest):
-    def testProductionNoService(self):
+    def test_production_no_service(self):
         product_component = self.create_product_component()
         wizard = ProductionWizard(store=self.store)
 
@@ -40,7 +40,7 @@ class TestProductionWizard(GUITest):
         self.assertTrue(isinstance(step, OpenProductionOrderStep))
         self.assertNotSensitive(wizard, ['next_button'])
         step.description.update('Testing production wizard.')
-        step.order_number.update('9876')
+        step.identifier.update('9876')
         self.assertSensitive(wizard, ['next_button'])
         self.check_wizard(wizard, 'wizard-production-no-service-open-step')
         self.click(wizard.next_button)
@@ -80,7 +80,7 @@ class TestProductionWizard(GUITest):
                           self.store.find(ProductionOrder,
                                           id=wizard.model.id).one())
 
-    def testProductionWithService(self):
+    def test_production_with_service(self):
         service = self.create_service()
         product_component = self.create_product_component()
         wizard = ProductionWizard(store=self.store)
@@ -89,7 +89,7 @@ class TestProductionWizard(GUITest):
         self.assertTrue(isinstance(step, OpenProductionOrderStep))
         self.assertNotSensitive(wizard, ['next_button'])
         step.description.update('Testing production wizard.')
-        step.order_number.update('9876')
+        step.identifier.update('9876')
         self.assertSensitive(wizard, ['next_button'])
         self.check_wizard(wizard, 'wizard-production-with-service-open-step')
         self.click(wizard.next_button)
