@@ -23,11 +23,11 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.producteditor import ProductManufacturerEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductManufacturerEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = ProductManufacturerEditor(self.store)
         self.check_editor(editor, 'editor-productmanufacturer-create')
