@@ -25,32 +25,41 @@
 import datetime
 import mock
 
-from kiwi.ui.search import Any, DateSearchFilter
-
+from stoqlib.api import api
 from stoqlib.database.runtime import get_current_branch, get_current_user
 from stoqlib.domain.person import Branch
 from stoqlib.domain.product import (ProductHistory, Storable, Product,
-                                    ProductStockItem, ProductSupplierInfo)
+                                    ProductStockItem, ProductSupplierInfo,
+                                    StockTransactionHistory)
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sale import SaleItem
 from stoqlib.domain.sellable import Sellable
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.search.productsearch import (ProductSearch,
                                               ProductSearchQuantity,
                                               ProductsSoldSearch,
                                               ProductStockSearch,
                                               ProductClosedStockSearch,
-                                              format_data)
+                                              format_data, ProductBrandSearch)
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.search.searchoptions import Any
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.permissions import PermissionManager
 from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.product import (ProductReport, ProductPriceReport,
                                        ProductQuantityReport,
                                        ProductsSoldReport,
                                        ProductStockReport,
-                                       ProductClosedStockReport)
+                                       ProductClosedStockReport, ProductBrandReport)
 
 
 class TestProductSearch(GUITest):
+    def tearDown(self):
+        GUITest.tearDown(self)
+
+        # Reset the permitions so they wont influence other tests
+        pm = PermissionManager.get_permission_manager()
+        pm.set('Product', PermissionManager.PERM_ALL)
 
     def _show_search(self):
         search = ProductSearch(self.store)
@@ -58,12 +67,12 @@ class TestProductSearch(GUITest):
         search.results.select(search.results[0])
         return search
 
-    def testShow(self):
+    def test_show(self):
         search = self._show_search()
         self.check_search(search, 'product-show')
 
-    @mock.patch('stoqlib.gui.base.search.run_dialog')
-    def testShowWithPermission(self, run_dialog):
+    @mock.patch('stoqlib.gui.search.searcheditor.run_dialog')
+    def test_show_with_permission(self, run_dialog):
         search = self._show_search()
 
         self.assertVisible(search._toolbar, ['new_button'])
@@ -77,10 +86,11 @@ class TestProductSearch(GUITest):
         self.assertTrue('visual_mode' in kwargs)
         self.assertEquals(kwargs['visual_mode'], False)
 
-    @mock.patch('stoqlib.gui.base.search.run_dialog')
-    def testShowWithoutPermission(self, run_dialog):
+    @mock.patch('stoqlib.gui.search.searcheditor.run_dialog')
+    def test_show_without_permission(self, run_dialog):
         # Our only permission now is to see details
         pm = PermissionManager.get_permission_manager()
+        default_persmission = pm.get('Product')
         pm.set('Product', pm.PERM_ONLY_DETAILS)
         search = self._show_search()
 
@@ -97,46 +107,37 @@ class TestProductSearch(GUITest):
         self.assertTrue('visual_mode' in kwargs)
         self.assertEquals(kwargs['visual_mode'], True)
 
-    @mock.patch('stoqlib.gui.search.productsearch.print_report')
-    def testPrintButton(self, print_report):
+        # Retore the default permission so it doens't effect other tests
+        pm.set('Product', default_persmission)
+
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
         search = self._show_search()
 
         self.assertSensitive(search._details_slave, ['print_button'])
 
         self.click(search._details_slave.print_button)
         args, kwargs = print_report.call_args
-        print_report.assert_called_once_with(ProductReport, search.results,
-                      list(search.results),
-                      filters=search.search.get_search_filters())
+        print_report.assert_called_once_with(
+            ProductReport, search.results, list(search.results),
+            filters=search.search.get_search_filters())
 
     @mock.patch('stoqlib.gui.search.productsearch.print_report')
-    def testPrintPriceButton(self, print_report):
+    def test_print_price_button(self, print_report):
         search = self._show_search()
 
         self.assertSensitive(search._print_slave, ['print_price_button'])
 
         self.click(search._print_slave.print_price_button)
         args, kwargs = print_report.call_args
-        print_report.assert_called_once_with(ProductPriceReport,
-                      list(search.results),
-                      filters=search.search.get_search_filters(),
-                      branch_name=search.branch_filter.combo.get_active_text())
+        print_report.assert_called_once_with(
+            ProductPriceReport, list(search.results),
+            filters=search.search.get_search_filters(),
+            branch_name=search.branch_filter.combo.get_active_text())
 
-    @mock.patch('stoqlib.gui.search.productsearch.SpreadSheetExporter.export')
-    def testPrintExportCSVButton(self, export):
-        search = self._show_search()
-
-        self.assertSensitive(search, ['csv_button'])
-
-        self.click(search.csv_button)
-        args, kwargs = export.call_args
-        export.assert_called_once_with(object_list=search.results,
-                                       name=_('Product'),
-                                       filename_prefix=_('product'))
-
-    def testSearch(self):
-        self.clean_domain([ProductSupplierInfo, ProductStockItem, Storable,
-                           Product])
+    def test_search(self):
+        self.clean_domain([StockTransactionHistory, ProductSupplierInfo,
+                           ProductStockItem, Storable, Product])
 
         branches = self.store.find(Branch)
 
@@ -148,7 +149,6 @@ class TestProductSearch(GUITest):
                          store=self.store)
         product.sellable.code = u'1'
         product.sellable.description = u'Luvas'
-        product.sellable.status = Sellable.STATUS_AVAILABLE
 
         product = self.create_product()
         storable = self.create_storable(product=product)
@@ -158,7 +158,7 @@ class TestProductSearch(GUITest):
                          store=self.store)
         product.sellable.code = u'2'
         product.sellable.description = u'Botas'
-        product.sellable.status = Sellable.STATUS_UNAVAILABLE
+        product.sellable.status = Sellable.STATUS_CLOSED
 
         search = ProductSearch(self.store)
 
@@ -181,7 +181,6 @@ class TestProductSearch(GUITest):
 
 
 class TestProductSearchQuantity(GUITest):
-
     def _show_search(self):
         search = ProductSearchQuantity(self.store)
         search.search.refresh()
@@ -193,7 +192,7 @@ class TestProductSearchQuantity(GUITest):
 
         branch = get_current_branch(self.store)
         user = get_current_user(self.store)
-        self.today = datetime.date.today()
+        self.today = localtoday()
 
         product = self.create_product()
         Storable(store=self.store, product=product)
@@ -218,11 +217,13 @@ class TestProductSearchQuantity(GUITest):
         receiving.identifier = 222
         receiving.receival_date = self.today
         self.create_receiving_order_item(receiving, product.sellable, p_item, 8)
-        self.create_receiving_order_item(receiving, product2.sellable, p2_item, 12)
+        self.create_receiving_order_item(receiving, product2.sellable, p2_item,
+                                         12)
         receiving.confirm()
 
         # Sale
-        sale = self.create_sale(123, branch=branch)
+        sale = self.create_sale(branch=branch)
+        sale.identifier = 123
         sale.open_date = self.today
         sale.add_sellable(product.sellable, 3)
         sale.add_sellable(product2.sellable, 5)
@@ -230,7 +231,7 @@ class TestProductSearchQuantity(GUITest):
         self.add_payments(sale, date=self.today)
         sale.confirm()
 
-    def testSearch(self):
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -251,8 +252,8 @@ class TestProductSearchQuantity(GUITest):
         search.search.refresh()
         self.check_search(search, 'product-quantity-date-day-filter')
 
-    @mock.patch('stoqlib.gui.search.productsearch.print_report')
-    def testPrintButton(self, print_report):
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
         self._create_domain()
         search = self._show_search()
 
@@ -260,14 +261,12 @@ class TestProductSearchQuantity(GUITest):
 
         self.click(search._details_slave.print_button)
         args, kwargs = print_report.call_args
-        print_report.assert_called_once_with(ProductQuantityReport,
-                      search.results,
-                      list(search.results),
-                      filters=search.search.get_search_filters())
+        print_report.assert_called_once_with(
+            ProductQuantityReport, search.results, list(search.results),
+            filters=search.search.get_search_filters())
 
 
 class TestProductsSoldSearch(GUITest):
-
     def _show_search(self):
         search = ProductsSoldSearch(self.store)
         search.search.refresh()
@@ -278,13 +277,12 @@ class TestProductsSoldSearch(GUITest):
         self.clean_domain([SaleItem])
 
         branch = get_current_branch(self.store)
-        self.today = datetime.date.today()
+        self.today = localtoday()
 
         product = self.create_product()
         storable = Storable(store=self.store, product=product)
         ProductStockItem(storable=storable, branch=branch, quantity=5,
                          store=self.store)
-        product.sellable.status = Sellable.STATUS_AVAILABLE
         product.sellable.code = u'1'
         product.sellable.description = u'Luvas'
 
@@ -292,12 +290,12 @@ class TestProductsSoldSearch(GUITest):
         storable2 = Storable(store=self.store, product=product2)
         ProductStockItem(storable=storable2, branch=branch, quantity=5,
                          store=self.store)
-        product2.sellable.status = Sellable.STATUS_AVAILABLE
         product2.sellable.code = u'2'
         product2.sellable.description = u'Botas'
 
         # Sale
-        sale = self.create_sale(123, branch=branch)
+        sale = self.create_sale(branch=branch)
+        sale.identifier = 123
         sale.open_date = self.today
         sale.add_sellable(product.sellable, 3)
         sale.add_sellable(product2.sellable, 5)
@@ -305,7 +303,7 @@ class TestProductsSoldSearch(GUITest):
         self.add_payments(sale, date=self.today)
         sale.confirm()
 
-    def testSearch(self):
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -317,7 +315,7 @@ class TestProductsSoldSearch(GUITest):
         self.check_search(search, 'product-sold-string-filter')
 
         search.set_searchbar_search_string('')
-        search.branch_filter.set_state(2)
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
         search.search.refresh()
         self.check_search(search, 'product-sold-branch-filter')
 
@@ -333,8 +331,8 @@ class TestProductsSoldSearch(GUITest):
         search.search.refresh()
         self.check_search(search, 'product-sold-date-day-filter')
 
-    @mock.patch('stoqlib.gui.search.productsearch.print_report')
-    def testPrintButton(self, print_report):
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
         self._create_domain()
         search = self._show_search()
 
@@ -343,13 +341,12 @@ class TestProductsSoldSearch(GUITest):
         self.click(search._details_slave.print_button)
         args, kwargs = print_report.call_args
         print_report.assert_called_once_with(ProductsSoldReport,
-                      search.results,
-                      list(search.results),
-                      filters=search.search.get_search_filters())
+                                             search.results,
+                                             list(search.results),
+                                             filters=search.search.get_search_filters())
 
 
 class TestProductStockSearch(GUITest):
-
     def _show_search(self):
         search = ProductStockSearch(self.store)
         search.search.refresh()
@@ -357,12 +354,12 @@ class TestProductStockSearch(GUITest):
         return search
 
     def _create_domain(self):
-        self.clean_domain([ProductSupplierInfo, ProductStockItem, Storable,
-                           Product])
+        self.clean_domain([StockTransactionHistory, ProductSupplierInfo,
+                           ProductStockItem, Storable, Product])
 
         branch = get_current_branch(self.store)
         user = get_current_user(self.store)
-        self.today = datetime.date.today()
+        self.today = localtoday()
 
         product = self.create_product()
         Storable(store=self.store, product=product, minimum_quantity=3,
@@ -390,10 +387,11 @@ class TestProductStockSearch(GUITest):
         receiving.identifier = 222
         receiving.receival_date = self.today
         self.create_receiving_order_item(receiving, product.sellable, p_item, 8)
-        self.create_receiving_order_item(receiving, product2.sellable, p2_item, 12)
+        self.create_receiving_order_item(receiving, product2.sellable, p2_item,
+                                         12)
         receiving.confirm()
 
-    def testSearch(self):
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -405,12 +403,12 @@ class TestProductStockSearch(GUITest):
         self.check_search(search, 'product-stock-string-filter')
 
         search.set_searchbar_search_string('')
-        search.branch_filter.set_state(2)
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
         search.search.refresh()
         self.check_search(search, 'product-stock-branch-filter')
 
-    @mock.patch('stoqlib.gui.search.productsearch.print_report')
-    def testPrintButton(self, print_report):
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
         self._create_domain()
         search = self._show_search()
 
@@ -419,13 +417,69 @@ class TestProductStockSearch(GUITest):
         self.click(search._details_slave.print_button)
         args, kwargs = print_report.call_args
         print_report.assert_called_once_with(ProductStockReport,
-                      search.results,
-                      list(search.results),
-                      filters=search.search.get_search_filters())
+                                             search.results,
+                                             list(search.results),
+                                             filters=search.search.get_search_filters())
+
+
+class TestProductBrandSearch(GUITest):
+    def _show_search(self):
+        search = ProductBrandSearch(self.store)
+        search.search.refresh()
+        search.results.select(search.results[0])
+        return search
+
+    def _create_domain(self):
+        branch = get_current_branch(self.store)
+
+        product = self.create_product()
+        storable = Storable(store=self.store, product=product)
+        ProductStockItem(store=self.store, storable=storable,
+                         branch=branch, quantity=2)
+        product.brand = u''
+        product.sellable.code = u'1'
+        product.sellable.description = u'Luvas'
+
+        product2 = self.create_product()
+        storable2 = Storable(store=self.store, product=product2)
+        ProductStockItem(store=self.store, storable=storable2,
+                         branch=branch, quantity=4)
+        product2.brand = u'brand'
+        product.sellable.code = u'2'
+        product.sellable.description = u'Botas'
+
+    def test_search(self):
+        self._create_domain()
+        search = self._show_search()
+
+        search.branch_filter.set_state(None)
+        self.check_search(search, 'brand-no-filter')
+
+        search.set_searchbar_search_string('bran')
+        search.search.refresh()
+        self.check_search(search, 'brand-string-filter')
+
+        search.set_searchbar_search_string('')
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
+        search.search.refresh()
+        self.check_search(search, 'brand-branch-filter')
+
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
+        self._create_domain()
+        search = self._show_search()
+
+        self.assertSensitive(search._details_slave, ['print_button'])
+
+        self.click(search._details_slave.print_button)
+        args, kwargs = print_report.call_args
+        print_report.assert_called_once_with(ProductBrandReport,
+                                             search.results,
+                                             list(search.results),
+                                             filters=search.search.get_search_filters())
 
 
 class TestProductClosedStockSearch(GUITest):
-
     def _show_search(self):
         search = ProductClosedStockSearch(self.store)
         search.search.refresh()
@@ -453,7 +507,7 @@ class TestProductClosedStockSearch(GUITest):
         product.sellable.description = u'Botas'
         product.sellable.status = Sellable.STATUS_CLOSED
 
-    def testSearch(self):
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -465,12 +519,12 @@ class TestProductClosedStockSearch(GUITest):
         self.check_search(search, 'product-closed-stock-string-filter')
 
         search.set_searchbar_search_string('')
-        search.branch_filter.set_state(2)
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
         search.search.refresh()
         self.check_search(search, 'product-closed-stock-branch-filter')
 
-    @mock.patch('stoqlib.gui.search.productsearch.print_report')
-    def testPrintButton(self, print_report):
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_print_button(self, print_report):
         self._create_domain()
         search = self._show_search()
 
@@ -478,10 +532,10 @@ class TestProductClosedStockSearch(GUITest):
 
         self.click(search._details_slave.print_button)
         args, kwargs = print_report.call_args
-        print_report.assert_called_once_with(ProductClosedStockReport,
-                      search.results,
-                      filters=search.search.get_search_filters(),
-                      branch_name=search.branch_filter.combo.get_active_text())
+        print_report.assert_called_once_with(
+            ProductClosedStockReport,
+            search.results, list(search.results),
+            filters=search.search.get_search_filters())
 
 
 class TestFormatData(GUITest):
