@@ -27,20 +27,25 @@ import unittest
 
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.gui.dialogs.productstockdetails import ProductStockHistoryDialog
-from stoqlib.gui.uitestutils import GUITest
-from stoqlib.domain.product import Storable
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.database.runtime import get_current_branch, get_current_user
 
 
 class TestProductStockHistoryDialog(GUITest):
 
-    def testShow(self):
+    def test_show(self):
+        with self.sysparam(SYNCHRONIZED_MODE=True):
+            self._test_show()
+
+    def _test_show(self):
         date = datetime.date(2012, 1, 1)
         today = datetime.date.today()
         branch = get_current_branch(self.store)
         user = get_current_user(self.store)
-        product = self.create_product()
-        Storable(store=self.store, product=product)
+        storable = self.create_storable(is_batch=True)
+        product = storable.product
+        batch = self.create_storable_batch(storable)
+        batch.create_date = datetime.datetime(2013, 1, 27)
 
         # Purchase
         order = self.create_purchase_order(branch=branch)
@@ -56,12 +61,14 @@ class TestProductStockHistoryDialog(GUITest):
         receiving.receival_date = date
         r_item = self.create_receiving_order_item(receiving, product.sellable, p_item)
         r_item.quantity_received = 8
+        r_item.batch = batch
         receiving.confirm()
 
         # Sale
-        sale = self.create_sale(123, branch=branch)
+        sale = self.create_sale(branch=branch)
+        sale.identifier = 123
         sale.open_date = today
-        sale.add_sellable(product.sellable, 3)
+        sale.add_sellable(product.sellable, 3, batch=batch)
         sale.order()
         self.add_payments(sale, date=today)
         sale.confirm()
@@ -70,30 +77,33 @@ class TestProductStockHistoryDialog(GUITest):
         transfer = self.create_transfer_order(source_branch=branch)
         transfer.open_date = date
         transfer.identifier = 55
-        t_item = self.create_transfer_order_item(transfer, 2, product.sellable)
-        transfer.send_item(t_item)
-        transfer.receive(today)
+        self.create_transfer_order_item(transfer, 2, product.sellable,
+                                        batch=batch)
+        transfer.send()
+        transfer.receive(self.create_employee())
 
         # Transfer from another to branch
         transfer = self.create_transfer_order(source_branch=transfer.destination_branch,
-                                dest_branch=branch)
+                                              dest_branch=branch)
         transfer.open_date = date
         transfer.identifier = 66
-        t_item = self.create_transfer_order_item(transfer, 1, product.sellable)
-        transfer.send_item(t_item)
-        transfer.receive(today)
+        self.create_transfer_order_item(transfer, 1, product.sellable,
+                                        batch=batch)
+        transfer.send()
+        transfer.receive(self.create_employee())
 
         # Loan
-        # FIXME: See bug 5147
-        #loan = self.create_loan(branch)
-        #loan.add_sellable(product.sellable, 2)
-        #loan.sync_stock()
+        loan = self.create_loan(branch)
+        loan.identifier = 33
+        loan.open_date = date
+        loan.add_sellable(product.sellable, 2, batch=batch)
+        loan.sync_stock()
 
         # Stock Decrease
         decrease = self.create_stock_decrease(branch, user)
         decrease.identifier = 4
         decrease.confirm_date = date
-        decrease.add_sellable(product.sellable)
+        decrease.add_sellable(product.sellable, batch=batch)
         decrease.confirm()
 
         dialog = ProductStockHistoryDialog(self.store, product.sellable, branch)
