@@ -23,12 +23,12 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.producteditor import ProductStockEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductStockEditor(GUITest):
-    def testShow(self):
-        product = self.create_product()
+    def test_show(self):
+        product = self.create_product(storable=True)
         editor = ProductStockEditor(self.store, product)
         self.check_editor(editor, 'editor-productstock-show')
