@@ -23,13 +23,13 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.producteditor import ProductSupplierEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestProductSupplierEditor(GUITest):
-    def testShow(self):
-        product = self.create_product(create_supplier=True)
+    def test_show(self):
+        product = self.create_product(with_supplier=True)
         supplier_info = product.get_main_supplier_info()
         editor = ProductSupplierEditor(self.store, supplier_info)
         self.check_editor(editor, 'editor-productsupplier-show')
