@@ -21,19 +21,35 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
-
-import datetime
-
 from stoqlib.domain.product import Storable
-from stoqlib.gui.uitestutils import GUITest
-from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
+from stoqlib.domain.purchase import PurchaseOrder
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.gui.wizards.purchasewizard import PurchaseWizard, FinishPurchaseStep
+from stoqlib.lib.dateutils import localdate
 from stoqlib.lib.parameters import sysparam
 
 
+class TestFinishPurchaseStep(GUITest):
+    def test_post_init(self):
+        purchase_order = self.create_purchase_order()
+        receiving_order = self.create_receiving_order(
+            purchase_order=purchase_order)
+        self.create_receiving_order_item(
+            receiving_order=receiving_order)
+        wizard = PurchaseWizard(store=self.store)
+        finish_step = FinishPurchaseStep(model=wizard.model,
+                                         store=self.store,
+                                         wizard=wizard)
+        sellable = self.create_sellable()
+        purchase_item = purchase_order.add_item(sellable=sellable)
+        receiving_order.add_purchase_item(purchase_item)
+        finish_step.post_init()
+
+
 class TestPurchaseWizard(GUITest):
-    def _check_start_step(self, uitest='', order_number="12345"):
+    def _check_start_step(self, uitest='', identifier="12345"):
         start_step = self.wizard.get_current_step()
-        start_step.order_number.update("12345")
+        start_step.identifier.update(identifier)
         if uitest:
             self.check_wizard(self.wizard, uitest)
         self.click(self.wizard.next_button)
@@ -53,14 +69,17 @@ class TestPurchaseWizard(GUITest):
             self.check_wizard(self.wizard, uitest)
         self.click(self.wizard.next_button)
 
-    def testCreate(self):
+    def test_create(self):
         # Allow creating purchases in the past.
-        sysparam(self.store).update_parameter(
-            u"ALLOW_OUTDATED_OPERATIONS", u"1")
+        sysparam.set_bool(self.store, 'ALLOW_OUTDATED_OPERATIONS', True)
 
         self.wizard = PurchaseWizard(self.store)
+        purchase_branch = self.create_branch()
+        purchase_order = PurchaseOrder(branch=purchase_branch)
+        sellable = self.create_sellable()
+        purchase_order.add_item(sellable=sellable)
         self.wizard.model.identifier = 12345
-        self.wizard.model.open_date = datetime.date(2010, 1, 3)
+        self.wizard.model.open_date = localdate(2010, 1, 3).date()
         self._check_start_step('wizard-purchase-start-step')
         self._check_item_step('wizard-purchase-item-step')
         self._check_payment_step('wizard-purchase-payment-step')
@@ -76,21 +95,23 @@ class TestPurchaseWizard(GUITest):
 
         self.click(self.wizard.next_button)
 
-    def testCreateAndReceive(self):
+    def test_create_and_receive(self):
         self.wizard = PurchaseWizard(self.store)
         self.wizard.model.identifier = 12345
-        self.wizard.model.open_date = datetime.date(2010, 1, 3)
+        self.wizard.model.open_date = localdate(2010, 1, 3).date()
         self._check_start_step()
         self._check_item_step()
         self._check_payment_step()
 
         finish_step = self.wizard.get_current_step()
         finish_step.receive_now.set_active(True)
+        self.wizard.model.expected_receival_date = localdate(2010, 1, 4).date()
 
+        self.wizard.enable_next()
         self.click(self.wizard.next_button)
 
         receiving_step = self.wizard.get_current_step()
-        receiving_step.invoice_slave.order_number.update("12345")
+        receiving_step.invoice_slave.identifier.set_text("12345")
         receiving_step.invoice_slave.invoice_number.update(67890)
 
         self.check_wizard(self.wizard, 'wizard-purchase-invoice-step')
@@ -107,7 +128,28 @@ class TestPurchaseWizard(GUITest):
         models.append(receive)
         models.extend(receive.get_items())
         for item in receive.get_items():
-            models.extend(list(item.sellable.product_storable.get_stock_items()))
+            models.extend(
+                list(item.sellable.product_storable.get_stock_items()))
 
         self.check_wizard(self.wizard, 'wizard-purchase-done-received',
                           models=models)
+
+    def test_no_receive_now_for_batch_items(self):
+        sellable = self.create_sellable()
+        product = self.create_product()
+        storable = self.create_storable(is_batch=True)
+        storable.product = product
+        sellable.product = product
+
+        wizard = PurchaseWizard(self.store)
+        self.click(wizard.next_button)
+
+        step = wizard.get_current_step()
+        step.sellable_selected(sellable)
+        self.click(step.add_sellable_button)
+        self.click(wizard.next_button)
+
+        self.click(wizard.next_button)
+
+        step = wizard.get_current_step()
+        self.assertNotVisible(step, ['receive_now'])
