@@ -22,22 +22,22 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
 import unittest
 
 import mock
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.domain.purchase import PurchaseOrder
-from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.labeldialog import SkipLabelsEditor
+from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.lib.dateutils import localdate
 from stoqlib.reporting.purchase import PurchaseOrderReport, PurchaseQuoteReport
 
 
 class TestPurchaseDetailsDialog(GUITest):
 
-    def testShow(self):
-        date = datetime.date(2012, 1, 1)
+    def test_show(self):
+        date = localdate(2012, 1, 1).date()
         supplier = self.create_supplier()
 
         # New purchase
@@ -58,7 +58,7 @@ class TestPurchaseDetailsDialog(GUITest):
         self.check_editor(dialog, 'dialog-purchase-details')
 
     @mock.patch('stoqlib.gui.dialogs.purchasedetails.SpreadSheetExporter.export')
-    def testExportSpreadSheet(self, export):
+    def test_export_spread_sheet(self, export):
         order = self.create_purchase_order()
         dialog = PurchaseDetailsDialog(self.store, order)
 
@@ -66,7 +66,7 @@ class TestPurchaseDetailsDialog(GUITest):
         self.assertEquals(export.call_count, 1)
 
     @mock.patch('stoqlib.gui.dialogs.purchasedetails.print_report')
-    def testPrintDetails(self, print_report):
+    def test_print_details(self, print_report):
         order = self.create_purchase_order()
         dialog = PurchaseDetailsDialog(self.store, order)
         self.assertSensitive(dialog, ['print_button'])
@@ -81,7 +81,7 @@ class TestPurchaseDetailsDialog(GUITest):
         self.click(dialog.print_button)
         print_report.assert_called_once_with(PurchaseOrderReport, order)
 
-    @mock.patch('stoqlib.gui.printing.warning')
+    @mock.patch('stoqlib.gui.utils.printing.warning')
     @mock.patch('stoqlib.gui.dialogs.purchasedetails.run_dialog')
     def test_print_labels(self, run_dialog, warning):
         order = self.create_purchase_order()
