@@ -23,13 +23,21 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.purchaseeditor import PurchaseItemEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestPurchaseItemEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         item = self.create_purchase_order_item()
         editor = PurchaseItemEditor(self.store, item)
         editor.order.set_label("12345")
+
+        # quantity=8, price=125
+        self.assertEqual(editor.total.read(), 1000)
+        editor.quantity.update(10)
+        self.assertEqual(editor.total.read(), 1250)
+        editor.cost.update(150)
+        self.assertEqual(editor.total.read(), 1500)
+
         self.check_editor(editor, 'editor-purchaseitem-show')
