@@ -23,12 +23,12 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.purchaseeditor import PurchaseQuoteItemEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestPurchaseQuoteItemEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         item = self.create_purchase_order_item()
         editor = PurchaseQuoteItemEditor(self.store, item)
         editor.order.set_label("12345")
