@@ -22,18 +22,17 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 import mock
 import gtk
 
 from stoqlib.domain.base import Domain
 from stoqlib.domain.product import Storable
 from stoqlib.gui.base.lists import SimpleListDialog
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
 from stoqlib.gui.wizards.purchasequotewizard import (QuotePurchaseWizard,
                                                      ReceiveQuoteWizard)
+from stoqlib.lib.dateutils import localdate, localdatetime
 from stoqlib.lib.parameters import sysparam
 from stoqlib.reporting.purchase import PurchaseQuoteReport
 
@@ -41,7 +40,7 @@ from stoqlib.reporting.purchase import PurchaseQuoteReport
 class TestQuotePurchaseeWizard(GUITest):
     def _check_start_step(self, uitest=''):
         start_step = self.wizard.get_current_step()
-        start_step.quote_deadline.update(datetime.datetime(2020, 1, 1))
+        start_step.quote_deadline.update(localdatetime(2020, 1, 1))
         start_step.quote_group.set_text("12345")
         if uitest:
             self.check_wizard(self.wizard, uitest)
@@ -64,14 +63,14 @@ class TestQuotePurchaseeWizard(GUITest):
 
     @mock.patch('stoqlib.database.runtime.StoqlibStore.commit')
     @mock.patch('stoqlib.domain.purchase.PurchaseOrder.delete')
-    def testCreate(self, delete, commit):
+    def test_create(self, delete, commit):
         # Allow creating purchases in the past.
-        sysparam(self.store).update_parameter(u"ALLOW_OUTDATED_OPERATIONS", u"1")
+        sysparam.set_bool(self.store, 'ALLOW_OUTDATED_OPERATIONS', True)
 
         self.wizard = QuotePurchaseWizard(self.store)
         self.wizard.model.branch = self.create_branch()
         self.wizard.model.identifier = 12345
-        self.wizard.model.open_date = datetime.date(2010, 1, 3)
+        self.wizard.model.open_date = localdate(2010, 1, 3).date()
         self._check_start_step('wizard-purchasequote-start-step')
         self._check_item_step('wizard-purchasequote-item-step')
 
@@ -118,9 +117,9 @@ class TestReceiveQuoteWizard(GUITest):
 
     @mock.patch('stoqlib.gui.wizards.purchasequotewizard.run_dialog')
     @mock.patch('stoqlib.gui.wizards.purchasequotewizard.yesno')
-    def testCreate(self, yesno, run_dialog):
+    def test_create(self, yesno, run_dialog):
         # Allow creating purchases in the past.
-        sysparam(self.store).update_parameter(u"ALLOW_OUTDATED_OPERATIONS", u"1")
+        sysparam.set_bool(self.store, 'ALLOW_OUTDATED_OPERATIONS', True)
 
         quotation = self.create_quotation()
         quotation.identifier = 12345
@@ -132,7 +131,7 @@ class TestReceiveQuoteWizard(GUITest):
 
         purchase = self.purchase = quotation.purchase
         purchase.clone = _purchase_clone
-        purchase.open_date = datetime.date(2012, 1, 1)
+        purchase.open_date = localdate(2012, 1, 1).date()
         self.create_purchase_order_item(purchase)
 
         self.wizard = ReceiveQuoteWizard(self.store)
