@@ -24,16 +24,17 @@
 
 import datetime
 
+from stoqlib.api import api
 from stoqlib.domain.person import Branch
 from stoqlib.domain.product import ProductStockItem
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.gui.search.purchasesearch import PurchasedItemsSearch
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
-class TestPurchaseSearch(GUITest):
-    def testPurchasedItemsSearch(self):
-        branch = self.store.find(Branch, id=1).one()
+class TestPurchasedItemsSearch(GUITest):
+    def test_search(self):
+        branch = api.get_current_branch(self.store)
         order = self.create_purchase_order(branch=branch)
         item = self.create_purchase_order_item(order=order)
         item.sellable.description = u'Camisa listrada'
@@ -47,7 +48,7 @@ class TestPurchaseSearch(GUITest):
                          storable=storable,
                          store=self.store)
 
-        branch = self.store.find(Branch, id=2).one()
+        branch = self.store.find(Branch, Branch.id != branch.id).any()
         order = self.create_purchase_order(branch=branch)
         item = self.create_purchase_order_item(order=order)
         item.sellable.description = u'Camisa bordada'
@@ -65,13 +66,13 @@ class TestPurchaseSearch(GUITest):
 
         search.search.refresh()
         search.branch_filter.set_state(None)
-        self.check_search(search, 'purchase-no-filter')
+        self.check_search(search, 'purchased-items-no-filter')
 
         search.set_searchbar_search_string('bor')
         search.search.refresh()
-        self.check_search(search, 'purchase-string-filter')
+        self.check_search(search, 'purchased-items-string-filter')
 
         search.set_searchbar_search_string('')
-        search.branch_filter.set_state(1)
+        search.branch_filter.set_state(api.get_current_branch(self.store).id)
         search.search.refresh()
-        self.check_search(search, 'purchase-branch-filter')
+        self.check_search(search, 'purchased-items-branch-filter')
