@@ -23,11 +23,11 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.producteditor import QualityTestEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestQualityTestEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = QualityTestEditor(self.store)
         self.check_editor(editor, 'editor-qualitytest-create')
