@@ -22,20 +22,20 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 import mock
 
-from stoqlib.domain.receiving import ReceivingOrder, ReceivingOrderItem
+from stoqlib.domain.receiving import (ReceivingOrder, ReceivingOrderItem,
+                                      PurchaseReceivingMap)
 from stoqlib.gui.dialogs.receivingdialog import ReceivingOrderDetailsDialog
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.search.receivingsearch import PurchaseReceivingSearch
 from stoqlib.reporting.purchasereceival import PurchaseReceivalReport
+from stoqlib.lib.dateutils import localdatetime
 
 
 class TestReceivingOrderSearch(GUITest):
     def _create_domain(self):
-        self.clean_domain([ReceivingOrderItem, ReceivingOrder])
+        self.clean_domain([ReceivingOrderItem, PurchaseReceivingMap, ReceivingOrder])
 
         supplier_a = self.create_supplier(u'Mark')
         purchase_order_a = self.create_purchase_order(supplier=supplier_a)
@@ -45,11 +45,11 @@ class TestReceivingOrderSearch(GUITest):
         purchase_order_b = self.create_purchase_order(supplier=supplier_b)
         order_b = self.create_receiving_order(purchase_order=purchase_order_b)
 
-        order_a.purchase.identifier = 81954
-        order_a.receival_date = datetime.datetime(2012, 1, 1)
+        purchase_order_a.identifier = 81954
+        order_a.receival_date = localdatetime(2012, 1, 1)
 
-        order_b.purchase.identifier = 78526
-        order_b.receival_date = datetime.datetime(2012, 2, 2)
+        purchase_order_b.identifier = 78526
+        order_b.receival_date = localdatetime(2012, 2, 2)
 
     def _show_search(self):
         search = PurchaseReceivingSearch(self.store)
@@ -57,7 +57,7 @@ class TestReceivingOrderSearch(GUITest):
         search.results.select(search.results[0])
         return search
 
-    def testReceivingOrderSearch(self):
+    def test_receiving_order_search(self):
         self._create_domain()
         search = self._show_search()
 
@@ -68,17 +68,17 @@ class TestReceivingOrderSearch(GUITest):
         self.check_search(search, 'receiving-string-filter')
 
     @mock.patch('stoqlib.gui.search.receivingsearch.run_dialog')
-    @mock.patch('stoqlib.gui.search.receivingsearch.print_report')
-    def testButtons(self, print_report, run_dialog):
+    @mock.patch('stoqlib.gui.search.searchdialog.print_report')
+    def test_buttons(self, print_report, run_dialog):
         self._create_domain()
         search = self._show_search()
 
         self.assertSensitive(search._details_slave, ['print_button'])
         self.click(search._details_slave.print_button)
         print_report.assert_called_once_with(PurchaseReceivalReport,
-                                    search.results,
-                                    list(search.results),
-                                    filters=search.search.get_search_filters())
+                                             search.results,
+                                             list(search.results),
+                                             filters=search.search.get_search_filters())
 
         search.search.refresh()
         self.assertNotSensitive(search._details_slave, ['details_button'])
