@@ -27,9 +27,9 @@ from decimal import Decimal
 
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.sale import Sale
-from stoqlib.gui.wizards.salewizard import PaymentMethodStep
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.wizards.renegotiationwizard import PaymentRenegotiationWizard
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.wizards.salewizard import PaymentMethodStep
 
 
 class TestPaymentRenegotiationWizard(GUITest):
@@ -63,7 +63,8 @@ class TestPaymentRenegotiationWizard(GUITest):
         wizard = PaymentRenegotiationWizard(self.store, [group])
 
         step = wizard.get_current_step()
-        step.pm_slave.select_method('store_credit')
+        widget = step.pm_slave._widgets['store_credit']
+        widget.set_active(True)
         self.check_wizard(wizard,
                           'wizard-renegotiation-store-credit-payment-list-step')
 
