@@ -23,16 +23,18 @@
 ##
 
 from decimal import Decimal
-import datetime
 import unittest
 
 import mock
-from stoqlib.gui.uitestutils import GUITest
 
 from stoqlib.database.runtime import StoqlibStore, get_current_branch
-from stoqlib.domain.sale import SaleView
-from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
+from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.sale import SaleView, SaleComment
 from stoqlib.gui.dialogs.clientdetails import ClientDetailsDialog
+from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
+from stoqlib.gui.editors.noteeditor import NoteEditor
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.lib.dateutils import localdate
 from stoqlib.reporting.boleto import BillReport
 from stoqlib.reporting.booklet import BookletReport
 from stoqlib.reporting.sale import SaleOrderReport
@@ -41,7 +43,7 @@ from stoqlib.reporting.sale import SaleOrderReport
 class TestSaleDetails(GUITest):
 
     def _create_sale(self):
-        today = datetime.date(2010, 12, 1)
+        today = localdate(2010, 12, 1)
         client = self.create_client()
 
         # new sale
@@ -58,7 +60,6 @@ class TestSaleDetails(GUITest):
         # Service
         item = self.create_sale_item(sale, product=False)
         item.estimated_fix_date = today
-        item.sellable.can_sell()
 
         # Payments
         payment = self.add_payments(sale, date=today)[0]
@@ -67,38 +68,47 @@ class TestSaleDetails(GUITest):
 
         sale.order()
         sale.confirm()
-        sale.set_paid()
+        sale.group.pay()
 
         payment.paid_date = today
 
         return sale
 
-    def testShow(self):
+    def test_show(self):
         sale = self._create_sale()
         # SaleDetailsDialog needs a SaleView model
         model = self.store.find(SaleView, id=sale.id).one()
         dialog = SaleDetailsDialog(self.store, model)
         self.check_editor(dialog, 'dialog-sale-details')
 
-    def testShowWithReturns(self):
-        date = datetime.date(2010, 12, 10)
+    @mock.patch('stoqlib.gui.dialogs.saledetails.print_report')
+    def test_show_with_returns_and_comments(self, print_report):
+        date = localdate(2010, 12, 10).date()
 
         sale = self._create_sale()
         returned_sale = sale.create_sale_return_adapter()
         returned_sale.return_()
         returned_sale.return_date = date
+
         # payments[0] is the sale's payment created on self._create_sale
-        returned_payment = returned_sale.group.payments[1]
+        returned_payment = returned_sale.group.payments.find(
+            Payment.identifier != 999).one()
         returned_payment.identifier = 666
         returned_payment.due_date = date
         returned_payment.paid_date = date
 
+        comment = self.create_sale_comment(sale)
+        comment.date = date
+
         model = self.store.find(SaleView, id=sale.id).one()
+
         dialog = SaleDetailsDialog(self.store, model)
+        self.click(dialog.print_return_report)
+
         self.check_editor(dialog, 'dialog-sale-details-with-returns')
 
     @mock.patch('stoqlib.gui.dialogs.saledetails.run_dialog')
-    def testClientDetails(self, run_dialog):
+    def test_client_details(self, run_dialog):
         sale = self.create_sale()
         sale.client = self.create_client()
         self.create_sale_item(sale, product=True)
@@ -116,7 +126,7 @@ class TestSaleDetails(GUITest):
 
     @mock.patch('stoqlib.gui.dialogs.saledetails.BillReport.check_printable')
     @mock.patch('stoqlib.gui.dialogs.saledetails.print_report')
-    def testPrintBill(self, print_report, check_printable):
+    def test_print_bill(self, print_report, check_printable):
         sale = self.create_sale()
         sale.client = self.create_client()
         self.create_sale_item(sale, product=True)
@@ -134,7 +144,7 @@ class TestSaleDetails(GUITest):
         print_report.assert_called_once_with(BillReport, [payment])
 
     @mock.patch('stoqlib.gui.dialogs.saledetails.print_report')
-    def testPrintBooklet(self, print_report):
+    def test_print_booklet(self, print_report):
         sale = self.create_sale()
         sale.client = self.create_client()
         self.create_sale_item(sale, product=True)
@@ -149,7 +159,7 @@ class TestSaleDetails(GUITest):
         print_report.assert_called_once_with(BookletReport, [payment])
 
     @mock.patch('stoqlib.gui.dialogs.saledetails.print_report')
-    def testPrintDetails(self, print_report):
+    def test_print_details(self, print_report):
         sale = self.create_sale()
         sale.client = self.create_client()
         self.create_sale_item(sale, product=True)
@@ -161,6 +171,31 @@ class TestSaleDetails(GUITest):
         self.click(dialog.print_button)
         print_report.assert_called_once_with(SaleOrderReport, sale)
 
+    @mock.patch('stoqlib.gui.dialogs.saledetails.api.new_store')
+    @mock.patch('stoqlib.gui.dialogs.saledetails.run_dialog')
+    def test_add_note(self, run_dialog, new_store):
+        new_store.return_value = self.store
+        run_dialog.return_value = False
+
+        sale = self.create_sale()
+        sale.client = self.create_client()
+        self.create_sale_item(sale, product=True)
+        model = self.store.find(SaleView, id=sale.id).one()
+
+        dialog = SaleDetailsDialog(self.store, model)
+        with mock.patch.object(self.store, 'commit'):
+            with mock.patch.object(self.store, 'close'):
+                self.click(dialog.comment_add)
+
+        args, kwargs = run_dialog.call_args
+        editor, parent, store, model, prop_name = args
+        self.assertEquals(editor, NoteEditor)
+        self.assertEquals(parent, dialog)
+        self.assertTrue(isinstance(model, SaleComment))
+        self.assertTrue(isinstance(store, StoqlibStore))
+        self.assertEquals(prop_name, 'comment')
+        self.assertEquals(kwargs['title'], 'New Sale Comment')
+
 
 if __name__ == '__main__':
     from stoqlib.api import api
