@@ -23,12 +23,12 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.dialogs.invoicedialog import SaleInvoicePrinterDialog
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSaleInvoicePrinterDialog(GUITest):
-    def testShow(self):
+    def test_show(self):
         sale = self.create_sale()
         printer = self.create_invoice_printer()
         editor = SaleInvoicePrinterDialog(self.store, sale, printer)
