@@ -23,12 +23,13 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.paymentseditor import SalePaymentsEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSalePaymentsEditor(GUITest):
-    def testShow(self):
-        sale = self.create_sale()
+    def test_show(self):
+        client = self.create_client()
+        sale = self.create_sale(client=client)
         editor = SalePaymentsEditor(self.store, sale)
         self.check_editor(editor, 'editor-salepayments-show')
