@@ -22,18 +22,17 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 import mock
 
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.wizards.salereturnwizard import (SaleReturnWizard,
                                                   SaleTradeWizard)
+from stoqlib.lib.dateutils import localdate
 from stoqlib.lib.parameters import sysparam
 
 
 class TestSaleReturnWizard(GUITest):
-    def testCreate(self):
+    def test_create(self):
         sale = self.create_sale()
         self.add_product(sale)
         self.add_product(sale, quantity=2)
@@ -48,10 +47,10 @@ class TestSaleReturnWizard(GUITest):
             self.assertEqual(item.quantity, item.max_quantity)
 
     @mock.patch('stoqlib.gui.wizards.salereturnwizard.info')
-    def testSaleReturnItemsStep(self, info):
+    def test_sale_return_items_step(self, info):
         sale = self.create_sale()
-        self.add_product(sale)
-        self.add_product(sale, quantity=2)
+        self.add_product(sale, code=u'1234')
+        self.add_product(sale, quantity=2, code=u'5678')
         self.add_payments(sale)
         sale.order()
         sale.confirm()
@@ -101,7 +100,7 @@ class TestSaleReturnWizard(GUITest):
             self.assertNotSensitive(wizard, ['next_button'])
             _reset_objectlist(objectlist)
 
-    def testSaleReturnInvoiceStep(self):
+    def test_sale_return_invoice_step(self):
         sale = self.create_sale()
         self.add_product(sale)
         self.add_product(sale, quantity=2)
@@ -121,12 +120,12 @@ class TestSaleReturnWizard(GUITest):
             "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed\n"
             "do eiusmod tempor incididunt ut labore et dolore magna aliqua.")
         self.assertValid(step, ['reason'])
-        self.assertNotSensitive(wizard, ['next_button'])
 
-        self.assertInvalid(step, ['invoice_number'])
+        # XXX: changed because invoice_number is no longer mandatory
+        self.assertSensitive(wizard, ['next_button'])
+
         step.invoice_number.update(0)
         self.assertInvalid(step, ['invoice_number'])
-        self.assertNotSensitive(wizard, ['next_button'])
         step.invoice_number.update(1000000000)
         self.assertInvalid(step, ['invoice_number'])
         self.assertNotSensitive(wizard, ['next_button'])
@@ -143,11 +142,12 @@ class TestSaleReturnWizard(GUITest):
         self.assertSensitive(wizard, ['next_button'])
 
     @mock.patch('stoqlib.gui.wizards.salereturnwizard.info')
-    def testSaleReturnPaymentStepNotPaid(self, info):
-        sale = self.create_sale(id_=1234)
+    def test_sale_return_payment_step_not_paid(self, info):
+        sale = self.create_sale()
+        sale.identifier = 1234
         self.add_product(sale, price=50, quantity=6)
         self.add_payments(sale, method_type=u'check', installments=3,
-                          date=datetime.date(2012, 1, 1))
+                          date=localdate(2012, 1, 1).date())
         sale.order()
         sale.confirm()
         returned_sale = sale.create_sale_return_adapter()
@@ -172,11 +172,12 @@ class TestSaleReturnWizard(GUITest):
                           'wizard-sale-return-payment-step-not-paid')
 
     @mock.patch('stoqlib.gui.wizards.salereturnwizard.info')
-    def testSaleReturnPaymentStepPartiallyPaid(self, info):
-        sale = self.create_sale(id_=1234)
+    def test_sale_return_payment_step_partially_paid(self, info):
+        sale = self.create_sale()
+        sale.identifier = 1234
         self.add_product(sale, price=50, quantity=6)
         payments = self.add_payments(sale, method_type=u'check', installments=3,
-                                     date=datetime.date(2012, 1, 1))
+                                     date=localdate(2012, 1, 1).date())
         sale.order()
         sale.confirm()
         payments[0].pay()
@@ -202,7 +203,7 @@ class TestSaleReturnWizard(GUITest):
                           'wizard-sale-return-payment-step-partially-paid')
 
     @mock.patch('stoqlib.gui.wizards.salereturnwizard.info')
-    def testFinishWithGroupCancelling(self, info):
+    def test_finish_with_group_cancelling(self, info):
         sale = self.create_sale()
         self.add_product(sale)
         payment, = self.add_payments(sale)
@@ -218,14 +219,15 @@ class TestSaleReturnWizard(GUITest):
         with mock.patch(module) as emit:
             # Cancel the payment, so returned_sale.total_amount will be 0
             payment.cancel()
-            self.click(wizard.next_button)
+            with mock.patch.object(self.store, 'commit'):
+                self.click(wizard.next_button)
             info.assert_called_once_with(
                 "The client does not have a debt to this sale anymore. "
                 "Any existing unpaid installment will be cancelled.")
             emit.assert_called_once_with(returned_sale)
 
     @mock.patch('stoqlib.gui.wizards.salereturnwizard.info')
-    def testFinishWithReversalPayment(self, info):
+    def test_finish_with_reversal_payment(self, info):
         sale = self.create_sale()
         self.add_product(sale)
         payment, = self.add_payments(sale)
@@ -239,7 +241,8 @@ class TestSaleReturnWizard(GUITest):
 
         module = 'stoqlib.gui.events.SaleReturnWizardFinishEvent.emit'
         with mock.patch(module) as emit:
-            self.click(wizard.next_button)
+            with mock.patch.object(self.store, 'commit'):
+                self.click(wizard.next_button)
             info.assert_called_once_with(
                 "A reversal payment to the client will be created. "
                 "You can see it on the Payable Application.")
@@ -247,10 +250,10 @@ class TestSaleReturnWizard(GUITest):
 
 
 class TestSaleTradeWizard(GUITest):
-    def testCreate(self):
+    def test_create(self):
         SaleTradeWizard(self.store)
 
-    def testSaleSelectionStepKnownSale(self):
+    def test_sale_selection_step_known_sale(self):
         wizard = SaleTradeWizard(self.store)
         step = wizard.get_current_step()
         results = step.slave.results
@@ -286,9 +289,8 @@ class TestSaleTradeWizard(GUITest):
             self.click(wizard.next_button)
             emit.assert_called_once_with(wizard.model)
 
-    def testSaleSelectionStepUnknownSale(self):
-        sysparam(self.store).update_parameter(
-            u'ALLOW_TRADE_NOT_REGISTERED_SALES', u'True')
+    def test_sale_selection_step_unknown_sale(self):
+        sysparam.set_bool(self.store, 'ALLOW_TRADE_NOT_REGISTERED_SALES', True)
         wizard = SaleTradeWizard(self.store)
         step = wizard.get_current_step()
         results = step.slave.results
