@@ -22,23 +22,23 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
-from kiwi.ui.search import DateSearchFilter
-
+from stoqlib.api import api
+from stoqlib.lib.dateutils import localdate
+from stoqlib.gui.search.searchfilters import DateSearchFilter
 from stoqlib.gui.search.salespersonsearch import SalesPersonSalesSearch
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSalesPersonSalesSearch(GUITest):
-    def testShow(self):
+
+    def test_show(self):
         # 5 items in sale for first salesperson
         sale1 = self.create_sale()
         self.add_product(sale1, quantity=5)
         sale1.order()
         self.add_payments(sale1, method_type=u'check')
         sale1.confirm()
-        sale1.confirm_date = datetime.date(2011, 01, 01)
+        sale1.confirm_date = localdate(2011, 01, 01).date()
         sale1.salesperson.person.name = u'salesperson1'
 
         # 3 items in sale for first salesperson
@@ -62,5 +62,36 @@ class TestSalesPersonSalesSearch(GUITest):
         dialog = SalesPersonSalesSearch(self.store)
         dialog.date_filter.select(DateSearchFilter.Type.USER_DAY)
         dialog.date_filter.start_date.update(sale1.confirm_date)
-        self.click(dialog.search.search.search_button)
+        self.click(dialog.search.search_button)
         self.check_dialog(dialog, 'sales-person-sales-show')
+
+    def test_synchronized_mode(self):
+        # This is a non editable parameter
+        with self.sysparam(SYNCHRONIZED_MODE=True):
+            current = api.get_current_branch(self.store)
+            other_branch = self.create_branch()
+
+            # One sale on one branch
+            sale1 = self.create_sale(branch=current)
+            self.add_product(sale1)
+            sale1.order()
+            self.add_payments(sale1, method_type=u'check')
+            sale1.confirm()
+            sale1.confirm_date = localdate(2011, 01, 01).date()
+            sale1.salesperson.person.name = u'salesperson1'
+
+            # And another one on a second branch
+            sale2 = self.create_sale(branch=other_branch)
+            sale2.salesperson = sale1.salesperson
+            self.add_product(sale2)
+            sale2.order()
+            self.add_payments(sale2, method_type=u'money')
+            sale2.confirm()
+            sale2.confirm_date = sale1.confirm_date
+
+            dialog = SalesPersonSalesSearch(self.store)
+            dialog.date_filter.select(DateSearchFilter.Type.USER_INTERVAL)
+            dialog.date_filter.start_date.update(sale1.confirm_date)
+            dialog.date_filter.end_date.update(sale1.confirm_date)
+            self.click(dialog.search.search_button)
+            self.check_dialog(dialog, 'sales-person-sales-synchronized-show')
