@@ -24,12 +24,12 @@
 
 from decimal import Decimal
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.sellableeditor import SellableTaxConstantEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSellableTaxConstantEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = SellableTaxConstantEditor(self.store)
         self.check_editor(editor, 'editor-sellabletaxconstant-create')
 
