@@ -23,11 +23,11 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.sellableuniteditor import SellableUnitEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSellableUnitEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = SellableUnitEditor(self.store)
         self.check_editor(editor, 'editor-sellableunit-create')
