@@ -23,11 +23,11 @@
 ##
 
 from stoqlib.gui.search.sellableunitsearch import SellableUnitSearch
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSellableUnitSearchSearch(GUITest):
-    def testSearch(self):
+    def test_search(self):
         search = SellableUnitSearch(self.store)
 
         search.search.refresh()
