@@ -22,11 +22,11 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.shortcutseditor import ShortcutsEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestShortcutsEditor(GUITest):
-    def testShow(self):
+    def test_show(self):
         editor = ShortcutsEditor()
         self.check_dialog(editor, 'dialog-shortcuts-show')
