@@ -29,21 +29,23 @@ import gtk
 
 from stoqlib.api import api
 from stoqlib.domain.system import SystemTable
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.dialogs.sintegradialog import SintegraDialog
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
 
 class TestSintegraDialog(GUITest):
-    @mock.patch('stoqlib.gui.dialogs.sintegradialog.datetime',
-                GUITest.fake.datetime)
+    @mock.patch('stoqlib.gui.dialogs.sintegradialog.localtoday')
     @mock.patch('stoqlib.gui.dialogs.sintegradialog.StoqlibSintegraGenerator')
     @mock.patch('stoqlib.gui.dialogs.sintegradialog.save')
-    def test_confirm(self, save, generator):
+    def test_confirm(self, save, generator, localtoday):
         save.return_value = True
 
+        value = datetime.datetime(2012, 1, 31)
+        localtoday.return_value = value
+
         # we need to create a system table because it is used by the sintegra
         # dialog to populate the date filter
         SystemTable(updated=datetime.datetime(2012, 1, 1),
