@@ -23,11 +23,11 @@
 ##
 
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.stationeditor import StationEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestStationEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = StationEditor(self.store)
         self.check_editor(editor, 'editor-station-create')
