@@ -26,11 +26,11 @@ import mock
 
 from stoqlib.api import api
 from stoqlib.domain.costcenter import CostCenterEntry
-from stoqlib.lib.parameters import sysparam
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.domain.stockdecrease import StockDecrease
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.gui.wizards.salewizard import PaymentMethodStep
 from stoqlib.gui.wizards.stockdecreasewizard import StockDecreaseWizard
-from stoqlib.domain.stockdecrease import StockDecrease
+from stoqlib.lib.parameters import sysparam
 
 
 class TestStockDecreaseWizard(GUITest):
@@ -61,7 +61,8 @@ class TestStockDecreaseWizard(GUITest):
         self.assertSensitive(wizard, ['next_button'])
         module = 'stoqlib.gui.events.StockDecreaseWizardFinishEvent.emit'
         with mock.patch(module) as emit:
-            self.click(wizard.next_button)
+            with mock.patch.object(self.store, 'commit'):
+                self.click(wizard.next_button)
             self.assertEquals(emit.call_count, 1)
             args, kwargs = emit.call_args
             self.assertTrue(isinstance(args[0], StockDecrease))
@@ -75,9 +76,7 @@ class TestStockDecreaseWizard(GUITest):
     def test_wizard_create_payment(self, yesno):
         yesno.return_value = False
 
-        sysparam(self.store).update_parameter(
-            u'CREATE_PAYMENTS_ON_STOCK_DECREASE',
-            u'True')
+        sysparam.set_bool(self.store, 'CREATE_PAYMENTS_ON_STOCK_DECREASE', True)
 
         till = self.create_till()
         till.open_till()
@@ -107,6 +106,7 @@ class TestStockDecreaseWizard(GUITest):
 
     @mock.patch('stoqlib.gui.wizards.stockdecreasewizard.yesno')
     def test_wizard_with_cost_center(self, yesno):
+        sysparam.set_bool(self.store, 'CREATE_PAYMENTS_ON_STOCK_DECREASE', True)
         yesno.return_value = False
 
         branch = api.get_current_branch(self.store)
@@ -132,7 +132,8 @@ class TestStockDecreaseWizard(GUITest):
         step.sellable_selected(sellable)
         step.quantity.update(1)
         self.click(step.add_sellable_button)
-        self.click(wizard.next_button)
+        with mock.patch.object(self.store, 'commit'):
+            self.click(wizard.next_button)
 
         self.assertEquals(wizard.model.cost_center, cost_center)
         entry = self.store.find(CostCenterEntry,
