@@ -30,12 +30,12 @@ from stoqlib.database.runtime import StoqlibStore
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.gui.dialogs.supplierdetails import SupplierDetailsDialog
 from stoqlib.gui.editors.personeditor import SupplierEditor
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSupplierDetails(GUITest):
 
-    def testShow(self):
+    def test_show(self):
         date = datetime.date(2012, 1, 1)
         supplier = self.create_supplier()
 
@@ -58,7 +58,7 @@ class TestSupplierDetails(GUITest):
         self.check_editor(dialog, 'dialog-supplier-details')
 
     @mock.patch('stoqlib.gui.dialogs.supplierdetails.run_person_role_dialog')
-    def testFurtherDetails(self, run_dialog):
+    def test_further_details(self, run_dialog):
         supplier = self.create_supplier()
 
         dialog = SupplierDetailsDialog(self.store, supplier)
