@@ -24,8 +24,8 @@
 
 
 from stoqlib.domain.parameter import ParameterData
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.parameterseditor import SystemParameterEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestSystemParameterEditor(GUITest):
@@ -34,7 +34,7 @@ class TestSystemParameterEditor(GUITest):
         editor = SystemParameterEditor(self.store, parameter_data)
         self.check_editor(editor, 'editor-systemparameter-show')
 
-    def testConfirm(self):
+    def test_confirm(self):
         parameter_data = self.create_parameter_data()
         editor = SystemParameterEditor(self.store, parameter_data)
 
@@ -42,7 +42,7 @@ class TestSystemParameterEditor(GUITest):
         self.assertFalse(editor.validate_confirm())
         self.assertFalse(editor.confirm())
 
-        editor.model.field_value = u'25'
+        editor.model.field_value = self.create_account().id
         self.assertTrue(editor.confirm())
         self.check_editor(editor, 'editor-systemparameter-confirm',
                           [editor.retval])
