@@ -24,11 +24,11 @@
 
 from stoqlib.domain.taxes import ProductTaxTemplate
 from stoqlib.gui.search.taxclasssearch import TaxTemplatesSearch
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestTaxClassSearch(GUITest):
-    def testSearch(self):
+    def test_search(self):
         ProductTaxTemplate(name=u'Test ICMS Tax Template',
                            tax_type=ProductTaxTemplate.TYPE_ICMS,
                            store=self.store)
