@@ -23,14 +23,13 @@
 ##
 
 from decimal import Decimal
-import datetime
-
-from kiwi.ui.search import DateSearchFilter
 
 from stoqlib.api import api
 from stoqlib.domain.till import Till, TillEntry
+from stoqlib.lib.dateutils import localdate
 from stoqlib.gui.dialogs.tillhistory import TillHistoryDialog
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestTillHistory(GUITest):
@@ -41,7 +40,7 @@ class TestTillHistory(GUITest):
     def test_date_search(self):
         entry = TillEntry(identifier=1234,
                           description=u'desc',
-                          date=datetime.date(2011, 01, 01),
+                          date=localdate(2011, 01, 01).date(),
                           value=Decimal(123.0),
                           till=self.store.find(Till)[0],
                           payment=None,
@@ -51,5 +50,5 @@ class TestTillHistory(GUITest):
         dialog = TillHistoryDialog(self.store)
         dialog.date_filter.select(DateSearchFilter.Type.USER_DAY)
         dialog.date_filter.start_date.update(entry.date)
-        self.click(dialog.search.search.search_button)
+        self.click(dialog.search.search_button)
         self.check_dialog(dialog, 'till-history-dialog-custom-day')
