@@ -21,16 +21,16 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import datetime
-
 import mock
 
-from kiwi.ui.search import DateSearchFilter
-
+from stoqlib.api import api
+from stoqlib.domain.person import Branch
 from stoqlib.domain.transfer import TransferOrder, TransferOrderItem
+from stoqlib.lib.dateutils import localdate, localdatetime
 from stoqlib.gui.dialogs.transferorderdialog import TransferOrderDetailsDialog
+from stoqlib.gui.search.searchfilters import DateSearchFilter
 from stoqlib.gui.search.transfersearch import TransferOrderSearch
-from stoqlib.gui.uitestutils import GUITest
+from stoqlib.gui.test.uitestutils import GUITest
 from stoqlib.reporting.transferreceipt import TransferOrderReceipt
 
 
@@ -43,27 +43,66 @@ class TestTransferOrderSearch(GUITest):
 
     def _create_domain(self):
         self.clean_domain([TransferOrderItem, TransferOrder])
+        responsible = self.create_employee()
 
-        source_branch = self.create_branch(u'Riachuelo')
-        dest_branch = self.create_branch(u'Marisa')
-        order = self.create_transfer_order(source_branch=source_branch,
-                                           dest_branch=dest_branch)
+        other_branch = Branch.get_active_remote_branches(self.store)[0]
+        current_branch = api.get_current_branch(self.store)
+
+        # One transfer that we did not receive yet
+        order = self.create_transfer_order(source_branch=other_branch,
+                                           dest_branch=current_branch)
         self.create_transfer_order_item(order=order)
         order.identifier = 75168
-        order.open_date = datetime.datetime(2012, 1, 1)
+        order.open_date = localdatetime(2012, 1, 1)
+        order.send()
 
-        source_branch = self.create_branch(u'Opera Rock')
-        dest_branch = self.create_branch(u'Cavalera')
-        order = self.create_transfer_order(source_branch=source_branch,
-                                           dest_branch=dest_branch)
+        # One that we have already received
+        order = self.create_transfer_order(source_branch=other_branch,
+                                           dest_branch=current_branch)
         self.create_transfer_order_item(order=order)
         order.identifier = 56832
-        order.open_date = datetime.datetime(2012, 2, 2)
+        order.open_date = localdatetime(2012, 2, 2)
+        order.send()
+        order.receive(responsible)
+        order.receival_date = localdatetime(2012, 2, 2)
 
-    def testSearch(self):
+        # One that we have sent but is not received yet
+        order = self.create_transfer_order(source_branch=current_branch,
+                                           dest_branch=other_branch)
+        self.create_transfer_order_item(order=order)
+        order.identifier = 20486
+        order.open_date = localdatetime(2012, 3, 3)
+        order.send()
+
+        # And another one that we have sent and is recived
+        order = self.create_transfer_order(source_branch=current_branch,
+                                           dest_branch=other_branch)
+        self.create_transfer_order_item(order=order)
+        order.identifier = 20489
+        order.open_date = localdatetime(2012, 3, 4)
+        order.send()
+
+        order.receive(responsible)
+        order.receival_date = localdatetime(2012, 3, 5)
+
+    def test_search(self):
         self._create_domain()
         search = self._show_search()
 
+        # Pending searches
+        search.status_filter.select('pending')
+        self.check_search(search, 'transfer-pending')
+
+        # Sent transfers
+        search.status_filter.select('sent')
+        self.check_search(search, 'transfer-sent')
+
+        # Received transfers
+        search.status_filter.select('received')
+        self.check_search(search, 'transfer-received')
+
+        # Show all transfers
+        search.status_filter.select(None)
         self.check_search(search, 'transfer-no-filter')
 
         search.set_searchbar_search_string('mar')
@@ -72,19 +111,20 @@ class TestTransferOrderSearch(GUITest):
 
         search.set_searchbar_search_string('')
         search.date_filter.select(DateSearchFilter.Type.USER_DAY)
-        search.date_filter.start_date.update(datetime.date(2012, 1, 1))
+        search.date_filter.start_date.update(localdate(2012, 1, 1).date())
         search.search.refresh()
         self.check_search(search, 'transfer-date-day-filter')
 
         search.date_filter.select(DateSearchFilter.Type.USER_INTERVAL)
-        search.date_filter.start_date.update(datetime.date(2012, 1, 10))
-        search.date_filter.end_date.update(datetime.date(2012, 2, 20))
+        search.date_filter.start_date.update(localdate(2012, 1, 10).date())
+        search.date_filter.end_date.update(localdate(2012, 2, 20).date())
         search.search.refresh()
+        search.status_filter.select(None)
         self.check_search(search, 'transfer-date-interval-filter')
 
     @mock.patch('stoqlib.gui.search.transfersearch.print_report')
     @mock.patch('stoqlib.gui.search.transfersearch.run_dialog')
-    def testButtons(self, run_dialog, print_report):
+    def test_buttons(self, run_dialog, print_report):
         self._create_domain()
         search = self._show_search()
 
