@@ -22,11 +22,16 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from stoqlib.gui.uitestutils import GUITest
 from stoqlib.gui.editors.profileeditor import UserProfileEditor
+from stoqlib.gui.test.uitestutils import GUITest
 
 
 class TestUserProfileEditor(GUITest):
-    def testCreate(self):
+    def test_create(self):
         editor = UserProfileEditor(self.store)
         self.check_editor(editor, 'editor-userprofile-create')
+
+    def test_with_max_discount(self):
+        profile = self.create_user_profile(max_discount=10)
+        editor = UserProfileEditor(self.store, model=profile)
+        self.check_editor(editor, 'editor-userprofile-with-max-discount')
