@@ -25,8 +25,10 @@
 import mock
 
 from stoqlib.database.viewable import Viewable
-from stoqlib.gui.uitestutils import GUITest
-from stoqlib.gui.wizards.abstractwizard import AdvancedSellableSearch
+from stoqlib.gui.test.uitestutils import GUITest
+from stoqlib.gui.search.sellablesearch import (SellableSearch,
+                                               PurchaseSellableSearch)
+from stoqlib.gui.wizards.loanwizard import (NewLoanWizard, LoanItemStep)
 from stoqlib.gui.wizards.productionwizard import (ProductionWizard, ProductionItemStep,
                                                   ProductionServiceStep)
 from stoqlib.gui.wizards.purchasequotewizard import (QuotePurchaseWizard,
@@ -36,24 +38,20 @@ from stoqlib.gui.wizards.purchasewizard import (PurchaseWizard,
 from stoqlib.gui.wizards.salequotewizard import (SaleQuoteWizard,
                                                  SaleQuoteItemStep)
 from stoqlib.gui.wizards.stockdecreasewizard import (StockDecreaseWizard,
-                                                 DecreaseItemStep)
+                                                     DecreaseItemStep)
 from stoqlib.gui.wizards.stocktransferwizard import (StockTransferWizard,
                                                      StockTransferItemStep)
-from stoqlib.lib.permissions import PermissionManager
 
 
 class BaseTest(object):
     wizard_class = None
     step_class = None
     search_name = None
+    search_class = SellableSearch
 
     def setUp(self):
         super(BaseTest, self).setUp()
 
-        # The final interface depends on this
-        pm = PermissionManager.get_permission_manager()
-        pm.set('Product', PermissionManager.PERM_ALL)
-
         self.wizard = self.wizard_class(self.store)
         self.step = self.step_class(self.wizard, None, self.store, self.wizard.model)
 
@@ -66,8 +64,8 @@ class BaseTest(object):
     def test_sellable_search(self):
         viewable, query = self.step.get_sellable_view_query()
         hide_toolbar = not self.step.sellable_editable
-        search = AdvancedSellableSearch(self.store, viewable, query=query,
-                                        hide_toolbar=hide_toolbar)
+        search = self.search_class(self.store, search_spec=viewable,
+                                   search_query=query, hide_toolbar=hide_toolbar)
         search.search.refresh()
         self.check_search(search, self.search_name)
 
@@ -99,12 +97,14 @@ class TestProductionItemStep(BaseTest, GUITest):
 class TestQuoteItemStep(BaseTest, GUITest):
     wizard_class = QuotePurchaseWizard
     step_class = QuoteItemStep
+    search_class = PurchaseSellableSearch
     search_name = 'item-step-quote-wizard'
 
 
 class TestPurchaseItemStep(BaseTest, GUITest):
     wizard_class = PurchaseWizard
     step_class = PurchaseItemStep
+    search_class = PurchaseSellableSearch
     search_name = 'item-step-purchase-wizard'
 
 
@@ -124,3 +124,9 @@ class TestStockTransferItemStep(BaseTest, GUITest):
     wizard_class = StockTransferWizard
     step_class = StockTransferItemStep
     search_name = 'item-step-stock-transfer-wizard'
+
+
+class TestLoanItemStep(BaseTest, GUITest):
+    wizard_class = NewLoanWizard
+    step_class = LoanItemStep
+    search_name = 'item-step-new-loan-wizard'
