@@ -28,17 +28,16 @@ from decimal import Decimal
 
 from kiwi.currency import currency
 from kiwi.python import Settable
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.product import StockTransactionHistory
 from stoqlib.domain.purchase import PurchaseOrderView, PurchaseOrder
-from stoqlib.domain.receiving import (ReceivingOrder,
-                                      get_receiving_items_by_purchase_order)
+from stoqlib.domain.receiving import ReceivingOrder
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.wizards import BaseWizard, BaseWizardStep
 from stoqlib.gui.editors.purchaseeditor import InConsignmentItemEditor
+from stoqlib.gui.search.searchcolumns import IdentifierColumn
 from stoqlib.gui.slaves.paymentslave import (register_payment_slaves,
                                              MultipleMethodSlave)
 from stoqlib.gui.wizards.purchasewizard import (StartPurchaseStep,
@@ -71,15 +70,16 @@ class ConsignmentItemStep(PurchaseItemStep):
 
         receiving_model = ReceivingOrder(
             responsible=api.get_current_user(self.store),
-            purchase=self.model,
             supplier=self.model.supplier,
             branch=self.model.branch,
             transporter=self.model.transporter,
             invoice_number=None,
             store=self.store)
+        receiving_model.add_purchase(self.model)
 
         # Creates ReceivingOrderItem's
-        get_receiving_items_by_purchase_order(self.model, receiving_model)
+        for item in self.model.get_pending_items():
+            receiving_model.add_purchase_item(item)
 
         self.wizard.receiving_model = receiving_model
 
@@ -99,7 +99,8 @@ class ConsignmentSelectionStep(PurchaseSelectionStep):
 
     def next_step(self):
         self.search.save_columns()
-        selected = self.search.results.get_selected()
+        # FIXME: Precisa desabilitar se tem mais de um selecionado.
+        selected = self.search.result_view.get_selected_rows()[0]
         consignment = selected.purchase
         self.wizard.purchase_model = consignment
 
@@ -129,29 +130,19 @@ class ConsignmentItemSelectionStep(BaseWizardStep):
             self.consignment_items.update(item)
             self._validate_step(True)
 
-    def _return_single_item(self, item, quantity):
-        storable = item.sellable.product_storable
-        assert storable
-
-        branch = self.consignment.branch
-        storable.decrease_stock(quantity=quantity, branch=branch,
-                                type=StockTransactionHistory.TYPE_CONSIGNMENT_RETURNED,
-                                object_id=item.id)
-
     def get_saved_items(self):
         # we keep a copy of the important data to calculate values when we
         # finish this step
         for item in self.consignment.get_items():
             self._original_items[item.id] = Settable(item_id=item.id,
-                                             sold=item.quantity_sold,
-                                             returned=item.quantity_returned)
+                                                     sold=item.quantity_sold,
+                                                     returned=item.quantity_returned)
             # self.store.fetch: used to bring the objet to this store.
             yield self.store.fetch(item)
 
     def get_columns(self):
         return [
-            Column('order.identifier', title=_('Order'), width=60, data_type=int,
-                   sorted=True),
+            IdentifierColumn('order.identifier', title=_('Order #'), sorted=True),
             Column('sellable.code', title=_('Code'), width=70, data_type=str),
             Column('sellable.description', title=_('Description'),
                    data_type=str, expand=True, searchable=True),
@@ -164,7 +155,7 @@ class ConsignmentItemSelectionStep(BaseWizardStep):
             Column('cost', title=_('Cost'), data_type=currency,
                    format_func=get_formatted_cost),
             Column('total_sold', title=_('Total Sold'), data_type=currency),
-            ]
+        ]
 
     #
     # WizardStep
@@ -189,14 +180,15 @@ class ConsignmentItemSelectionStep(BaseWizardStep):
             to_return = final.quantity_returned - initial.returned
 
             if to_return > 0:
-                self._return_single_item(final, to_return)
+                final.return_consignment(to_return)
             if to_sold > 0:
                 total_charged = final.cost * to_sold
 
         if total_charged == 0:
+            #FIXME Gramatical error
             info(_(u'No payments was generated.'),
                  _(u'The changes performed does not require payment creation, '
-                    'so this wizard will be finished.'))
+                   'so this wizard will be finished.'))
             self.wizard.finish()
 
         # total_charged plus what was previously charged
@@ -297,7 +289,7 @@ class CloseInConsignmentWizard(BaseWizard):
     def finish(self):
         purchase = self.store.fetch(self.purchase_model)
         can_close = all([i.quantity_received == i.quantity_sold +
-                                                i.quantity_returned
+                         i.quantity_returned
                          for i in purchase.get_items()])
         for payment in purchase.group.payments:
             if payment.is_preview():
