@@ -26,38 +26,44 @@
 
 from decimal import Decimal
 import datetime
-import sys
 
 import gtk
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
 from kiwi.ui.widgets.entry import ProxyEntry
-from kiwi.ui.objectlist import Column, SearchColumn
+from kiwi.ui.objectlist import Column
+from storm.expr import And, Or, Eq
 
 from stoqlib.api import api
-from stoqlib.database.queryexecuter import StoqlibQueryExecuter
 from stoqlib.domain.person import (Client, LoginUser,
                                    ClientCategory)
 from stoqlib.domain.loan import Loan, LoanItem
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.sale import Sale
-from stoqlib.domain.views import LoanView, ProductFullStockItemView
+from stoqlib.domain.sellable import Sellable
+from stoqlib.domain.views import LoanView, ProductWithStockBranchView
+from stoqlib.lib.dateutils import localtoday
+from stoqlib.lib.defaults import MAX_INT
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.message import info, yesno
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.base.wizards import (WizardEditorStep, BaseWizard,
                                       BaseWizardStep)
+from stoqlib.gui.dialogs.batchselectiondialog import BatchDecreaseSelectionDialog
 from stoqlib.gui.dialogs.clientdetails import ClientDetailsDialog
+from stoqlib.gui.dialogs.missingitemsdialog import (get_missing_items,
+                                                    MissingItemsDialog)
 from stoqlib.gui.events import (NewLoanWizardFinishEvent,
                                 CloseLoanWizardFinishEvent,
                                 LoanItemSelectionStepEvent)
+from stoqlib.gui.editors.loanitemeditor import LoanItemEditor
 from stoqlib.gui.editors.noteeditor import NoteEditor
 from stoqlib.gui.editors.personeditor import ClientEditor
-from stoqlib.gui.editors.loaneditor import LoanItemEditor
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.search.searchcolumns import IdentifierColumn, SearchColumn
+from stoqlib.gui.search.searchslave import SearchSlave
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.gui.wizards.abstractwizard import SellableItemStep
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.gui.wizards.salequotewizard import SaleQuoteItemStep
@@ -79,8 +85,8 @@ class StartNewLoanStep(WizardEditorStep):
 
     def _setup_widgets(self):
         # Hide total and subtotal
-        self.table1.hide()
-        self.hbox4.hide()
+        self.summary_table.hide()
+        self.total_box.hide()
 
         # Hide invoice number details
         self.invoice_number_label.hide()
@@ -119,16 +125,12 @@ class StartNewLoanStep(WizardEditorStep):
         self.removed_by.show()
         self._replace_widget(self.transporter, self.removed_by)
 
-        # Operation Nature widget
-        self.operation_nature.hide()
-        self.nature_lbl.hide()
-
     def _fill_clients_combo(self):
         # FIXME: This should not be using a normal ProxyComboEntry,
         #        we need a specialized widget that does the searching
         #        on demand.
-        clients = Client.get_active_clients(self.store)
-        self.client.prefill(api.for_person_combo(clients))
+        items = Client.get_active_items(self.store)
+        self.client.prefill(items)
         self.client.mandatory = True
 
     def _fill_clients_category_combo(self):
@@ -144,8 +146,10 @@ class StartNewLoanStep(WizardEditorStep):
         right = parent.child_get_property(old_widget, 'right-attach')
         parent.remove(old_widget)
         parent.attach(new_widget, left, right, top, bottom)
-        parent.child_set_property(new_widget, 'y-padding', 3)
-        parent.child_set_property(new_widget, 'x-padding', 3)
+
+    def _get_client(self):
+        client_id = self.client.read()
+        return self.store.get(Client, client_id)
 
     #
     # WizardStep hooks
@@ -179,26 +183,25 @@ class StartNewLoanStep(WizardEditorStep):
         store = api.new_store()
         client = run_person_role_dialog(ClientEditor, self.wizard, store, None)
         retval = store.confirm(client)
-        client = self.store.fetch(client)
         store.close()
         if not retval:
             return
         self._fill_clients_combo()
-        self.client.select(client)
+        self.client.select(client.id)
 
     def on_client__changed(self, widget):
         self.toogle_client_details()
-        client = self.client.get_selected()
+        client = self._get_client()
         if not client:
             return
         self.client_category.select(client.category)
 
     def on_expire_date__validate(self, widget, value):
-        if value < datetime.date.today():
+        if value < localtoday().date():
             msg = _(u"The expire date must be set to today or a future date.")
             return ValidationError(msg)
 
-    def on_notes_button__clicked(self, *args):
+    def on_observations_button__clicked(self, *args):
         run_dialog(NoteEditor, self.wizard, self.store, self.model, 'notes',
                    title=_("Additional Information"))
 
@@ -211,25 +214,25 @@ class LoanItemStep(SaleQuoteItemStep):
     """ Wizard step for loan items selection """
     model_type = Loan
     item_table = LoanItem
-    sellable_view = ProductFullStockItemView
+    sellable_view = ProductWithStockBranchView
     item_editor = LoanItemEditor
+    validate_stock = True
+    batch_selection_dialog = BatchDecreaseSelectionDialog
 
-    def _has_stock(self, sellable, quantity):
-        storable = sellable.product_storable
-        if storable is not None:
-            balance = storable.get_balance_for_branch(self.model.branch)
-        else:
-            balance = Decimal(0)
-        return balance >= quantity
+    def get_sellable_view_query(self):
+        branch = self.model.branch
+        # Also include products that are not storable
+        branch_query = Or(self.sellable_view.branch_id == branch.id,
+                          Eq(self.sellable_view.branch_id, None))
 
-    def on_quantity__validate(self, widget, value):
-        if value <= 0:
-            return ValidationError(_(u'Quantity should be positive.'))
+        # The stock quantity of consigned products can not be
+        # decreased manually. See bug 5212.
+        query = And(branch_query,
+                    Sellable.get_available_sellables_query(self.store))
+        return self.sellable_view, query
 
-        sellable = self.proxy.model.sellable
-        if not self._has_stock(sellable, value):
-            return ValidationError(
-                _(u'The quantity is greater than the quantity in stock.'))
+    def has_next_step(self):
+        return False
 
 
 class LoanSelectionStep(BaseWizardStep):
@@ -240,11 +243,10 @@ class LoanSelectionStep(BaseWizardStep):
         self.setup_slaves()
 
     def _create_filters(self):
-        self.search.set_text_field_columns(['client_name'])
+        self.search.set_text_field_columns(['client_name', 'identifier_str'])
 
     def _get_columns(self):
-        return [SearchColumn('identifier', title=_('#'), sorted=True,
-                             data_type=int),
+        return [IdentifierColumn('identifier', sorted=True),
                 SearchColumn('responsible_name', title=_(u'Responsible'),
                              data_type=str, expand=True),
                 SearchColumn('client_name', title=_(u'Client'),
@@ -254,28 +256,37 @@ class LoanSelectionStep(BaseWizardStep):
                 SearchColumn('expire_date', title=_(u'Expire'),
                              data_type=datetime.date),
                 Column('loaned', title=_(u'Loaned'),
-                             data_type=Decimal),
-        ]
+                       data_type=Decimal),
+                ]
 
     def _refresh_next(self, value=None):
-        has_selected = self.search.results.get_selected() is not None
-        self.wizard.refresh_next(has_selected)
+        can_continue = False
+        selected_rows = self.search.results.get_selected_rows()
+        if selected_rows:
+            client = selected_rows[0].client_id
+            branch = selected_rows[0].branch_id
+            # Only loans that belong to the same client and are from the same
+            # branch can be closed together
+            can_continue = all(v.client_id == client and v.branch_id == branch
+                               for v in selected_rows)
+        self.wizard.refresh_next(can_continue)
 
     def get_extra_query(self, states):
         return LoanView.status == Loan.STATUS_OPEN
 
     def setup_slaves(self):
-        self.search = StoqlibSearchSlaveDelegate(self._get_columns(),
-                                        restore_name=self.__class__.__name__)
+        self.search = SearchSlave(self._get_columns(),
+                                  restore_name=self.__class__.__name__,
+                                  store=self.store,
+                                  search_spec=LoanView)
         self.search.enable_advanced_search()
         self.attach_slave('place_holder', self.search)
-        self.executer = StoqlibQueryExecuter(self.store)
-        self.search.set_query_executer(self.executer)
-        self.executer.set_table(LoanView)
-        self.executer.add_query_callback(self.get_extra_query)
+        executer = self.search.get_query_executer()
+        executer.add_query_callback(self.get_extra_query)
         self._create_filters()
         self.search.results.connect('selection-changed',
                                     self._on_results_selection_changed)
+        self.search.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.search.focus_search_entry()
 
     #
@@ -290,11 +301,11 @@ class LoanSelectionStep(BaseWizardStep):
         self.force_validation()
 
     def next_step(self):
-        loan = self.search.results.get_selected().loan
         # FIXME: For some reason, the loan isn't in self.store
-        self.wizard.model = self.store.fetch(loan)
+        views = self.search.results.get_selected_rows()
+        self.wizard.models = [self.store.fetch(v.loan) for v in views]
         return LoanItemSelectionStep(self.wizard, self, self.store,
-                                     self.wizard.model)
+                                     self.wizard.models)
 
     #
     # Callbacks
@@ -305,7 +316,7 @@ class LoanSelectionStep(BaseWizardStep):
 
 
 class LoanItemSelectionStep(SellableItemStep):
-    model_type = Loan
+    model_type = list
     item_table = LoanItem
     cost_editable = False
     summary_label_column = None
@@ -313,12 +324,13 @@ class LoanItemSelectionStep(SellableItemStep):
     def __init__(self, wizard, previous, store, model):
         super(LoanItemSelectionStep, self).__init__(wizard, previous,
                                                     store, model)
-        for item in self.model.loaned_items:
-            self.wizard.original_items[item] = Settable(
-                quantity=item.quantity,
-                sale_quantity=item.sale_quantity,
-                return_quantity=item.return_quantity,
-                remaining_quantity=item.get_remaining_quantity(),
+        for loan in model:
+            for item in loan.loaned_items:
+                self.wizard.original_items[item] = Settable(
+                    quantity=item.quantity,
+                    sale_quantity=item.sale_quantity,
+                    return_quantity=item.return_quantity,
+                    remaining_quantity=item.get_remaining_quantity(),
                 )
 
         LoanItemSelectionStepEvent.emit(self)
@@ -337,9 +349,6 @@ class LoanItemSelectionStep(SellableItemStep):
         self.hide_edit_button()
         self.hide_del_button()
         self.hide_item_addition_toolbar()
-        for widget in [self.minimum_quantity_lbl, self.minimum_quantity,
-                       self.stock_quantity, self.stock_quantity_lbl]:
-            widget.hide()
 
         self.slave.klist.connect('cell-edited', self._on_klist__cell_edited)
         self.slave.klist.connect('cell-editing-started',
@@ -347,7 +356,7 @@ class LoanItemSelectionStep(SellableItemStep):
         self.force_validation()
 
     def get_columns(self):
-        adjustment = gtk.Adjustment(lower=0, upper=sys.maxint, step_incr=1)
+        adjustment = gtk.Adjustment(lower=0, upper=MAX_INT, step_incr=1)
         return [
             Column('sellable.code', title=_('Code'),
                    data_type=str, visible=False),
@@ -366,16 +375,18 @@ class LoanItemSelectionStep(SellableItemStep):
             Column('remaining_quantity', title=_('Remaining'),
                    data_type=Decimal, format_func=format_quantity),
             Column('price', title=_('Price'), data_type=currency),
-            ]
+        ]
 
     def get_saved_items(self):
-        return self.model.loaned_items
+        for loan in self.model:
+            for item in loan.loaned_items:
+                yield item
 
     def validate_step(self):
         any_changed = False
         has_sale_items = False
 
-        for item in self.model.loaned_items:
+        for item in self.get_saved_items():
             original = self.wizard.original_items[item]
             sale_quantity = item.sale_quantity - original.sale_quantity
             if sale_quantity > 0:
@@ -476,9 +487,16 @@ class NewLoanWizard(BaseWizard):
     #
 
     def finish(self):
+        missing = get_missing_items(self.model, self.store)
+        if missing:
+            run_dialog(MissingItemsDialog, self, self.model, missing)
+            return False
+
         self.model.sync_stock()
         self.retval = self.model
         self.close()
+        # Confirm before printing to avoid losing data if something breaks
+        self.store.confirm(self.retval)
         NewLoanWizardFinishEvent.emit(self.model)
         self._print_receipt(self.model)
 
@@ -525,19 +543,22 @@ class CloseLoanWizard(BaseWizard):
     #
 
     def finish(self):
-        for item in self.model.loaned_items:
-            original = self.original_items[item]
-            sale_quantity = item.sale_quantity - original.sale_quantity
-            if sale_quantity > 0:
-                self._sold_items.append(
-                    (item.sellable, sale_quantity, item.price))
+        for loan in self.models:
+            for item in loan.loaned_items:
+                original = self.original_items[item]
+                sale_quantity = item.sale_quantity - original.sale_quantity
+                if sale_quantity > 0:
+                    self._sold_items.append(
+                        (item.sellable, sale_quantity, item.price))
 
         if self._create_sale and self._sold_items:
             user = api.get_current_user(self.store)
             sale = Sale(
                 store=self.store,
-                branch=self.model.branch,
-                client=self.model.client,
+                # Even if there is more than one loan, they are always from the
+                # same (client, branch)
+                branch=self.models[0].branch,
+                client=self.models[0].client,
                 salesperson=user.person.salesperson,
                 group=PaymentGroup(store=self.store),
                 coupon_id=None)
@@ -554,10 +575,22 @@ class CloseLoanWizard(BaseWizard):
         else:
             sale = None
 
-        self.model.sync_stock()
-        if self.model.can_close():
-            self.model.close()
+        for model in self.models:
+            model.sync_stock()
+            if model.can_close():
+                model.close()
 
-        self.retval = self.model
+        self.retval = self.models
         self.close()
-        CloseLoanWizardFinishEvent.emit(self.model, sale, self)
+        CloseLoanWizardFinishEvent.emit(self.models, sale, self)
+
+
+def test():  # pragma nocover
+    creator = api.prepare_test()
+    run_dialog(CloseLoanWizard, None, creator.store, create_sale=True)
+    creator.store.rollback()
+    #creator.store.confirm(retval)
+
+
+if __name__ == '__main__':  # pragma nocover
+    test()
