@@ -23,12 +23,11 @@
 ##
 """ Production wizard definition """
 
-import datetime
 from decimal import Decimal
 
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 from storm.expr import And
 
 from stoqlib.api import api
@@ -38,6 +37,7 @@ from stoqlib.domain.production import (ProductionOrder, ProductionItem,
 from stoqlib.domain.service import ServiceView
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import ProductComponentView
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.formatters import format_quantity
@@ -61,7 +61,7 @@ class OpenProductionOrderStep(WizardEditorStep):
     model_type = ProductionOrder
     proxy_widgets = ['open_date',
                      'expected_start_date',
-                     'order_number',
+                     'identifier',
                      'branch',
                      'responsible',
                      'description']
@@ -72,6 +72,8 @@ class OpenProductionOrderStep(WizardEditorStep):
     def _fill_branch_combo(self):
         branches = Branch.get_active_branches(self.store)
         self.branch.prefill(api.for_person_combo(branches))
+        sync_mode = api.sysparam.get_bool('SYNCHRONIZED_MODE')
+        self.branch.set_sensitive(not sync_mode)
 
     def _fill_responsible_combo(self):
         employees = self.store.find(Employee, status=Employee.STATUS_NORMAL)
@@ -103,7 +105,7 @@ class OpenProductionOrderStep(WizardEditorStep):
         self._setup_widgets()
         self.proxy = self.add_proxy(
             self.model, OpenProductionOrderStep.proxy_widgets)
-        self.proxy.update('order_number', u'%04d' % self.model.id)
+        self.proxy.update('identifier', unicode(self.model.identifier))
         # suggests a responsible for the production order
         if not self.model.responsible:
             self.responsible.select_item_by_position(0)
@@ -113,7 +115,7 @@ class OpenProductionOrderStep(WizardEditorStep):
     #
 
     def on_expected_start_date__validate(self, widget, value):
-        today = datetime.date.today()
+        today = localtoday().date()
         if value and value < today:
             return ValidationError(
                 _(u'Expected start date should be a future date.'))
@@ -132,7 +134,8 @@ class ProductionServiceStep(SellableItemStep):
     #
 
     def get_sellable_view_query(self):
-        delivery_sellable = sysparam(self.store).DELIVERY_SERVICE.sellable
+        delivery_sellable = sysparam.get_object(
+            self.store, 'DELIVERY_SERVICE').sellable
 
         query = And(ServiceView.status == Sellable.STATUS_AVAILABLE,
                     ServiceView.id != delivery_sellable.id)
@@ -159,7 +162,8 @@ class ProductionServiceStep(SellableItemStep):
         # This step is optional
         self.wizard.refresh_next(value)
 
-    def get_order_item(self, sellable, cost, quantity):
+    def get_order_item(self, sellable, cost, quantity, batch=None):
+        assert batch is None
         item = self._get_production_service_by_sellable(sellable)
         if item is None:
             return ProductionService(service=sellable.service,
@@ -176,15 +180,15 @@ class ProductionServiceStep(SellableItemStep):
         return [
             Column('service.sellable.code', title=_('Code'), data_type=str),
             Column('service.sellable.category_description', title=_('Category'),
-                    data_type=str, expand=True),
+                   data_type=str, expand=True),
             Column('service.sellable.description', title=_('Description'),
-                    data_type=str, expand=True, sorted=True),
+                   data_type=str, expand=True, sorted=True),
             Column('quantity', title=_('Quantity'), data_type=Decimal,
-                    format_func=format_quantity),
+                   format_func=format_quantity),
             Column('service.sellable.unit_description', title=_('Unit'),
-                    data_type=str),
+                   data_type=str),
             Column('service.sellable.cost', title=_('Cost'),
-                    data_type=currency)]
+                   data_type=currency)]
 
     def remove_items(self, items):
         for item in items:
@@ -230,7 +234,9 @@ class ProductionItemStep(SellableItemStep):
     # SellableItemStep virtual methods
     #
 
-    def get_order_item(self, sellable, cost, quantity):
+    def get_order_item(self, sellable, cost, quantity, batch=None):
+        # We are not allowing production items to control batches right now
+        assert batch is None
         item = self._get_production_item_by_sellable(sellable)
         if item is None:
             return self.model.add_item(sellable, quantity)
@@ -245,13 +251,13 @@ class ProductionItemStep(SellableItemStep):
         return [
             Column('product.sellable.code', title=_('Code'), data_type=str),
             Column('product.sellable.category_description', title=_('Category'),
-                    data_type=str, expand=True),
+                   data_type=str, expand=True),
             Column('product.sellable.description', title=_('Description'),
-                    data_type=str, expand=True, sorted=True),
+                   data_type=str, expand=True, sorted=True),
             Column('quantity', title=_('Quantity'), data_type=Decimal,
-                    format_func=format_quantity),
+                   format_func=format_quantity),
             Column('product.sellable.unit_description', title=_('Unit'),
-                    data_type=str)]
+                   data_type=str)]
 
     #
     # WizardStep hooks
