@@ -30,11 +30,9 @@ import gtk
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
-from kiwi.ui.search import DateSearchFilter
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
-from stoqlib.database.queryexecuter import StoqlibQueryExecuter
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.person import Branch
 from stoqlib.domain.purchase import (PurchaseOrder, PurchaseItem, QuoteGroup,
@@ -43,14 +41,17 @@ from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import QuotationView
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.lists import SimpleListDialog
-from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.base.wizards import (WizardEditorStep, BaseWizard,
                                       BaseWizardStep)
 from stoqlib.gui.dialogs.quotedialog import QuoteFillingDialog
 from stoqlib.gui.editors.purchaseeditor import PurchaseQuoteItemEditor
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.search.searchcolumns import IdentifierColumn
+from stoqlib.gui.search.searchfilters import DateSearchFilter
+from stoqlib.gui.search.searchslave import SearchSlave
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.gui.wizards.purchasewizard import (PurchaseItemStep,
                                                 PurchaseWizard)
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.message import info, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
@@ -74,11 +75,14 @@ class StartQuoteStep(WizardEditorStep):
         WizardEditorStep.__init__(self, store, wizard, model, previous)
 
     def _setup_widgets(self):
-        quote_group = "%05d" % self.wizard.quote_group.id
+        quote_group = str(self.wizard.quote_group.identifier)
         self.quote_group.set_text(quote_group)
 
         branches = Branch.get_active_branches(self.store)
         self.branch_combo.prefill(api.for_person_combo(branches))
+        sync_mode = api.sysparam.get_bool('SYNCHRONIZED_MODE')
+        self.branch_combo.set_sensitive(not sync_mode)
+
         self.notes.set_accepts_tab(False)
 
     def post_init(self):
@@ -101,7 +105,7 @@ class StartQuoteStep(WizardEditorStep):
     #
 
     def on_quote_deadline__validate(self, widget, date):
-        if date < datetime.date.today():
+        if date < localtoday().date():
             return ValidationError(_(u"The quote deadline date must be set to "
                                      "today or a future date"))
 
@@ -110,8 +114,7 @@ class QuoteItemStep(PurchaseItemStep):
     item_editor = PurchaseQuoteItemEditor
 
     def get_sellable_view_query(self):
-        query = Sellable.get_unblocked_sellables_query(self.store,
-                                                       storable=True)
+        query = Sellable.get_unblocked_sellables_query(self.store)
         return self.sellable_view, query
 
     def setup_slaves(self):
@@ -119,7 +122,8 @@ class QuoteItemStep(PurchaseItemStep):
         self.cost_label.hide()
         self.cost.hide()
 
-    def get_order_item(self, sellable, cost, quantity):
+    def get_order_item(self, sellable, cost, quantity, batch=None):
+        assert batch is None
         item = self.model.add_item(sellable, quantity)
         # since we are quoting products, it should not have
         # predefined cost. It should be filled later, when the
@@ -135,7 +139,7 @@ class QuoteItemStep(PurchaseItemStep):
                    format_func=format_quantity),
             Column('sellable.unit_description', title=_('Unit'), data_type=str,
                    width=70),
-            ]
+        ]
 
     def _setup_summary(self):
         # disables summary label for the quoting list
@@ -183,15 +187,15 @@ class QuoteSupplierStep(WizardEditorStep):
 
         if not len(self.quoting_list) > 0:
             info(_(u'No supplier have been found for any of the selected '
-                    'items.\nThis quote will be cancelled.'))
+                   'items.\nThis quote will be cancelled.'))
             self.wizard.finish()
 
     def _get_columns(self):
         return [Column('selected', title=" ", data_type=bool, editable=True),
                 Column('supplier.person.name', title=_('Supplier'),
-                        data_type=str, sorted=True, expand=True),
+                       data_type=str, sorted=True, expand=True),
                 Column('products_per_supplier', title=_('Supplied/Total'),
-                        data_type=str)]
+                       data_type=str)]
 
     def _update_widgets(self):
         selected = self.quoting_list.get_selected()
@@ -322,15 +326,13 @@ class QuoteGroupSelectionStep(BaseWizardStep):
         self._setup_slaves()
 
     def _setup_slaves(self):
-        self.search = StoqlibSearchSlaveDelegate(self._get_columns(),
-                                     restore_name=self.__class__.__name__)
+        self.search = SearchSlave(self._get_columns(),
+                                  restore_name=self.__class__.__name__,
+                                  search_spec=QuotationView,
+                                  store=self.store)
         self.attach_slave('search_group_holder', self.search)
 
-        executer = StoqlibQueryExecuter(self.store)
-        executer.set_table(QuotationView)
-        self.search.set_query_executer(executer)
-
-        self.search.set_text_field_columns(['supplier_name'])
+        self.search.set_text_field_columns(['supplier_name', 'identifier_str'])
         filter = self.search.get_primary_filter()
         filter.set_label(_(u'Supplier:'))
         self.search.focus_search_entry()
@@ -346,16 +348,14 @@ class QuoteGroupSelectionStep(BaseWizardStep):
         self.remove_button.set_sensitive(False)
 
     def _get_columns(self):
-        return [Column('identifier', title=_('Quote'), sorted=True,
-                        data_type=int, format="%04d"),
-                Column('group_identifier', title=_('Group'), data_type=int,
-                        format="%04d"),
+        return [IdentifierColumn('identifier', title=_("Quote #"), sorted=True),
+                IdentifierColumn('group_identifier', title=_('Group #')),
                 Column('supplier_name', title=_('Supplier'), data_type=str,
-                        width=300),
+                       width=300),
                 Column('open_date', title=_('Open date'),
-                        data_type=datetime.date),
+                       data_type=datetime.date),
                 Column('deadline', title=_('Deadline'),
-                        data_type=datetime.date)]
+                       data_type=datetime.date)]
 
     def _can_purchase(self, item):
         return item.cost > currency(0) and item.quantity > Decimal(0)
@@ -397,7 +397,7 @@ class QuoteGroupSelectionStep(BaseWizardStep):
         group.remove_item(quote)
         # there is no reason to keep the group if there's no more quotes
         if group.get_items().count() == 0:
-            QuoteGroup.delete(group.id, store=store)
+            store.remove(group)
         store.confirm(True)
         store.close()
         self.search.refresh()
@@ -458,7 +458,7 @@ class QuoteGroupItemsSelectionStep(BaseWizardStep):
                 self.quoted_items.append(Settable(
                     selected=True, order=quote.purchase, item=purchase_item,
                     description=sellable.get_description(),
-                    supplier=quote.purchase.get_supplier_name(),
+                    supplier=quote.purchase.supplier_name,
                     quantity=purchase_item.quantity,
                     ordered_quantity=ordered_qty,
                     cost=purchase_item.cost))
@@ -466,14 +466,14 @@ class QuoteGroupItemsSelectionStep(BaseWizardStep):
     def _get_columns(self):
         return [Column('selected', title=" ", data_type=bool, editable=True),
                 Column('description', title=_('Description'), data_type=str,
-                        expand=True, sorted=True),
+                       expand=True, sorted=True),
                 Column('supplier', title=_('Supplier'), data_type=str,
-                        expand=True),
+                       expand=True),
                 Column('quantity', title=_(u'Quantity'), data_type=Decimal),
                 Column('ordered_quantity', title=_(u'Ordered'),
-                        data_type=Decimal),
+                       data_type=Decimal),
                 Column('cost', title=_(u'Cost'), data_type=currency,
-                        format_func=get_formatted_cost)]
+                       format_func=get_formatted_cost)]
 
     def _update_widgets(self):
         if not self.quoted_items:
@@ -502,7 +502,7 @@ class QuoteGroupItemsSelectionStep(BaseWizardStep):
         store = api.new_store()
         group = store.fetch(self._group)
         group.cancel()
-        QuoteGroup.delete(group.id, store=store)
+        store.remove(group)
         store.confirm(True)
         store.close()
         self.wizard.finish()
@@ -521,14 +521,14 @@ class QuoteGroupItemsSelectionStep(BaseWizardStep):
 
         # override some cloned data
         real_order.group = PaymentGroup(store=store)
-        real_order.open_date = datetime.date.today()
+        real_order.open_date = localtoday().date()
         real_order.quote_deadline = None
         real_order.status = PurchaseOrder.ORDER_PENDING
 
         if has_selected_items:
             return real_order
         else:
-            PurchaseOrder.delete(real_order.id, store=store)
+            store.remove(real_order)
 
     def _close_quotes(self, quotes):
         if not quotes:
@@ -536,7 +536,7 @@ class QuoteGroupItemsSelectionStep(BaseWizardStep):
 
         if not yesno(_('Should we close the quotes used to compose the '
                        'purchase order ?'),
-                    gtk.RESPONSE_NO, _("Close quotes"), _("Don't close")):
+                     gtk.RESPONSE_NO, _("Close quotes"), _("Don't close")):
             return
 
         store = api.new_store()
@@ -628,11 +628,12 @@ class QuotePurchaseWizard(BaseWizard):
         return _('Edit Quote')
 
     def _create_model(self, store):
-        supplier = sysparam(store).SUGGESTED_SUPPLIER
+        supplier_id = sysparam.get_object_id('SUGGESTED_SUPPLIER')
         branch = api.get_current_branch(store)
         status = PurchaseOrder.ORDER_QUOTING
         group = PaymentGroup(store=store)
-        return PurchaseOrder(supplier=supplier, branch=branch, status=status,
+        return PurchaseOrder(supplier_id=supplier_id,
+                             branch=branch, status=status,
                              expected_receival_date=None,
                              responsible=api.get_current_user(store),
                              group=group,
