@@ -25,14 +25,13 @@
 """ Purchase wizard definition """
 
 import datetime
-import sys
 
 import gtk
 
 from kiwi.component import get_utility
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
-from kiwi.ui.widgets.list import Column
+from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.inventory import Inventory
@@ -41,8 +40,7 @@ from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.person import Branch, Supplier, Transporter
 from stoqlib.domain.product import ProductSupplierInfo
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseItem
-from stoqlib.domain.receiving import (ReceivingOrder, ReceivingOrderItem,
-                                      get_receiving_items_by_purchase_order)
+from stoqlib.domain.receiving import ReceivingOrder
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import ProductFullStockItemSupplierView
 from stoqlib.gui.base.dialogs import run_dialog
@@ -50,14 +48,18 @@ from stoqlib.gui.base.wizards import WizardEditorStep, BaseWizard
 from stoqlib.gui.editors.purchaseeditor import PurchaseItemEditor
 from stoqlib.gui.editors.personeditor import SupplierEditor, TransporterEditor
 from stoqlib.gui.interfaces import IDomainSlaveMapper
-from stoqlib.gui.printing import print_report
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.gui.wizards.receivingwizard import ReceivingInvoiceStep
 from stoqlib.gui.wizards.abstractwizard import SellableItemStep
+from stoqlib.gui.search.sellablesearch import PurchaseSellableSearch
 from stoqlib.gui.slaves.paymentmethodslave import SelectPaymentMethodSlave
 from stoqlib.gui.slaves.paymentslave import register_payment_slaves
+from stoqlib.gui.utils.printing import print_report
+from stoqlib.lib.defaults import MAX_INT
+from stoqlib.lib.dateutils import localtoday
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.permissions import PermissionManager
 from stoqlib.lib.formatters import format_quantity, get_formatted_cost
 from stoqlib.reporting.purchase import PurchaseOrderReport
 
@@ -73,7 +75,7 @@ class StartPurchaseStep(WizardEditorStep):
     gladefile = 'StartPurchaseStep'
     model_type = PurchaseOrder
     proxy_widgets = ['open_date',
-                     'order_number',
+                     'identifier',
                      'supplier',
                      'branch',
                      'expected_freight',
@@ -81,6 +83,11 @@ class StartPurchaseStep(WizardEditorStep):
 
     def __init__(self, wizard, store, model):
         WizardEditorStep.__init__(self, store, wizard, model)
+        pm = PermissionManager.get_permission_manager()
+        if not pm.can_create('Supplier'):
+            self.add_supplier.hide()
+        if not pm.can_edit('Supplier'):
+            self.edit_supplier.hide()
 
     def _fill_supplier_combo(self):
         suppliers = Supplier.get_active_suppliers(self.store)
@@ -89,9 +96,11 @@ class StartPurchaseStep(WizardEditorStep):
     def _fill_branch_combo(self):
         branches = Branch.get_active_branches(self.store)
         self.branch.prefill(api.for_person_combo(branches))
+        sync_mode = api.sysparam.get_bool('SYNCHRONIZED_MODE')
+        self.branch.set_sensitive(not sync_mode)
 
     def _setup_widgets(self):
-        allow_outdated = sysparam(self.store).ALLOW_OUTDATED_OPERATIONS
+        allow_outdated = sysparam.get_bool('ALLOW_OUTDATED_OPERATIONS')
         self.open_date.set_sensitive(allow_outdated)
         self._fill_supplier_combo()
         self._fill_branch_combo()
@@ -137,12 +146,6 @@ class StartPurchaseStep(WizardEditorStep):
 
     def post_init(self):
         self.open_date.grab_focus()
-        self.table.set_focus_chain([
-            self.open_date,
-            self.branch,
-            self.supplier, self.supplier_buttons,
-            self.radio_hbox, self.expected_freight])
-        self.radio_hbox.set_focus_chain([self.cif_radio, self.fob_radio])
         self.register_validate_function(self.wizard.refresh_next)
         self.force_validation()
 
@@ -172,9 +175,9 @@ class StartPurchaseStep(WizardEditorStep):
         self._edit_supplier()
 
     def on_open_date__validate(self, widget, date):
-        if sysparam(self.store).ALLOW_OUTDATED_OPERATIONS:
+        if sysparam.get_bool('ALLOW_OUTDATED_OPERATIONS'):
             return
-        if date < datetime.date.today():
+        if date < localtoday().date():
             return ValidationError(
                 _("Open date must be set to today or "
                   "a future date"))
@@ -182,7 +185,7 @@ class StartPurchaseStep(WizardEditorStep):
     def on_expected_freight__validate(self, widget, value):
         if value < 0:
             return ValidationError(_(u'The expected freight value must be a '
-                                      'positive number.'))
+                                     'positive number.'))
 
 
 class PurchaseItemStep(SellableItemStep):
@@ -192,6 +195,7 @@ class PurchaseItemStep(SellableItemStep):
     summary_label_text = "<b>%s</b>" % api.escape(_('Total Ordered:'))
     sellable_editable = True
     item_editor = PurchaseItemEditor
+    sellable_search = PurchaseSellableSearch
 
     def _set_expected_receival_date(self, item):
         supplier = self.model.supplier
@@ -219,17 +223,17 @@ class PurchaseItemStep(SellableItemStep):
         else:
             viewable = self.sellable_view
 
-        query = Sellable.get_unblocked_sellables_query(self.store,
-                                   storable=True, supplier=supplier,
-                                   consigned=self.model.consigned)
+        query = Sellable.get_unblocked_sellables_query(self.store, supplier=supplier,
+                                                       consigned=self.model.consigned)
         return viewable, query
 
     def setup_slaves(self):
         SellableItemStep.setup_slaves(self)
         self.hide_add_button()
-
         self.cost.set_editable(True)
         self.quantity.connect('validate', self._on_quantity__validate)
+        self.slave.klist.connect('selection-changed',
+                                 self._on_klist_selection_changed)
 
     #
     # SellableItemStep virtual methods
@@ -237,10 +241,11 @@ class PurchaseItemStep(SellableItemStep):
 
     def validate(self, value):
         SellableItemStep.validate(self, value)
-        can_purchase = self.model.get_purchase_total() > 0
+        can_purchase = self.model.purchase_total > 0
         self.wizard.refresh_next(value and can_purchase)
 
-    def get_order_item(self, sellable, cost, quantity):
+    def get_order_item(self, sellable, cost, quantity, batch=None):
+        assert batch is None
         # Associate the product with the supplier if they are not yet. This
         # happens when the user checked the option to show all products on the
         # first step
@@ -259,19 +264,22 @@ class PurchaseItemStep(SellableItemStep):
     def get_saved_items(self):
         return list(self.model.get_items())
 
-    def sellable_selected(self, sellable):
-        super(PurchaseItemStep, self).sellable_selected(sellable)
+    def sellable_selected(self, sellable, batch=None):
+        super(PurchaseItemStep, self).sellable_selected(sellable, batch=batch)
         supplier_info = self._get_supplier_info()
         if not supplier_info:
             return
 
         minimum = supplier_info.minimum_purchase
         self.quantity.set_adjustment(gtk.Adjustment(lower=minimum,
-                                                    upper=sys.maxint,
+                                                    upper=MAX_INT,
                                                     step_incr=1))
         self.quantity.set_value(minimum)
         self.cost.set_value(supplier_info.base_cost)
 
+    def get_sellable_search_extra_kwargs(self):
+        return dict(supplier=self.model.supplier)
+
     def get_columns(self):
         return [
             Column('sellable.code', title=_('Code'), width=100, data_type=str),
@@ -288,7 +296,7 @@ class PurchaseItemStep(SellableItemStep):
             Column('cost', title=_('Cost'), data_type=currency,
                    format_func=get_formatted_cost, width=90),
             Column('total', title=_('Total'), data_type=currency, width=100),
-            ]
+        ]
 
     #
     # WizardStep hooks
@@ -304,7 +312,10 @@ class PurchaseItemStep(SellableItemStep):
     #
 
     def _get_supplier_info(self):
-        sellable = self.proxy.model.sellable or self._get_sellable()
+        sellable = self.proxy.model.sellable
+        if not sellable:
+            # FIXME: We should not be accessing a private method here
+            sellable, batch = self._get_sellable_and_batch()
         if not sellable:
             return
         product = sellable.product
@@ -323,11 +334,14 @@ class PurchaseItemStep(SellableItemStep):
         supplier_info = self._get_supplier_info()
         if supplier_info and value < supplier_info.minimum_purchase:
             return ValidationError(_(u'Quantity below the minimum required '
-                                      'by the supplier'))
-
+                                     'by the supplier'))
         return super(PurchaseItemStep,
                      self).on_quantity__validate(widget, value)
 
+    def _on_klist_selection_changed(self, klist, data):
+        can_delete = all(product.quantity_received == 0 for product in data)
+        self.slave.delete_button.set_sensitive(can_delete)
+
 
 class PurchasePaymentStep(WizardEditorStep):
     gladefile = 'PurchasePaymentStep'
@@ -352,7 +366,7 @@ class PurchasePaymentStep(WizardEditorStep):
 
             # due_date is datetime.datetime. Converting it to datetime.date
             due_date = model.payments[0].due_date.date()
-            self._first_duedate = (due_date >= datetime.date.today() and
+            self._first_duedate = (due_date >= localtoday().date() and
                                    due_date or None)
 
         WizardEditorStep.__init__(self, store, wizard, model.group, previous)
@@ -362,7 +376,8 @@ class PurchasePaymentStep(WizardEditorStep):
 
         self._ms = SelectPaymentMethodSlave(store=self.store,
                                             payment_type=Payment.TYPE_OUT,
-                                            default_method=self._method)
+                                            default_method=self._method,
+                                            no_payments=True)
         self._ms.connect_after('method-changed',
                                self._after_method_select__method_changed)
 
@@ -403,7 +418,9 @@ class PurchasePaymentStep(WizardEditorStep):
     #
 
     def validate_step(self):
-        return self.slave.finish()
+        if self.slave:
+            return self.slave.finish()
+        return True
 
     def next_step(self):
         return FinishPurchaseStep(self.store, self.wizard, self.order, self)
@@ -454,20 +471,23 @@ class FinishPurchaseStep(WizardEditorStep):
 
     def _create_receiving_order(self):
         # since we will create a new receiving order, we should confirm the
-        # purchase first.
-        self.model.confirm()
+        # purchase first. Note that the purchase may already be confirmed
+        if self.model.status in [PurchaseOrder.ORDER_PENDING,
+                                 PurchaseOrder.ORDER_CONSIGNED]:
+            self.model.confirm()
 
         receiving_model = ReceivingOrder(
             responsible=api.get_current_user(self.store),
-            purchase=self.model,
             supplier=self.model.supplier,
             branch=self.model.branch,
             transporter=self.model.transporter,
             invoice_number=None,
             store=self.store)
+        receiving_model.add_purchase(self.model)
 
         # Creates ReceivingOrderItem's
-        get_receiving_items_by_purchase_order(self.model, receiving_model)
+        for item in self.model.get_pending_items():
+            receiving_model.add_purchase_item(item)
 
         self.wizard.receiving_model = receiving_model
 
@@ -495,13 +515,16 @@ class FinishPurchaseStep(WizardEditorStep):
         receiving_model = self.wizard.receiving_model
         if receiving_model:
             for item in receiving_model.get_items():
-                ReceivingOrderItem.delete(item.id, self.store)
-
-            ReceivingOrder.delete(receiving_model.id, store=self.store)
+                self.store.remove(item)
+            self.store.remove(receiving_model)
             self.wizard.receiving_model = None
 
         self.salesperson_name.grab_focus()
         self._set_receival_date_suggestion()
+
+        if self.model.has_batch_item():
+            self.receive_now.hide()
+
         self.register_validate_function(self.wizard.refresh_next)
         self.force_validation()
 
@@ -509,9 +532,10 @@ class FinishPurchaseStep(WizardEditorStep):
         # Avoid changing widget states in __init__, so that plugins have a
         # chance to override the default settings
         has_open_inventory = Inventory.has_open(self.store,
-                                            api.get_current_branch(self.store))
+                                                api.get_current_branch(self.store))
         self.receive_now.set_sensitive(not bool(has_open_inventory))
 
+        self._setup_focus()
         self._setup_transporter_entry()
         self.proxy = self.add_proxy(self.model, self.proxy_widgets)
 
@@ -519,7 +543,7 @@ class FinishPurchaseStep(WizardEditorStep):
         store = api.new_store()
         transporter = store.fetch(transporter)
         model = run_person_role_dialog(TransporterEditor, self.wizard, store,
-                                        transporter)
+                                       transporter)
         rv = store.confirm(model)
         store.close()
         if rv:
@@ -528,10 +552,10 @@ class FinishPurchaseStep(WizardEditorStep):
             self.transporter.select(model)
 
     def on_expected_receival_date__validate(self, widget, date):
-        if sysparam(self.store).ALLOW_OUTDATED_OPERATIONS:
+        if sysparam.get_bool('ALLOW_OUTDATED_OPERATIONS'):
             return
 
-        if date < datetime.date.today():
+        if date < localtoday().date():
             return ValidationError(_("Expected receival date must be set to a future date"))
 
     def on_add_transporter__clicked(self, button):
@@ -571,9 +595,12 @@ class PurchaseWizard(BaseWizard):
 
         # If we receive the order right after the purchase.
         self.receiving_model = None
-        if model.status != PurchaseOrder.ORDER_PENDING:
+        purchase_edit = [PurchaseOrder.ORDER_CONFIRMED,
+                         PurchaseOrder.ORDER_PENDING]
+
+        if not model.status in purchase_edit:
             raise ValueError('Invalid order status. It should '
-                             'be ORDER_PENDING')
+                             'be ORDER_PENDING or ORDER_CONFIRMED')
         first_step = StartPurchaseStep(self, store, model)
         BaseWizard.__init__(self, store, first_step, model, title=title,
                             edit_mode=edit_mode)
@@ -584,11 +611,11 @@ class PurchaseWizard(BaseWizard):
         return _('Edit Order')
 
     def _create_model(self, store):
-        supplier = sysparam(store).SUGGESTED_SUPPLIER
+        supplier_id = sysparam.get_object_id('SUGGESTED_SUPPLIER')
         branch = api.get_current_branch(store)
         group = PaymentGroup(store=store)
         status = PurchaseOrder.ORDER_PENDING
-        return PurchaseOrder(supplier=supplier,
+        return PurchaseOrder(supplier_id=supplier_id,
                              responsible=api.get_current_user(store),
                              branch=branch,
                              status=status,
