@@ -25,7 +25,6 @@
 """ Sale return wizards definition """
 
 import decimal
-import sys
 
 import gtk
 from kiwi.currency import currency
@@ -35,19 +34,25 @@ from storm.expr import Or
 
 from stoqlib.api import api
 from stoqlib.database.runtime import get_current_user, get_current_branch
+from stoqlib.domain.product import StorableBatch
 from stoqlib.domain.returnedsale import ReturnedSale, ReturnedSaleItem
 from stoqlib.domain.sale import Sale
-from stoqlib.lib.formatters import format_quantity
-from stoqlib.lib.message import info
+from stoqlib.enums import ReturnPolicy
+from stoqlib.lib.defaults import MAX_INT
+from stoqlib.lib.formatters import format_quantity, format_sellable_description
+from stoqlib.lib.message import info, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.base.wizards import WizardEditorStep, BaseWizard
+from stoqlib.gui.dialogs.batchselectiondialog import BatchIncreaseSelectionDialog
 from stoqlib.gui.events import (SaleReturnWizardFinishEvent,
                                 SaleTradeWizardFinishEvent)
 from stoqlib.gui.search.salesearch import SaleSearch
 from stoqlib.gui.slaves.paymentslave import (register_payment_slaves,
                                              MultipleMethodSlave)
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.gui.wizards.abstractwizard import SellableItemStep
+from stoqlib.reporting.clientcredit import ClientCreditReport
 
 
 _ = stoqlib_gettext
@@ -59,7 +64,7 @@ def _adjust_returned_sale_item(item):
     if item.sale_item:
         item.max_quantity = item.quantity
     else:
-        item.max_quantity = sys.maxint
+        item.max_quantity = MAX_INT
 
 
 #
@@ -90,7 +95,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
 
     def setup_slaves(self):
         self.slave = SaleSearch(self.store)
-        self.slave.executer.set_query(self._sale_executer_query)
+        self.slave.search.set_query(self._sale_executer_query)
         self.attach_slave('place_holder', self.slave)
         self.slave.search.refresh()
 
@@ -107,7 +112,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
     #
 
     def _allow_unknown_sales(self):
-        return sysparam(self.store).ALLOW_TRADE_NOT_REGISTERED_SALES
+        return sysparam.get_bool('ALLOW_TRADE_NOT_REGISTERED_SALES')
 
     def _validation_func(self, value):
         has_selected = self.slave.results.get_selected()
@@ -142,7 +147,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
                 store=self.store,
                 responsible=get_current_user(self.store),
                 branch=get_current_branch(self.store),
-                )
+            )
 
         self.wizard.model = model
 
@@ -150,7 +155,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
         # Only show sales that can be returned
         query = Or(Sale.status == Sale.STATUS_CONFIRMED,
                    Sale.status == Sale.STATUS_PAID)
-        return store.find(self.slave.search_table, query)
+        return store.find(self.slave.search_spec, query)
 
     #
     #  Callbacks
@@ -173,6 +178,9 @@ class SaleReturnItemsStep(SellableItemStep):
     item_table = ReturnedSaleItem
     cost_editable = False
     summary_label_text = '<b>%s</b>' % api.escape(_("Total to return:"))
+    # This will only be used when wizard.unkown_sale is True
+    batch_selection_dialog = BatchIncreaseSelectionDialog
+    stock_labels_visible = False
 
     #
     #  SellableItemStep
@@ -185,9 +193,6 @@ class SaleReturnItemsStep(SellableItemStep):
         self.hide_add_button()
         self.hide_edit_button()
         self.hide_del_button()
-        for widget in [self.minimum_quantity_lbl, self.minimum_quantity,
-                       self.stock_quantity, self.stock_quantity_lbl]:
-            widget.hide()
         # If we have a sale reference, we cannot add more items
         if self.model.sale:
             self.hide_item_addition_toolbar()
@@ -202,20 +207,22 @@ class SaleReturnItemsStep(SellableItemStep):
                                      model=self.model, previous=self)
 
     def get_columns(self, editable=True):
-        adjustment = gtk.Adjustment(lower=0, upper=sys.maxint,
+        adjustment = gtk.Adjustment(lower=0, upper=MAX_INT,
                                     step_incr=1)
         columns = [
             Column('will_return', title=_('Return'),
                    data_type=bool, editable=editable),
             Column('sellable.code', title=_('Code'),
-                   data_type=str, visible=False),
+                   data_type=str, visible=False, sorted=True),
             Column('sellable.barcode', title=_('Barcode'),
                    data_type=str, visible=False),
             Column('sellable.description', title=_('Description'),
-                   data_type=str, expand=True),
+                   data_type=str, expand=True,
+                   format_func=self._format_description,
+                   format_func_data=True),
             Column('price', title=_('Sale price'),
                    data_type=currency),
-            ]
+        ]
 
         # max_quantity has no meaning on returns without a sale reference
         if self.model.sale:
@@ -231,26 +238,33 @@ class SaleReturnItemsStep(SellableItemStep):
                    editable=editable, **kwargs),
             Column('total', title=_('Total'),
                    data_type=currency),
-            ])
+        ])
 
         return columns
 
     def get_saved_items(self):
         return self.model.returned_items
 
-    def get_order_item(self, sellable, price, quantity):
+    def get_order_item(self, sellable, price, quantity, batch=None):
+        if batch is not None:
+            batch = StorableBatch.get_or_create(
+                self.store,
+                storable=sellable.product_storable,
+                batch_number=batch)
+
         item = ReturnedSaleItem(
             store=self.store,
             quantity=quantity,
             price=price,
             sellable=sellable,
+            batch=batch,
             returned_sale=self.model,
-            )
+        )
         _adjust_returned_sale_item(item)
         return item
 
-    def sellable_selected(self, sellable):
-        SellableItemStep.sellable_selected(self, sellable)
+    def sellable_selected(self, sellable, batch=None):
+        SellableItemStep.sellable_selected(self, sellable, batch=batch)
         if sellable:
             self.cost.update(sellable.price)
 
@@ -274,18 +288,19 @@ class SaleReturnItemsStep(SellableItemStep):
         super(SaleReturnItemsStep, self).validate(value)
         self.wizard.refresh_next(value and self.validate_step())
 
+    #
+    #  Private
+    #
+
+    def _format_description(self, item, data):
+        return format_sellable_description(item.sellable, item.batch)
+
     #
     #  Callbacks
     #
 
     def _on_klist__cell_edited(self, klist, obj, attr):
         if attr == 'quantity':
-            # FIXME: Even with the adjustment, the user still can type
-            # values out of range with the keyboard. Maybe it's kiwi's fault
-            if obj.quantity > obj.max_quantity:
-                obj.quantity = obj.max_quantity
-            if obj.quantity < 0:
-                obj.quantity = 0
             # Changing quantity from anything to 0 will uncheck will_return
             # Changing quantity from 0 to anything will check will_return
             obj.will_return = bool(obj.quantity)
@@ -318,7 +333,7 @@ class SaleReturnInvoiceStep(WizardEditorStep):
         'paid_total',
         'returned_total',
         'total_amount_abs',
-        ]
+    ]
 
     #
     #  WizardEditorStep
@@ -361,6 +376,16 @@ class SaleReturnInvoiceStep(WizardEditorStep):
         else:
             self.total_amount_lbl.set_text(_("Difference:"))
 
+        if (isinstance(self.wizard, SaleTradeWizard) or
+                not self.wizard.model.sale.client):
+            self.credit_checkbutton.hide()
+
+        policy = sysparam.get_int('RETURN_POLICY_ON_SALES')
+        self.credit_checkbutton.set_sensitive(policy == ReturnPolicy.CLIENT_CHOICE)
+        self.credit_checkbutton.set_active(policy == ReturnPolicy.RETURN_CREDIT)
+
+        self.wizard.credit = self.credit_checkbutton.read()
+
         self.wizard.update_view()
         self.force_validation()
 
@@ -376,6 +401,9 @@ class SaleReturnInvoiceStep(WizardEditorStep):
                                                 value):
             return ValidationError(_("Invoice number already exists."))
 
+    def on_credit_checkbutton__toggled(self, widget):
+        self.wizard.credit = self.credit_checkbutton.read()
+
 
 class SaleReturnPaymentStep(WizardEditorStep):
     gladefile = 'HolderTemplate'
@@ -391,12 +419,13 @@ class SaleReturnPaymentStep(WizardEditorStep):
 
         before_debt = currency(self.model.sale_total - self.model.paid_total)
         now_debt = currency(before_debt - self.model.returned_total)
-        info(_("The client's debt has changed. "
-               "Use this step to adjust the payments."),
-             _("The debt before was %s and now is %s. Cancel some unpaid "
-               "installments and create new ones.") % (
-             converter.as_string(currency, before_debt),
-             converter.as_string(currency, now_debt)))
+        short = _("The client's debt has changed. "
+                  "Use this step to adjust the payments.")
+        longdesc = _("The debt before was %s and now is %s. Cancel some unpaid "
+                     "installments and create new ones.")
+        info(short,
+             longdesc % (converter.as_string(currency, before_debt),
+                         converter.as_string(currency, now_debt)))
 
     def setup_slaves(self):
         register_payment_slaves()
@@ -431,7 +460,7 @@ class SaleReturnPaymentStep(WizardEditorStep):
 
 
 class _BaseSaleReturnWizard(BaseWizard):
-    size = (600, 350)
+    size = (800, 450)
 
     def __init__(self, store, model=None):
         self.unkown_sale = False
@@ -466,17 +495,27 @@ class SaleReturnWizard(_BaseSaleReturnWizard):
         SaleReturnWizardFinishEvent.emit(self.model)
 
         total_amount = self.model.total_amount
-        if total_amount == 0:
-            info(_("The client does not have a debt to this sale anymore. "
-                   "Any existing unpaid installment will be cancelled."))
-        elif total_amount < 0:
-            info(_("A reversal payment to the client will be created. "
-                   "You can see it on the Payable Application."))
+        # If the user chose to create credit for the client instead of returning
+        # money, there is no need to display this messages.
+        if not self.credit:
+            if total_amount == 0:
+                info(_("The client does not have a debt to this sale anymore. "
+                       "Any existing unpaid installment will be cancelled."))
+            elif total_amount < 0:
+                info(_("A reversal payment to the client will be created. "
+                       "You can see it on the Payable Application."))
 
-        self.model.return_()
+        self.model.return_(method_name=u'credit' if self.credit else u'money')
         self.retval = self.model
         self.close()
 
+        # Commit before printing to avoid losing data if something breaks
+        self.store.confirm(self.retval)
+        if self.credit:
+            if yesno(_(u'Would you like to print the credit letter?'),
+                     gtk.RESPONSE_YES, _(u"Print Letter"), _(u"Don't print")):
+                print_report(ClientCreditReport, self.model.client)
+
 
 class SaleTradeWizard(_BaseSaleReturnWizard):
     """Wizard for trading a sale"""
