@@ -24,11 +24,14 @@
 ##
 """ Sale wizard definition """
 
+import decimal
+
 import gtk
 from kiwi.component import get_utility
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
+from kiwi.ui.objectlist import Column
 from storm.expr import And
 
 from stoqlib.api import api
@@ -40,33 +43,69 @@ from stoqlib.domain.payment.card import CreditProvider
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.person import Client, SalesPerson, Transporter
-from stoqlib.domain.sale import Sale
+from stoqlib.domain.sale import Sale, SaleComment
 from stoqlib.enums import CreatePaymentStatus
-from stoqlib.exceptions import SellError, StoqlibError
-from stoqlib.lib.message import warning, yesno, marker
+from stoqlib.exceptions import SellError, StoqlibError, PaymentMethodError
+from stoqlib.lib.formatters import get_formatted_cost
+from stoqlib.lib.message import warning, marker
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.base.wizards import WizardEditorStep, BaseWizard, BaseWizardStep
 from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.dialogs.batchselectiondialog import BatchDecreaseSelectionDialog
 from stoqlib.gui.dialogs.clientdetails import ClientDetailsDialog
+from stoqlib.gui.dialogs.missingitemsdialog import (get_missing_items,
+                                                    MissingItemsDialog)
 from stoqlib.gui.editors.fiscaleditor import CfopEditor
 from stoqlib.gui.editors.noteeditor import NoteEditor
 from stoqlib.gui.editors.personeditor import ClientEditor, TransporterEditor
+from stoqlib.gui.events import ConfirmSaleWizardFinishEvent
 from stoqlib.gui.interfaces import IDomainSlaveMapper
-from stoqlib.gui.printing import print_report
 from stoqlib.gui.slaves.cashchangeslave import CashChangeSlave
 from stoqlib.gui.slaves.paymentmethodslave import SelectPaymentMethodSlave
 from stoqlib.gui.slaves.paymentslave import (register_payment_slaves,
                                              MultipleMethodSlave)
 from stoqlib.gui.slaves.saleslave import SaleDiscountSlave
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
-from stoqlib.reporting.boleto import BillReport
-from stoqlib.reporting.booklet import BookletReport
 
 N_ = _ = stoqlib_gettext
 
 
+class _TemporarySaleItem(object):
+    def __init__(self, item):
+        sellable = item.sellable
+        self.storable = sellable.product_storable
+        assert self.storable and self.storable.is_batch
+
+        self.code = sellable.code
+        self.barcode = sellable.barcode
+        self.sale_item = item
+        self.description = sellable.description
+        self.category_description = sellable.get_category_description()
+        self.price = item.price
+        self.original_quantity = item.quantity
+        self.batches = {}
+
+    @property
+    def quantity(self):
+        return sum(quantity for quantity in self.batches.values())
+
+    @property
+    def total(self):
+        return currency(self.price * self.quantity)
+
+    @property
+    def need_adjust_batch(self):
+        return self.original_quantity != self.quantity
+
+
+class _SaleBatchDecreaseSelectionDialog(BatchDecreaseSelectionDialog):
+    # We are finishing the sale here and this dialog will be used to select
+    # batches to decrease. We cannot decrease more than we sold
+    validate_max_quantity = True
+
+
 #
 # Wizard Steps
 #
@@ -160,6 +199,9 @@ class BaseMethodSelectionStep(object):
                 self.cash_change_slave.enable_cash_change()
             else:
                 self.cash_change_slave.disable_cash_change()
+        elif method and method.method_name == u'credit':
+            self.wizard.enable_finish()
+            self.cash_change_slave.disable_cash_change()
         else:
             self.wizard.disable_finish()
             self.cash_change_slave.disable_cash_change()
@@ -174,8 +216,11 @@ class BaseMethodSelectionStep(object):
     def setup_cash_payment(self, total=None):
         money_method = PaymentMethod.get_by_name(self.store, u'money')
         total = total or self.wizard.get_total_to_pay()
-        return money_method.create_inpayment(self.model.group,
-                                             self.model.branch, total)
+        try:
+            return money_method.create_payment(Payment.TYPE_IN, self.model.group,
+                                               self.model.branch, total)
+        except PaymentMethodError as err:
+            warning(str(err))
 
     #
     # WizardStep hooks
@@ -187,13 +232,13 @@ class BaseMethodSelectionStep(object):
                            self.subtotal_expander]:
                 widget.hide()
 
+        self.pm_slave.connect('method-changed', self.on_payment_method_changed)
         self._update_next_step(self.pm_slave.get_selected_method())
 
     def setup_slaves(self):
         marker('SelectPaymentMethodSlave')
         self.pm_slave = SelectPaymentMethodSlave(store=self.store,
                                                  payment_type=Payment.TYPE_IN)
-        self.pm_slave.connect('method-changed', self.on_payment_method_changed)
         self.attach_slave('select_method_holder', self.pm_slave)
 
         marker('CashChangeSlave')
@@ -219,9 +264,28 @@ class BaseMethodSelectionStep(object):
             # We have to modify the payment, so the fiscal printer can
             # calculate and print the payback, if necessary.
             payment = self.setup_cash_payment()
+            if payment is None:
+                return
+
             total = self.cash_change_slave.get_received_value()
             payment.base_value = total
 
+            # Return None here means call wizard.finish, which is exactly
+            # what we need
+            return None
+        elif selected_method.method_name == u'credit':
+            client = self.model.client
+            total = self.wizard.get_total_to_pay()
+
+            assert client.can_purchase(selected_method, total)
+
+            try:
+                payment = selected_method.create_payment(
+                    Payment.TYPE_IN, self.model.group, self.model.branch, total)
+            except PaymentMethodError as err:
+                warning(str(err))
+                return self
+
             # Return None here means call wizard.finish, which is exactly
             # what we need
             return None
@@ -254,9 +318,11 @@ class BaseMethodSelectionStep(object):
             else:
                 outstanding_value = self.wizard.get_total_to_pay()
 
+            manager = get_plugin_manager()
             return step_class(self.wizard, self, self.store, self.model,
                               selected_method,
-                              outstanding_value=outstanding_value)
+                              outstanding_value=outstanding_value,
+                              finish_on_total=manager.is_active('tef'))
 
         # finish the wizard
         if retval == CreatePaymentStatus.SUCCESS:
@@ -273,6 +339,124 @@ class BaseMethodSelectionStep(object):
         self._update_next_step(method_name)
 
 
+class ConfirmSaleBatchStep(WizardEditorStep):
+    """Step for selecting |batches| for sale items
+
+    Before going to :class:`.SalesPersonStep`, if a product is controlling
+    batch and that information is not available (probably because the
+    sale is quoted) this step will set it for you.
+
+    Note that each item can produce n items, n being the number of
+    batches used for it. All of those items will be already on the
+    sale and adjusted properly, tough.
+    """
+
+    gladefile = 'ConfirmSaleBatchStep'
+    model_type = Sale
+
+    #
+    #  WizardEditorStep
+    #
+
+    def post_init(self):
+        # If the user goes back from the previous step, make sure
+        # things don't get messed
+        if self.store.savepoint_exists('before_salesperson_step'):
+            self.store.rollback_to_savepoint('before_salesperson_step')
+
+        self.register_validate_function(self._validation_func)
+        self.force_validation()
+
+    def setup_proxies(self):
+        self._setup_widgets()
+        self.force_validation()
+
+    def next_step(self):
+        self.store.savepoint('before_salesperson_step')
+
+        marker('running SalesPersonStep')
+        self._update_sale_items()
+        step = SalesPersonStep(self.wizard, self.store, self.model,
+                               self.wizard.payment_group,
+                               self.wizard.invoice_model)
+        marker('finished creating SalesPersonStep')
+        return step
+
+    #
+    #  Private
+    #
+
+    def _setup_widgets(self):
+        self.sale_items.set_columns([
+            Column('code', title=_('Code'),
+                   data_type=str, visible=False),
+            Column('barcode', title=_('Barcode'),
+                   data_type=str, visible=False),
+            Column('description', title=_('Description'),
+                   data_type=str, expand=True),
+            Column('category_description', title=_('Category'),
+                   data_type=str),
+            Column('original_quantity', title=_('Quantity'),
+                   data_type=decimal.Decimal),
+            Column('quantity', title=_('Adjusted qty'),
+                   data_type=decimal.Decimal),
+            Column('price', title=_('price'), data_type=currency,
+                   format_func=get_formatted_cost),
+            Column('total', title=_('Total'), data_type=currency)])
+        self.sale_items.extend(self._get_sale_items())
+
+        self.sale_items.set_cell_data_func(self._on_sale_items__cell_data_func)
+
+    def _get_sale_items(self):
+        for item in self.model.get_items_missing_batch():
+            yield _TemporarySaleItem(item)
+
+    def _edit_item(self, item):
+        retval = run_dialog(_SaleBatchDecreaseSelectionDialog, self.wizard,
+                            store=self.store, model=item.storable,
+                            quantity=item.original_quantity,
+                            original_batches=item.batches)
+        item.batches = retval or item.batches
+        self.sale_items.update(item)
+
+        self.force_validation()
+
+    def _validation_func(self, value):
+        need_adjust_batch = any(i.need_adjust_batch for i in self.sale_items)
+        self.wizard.refresh_next(value and not need_adjust_batch)
+
+    def _update_sale_items(self):
+        for temp_item in self.sale_items:
+            sale_item = temp_item.sale_item
+            if temp_item.batches:
+                sale_item.set_batches(temp_item.batches)
+
+    #
+    #  Callbacks
+    #
+
+    def _on_sale_items__cell_data_func(self, column, renderer, obj, text):
+        if not isinstance(renderer, gtk.CellRendererText):
+            return text
+
+        # Set red to provide a visual indication for the user that
+        # the item needs to be adjusted
+        renderer.set_property('foreground', 'red')
+        renderer.set_property('foreground-set', obj.need_adjust_batch)
+
+        return text
+
+    def on_sale_items__selection_changed(self, sale_items, item):
+        self.edit_btn.set_sensitive(bool(item))
+
+    def on_sale_items__row_activated(self, sale_items, item):
+        self._edit_item(item)
+
+    def on_edit_btn__clicked(self, button):
+        item = self.sale_items.get_selected()
+        self._edit_item(item)
+
+
 class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     """ An abstract step which allows to define a salesperson, the sale's
     discount and surcharge, when it is needed.
@@ -288,14 +472,15 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     cfop_widgets = ('cfop', )
 
     def __init__(self, wizard, store, model, payment_group,
-                 invoice_model):
+                 invoice_model, previous=None):
         self.invoice_model = invoice_model
-
+        self.pm_slave = None
         self.payment_group = payment_group
 
         BaseMethodSelectionStep.__init__(self)
         marker("WizardEditorStep.__init__")
-        WizardEditorStep.__init__(self, store, wizard, model)
+        WizardEditorStep.__init__(self, store, wizard, model,
+                                  previous=previous)
 
         self._update_totals()
         self.update_discount_and_surcharge()
@@ -304,6 +489,12 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     # Private API
     #
 
+    def _get_client(self):
+        client_id = self.client.read()
+        if not client_id:
+            return None
+        return self.store.get(Client, client_id)
+
     def _update_totals(self):
         subtotal = self.wizard.get_subtotal()
         self.subtotal_lbl.update(subtotal)
@@ -315,19 +506,14 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self.cash_change_slave.update_total_sale_amount(to_pay)
         self.total_lbl.update(to_pay)
 
-    def _update_widgets(self):
-        has_client = bool(self.client.get_selected())
-        self.pm_slave.method_set_sensitive(u'store_credit', has_client)
-        self.pm_slave.method_set_sensitive(u'bill', has_client)
-
     def _fill_clients_combo(self):
         marker('Filling clients')
         # FIXME: This should not be using a normal ProxyComboEntry,
         #        we need a specialized widget that does the searching
         #        on demand.
 
-        clients = Client.get_active_clients(self.store)
-        self.client.prefill(api.for_person_combo(clients))
+        items = Client.get_active_items(self.store)
+        self.client.prefill(items)
         self.client.set_sensitive(len(self.client.get_model()))
         marker('Filled clients')
 
@@ -364,29 +550,28 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         store = api.new_store()
         client = run_person_role_dialog(ClientEditor, self.wizard, store, None)
         store.confirm(client)
-        client = self.store.fetch(client)
-        store.close()
+
         if not client:
             return
         if len(self.client) == 0:
             self._fill_clients_combo()
             return
         clients = self.client.get_model_items().values()
-        if client in clients:
+        if client.id in clients:
             if client.is_active:
-                self.client.select(client)
+                self.client.select(client.id)
             else:
                 # remove client from combo
-                self.client.select_item_by_data(client)
+                self.client.select_item_by_data(client.id)
                 iter = self.client.get_active_iter()
                 model = self.client.get_model()
                 model.remove(iter)
                 # just in case the inactive client was selected before.
                 self.client.select_item_by_position(0)
         elif client.is_active:
-            self.client.append_item(client.person.name, client)
-            self.client.select(client)
-        self._update_widgets()
+            self.client.append_item(client.person.name, client.id)
+            self.client.select(client.id)
+        store.close()
 
     #
     # Public API
@@ -398,7 +583,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         # Sale in the POS application, i.e, we should not reset the
         # discount and surcharge if they are already set (this is the
         # case when CONFIRM_SALES_ON_TILL parameter is enabled).
-        if not sysparam(self.store).CONFIRM_SALES_ON_TILL:
+        if not sysparam.get_bool('CONFIRM_SALES_ON_TILL'):
             self.model.discount_value = currency(0)
             self.model.surcharge_value = currency(0)
 
@@ -408,10 +593,6 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self.expire_date.hide()
         self.expire_label.hide()
 
-        # Hide operation nature widgets
-        self.operation_nature.hide()
-        self.nature_lbl.hide()
-
         # Hide client category widgets
         self.client_category_lbl.hide()
         self.client_category.hide()
@@ -429,7 +610,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         marker('Finished filling sales persons')
 
         marker('Read parameter')
-        if not sysparam(self.store).ACCEPT_CHANGE_SALESPERSON:
+        if not sysparam.get_bool('ACCEPT_CHANGE_SALESPERSON'):
             self.salesperson.set_sensitive(False)
         else:
             self.salesperson.grab_focus()
@@ -438,7 +619,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self._fill_transporter_combo()
         self._fill_cost_center_combo()
 
-        if sysparam(self.store).ASK_SALES_CFOP:
+        if sysparam.get_bool('ASK_SALES_CFOP'):
             self._fill_cfop_combo()
         else:
             self.cfop_lbl.hide()
@@ -473,7 +654,6 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         BaseMethodSelectionStep.post_init(self)
 
         marker('Entering post_init')
-        self.toogle_client_details()
         if self.wizard.need_create_payment():
             self.wizard.payment_group.clear_unused()
         self.register_validate_function(self._refresh_next)
@@ -489,10 +669,8 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         BaseMethodSelectionStep.setup_slaves(self)
         marker('Finished parent')
 
-        self.pm_slave.method_set_sensitive(u'store_credit',
-                                           bool(self.model.client))
-        self.pm_slave.method_set_sensitive(u'bill',
-                                           bool(self.model.client))
+        self.pm_slave.set_client(self.model.client,
+                                 total_amount=self.wizard.get_total_to_pay())
 
         marker('Setting discount')
         self.discount_slave = SaleDiscountSlave(self.store, self.model,
@@ -517,8 +695,9 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         if self.model.client:
             self.client.set_sensitive(False)
             self.create_client.set_sensitive(False)
-        if sysparam(self.store).ASK_SALES_CFOP:
+        if sysparam.get_bool('ASK_SALES_CFOP'):
             self.add_proxy(self.model, SalesPersonStep.cfop_widgets)
+        self.toogle_client_details()
         marker('Finished setting up proxies')
 
     def toogle_client_details(self):
@@ -530,28 +709,33 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     #
 
     def on_client__changed(self, entry):
+        # This gets called before setup_slaves, but we must wait until slaves
+        # are setup correctly
+        if not self.pm_slave:
+            return
         self.toogle_client_details()
-        self._update_widgets()
         self.discount_slave.update_max_discount()
+        self.pm_slave.set_client(
+            client=self._get_client(),
+            total_amount=self.wizard.get_total_to_pay())
 
-    def on_payment_method_changed(self, slave, method_name):
-        self.client.validate(force=True)
-        self._update_next_step(method_name)
+    def on_payment_method_changed(self, slave, method):
+        self.force_validation()
+        self._update_next_step(method)
 
-    def on_client__validate(self, widget, client):
-        if not client:
+    def on_client__validate(self, widget, client_id):
+        if not client_id:
             return
 
         # this is used to avoid some tests from crashing
-        if not hasattr(self, 'pm_slave'):
+        if self.pm_slave is None:
             return
 
+        client = self.store.get(Client, client_id)
         method = self.pm_slave.get_selected_method()
         try:
             client.can_purchase(method, self.model.get_total_sale_amount())
-            self.wizard.refresh_next(True)
         except SellError as e:
-            self.wizard.refresh_next(False)
             return ValidationError(e)
 
     def on_create_client__clicked(self, button):
@@ -573,9 +757,17 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self._update_totals()
         self.client.validate()
 
-    def on_notes_button__clicked(self, *args):
-        run_dialog(NoteEditor, self.wizard, self.store, self.model, 'notes',
-                   title=_("Additional Information"))
+    def on_observations_button__clicked(self, *args):
+        self.store.savepoint('before_run_notes_editor')
+
+        model = self.model.comments.order_by(SaleComment.date).first()
+        if not model:
+            model = SaleComment(store=self.store, sale=self.model,
+                                author=api.get_current_user(self.store))
+        rv = run_dialog(NoteEditor, self.wizard, self.store, model, 'comment',
+                        title=_('Sale observations'))
+        if not rv:
+            self.store.rollback_to_savepoint('before_run_notes_editor')
 
     def on_create_cfop__clicked(self, widget):
         self.store.savepoint('before_run_editor_cfop')
@@ -611,7 +803,6 @@ class ConfirmSaleWizard(BaseWizard):
     payments, fiscal data and update stock
     """
     size = (600, 400)
-    first_step = SalesPersonStep
     title = _("Sale Checkout")
     help_section = 'sale-confirm'
 
@@ -632,7 +823,6 @@ class ConfirmSaleWizard(BaseWizard):
         """
         marker('ConfirmSaleWizard')
         self._check_payment_group(model, store)
-
         self._subtotal = subtotal
         self._total_paid = total_paid
         self.model = model
@@ -640,14 +830,20 @@ class ConfirmSaleWizard(BaseWizard):
         # invoice_model is a Settable so avoid bug 4218, where more
         # than one checkout may try to use the same invoice number.
         self.invoice_model = Settable(invoice_number=None,
-                                     original_invoice=None)
-        marker('running SalesPersonStep')
-        first_step = self.first_step(self, store, model, self.payment_group,
-                                     self.invoice_model)
-        marker('finished creating SalesPersonStep')
+                                      original_invoice=None)
+
+        adjusted_batches = model.check_and_adjust_batches()
+        if not adjusted_batches:
+            first_step = ConfirmSaleBatchStep(store, self, model, None)
+        else:
+            marker('running SalesPersonStep')
+            first_step = SalesPersonStep(self, store, model, self.payment_group,
+                                         self.invoice_model)
+            marker('finished creating SalesPersonStep')
+
         BaseWizard.__init__(self, store, first_step, model)
 
-        if not sysparam(self.store).CONFIRM_SALES_ON_TILL:
+        if not sysparam.get_bool('CONFIRM_SALES_ON_TILL'):
             # This was added to allow us to work even if an error
             # happened while adding a payment, where we already order
             # but cannot confirm and are thrown back to the main
@@ -703,6 +899,14 @@ class ConfirmSaleWizard(BaseWizard):
         return self.get_total_to_pay() > 0
 
     def finish(self):
+        missing = get_missing_items(self.model, self.store)
+        if missing:
+            # We want to close the checkout, so the user will be back to the
+            # list of items in the sale.
+            self.close()
+            run_dialog(MissingItemsDialog, self, self.model, missing)
+            return False
+
         self.retval = True
         invoice_number = self.invoice_model.invoice_number
 
@@ -737,18 +941,7 @@ class ConfirmSaleWizard(BaseWizard):
         #        have a payer, we won't be able to print bills/booklets.
         group.payer = self.model.client and self.model.client.person
 
-        booklets = list(group.get_payments_by_method_name(u'store_credit'))
-        bills = list(group.get_payments_by_method_name(u'bill'))
-
-        if (booklets and
-            yesno(_("Do you want to print the booklets for this sale?"),
-                  gtk.RESPONSE_YES, _("Print booklets"), _("Don't print"))):
-            print_report(BookletReport, booklets)
-
-        if (bills and BillReport.check_printable(bills) and
-            yesno(_("Do you want to print the bills for this sale?"),
-                  gtk.RESPONSE_YES, _("Print bills"), _("Don't print"))):
-            print_report(BillReport, bills)
+        ConfirmSaleWizardFinishEvent.emit(self.model)
 
 
 def test():  # pragma nocover
