@@ -28,29 +28,33 @@ from decimal import Decimal
 
 import gtk
 from kiwi.currency import currency
-from kiwi.datatypes import ValidationError
-from kiwi.ui.widgets.list import Column
-from storm.expr import And
+from kiwi.ui.objectlist import Column
+from storm.expr import And, Eq
 
 from stoqlib.api import api
 from stoqlib.domain.costcenter import CostCenter
 from stoqlib.domain.fiscal import CfopData
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.person import Branch, Employee
-from stoqlib.domain.product import Product, ProductStockItem
+from stoqlib.domain.person import Branch, Employee, Person
+from stoqlib.domain.product import Product
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.stockdecrease import StockDecrease, StockDecreaseItem
 from stoqlib.domain.till import Till
+from stoqlib.domain.views import ProductWithStockBranchView
 from stoqlib.exceptions import TillError
+from stoqlib.lib.defaults import MAX_INT
+from stoqlib.lib.formatters import format_quantity, format_sellable_description
 from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.formatters import format_quantity
+from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.wizards import WizardEditorStep, BaseWizard
-from stoqlib.gui.editors.decreaseeditor import DecreaseItemEditor
+from stoqlib.gui.dialogs.batchselectiondialog import BatchDecreaseSelectionDialog
+from stoqlib.gui.dialogs.missingitemsdialog import (get_missing_items,
+                                                    MissingItemsDialog)
 from stoqlib.gui.events import StockDecreaseWizardFinishEvent
-from stoqlib.gui.printing import print_report
+from stoqlib.gui.utils.printing import print_report
 from stoqlib.gui.wizards.abstractwizard import SellableItemStep
 from stoqlib.gui.wizards.salewizard import PaymentMethodStep
 from stoqlib.reporting.stockdecreasereceipt import StockDecreaseReceipt
@@ -71,8 +75,8 @@ class StartStockDecreaseStep(WizardEditorStep):
                      'reason',
                      'removed_by',
                      'cfop',
-                     'cost_center'
-                     )
+                     'cost_center',
+                     'person')
 
     def _fill_employee_combo(self):
         employess = self.store.find(Employee)
@@ -81,6 +85,8 @@ class StartStockDecreaseStep(WizardEditorStep):
     def _fill_branch_combo(self):
         branches = Branch.get_active_branches(self.store)
         self.branch.prefill(api.for_person_combo(branches))
+        sync_mode = api.sysparam.get_bool('SYNCHRONIZED_MODE')
+        self.branch.set_sensitive(not sync_mode)
 
     def _fill_cfop_combo(self):
         cfops = self.store.find(CfopData)
@@ -99,14 +105,20 @@ class StartStockDecreaseStep(WizardEditorStep):
         self.cost_center.set_visible(cost_centers_exists)
         self.cost_center_lbl.set_visible(cost_centers_exists)
 
+    def _fill_person_combo(self):
+        items = Person.get_items(self.store,
+                                 Person.branch != api.get_current_branch(self.store))
+        self.person.prefill(items)
+
     def _setup_widgets(self):
         self.confirm_date.set_sensitive(False)
         self._fill_employee_combo()
         self._fill_branch_combo()
         self._fill_cfop_combo()
         self._fill_cost_center_combo()
+        self._fill_person_combo()
 
-        if not sysparam(self.store).CREATE_PAYMENTS_ON_STOCK_DECREASE:
+        if not sysparam.get_bool('CREATE_PAYMENTS_ON_STOCK_DECREASE'):
             self.create_payments.hide()
 
     #
@@ -116,7 +128,8 @@ class StartStockDecreaseStep(WizardEditorStep):
     def post_init(self):
         self.confirm_date.grab_focus()
         self.table1.set_focus_chain([self.confirm_date, self.branch,
-                                     self.removed_by, self.reason, self.cfop])
+                                     self.removed_by, self.reason, self.cfop,
+                                     self.person])
         self.register_validate_function(self.wizard.refresh_next)
         self.force_validation()
 
@@ -149,62 +162,65 @@ class DecreaseItemStep(SellableItemStep):
     """ Wizard step for purchase order's items selection """
     model_type = StockDecrease
     item_table = StockDecreaseItem
+    sellable_view = ProductWithStockBranchView
     summary_label_text = "<b>%s</b>" % api.escape(_('Total Ordered:'))
     summary_label_column = None
     sellable_editable = False
-    item_editor = DecreaseItemEditor
+    validate_stock = True
+    batch_selection_dialog = BatchDecreaseSelectionDialog
 
     #
-    # Helper methods
+    # SellableItemStep
     #
 
+    def post_init(self):
+        self.hide_add_button()
+        self.hide_edit_button()
+        if not self.wizard.create_payments:
+            self.cost_label.hide()
+            # Since the model is set to None, we need to remove cost from the
+            # proxy or when hiding it an AttributeError will be raised
+            self.proxy.remove_widget('cost')
+            self.cost.hide()
+            self.cost.update(0)
+
+        self.slave.klist.connect('cell-editing-started',
+                                 self._on_klist__cell_editing_started)
+
+        super(DecreaseItemStep, self).post_init()
+
     def get_sellable_view_query(self):
         branch = self.model.branch
-        branch_query = ProductStockItem.branch_id == branch.id
+        branch_query = self.sellable_view.branch_id == branch.id
         # The stock quantity of consigned products can not be
         # decreased manually. See bug 5212.
         query = And(branch_query,
-                    Product.consignment == False,
+                    Eq(Product.consignment, False),
                     Sellable.get_available_sellables_query(self.store))
         return self.sellable_view, query
 
-    def setup_slaves(self):
-        SellableItemStep.setup_slaves(self)
-        self.hide_add_button()
-
-        if not self.wizard.create_payments:
-            self.cost_label.hide()
-            self.cost.hide()
-        self.quantity.connect('validate', self._on_quantity__validate)
-
-    #
-    # SellableItemStep virtual methods
-    #
-
-    def validate(self, value):
-        SellableItemStep.validate(self, value)
-        can_decrease = self.model.get_items().count()
-        self.wizard.refresh_next(value and can_decrease)
-
-    def get_order_item(self, sellable, cost, quantity):
-        item = self.model.add_sellable(sellable, cost, quantity)
-        return item
+    def get_order_item(self, sellable, cost, quantity, batch=None):
+        return self.model.add_sellable(sellable, cost, quantity, batch=batch)
 
     def get_saved_items(self):
-        return list(self.model.get_items())
+        return self.model.get_items()
 
     def get_columns(self):
+        adjustment = gtk.Adjustment(lower=0, upper=MAX_INT,
+                                    step_incr=1, page_incr=10)
         columns = [
-            Column('sellable.code', title=_('Code'), width=100, data_type=str),
+            Column('sellable.code', title=_('Code'), data_type=str),
             Column('sellable.description', title=_('Description'),
-                   data_type=str, expand=True, searchable=True),
+                   data_type=str, expand=True, searchable=True,
+                   format_func=self._format_description, format_func_data=True),
             Column('sellable.category_description', title=_('Category'),
                    data_type=str, expand=True, searchable=True),
-            Column('quantity', title=_('Quantity'), data_type=float, width=90,
+            Column('quantity', title=_('Quantity'), data_type=Decimal,
+                   editable=True, spin_adjustment=adjustment,
                    format_func=format_quantity),
             Column('sellable.unit_description', title=_('Unit'), data_type=str,
                    width=70),
-            ]
+        ]
 
         if self.wizard.create_payments:
             columns.extend([
@@ -214,10 +230,6 @@ class DecreaseItemStep(SellableItemStep):
 
         return columns
 
-    #
-    # WizardStep hooks
-    #
-
     def has_next_step(self):
         return self.wizard.create_payments
 
@@ -231,28 +243,32 @@ class DecreaseItemStep(SellableItemStep):
                                  PaymentMethod.get_by_name(self.store, u'multiple'),
                                  finish_on_total=False)
 
+    def validate(self, value):
+        for item in self.model.get_items():
+            if item.quantity == 0:
+                value = False
+                break
+
+        super(DecreaseItemStep, self).validate(value)
+
+    #
+    # Private
+    #
+
+    def _format_description(self, item, data):
+        return format_sellable_description(item.sellable, item.batch)
+
     #
     # Callbacks
     #
 
-    def _on_quantity__validate(self, widget, value):
-        sellable = self.proxy.model.sellable
-        if not sellable:
-            return
-
-        if not value or value <= Decimal(0):
-            return ValidationError(_(u'Quantity must be greater than zero'))
-
-        storable = sellable.product_storable
-        assert storable
-        balance = storable.get_balance_for_branch(branch=self.model.branch)
-        for i in self.slave.klist:
-            if i.sellable == sellable:
-                balance -= i.quantity
-
-        if value > balance:
-            return ValidationError(
-                _(u'Quantity is greater than the quantity in stock.'))
+    def _on_klist__cell_editing_started(self, klist, obj, attr,
+                                        renderer, editable):
+        if attr == 'quantity':
+            adjustment = editable.get_adjustment()
+            remaining_quantity = self.get_remaining_quantity(obj.sellable,
+                                                             obj.batch)
+            adjustment.set_upper(obj.quantity + remaining_quantity)
 
 
 class StockDecreaseWizard(BaseWizard):
@@ -270,12 +286,12 @@ class StockDecreaseWizard(BaseWizard):
         branch = api.get_current_branch(store)
         user = api.get_current_user(store)
         employee = user.person.employee
-        cfop = sysparam(store).DEFAULT_STOCK_DECREASE_CFOP
+        cfop_id = sysparam.get_object_id('DEFAULT_STOCK_DECREASE_CFOP')
         return StockDecrease(responsible=user,
                              removed_by=employee,
                              branch=branch,
                              status=StockDecrease.STATUS_INITIAL,
-                             cfop=cfop,
+                             cfop_id=cfop_id,
                              store=store)
 
     def _receipt_dialog(self):
@@ -283,15 +299,22 @@ class StockDecreaseWizard(BaseWizard):
         if yesno(msg, gtk.RESPONSE_YES,
                  _("Print receipt"), _("Don't print")):
             print_report(StockDecreaseReceipt, self.model)
-        return
 
     #
     # WizardStep hooks
     #
 
     def finish(self):
+        missing = get_missing_items(self.model, self.store)
+        if missing:
+            run_dialog(MissingItemsDialog, self, self.model, missing)
+            return False
+
         self.retval = self.model
         self.model.confirm()
         self.close()
+
+        # Commit before printing to avoid losing data if something breaks
+        self.store.confirm(self.retval)
         StockDecreaseWizardFinishEvent.emit(self.model)
         self._receipt_dialog()
