@@ -45,6 +45,8 @@ class BranchImporter(CSVImporter):
               'postal_code',
               ]
 
+    branches = []
+
     def process_one(self, data, fields, store):
         person = Person(
             store=store,
@@ -71,20 +73,19 @@ class BranchImporter(CSVImporter):
             streetnumber=streetnumber,
             district=data.district,
             postal_code=data.postal_code
-            )
+        )
 
         branch = Branch(person=person, store=store)
         for user in store.find(LoginUser):
             user.add_access_to(branch)
+        self.branches.append(branch)
 
     def when_done(self, store):
-        sparam = sysparam(store)
-        if sparam.MAIN_COMPANY:
+        if sysparam.has_object('MAIN_COMPANY'):
             return
 
-        branch = store.find(Branch).order_by(Branch.id)
-        if not branch.count():
+        if not self.branches:
             return
 
-        sparam.MAIN_COMPANY = branch[0].id
-        assert sparam.MAIN_COMPANY
+        sysparam.set_object(store, 'MAIN_COMPANY', self.branches[0])
+        assert sysparam.has_object('MAIN_COMPANY')
