@@ -33,6 +33,7 @@ import time
 
 from stoqlib.database.runtime import new_store
 from stoqlib.importers.importer import Importer
+from stoqlib.lib.dateutils import localdate
 
 
 class CSVRow(object):
@@ -41,7 +42,7 @@ class CSVRow(object):
     def __init__(self, item, field_names):
         self.fields = []
         for i, field in enumerate(item):
-            #XXX: we expect to receive unicode data
+            # XXX: we expect to receive unicode data
             setattr(self, field_names[i], unicode(field, 'utf-8'))
             self.fields.append(field_names[i])
 
@@ -93,44 +94,50 @@ class CSVImporter(Importer):
         if len(item) < len(self.fields):
             raise ValueError(
                 "line %d in file %s has %d fields, but we need at "
-                "least %d fields to be able to process it" % (
-                self.lineno, self.filename, len(item), len(self.fields)))
+                "least %d fields to be able to process it" % (self.lineno,
+                                                              self.filename,
+                                                              len(item),
+                                                              len(self.fields)))
 
         field_names = self.fields + self.optional_fields
         if len(item) > len(field_names):
             raise ValueError(
                 "line %d in file %s has %d fields, but we can at most "
-                "handle %d fields, fields=%r" % (
-                self.lineno, self.filename, len(item), len(field_names), item))
+                "handle %d fields, fields=%r" % (self.lineno,
+                                                 self.filename,
+                                                 len(item),
+                                                 len(field_names),
+                                                 item))
 
         row = CSVRow(item, field_names)
         try:
             self.process_one(row, row.fields, store)
         except Exception:
-            print
-            print 'Error while processing row %d %r' % (self.lineno, row, )
-            print
+            print()
+            print('Error while processing row %d %r' % (self.lineno, row, ))
+            print()
             raise
 
         if self.items != -1:
             if self.lineno % self.items == 0:
                 t2 = time.time()
-                print '%s Imported %d entries in %2.2f sec total=%d' % (
+                print('%s Imported %d entries in %2.2f sec total=%d' % (
                     datetime.datetime.now().strftime('%T'), self.items,
-                    t2 - t, self.lineno)
+                    t2 - t, self.lineno))
                 t = t2
 
         self.lineno += 1
         return True
 
     def parse_date(self, data):
-        return datetime.datetime(*map(int, data.split('-')))
+        return localdate(*map(int, data.split('-')))
 
     def parse_multi(self, domain_class, field, store):
         if field == '*':
             field_values = store.find(domain_class)
         else:
-            field_values = [domain_class.get(int(field_id), store=store)
+            items = store.find(domain_class).order_by(domain_class.te_id)
+            field_values = [items[int(field_id) - 1]
                             for field_id in field.split('|')]
         return field_values
 
