@@ -29,16 +29,15 @@ OFX importing
 
 import datetime
 import decimal
+import logging
 import sgmllib
 
-from kiwi.log import Logger
-
 from stoqlib.domain.account import Account, AccountTransaction
 from stoqlib.importers.importer import Importer
 from stoqlib.lib.parameters import sysparam
 
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class OFXTagParser(sgmllib.SGMLParser):
@@ -163,10 +162,10 @@ class OFXImporter(Importer):
             account = Account(description=self.get_account_id(),
                               code=unicode(self.tp.account_id),
                               account_type=Account.TYPE_BANK,
-                              parent=sysparam(store).BANKS_ACCOUNT,
+                              parent=sysparam.get_object(store, 'BANKS_ACCOUNT'),
                               store=store)
         self.account_id = account.id
-        self.source_account_id = sysparam(store).IMBALANCE_ACCOUNT.id
+        self.source_account_id = sysparam.get_object_id('IMBALANCE_ACCOUNT')
         self.skipped = 0
 
     def get_n_items(self):
@@ -183,7 +182,7 @@ class OFXImporter(Importer):
         value = self._parse_number(t['trnamt'])
         if value == 0:
             self.skipped += 1
-            # We can't import transactions with a value = 0, skip it.
+            # We can't import transactions without a value = 0, skip it.
             return False
         source_account = store.get(Account, self.source_account_id)
         account = store.get(Account, self.account_id)
@@ -213,7 +212,7 @@ class OFXImporter(Importer):
     def get_account_id(self):
         if self.tp.fi:
             return u'%s - %s' % (self.tp.fi['org'],
-                                self.tp.account_type)
+                                 self.tp.account_type)
         return unicode(self.tp.account_type)
 
 if __name__ == '__main__':  # pragma nocover
