@@ -52,7 +52,7 @@ class ProductImporter(CSVImporter):
 
     optional_fields = [
         'unit',
-        ]
+    ]
 
     def __init__(self):
         super(ProductImporter, self).__init__()
@@ -67,7 +67,9 @@ class ProductImporter(CSVImporter):
         for unit in default_store.find(SellableUnit):
             self.units[unit.description] = unit
 
-        self.tax_constant = sysparam(default_store).DEFAULT_PRODUCT_TAX_CONSTANT
+        self.tax_constant_id = sysparam.get_object_id(
+            'DEFAULT_PRODUCT_TAX_CONSTANT')
+        self._code = 1
 
     def _get_or_create(self, table, store, **attributes):
         obj = store.find(table, **attributes).one()
@@ -101,12 +103,14 @@ class ProductImporter(CSVImporter):
                             category=category,
                             description=data.description,
                             price=int(data.price))
-        sellable.barcode = sellable.code = data.barcode
+        sellable.barcode = data.barcode
+        sellable.code = u'%02d' % self._code
+        self._code += 1
         if u'unit' in fields:
             if not data.unit in self.units:
                 raise ValueError(u"invalid unit: %s" % data.unit)
             sellable.unit = store.fetch(self.units[data.unit])
-        sellable.tax_constant = store.fetch(self.tax_constant)
+        sellable.tax_constant_id = self.tax_constant_id
 
         product = Product(sellable=sellable, store=store)
 
