@@ -27,6 +27,7 @@ from stoqlib.database.runtime import get_current_user
 from stoqlib.domain.person import Person
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod
+from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseItem
 from stoqlib.domain.receiving import ReceivingOrder, ReceivingOrderItem
 from stoqlib.domain.sellable import Sellable
@@ -40,7 +41,7 @@ class PurchaseImporter(CSVImporter):
               'user_name',
               'payment_method',
               'due_date',
-              'sellable_list', # ids separated by | or * for all
+              'sellable_list',  # ids separated by | or * for all
               'invoice',
               'quantity']
 
@@ -88,17 +89,18 @@ class PurchaseImporter(CSVImporter):
                          order=purchase)
 
         method = PaymentMethod.get_by_name(store, data.payment_method)
-        method.create_outpayment(purchase.group, branch, purchase.get_purchase_total(),
-                                 self.parse_date(data.due_date))
+        method.create_payment(Payment.TYPE_OUT, purchase.group, branch,
+                              purchase.purchase_total,
+                              self.parse_date(data.due_date))
         purchase.confirm()
 
-        receiving_order = ReceivingOrder(purchase=purchase,
-                                         responsible=login_user,
+        receiving_order = ReceivingOrder(responsible=login_user,
                                          supplier=supplier,
                                          invoice_number=int(data.invoice),
                                          transporter=transporter,
                                          branch=branch,
                                          store=store)
+        receiving_order.add_purchase(purchase)
 
         for purchase_item in purchase.get_items():
             ReceivingOrderItem(
@@ -108,5 +110,5 @@ class PurchaseImporter(CSVImporter):
                 quantity=int(data.quantity),
                 purchase_item=purchase_item,
                 receiving_order=receiving_order
-                )
+            )
         receiving_order.confirm()
