@@ -25,9 +25,9 @@
 
 import datetime
 from decimal import Decimal
+import logging
 
 from kiwi.environ import environ
-from kiwi.log import Logger
 
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.algorithms import (modulo10,
@@ -35,7 +35,7 @@ from stoqlib.lib.algorithms import (modulo10,
                                     calculaDuploDigito)
 
 _ = stoqlib_gettext
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 (BILL_OPTION_BANK_BRANCH,
@@ -181,56 +181,58 @@ class BankInfo(object):
     agencia = custom_property('agencia', 4)
     conta = custom_property('conta', 7)
 
-    def _get_valor(self):
+    @property
+    def valor(self):
         try:
             return "%.2f" % self._valor
         except AttributeError:
             pass
 
-    def _set_valor(self, val):
+    @valor.setter
+    def valor(self, val):
         if type(val) is Decimal:
             self._valor = val
         else:
             self._valor = Decimal(str(val), 2)
-    valor = property(_get_valor, _set_valor)
 
-    def _get_valor_documento(self):
+    @property
+    def valor_documento(self):
         try:
             return "%.2f" % self._valor_documento
         except AttributeError:
             pass
 
-    def _set_valor_documento(self, val):
+    @valor_documento.setter
+    def valor_documento(self, val):
         if type(val) is Decimal:
             self._valor_documento = val
         else:
             self._valor_documento = Decimal(str(val), 2)
-    valor_documento = property(
-        _get_valor_documento,
-        _set_valor_documento
-    )
 
-    def _instrucoes_get(self):
+    @property
+    def instrucoes(self):
         try:
             return self._instrucoes
         except AttributeError:
             pass
 
-    def _instrucoes_set(self, list_inst):
+    @instrucoes.setter
+    def instrucoes(self, list_inst):
         self._instrucoes = list_inst
-    instrucoes = property(_instrucoes_get, _instrucoes_set)
 
-    def _demonstrativo_get(self):
+    @property
+    def demonstrativo(self):
         try:
             return self._demonstrativo
         except AttributeError:
             pass
 
-    def _demonstrativo_set(self, list_dem):
+    @demonstrativo.setter
+    def demonstrativo(self, list_dem):
         self._demonstrativo = list_dem
-    demonstrativo = property(_demonstrativo_get, _demonstrativo_set)
 
-    def _sacado_get(self):
+    @property
+    def sacado(self):
         if not hasattr(self, '_sacado'):
             self.sacado = [
                 self.sacado_nome,
@@ -244,14 +246,14 @@ class BankInfo(object):
             ]
         return self._sacado
 
-    def _sacado_set(self, list_sacado):
+    @sacado.setter
+    def sacado(self, list_sacado):
         # Just get 3 lines
         list_sacado = list_sacado[:3]
         for i, line in enumerate(list_sacado):
             # Just get the first 80 characters
             list_sacado[i] = list_sacado[i][:80]
         self._sacado = list_sacado
-    sacado = property(_sacado_get, _sacado_set)
 
     @property
     def fator_vencimento(self):
@@ -338,8 +340,8 @@ class BankInfo(object):
                 if ret == 0:
                     pass
                 elif (ret is not None and
-                    str(ret) != dv.lower() and
-                    ret < 10):
+                      str(ret) != dv.lower() and
+                      ret < 10):
                     raise BoletoException(_('Invalid verifier digit'))
             else:
                 try:
@@ -395,7 +397,8 @@ class BankBanrisul(BankInfo):
     bank_number = 41
     logo = 'logo_banrisul.jpg'
     options = {u'agencia': BILL_OPTION_BANK_BRANCH,
-               u'conta': BILL_OPTION_BANK_BRANCH}
+               u'conta': BILL_OPTION_BANK_BRANCH,
+               u'especie_documento': BILL_OPTION_CUSTOM}
 
     nosso_numero = custom_property('nosso_numero', 8)
     conta = custom_property('conta', 6)
@@ -419,6 +422,7 @@ class BankBradesco(BankInfo):
     logo = "logo_bancobradesco.jpg"
 
     options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'especie_documento': BILL_OPTION_CUSTOM,
                u'agencia': BILL_OPTION_BANK_BRANCH,
                u'conta': BILL_OPTION_BANK_BRANCH}
 
@@ -485,7 +489,8 @@ class BankBB(BankInfo):
     logo = 'logo_bb.gif'
     options = {u'convenio': BILL_OPTION_CUSTOM,
                u'agencia': BILL_OPTION_BANK_BRANCH,
-               u'conta': BILL_OPTION_BANK_BRANCH}
+               u'conta': BILL_OPTION_BANK_BRANCH,
+               u'especie_documento': BILL_OPTION_CUSTOM}
 
     validate_field_func = 'modulo11'
     validate_field_dv_10 = 'x'
@@ -516,10 +521,13 @@ class BankBB(BankInfo):
         )
 
     # Nosso numero (sem dv) sao 11 digitos
-    def _get_nosso_numero(self):
+
+    @property
+    def nosso_numero(self):
         return self.convenio + self._nosso_numero
 
-    def _set_nosso_numero(self, val):
+    @nosso_numero.setter
+    def nosso_numero(self, val):
         val = str(val)
         if self.len_convenio == 4:
             nn = val.zfill(7)
@@ -534,14 +542,13 @@ class BankBB(BankInfo):
             nn = val.zfill(9)
         self._nosso_numero = nn
 
-    nosso_numero = property(_get_nosso_numero, _set_nosso_numero)
-
-    def _get_convenio(self):
+    @property
+    def convenio(self):
         return self._convenio
 
-    def _set_convenio(self, val):
+    @convenio.setter
+    def convenio(self, val):
         self._convenio = str(val).ljust(self.len_convenio, '0')
-    convenio = property(_get_convenio, _set_convenio)
 
     @property
     def agencia_conta(self):
@@ -599,23 +606,23 @@ class BankCaixa(BankInfo):
     bank_number = 104
     logo = 'logo_bancocaixa.jpg'
     options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'especie_documento': BILL_OPTION_CUSTOM,
                u'agencia': BILL_OPTION_BANK_BRANCH,
                u'conta': BILL_OPTION_BANK_BRANCH}
 
     inicio_nosso_numero = '80'
 
     # Nosso numero (sem dv) sao 10 digitos
-    def _nosso_numero_get(self):
+    @property
+    def nosso_numero(self):
+        '''Nosso Número sem DV, máximo 8 chars'''
         return self._nosso_numero
-    '''
-        Nosso Número sem DV, máximo 8 chars
-    '''
-    def _nosso_numero_set(self, val):
+
+    @nosso_numero.setter
+    def nosso_numero(self, val):
         self._nosso_numero = (self.inicio_nosso_numero +
                               self.formata_numero(val, 8))
 
-    nosso_numero = property(_nosso_numero_get, _nosso_numero_set)
-
     @property
     def dv_nosso_numero(self):
         resto2 = modulo11(self.nosso_numero.split('-')[0], 9, 1)
@@ -641,6 +648,7 @@ class BankItau(BankInfo):
     bank_number = 341
     logo = 'logo_itau.gif'
     options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'especie_documento': BILL_OPTION_CUSTOM,
                u'agencia': BILL_OPTION_BANK_BRANCH,
                u'conta': BILL_OPTION_BANK_BRANCH}
 
@@ -691,6 +699,7 @@ class BankReal(BankInfo):
     bank_number = 356
     logo = 'logo_bancoreal.jpg'
     options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'especie_documento': BILL_OPTION_CUSTOM,
                u'agencia': BILL_OPTION_BANK_BRANCH,
                u'conta': BILL_OPTION_BANK_BRANCH}
 
@@ -721,6 +730,7 @@ class BankSantander(BankInfo):
     bank_number = 33
     logo = 'logo_santander.jpg'
     options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'especie_documento': BILL_OPTION_CUSTOM,
                u'agencia': BILL_OPTION_BANK_BRANCH,
                u'conta': BILL_OPTION_BANK_BRANCH}
 
