@@ -27,7 +27,6 @@ import binascii
 from ConfigParser import SafeConfigParser
 import os
 
-from kiwi.component import provide_utility
 from stoqlib.lib.interfaces import IStoqConfig
 from stoqlib.lib.osutils import get_application_dir
 from stoqlib.lib.translation import stoqlib_gettext as _
@@ -56,13 +55,6 @@ class StoqConfig:
         self._config.read(filename)
         return True
 
-    def _get_password(self, filename):
-        if not os.path.exists(filename):
-            return
-
-        data = open(filename).read()
-        return binascii.a2b_base64(data)
-
     #
     # Public API
     #
@@ -104,7 +96,6 @@ class StoqConfig:
         self.set('Database', 'address', settings.address)
         self.set('Database', 'port', str(settings.port))
         self.set('Database', 'dbname', settings.dbname)
-        self.set('Database', 'testdb', settings.dbname)
         self.set('Database', 'dbusername', settings.username)
         if settings.password:
             self.store_password(settings.password)
@@ -129,9 +120,6 @@ class StoqConfig:
     def get_config_directory(self):
         return os.path.join(get_application_dir(self.domain))
 
-    def use_test_database(self):
-        self.set('Database', 'dbname', self.get('Database', 'testdb'))
-
     def store_password(self, password):
         configdir = self.get_config_directory()
         datafile = os.path.join(configdir, 'data')
@@ -140,7 +128,7 @@ class StoqConfig:
                 try:
                     os.makedirs(configdir)
                     os.chmod(configdir, 0700)
-                except OSError, e:
+                except OSError as e:
                     if e.errno == 13:
                         raise FilePermissionError(
                             "Could not " % configdir)
@@ -148,7 +136,7 @@ class StoqConfig:
 
         try:
             fd = open(datafile, "w")
-        except OSError, e:
+        except OSError as e:
             if e.errno == 13:
                 raise FilePermissionError("%s is not writable" % datafile)
             raise
@@ -158,14 +146,6 @@ class StoqConfig:
         fd.write(binascii.b2a_base64(password))
         fd.close()
 
-    def get_password(self):
-        """
-        :returns: password or None if it is not set
-        """
-        configdir = self.get_config_directory()
-        data_file = os.path.join(configdir, 'data')
-        return self._get_password(data_file)
-
     def get_settings(self):
         if self._settings:
             return self._settings
@@ -177,7 +157,6 @@ class StoqConfig:
         port = self.get('Database', 'port')
         if port:
             port = int(port)
-        password = self.get_password()
 
         database_section = self.get('General', 'database_section')
         if database_section is not None:
@@ -195,7 +174,7 @@ class StoqConfig:
         db_settings.port = port or db_settings.port
         db_settings.dbname = dbname or db_settings.dbname
         db_settings.username = username or db_settings.username
-        db_settings.password = password or db_settings.password
+        db_settings.password = db_settings.password
         return db_settings
 
     def set_from_options(self, options):
@@ -256,6 +235,7 @@ class StoqConfig:
 
 
 def register_config(config):
+    from kiwi.component import provide_utility
     global _config
     _config = config
 
@@ -263,7 +243,7 @@ def register_config(config):
         provide_utility(IStoqConfig, config, replace=True)
     except NoConfigurationError:
         msg = _(u"Error: Stoq configuration is not avaiable. Check that the "
-             "current user has a configuration file (~/.stoq/stoq.conf).")
+                "current user has a configuration file (~/.stoq/stoq.conf).")
         if os.geteuid() == 0:
             msg += _('\n\nYou are running stoq using sudo. That is not '
                      'recommended.')
@@ -271,5 +251,4 @@ def register_config(config):
 
 
 def get_config():
-    global _config
     return _config
