@@ -36,6 +36,11 @@ from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
+#: The max int for 32bits. Should be used instead of sys.maxint since
+#: it will be different depending on the cpu's architecture
+#: http://en.wikipedia.org/wiki/2147483647
+MAX_INT = (1 << 31) - 1
+
 MINIMUM_PASSWORD_CHAR_LEN = 6
 
 #
@@ -94,9 +99,9 @@ def get_weekday_start():
         process.close()
 
         # we will set week_1sday based on the dateutil.relativedelta.weekday mapping
-        if week_origin == '19971130': # Sunday
+        if week_origin == '19971130':  # Sunday
             week_1stday = 6
-        elif week_origin == '19971201': # Monday
+        elif week_origin == '19971201':  # Monday
             week_1stday = 0
         else:
             raise TypeError('Unknown NL_TIME_WEEK_1STDAY constant')
@@ -131,8 +136,8 @@ ALL_BRANCHES = _('All branches'), ALL_ITEMS_INDEX
 
 
 def _split_parts(a):
-    parts = re.findall('(\d+|\D+)', a)
-    for i in xrange(len(parts)):
+    parts = re.findall(r'(\d+|\D+)', a)
+    for i in range(len(parts)):
         try:
             parts[i] = int(parts[i])
         except:
