@@ -25,7 +25,6 @@ import re
 
 from kiwi.currency import format_price
 
-from stoqlib.database.runtime import get_default_store
 from stoqlib.l10n.l10n import get_l10n_field
 from stoqlib.lib.cardinals.cardinals import get_cardinal_function
 from stoqlib.lib.translation import stoqlib_gettext
@@ -60,8 +59,7 @@ def get_price_format_str():
 
 def get_price_as_cardinal(value):
     function = get_cardinal_function('to_words_as_money')
-    currency_names = get_l10n_field(get_default_store(),
-                                    'currency_names')
+    currency_names = get_l10n_field('currency_names')
     return function(value, currency_names)
 
 
@@ -72,7 +70,7 @@ def get_formatted_price(float_value, symbol=True, precision=DECIMAL_PRECISION):
 
 def get_formatted_cost(float_value, symbol=True):
     from stoqlib.lib.parameters import sysparam
-    precision = sysparam(get_default_store()).COST_PRECISION_DIGITS
+    precision = sysparam.get_int('COST_PRECISION_DIGITS')
     return get_formatted_price(float_value, symbol=symbol,
                                precision=precision)
 
@@ -91,8 +89,7 @@ def get_full_date(date):
       January 01, 2012
 
     """
-    full_date_format = get_l10n_field(get_default_store(),
-                                      "full_date_format")
+    full_date_format = get_l10n_field("full_date_format")
     return date.strftime(full_date_format)
 
 
@@ -118,7 +115,8 @@ def format_phone_number(phone_number):
     elif digits == 8:
         return '%s-%s' % (phone[:4], phone[4:8])
     elif digits == 9:
-        return '(%s) %s-%s' % (phone[:2], phone[2:5], phone[5:9])
+        # This is for the new mobile numbers with 9 digits
+        return '%s-%s' % (phone[:5], phone[5:9])
     elif digits == 10:
         # 0[3589]00 XXX-XXX
         if phone[:4] in ['0300', '0500', '0800', '0900']:
@@ -158,3 +156,31 @@ def format_postal_code(postal_code):
     postal_code = raw_postal_code(postal_code)
     return "%s-%s" % (postal_code[:5],
                       postal_code[5:8])
+
+
+#
+#  Sellable formatters
+#
+
+
+def format_sellable_description(sellable, batch=None):
+    """Gets the formatted description for *sellable*
+
+    If batch is ``None``, the description will be the same as
+    *sellable.get_description()*. But if is given, it's number will
+    be appended to the description, like::
+
+        Normal description:
+
+            "Cellphone"
+
+        With batch information:
+
+            "Cellphone [Batch: 123456]"
+
+    """
+    description = sellable.get_description()
+    if batch is None:
+        return description
+
+    return u'%s [%s: %s]' % (description, _("Batch"), batch.batch_number)
