@@ -38,7 +38,7 @@ def _get_xdg_dir(envname, default):
     filename = os.path.expanduser("~/.config/user-dirs.dirs")
     try:
         f = open(filename)
-    except IOError, e:
+    except IOError as e:
         if e.errno == errno.ENOENT:
             return default
     for line in f:
@@ -59,7 +59,7 @@ def get_application_dir(appname="stoq"):
         appdir = os.path.join(os.environ['APPDATA'], appname)
     elif _system == 'Darwin':
         appdir = os.path.join(os.environ['HOME'], 'Library',
-            'Application Support', 'Stoq')
+                              'Application Support', 'Stoq')
     else:
         raise SystemExit("unknown system: %s" % (_system, ))
     if not os.path.exists(appdir):
@@ -113,7 +113,7 @@ def read_registry_key(root, key, value):
         k = _winreg.OpenKey(root, key)
         reg_value, key_type = _winreg.QueryValueEx(k, value)
     except exceptions.WindowsError:
-        #log.info('Error while reading %s/%s/%s: %r' % (root, k, value, e))
+        # log.info('Error while reading %s/%s/%s: %r' % (root, k, value, e))
         return None
     return reg_value
 
@@ -173,7 +173,7 @@ def get_product_key():
         filename = os.path.join(app_dir, "product_key")
         try:
             return open(filename).read()
-        except IOError, e:
+        except IOError as e:
             if e.errno != errno.ENOENT:
                 raise
         return None
