@@ -22,13 +22,15 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import imp
+import glob
+import logging
 import os
+import sys
+from zipfile import ZipFile, is_zipfile
 
 from kiwi.desktopparser import DesktopParser
 from kiwi.component import get_utility, provide_utility
-from kiwi.log import Logger
-from zope.interface import implements
+from zope.interface import implementer
 
 from stoqlib.database.runtime import get_default_store, new_store
 from stoqlib.database.exceptions import SQLError
@@ -39,7 +41,7 @@ from stoqlib.lib.interfaces import IPlugin, IPluginManager
 from stoqlib.lib.osutils import get_system_locale
 from stoqlib.lib.settings import get_settings
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class PluginError(Exception):
@@ -47,8 +49,23 @@ class PluginError(Exception):
 
 
 class PluginDescription(object):
-    def __init__(self, config, filename):
-        self.name = unicode(os.path.basename(os.path.dirname(filename)))
+    def __init__(self, filename, is_egg=False):
+        config = DesktopParser()
+        if is_egg:
+            self.plugin_path = filename
+            msg = "%s is not a valid egg file" % filename
+            assert is_zipfile(filename), msg
+            with ZipFile(filename, "r") as egg:
+                filename = [f for f in egg.namelist()
+                            if f.endswith('plugin')][0]
+                plugin_file = egg.open(filename)
+                config.readfp(plugin_file)
+        else:
+            plugin_path = os.path.dirname(os.path.dirname(filename))
+            self.plugin_path = plugin_path
+            config.read(filename)
+
+        self.name = unicode(os.path.basename(filename).split('.')[0])
         self.entry = config.get('Plugin', 'Module')
         self.filename = filename
 
@@ -65,6 +82,7 @@ class PluginDescription(object):
         return os.path.dirname(self.filename)
 
 
+@implementer(IPluginManager)
 class PluginManager(object):
     """A class responsible for administrating plugins
 
@@ -73,8 +91,6 @@ class PluginManager(object):
     @important: Never instantialize this class. Always use
     """
 
-    implements(IPluginManager)
-
     def __init__(self):
         self._plugins = {}
         self._active_plugins = {}
@@ -89,7 +105,7 @@ class PluginManager(object):
     @property
     def available_plugins_names(self):
         """A list of names of all available plugins"""
-        return self._plugin_descriptions.keys()
+        return list(self._plugin_descriptions.keys())
 
     @property
     def installed_plugins_names(self):
@@ -97,13 +113,10 @@ class PluginManager(object):
         default_store = get_default_store()
         return [p.plugin_name for p in default_store.find(InstalledPlugin)]
 
-    def get_description_by_name(self, plugin_name):
-        return self._plugin_descriptions.get(plugin_name)
-
     @property
     def active_plugins_names(self):
         """A list of names of all active plugins"""
-        return self._active_plugins.keys()
+        return list(self._active_plugins.keys())
 
     #
     # Private
@@ -111,31 +124,26 @@ class PluginManager(object):
 
     def _read_plugin_descriptions(self):
         for path in library.get_resource_paths('plugin'):
-            for dirname in os.listdir(path):
-                if dirname == '.svn':
-                    continue
-                plugindir = os.path.join(path, dirname)
-                if not os.path.isdir(plugindir):
-                    continue
-                filename = os.path.join(plugindir, dirname + '.plugin')
-                if not os.path.exists(filename):
-                    continue
+            for filename in glob.iglob(os.path.join(path, '*', '*.plugin')):
                 self._register_plugin_description(filename)
+            for filename in glob.iglob(os.path.join(path, '*.egg')):
+                self._register_plugin_description(filename, is_egg=True)
 
-    def _register_plugin_description(self, filename):
-        dp = DesktopParser()
-        dp.read(filename)
-        desc = PluginDescription(dp, filename)
+    def _register_plugin_description(self, filename, is_egg=False):
+        desc = PluginDescription(filename, is_egg)
         self._plugin_descriptions[desc.name] = desc
 
     def _import_plugin(self, plugin_desc):
-        plugin_name = plugin_desc.name
-        fp, pathname, description = imp.find_module(plugin_desc.entry,
-                                                    [plugin_desc.dirname])
-        log.info("Loading plugin %s" % (plugin_name, ))
-        imp.load_module(plugin_name, fp, pathname, description)
+        log.info("Loading plugin %s" % (plugin_desc.name, ))
+        plugin_path = plugin_desc.plugin_path
+        if plugin_path not in sys.path:
+            sys.path.append(plugin_path)
 
-        assert plugin_name in self._plugins
+        # FIXME: Use setuptools entry points when we can
+        __import__(os.path.basename(plugin_desc.dirname), globals(), locals(),
+                   [plugin_desc.entry])
+
+        assert plugin_desc.name in self._plugins
 
     #
     # Public API
@@ -155,6 +163,13 @@ class PluginManager(object):
 
         return self._plugins[plugin_name]
 
+    def get_description_by_name(self, plugin_name):
+        """Returns the plugin's description given a plugin's name
+
+        :returns: the :class:`PluginDescription` for the plugin
+        """
+        return self._plugin_descriptions.get(plugin_name)
+
     def register_plugin(self, plugin):
         """Registers a plugin on manager
 
@@ -171,6 +186,11 @@ class PluginManager(object):
                             "interface" % (plugin, ))
         self._plugins[plugin.name] = plugin
 
+        if library.uninstalled:
+            gladedir = os.path.join('plugins', plugin.name, 'glade')
+            if os.path.exists(gladedir):
+                library.add_global_resource('glade', gladedir)
+
     def activate_plugin(self, plugin_name):
         """Activates a plugin
 
@@ -218,13 +238,13 @@ class PluginManager(object):
         if migration:
             try:
                 migration.apply_all_patches()
-            except SQLError:
+            except SQLError as e:
                 # This means a lock could not be obtained. Warn user about this
                 # and let stoq restart, that the schema will be upgraded
                 # correctly
                 error('Não foi possível terminar a instalação do plugin. '
                       'Por favor reinicie todas as instancias do Stoq que '
-                      'estiver executando')
+                      'estiver executando (%s)' % (e, ))
 
     def activate_installed_plugins(self):
         """Activate all installed plugins
