@@ -73,7 +73,8 @@ class TestBank(DomainTest):
                        bank_account=bank_account,
                        option=unicode(key),
                        value=value)
-        api.sysparam(self.store).BILL_INSTRUCTIONS = u'Primeia linha da instrução'
+        api.sysparam.set_string(self.store, 'BILL_INSTRUCTIONS',
+                                u'Primeia linha da instrução')
 
     def _get_expected(self, filename, generated):
         fname = get_tests_datadir(filename + '.pdf.html')
@@ -86,7 +87,7 @@ class TestBank(DomainTest):
         self.add_product(sale)
         sale.order()
         self.payment = self.add_payments(sale, method_type=u'bill',
-                                         date=datetime.date(2011, 5, 30))[0]
+                                         date=datetime.datetime(2011, 5, 30))[0]
         sale.client = self.create_client()
         address = self.create_address()
         address.person = sale.client.person
@@ -111,54 +112,60 @@ class TestBank(DomainTest):
         diff = diff_pdf_htmls(expected, generated)
         self.failIf(diff, '%s\n%s' % ("Files differ, output:", diff))
 
-    def testBancoDoBrasil(self):
+    def test_banco_do_brasil(self):
         sale = self._create_bill_sale()
         self._configure_boleto(u"001",
                                convenio=u"12345678",
                                agency=u"1172",
-                               account=u"00403005")
+                               account=u"00403005",
+                               especie_documento=u"DM")
         self._diff(sale, 'boleto-001')
 
-    def testBancoDoBrasilComDV(self):
+    def test_banco_do_brasil_com_d_v(self):
         sale = self._create_bill_sale()
         self._configure_boleto(u"001",
                                convenio=u"12345678",
                                agency=u"1172-X",
-                               account=u"00403005-X")
+                               account=u"00403005-X",
+                               especie_documento=u"DM")
         self._diff(sale, 'boleto-001')
 
-    def testNossaCaixa(self):
+    def test_nossa_caixa(self):
         sale = self._create_bill_sale()
         self._configure_boleto(u"104",
                                agency=u"1565",
-                               account=u"414-3")
+                               account=u"414-3",
+                               especie_documento=u"DM")
 
         self._diff(sale, 'boleto-104')
 
-    def testItau(self):
+    def test_itau(self):
         sale = self._create_bill_sale()
         self._configure_boleto(u"341",
                                account=u"13877",
                                agency=u"1565",
-                               carteira=u'175')
+                               carteira=u'175',
+                               especie_documento=u"DM")
 
         self._diff(sale, 'boleto-341')
 
-    def testBradesco(self):
+    def test_bradesco(self):
         sale = self._create_bill_sale()
         self._configure_boleto(u"237",
                                account=u"029232-4",
                                agency=u"278-0",
-                               carteira=u'06')
+                               carteira=u'06',
+                               especie_documento=u"DM")
 
         self._diff(sale, 'boleto-237')
 
-    def testReal(self):
+    def test_real(self):
         sale = self._create_bill_sale()
         self._configure_boleto(u"356",
                                account=u"5705853",
                                agency=u"0531",
-                               carteira=u'06')
+                               carteira=u'06',
+                               especie_documento=u"DM")
 
         self._diff(sale, 'boleto-356')
 
@@ -168,6 +175,7 @@ class TestBancoBanrisul(unittest.TestCase):
         self.dados = BankBanrisul(
             agencia=u'1102',
             conta=u'9000150',
+            especie_documento=u'DM',
             data_vencimento=datetime.date(2000, 7, 4),
             valor_documento=550,
             nosso_numero=u'22832563',
@@ -205,6 +213,7 @@ class TestBB(unittest.TestCase):
             valor_documento=2952.95,
             agencia=u'9999',
             conta=u'99999',
+            especie_documento=u'DM',
             convenio=u'7777777',
             nosso_numero=u'87654',
         )
@@ -212,13 +221,13 @@ class TestBB(unittest.TestCase):
 
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
-            '00190.00009 07777.777009 00087.654182 6 49000000295295'
-        )
+                         '00190.00009 07777.777009 00087.654182 6 49000000295295'
+                         )
 
     def test_codigo_de_barras(self):
         self.assertEqual(self.dados.barcode,
-            '00196490000002952950000007777777000008765418'
-        )
+                         '00196490000002952950000007777777000008765418'
+                         )
 
     def test_validate_field(self):
         valid = ['0295-x',
@@ -238,6 +247,7 @@ class TestBancoBradesco(unittest.TestCase):
             carteira=u'06',
             agencia=u'278-0',
             conta=u'039232-4',
+            especie_documento=u'DM',
             data_vencimento=datetime.date(2011, 2, 5),
             valor_documento=8280.00,
             nosso_numero=u'2125525',
@@ -247,6 +257,7 @@ class TestBancoBradesco(unittest.TestCase):
             carteira=u'06',
             agencia=u'1172',
             conta=u'403005',
+            especie_documento=u'DM',
             data_vencimento=datetime.date(2011, 3, 9),
             valor_documento=2952.95,
             nosso_numero=u'75896452',
@@ -255,20 +266,20 @@ class TestBancoBradesco(unittest.TestCase):
 
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
-            '23790.27804 60000.212559 25003.923205 4 48690000828000'
-        )
+                         '23790.27804 60000.212559 25003.923205 4 48690000828000'
+                         )
 
         self.assertEqual(self.dados2.linha_digitavel,
-            '23791.17209 60007.589645 52040.300502 1 49010000295295'
-        )
+                         '23791.17209 60007.589645 52040.300502 1 49010000295295'
+                         )
 
     def test_codigo_de_barras(self):
         self.assertEqual(self.dados.barcode,
-            '23794486900008280000278060000212552500392320'
-        )
+                         '23794486900008280000278060000212552500392320'
+                         )
         self.assertEqual(self.dados2.barcode,
-            '23791490100002952951172060007589645204030050'
-        )
+                         '23791490100002952951172060007589645204030050'
+                         )
 
     def test_agencia(self):
         self.assertEqual(self.dados.agencia, '0278-0')
@@ -286,7 +297,7 @@ class TestBancoBradesco(unittest.TestCase):
         for v in valid:
             self.dados.validate_field(v)
 
-    def testCarteira(self):
+    def test_carteira(self):
         x = BankBradesco(
             carteira=u'9',
             agencia=u'02752',
@@ -312,6 +323,7 @@ class TestBancoCaixa(unittest.TestCase):
             carteira=u'SR',
             agencia=u'1565',
             conta=u'414-3',
+            especie_documento=u'DM',
             data_vencimento=datetime.date(2011, 2, 5),
             valor_documento=355.00,
             nosso_numero=u'19525086',
@@ -319,16 +331,16 @@ class TestBancoCaixa(unittest.TestCase):
 
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
-            '10498.01952 25086.156509 00000.004143 7 48690000035500'
-        )
+                         '10498.01952 25086.156509 00000.004143 7 48690000035500'
+                         )
 
     def test_tamanho_codigo_de_barras(self):
         self.assertEqual(len(self.dados.barcode), 44)
 
     def test_codigo_de_barras(self):
         self.assertEqual(self.dados.barcode,
-            '10497486900000355008019525086156500000000414'
-        )
+                         '10497486900000355008019525086156500000000414'
+                         )
 
 
 class TestBancoItau(unittest.TestCase):
@@ -337,6 +349,7 @@ class TestBancoItau(unittest.TestCase):
             carteira=u'110',
             conta=u'12345-7',
             agencia=u'0057',
+            especie_documento=u'DM',
             data_vencimento=datetime.date(2002, 5, 1),
             valor_documento=123.45,
             nosso_numero=u'12345678',
@@ -344,13 +357,13 @@ class TestBancoItau(unittest.TestCase):
 
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
-            '34191.10121 34567.880058 71234.570001 6 16670000012345'
-        )
+                         '34191.10121 34567.880058 71234.570001 6 16670000012345'
+                         )
 
     def test_codigo_de_barras(self):
         self.assertEqual(self.dados.barcode,
-             '34196166700000123451101234567880057123457000'
-        )
+                         '34196166700000123451101234567880057123457000'
+                         )
 
 
 class TestBancoReal(unittest.TestCase):
@@ -359,6 +372,7 @@ class TestBancoReal(unittest.TestCase):
             carteira=u'06',
             agencia=u'0531',
             conta=u'5705853',
+            especie_documento=u'DM',
             data_vencimento=datetime.date(2011, 2, 5),
             valor_documento=355.00,
             nosso_numero=u'123',
@@ -366,13 +380,13 @@ class TestBancoReal(unittest.TestCase):
 
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
-            '35690.53154 70585.390001 00000.001230 8 48690000035500'
-        )
+                         '35690.53154 70585.390001 00000.001230 8 48690000035500'
+                         )
 
     def test_codigo_de_barras(self):
         self.assertEqual(self.dados.barcode,
-            '35698486900000355000531570585390000000000123'
-        )
+                         '35698486900000355000531570585390000000000123'
+                         )
 
 
 class TestSantander(unittest.TestCase):
@@ -380,6 +394,7 @@ class TestSantander(unittest.TestCase):
         self.dados = BankSantander(
             agencia=u'1333',
             conta=u'0707077',
+            especie_documento=u'DM',
             data_vencimento=datetime.date(2012, 1, 22),
             valor_documento=2952.95,
             nosso_numero=u'1234567',
@@ -387,16 +402,16 @@ class TestSantander(unittest.TestCase):
 
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
-            '03399.07073 07700.000123 34567.901029 6 52200000295295'
-        )
+                         '03399.07073 07700.000123 34567.901029 6 52200000295295'
+                         )
 
     def test_tamanho_codigo_de_barras(self):
         self.assertEqual(len(self.dados.barcode), 44)
 
     def test_codigo_de_barras(self):
         self.assertEqual(self.dados.barcode,
-            '03396522000002952959070707700000123456790102'
-        )
+                         '03396522000002952959070707700000123456790102'
+                         )
 
 if __name__ == '__main__':
     unittest.main()
