@@ -25,15 +25,30 @@
 
 import unittest
 
-from stoqlib.lib.formatters import format_phone_number
+from stoqlib.domain.test.domaintest import DomainTest
+from stoqlib.lib.formatters import (format_phone_number,
+                                    format_sellable_description)
 
 
-class TestValidators(unittest.TestCase):
-    def testFormatPhoneNumber(self):
+class TestFormatters(DomainTest):
+    def test_format_sellable_description(self):
+        sellable = self.create_sellable()
+        sellable.description = u"Cellphone"
+        self.assertEqual(format_sellable_description(sellable),
+                         u"Cellphone")
+
+        storable = self.create_storable(product=sellable.product)
+        batch = self.create_storable_batch(storable=storable,
+                                           batch_number=u'666')
+        self.assertEqual(format_sellable_description(sellable, batch=batch),
+                         u"Cellphone [Batch: 666]")
+
+    def test_format_phone_number(self):
         self.assertEquals(format_phone_number("190"), "190")
         self.assertEquals(format_phone_number("1052"), "1052")
         self.assertEquals(format_phone_number("10325"), "103 25")
 
+        self.assertEquals(format_phone_number("991236789"), "99123-6789")
         self.assertEquals(format_phone_number("0300123456"), "0300 123-456")
         self.assertEquals(format_phone_number("03001234567"), "0300 123-4567")
         self.assertEquals(format_phone_number("0500700600"), "0500 700-600")
