@@ -98,17 +98,16 @@ NEWFILEUID:NONE
 </BANKMSGSRSV1>
 </OFX>"""
 
-OFX_DATA2 = """OFXHEADER:100
-DATA:OFXSGML
-VERSION:102
-SECURITY:NONE
-ENCODING:USASCII
-CHARSET:1252
-COMPRESSION:NONE
-OLDFILEUID:NONE
-NEWFILEUID:NONE
-
-<OFX>
+OFX_DATA2 = ("OFXHEADER:100\r:"
+             "DATA:OFXSGML\r"
+             "VERSION:102\r"
+             "SECURITY:NONE\r"
+             "ENCODING:USASCII\r"
+             "CHARSET:1252\r"
+             "CO MPRESSION:NONE\r"
+             "OLDFILEUID:NONE\r"
+             "NEWFILEUID:NONE\r\r"
+             """<OFX>
    <SIGNONMSGSRSV1>
       <SONRS>
          <STATUS>
@@ -157,7 +156,7 @@ NEWFILEUID:NONE
          </STMTRS>
       </STMTTRNRS>
    </BANKMSGSRSV1>
-</OFX>"""
+</OFX>""")
 
 OFX_DATA3 = """OFXHEADER:100
 DATA:OFXSGML
@@ -222,12 +221,12 @@ NEWFILEUID:NONE
 
 
 class OFXImporterTest(DomainTest):
-    def testOFXImportBBJurdica(self):
+    def test_import_bb_juridica(self):
         ofx = OFXImporter()
         ofx.feed(StringIO(OFX_DATA))
         ofx.set_dry(True)
         ofx.process(self.store)
-        account = self.store.find(Account).order_by(Account.id).last()
+        account = self.store.find(Account).order_by(Account.code).first()
         self.failUnless(account)
         self.assertEquals(account.description, "Bank - CHECKING")
         self.assertEquals(account.code, "1234")
@@ -239,12 +238,12 @@ class OFXImporterTest(DomainTest):
         self.assertEquals(t2.value, 50)
         self.assertEquals(t2.code, '90068258')
 
-    def testOFXImportBBFisica(self):
+    def test_import_bb_fisica(self):
         ofx = OFXImporter()
         ofx.feed(StringIO(OFX_DATA2))
         ofx.set_dry(True)
         ofx.process(self.store)
-        account = self.store.find(Account).order_by(Account.id).last()
+        account = self.store.find(Account).order_by(Account.code).first()
         self.failUnless(account)
         self.assertEquals(account.description, "Banco do Brasil - CHECKING")
         self.assertEquals(account.code, "67890-X")
@@ -256,12 +255,12 @@ class OFXImporterTest(DomainTest):
         self.assertEquals(t.description,
                           'Compra com Cartão - 01/01 01:23 BURRITOS')
 
-    def testOFXImportSantander(self):
+    def test_import_santander(self):
         ofx = OFXImporter()
         ofx.feed(StringIO(OFX_DATA3))
         ofx.set_dry(True)
         ofx.process(self.store)
-        account = self.store.find(Account).order_by(Account.id).last()
+        account = self.store.find(Account).order_by(Account.code).first()
         self.failUnless(account)
         self.assertEquals(account.description, u"SANTANDER - CHECKING")
         self.assertEquals(account.code, u"012345678")
