@@ -25,20 +25,34 @@
 
 """Test for stoqlib.lib.pluginmanager module"""
 
-from zope.interface import implements
+import io
+
+import mock
+from zope.interface import implementer
 
 from stoqlib.database.runtime import new_store
 from stoqlib.domain.plugin import InstalledPlugin
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.interfaces import IPlugin, IPluginManager
 from stoqlib.lib.pluginmanager import (PluginError, register_plugin,
-                                       PluginManager, get_plugin_manager)
+                                       PluginManager, get_plugin_manager,
+                                       PluginDescription)
+
+plugin_desc = """
+[Plugin]
+Module=testplugin
+Version=1
+Name=Test plugin
+Description=Test plugin description
+Authors=Stoq Team <stoq-devel@async.com.br>
+Copyright=Copyright © 2007 Async Open Source
+Website=http://www.stoq.com.br/
+"""
 
 
+@implementer(IPlugin)
 class _TestPlugin(object):
 
-    implements(IPlugin)
-
     name = u'test_plugin'
 
     def __init__(self):
@@ -60,6 +74,24 @@ class _TestPlugin(object):
         return None
 
 
+class TestPluginDescription(DomainTest):
+
+    @mock.patch('stoqlib.lib.pluginmanager.ZipFile')
+    @mock.patch('stoqlib.lib.pluginmanager.is_zipfile')
+    def test_constructor_is_egg(self, is_zipfile, ZipFile):
+        ZipFile.return_value = mock.MagicMock()
+        egg = ZipFile.return_value.__enter__.return_value
+        egg.namelist.return_value = ['test.plugin']
+        egg.open.return_value = io.BytesIO(plugin_desc)
+
+        desc = PluginDescription('tmpfile', is_egg=True)
+
+        is_zipfile.assert_called_once_with('tmpfile')
+        self.assertEquals(desc.filename, 'test.plugin')
+        self.assertEquals(desc.plugin_path, 'tmpfile')
+        self.assertEquals(desc.long_name, 'Test plugin')
+
+
 class TestPluginManager(DomainTest):
 
     def setUp(self):
@@ -68,6 +100,9 @@ class TestPluginManager(DomainTest):
         # Since the plugins are commited inside pluginmanager, try to remove
         # it first, or we will have problems if STOQLIB_TEST_QUICK is set.
         store = new_store()
+        plugins = set(InstalledPlugin.get_plugin_names(store=self.store))
+        expected = set([u'ecf', u'nfe', u'optical'])
+        self.assertTrue(expected.issubset(plugins))
         test_plugin = store.find(InstalledPlugin,
                                  plugin_name=_TestPlugin.name).one()
         if test_plugin:
