@@ -20,7 +20,6 @@
 ## Foundation, Inc., or visit: http://www.gnu.org/.
 ##
 
-import datetime
 from decimal import Decimal
 import os
 
@@ -29,6 +28,7 @@ from dateutil.relativedelta import relativedelta
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.devices import FiscalDayHistory, FiscalDayTax
 from stoqlib.domain.test.domaintest import DomainTest
+from stoqlib.lib.dateutils import localdate, localdatetime
 from stoqlib.lib.diffutils import diff_files
 from stoqlib.lib.sintegra import SintegraFile
 from stoqlib.lib.unittestutils import get_tests_datadir
@@ -47,10 +47,10 @@ def compare_sintegra_file(sfile, basename):
 
 
 class SintegraTest(DomainTest):
-    def testComplete(self):
+    def test_complete(self):
         station = self.create_station()
-        today = datetime.date(2007, 1, 1)
-        reduction_date = datetime.datetime(2007, 1, 1, 23, 59)
+        today = localdate(2007, 1, 1)
+        reduction_date = localdatetime(2007, 1, 1, 23, 59)
         day = FiscalDayHistory(store=self.store,
                                emission_date=today,
                                station=station,
@@ -81,7 +81,7 @@ class SintegraTest(DomainTest):
         s = SintegraFile()
         s.add_header(company.get_cnpj_number(),
                      u'110042490114',
-                     company.fancy_name,
+                     branch.get_description(),
                      address.get_city(),
                      address.get_state(),
                      branch.person.get_fax_number_number(),
