@@ -26,19 +26,19 @@
 import datetime
 import json
 import os
+import logging
 import urllib
 import platform
 import sys
 
-from zope.interface import implements
 from kiwi.component import get_utility
-from kiwi.log import Logger
 from twisted.internet import reactor
 from twisted.internet.defer import succeed, Deferred
 from twisted.internet.protocol import Protocol
 from twisted.web.client import Agent
 from twisted.web.http_headers import Headers
 from twisted.web.iweb import IBodyProducer
+from zope.interface import implementer
 
 from stoqlib.database.runtime import get_default_store
 from stoqlib.exceptions import StoqlibError
@@ -48,7 +48,7 @@ from stoqlib.lib.osutils import get_product_key
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.pluginmanager import InstalledPlugin
 
-log = Logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class JsonDownloader(Protocol):
@@ -64,7 +64,7 @@ class JsonDownloader(Protocol):
         if not is_developer_mode():
             return
 
-        from stoqlib.gui.webview import show_html
+        from stoqlib.gui.widgets.webview import show_html
         show_html(data)
 
     def dataReceived(self, bytes):
@@ -80,9 +80,8 @@ class JsonDownloader(Protocol):
         self.finished.callback(data)
 
 
+@implementer(IBodyProducer)
 class StringProducer(object):
-    implements(IBodyProducer)
-
     def __init__(self, body):
         self.body = body
         self.length = len(body)
@@ -159,7 +158,7 @@ class WebService(object):
         result = default_store.execute("""SELECT company.cnpj
           FROM parameter_data, branch, company, person
          WHERE field_name = 'MAIN_COMPANY' AND
-               branch.id = field_value::int AND
+               branch.id::text = field_value AND
                branch.person_id = person.id AND
                company.person_id = person.id;""")
         data = result.get_one()
@@ -179,7 +178,7 @@ class WebService(object):
         :returns: a deferred with the version_string as a parameter
         """
         params = {
-            'demo': sysparam(store).DEMO_MODE,
+            'demo': sysparam.get_bool('DEMO_MODE'),
             'dist': platform.dist(),
             'cnpj': self._get_cnpj(),
             'plugins': InstalledPlugin.get_plugin_names(store),
@@ -198,7 +197,7 @@ class WebService(object):
         }
         if os.environ.get('STOQ_DISABLE_CRASHREPORT'):
             d = Deferred()
-            print >> sys.stderr, report
+            sys.stderr.write(report)
             d.callback({'report-url': '<not submitted>',
                         'report': '<none>'})
             return d
@@ -223,7 +222,7 @@ class WebService(object):
         default_store = get_default_store()
         params = {
             'cnpj': self._get_cnpj(),
-            'demo': sysparam(default_store).DEMO_MODE,
+            'demo': sysparam.get_bool('DEMO_MODE'),
             'dist': ' '.join(platform.dist()),
             'email': email,
             'feedback': feedback,
