@@ -51,17 +51,20 @@ class BoletoPDF(object):
         self.file_descr = file_descr
         self.width = 190 * mm
         self.widthCanhoto = 70 * mm
-        self.heightLine = 6.5 * mm
         self.space = 2
         self.fontSizeTitle = 6
         self.fontSizeValue = 9
-        self.deltaTitle = self.heightLine - (self.fontSizeTitle + 1)
-        self.deltaFont = self.fontSizeValue + 1
-        self.format = format
 
         pagesize = pagesizes.A4
         if format == self.FORMAT_CARNE:
             pagesize = pagesizes.landscape(pagesize)
+            self.heightLine = 5.75 * mm
+        else:
+            self.heightLine = 6.5 * mm
+
+        self.deltaTitle = self.heightLine - (self.fontSizeTitle + 1)
+        self.deltaFont = self.fontSizeValue + 1
+        self.format = format
 
         self.pdfCanvas = canvas.Canvas(self.file_descr, pagesize=pagesize)
         self.pdfCanvas.setStrokeColor(colors.black)
@@ -80,25 +83,25 @@ class BoletoPDF(object):
 
         self.pdfCanvas.setLineWidth(1)
         self._horizontalLine(0, (linhaInicial + 0) * self.heightLine,
-            self.widthCanhoto)
+                             self.widthCanhoto)
         self._horizontalLine(0, (linhaInicial + 1) * self.heightLine,
-            self.widthCanhoto)
+                             self.widthCanhoto)
 
         self.pdfCanvas.setLineWidth(2)
         self._horizontalLine(0, (linhaInicial + 2) * self.heightLine,
-            self.widthCanhoto)
+                             self.widthCanhoto)
 
         # Vertical Lines
         self.pdfCanvas.setLineWidth(1)
         self._verticalLine(self.widthCanhoto - (35 * mm),
-            (linhaInicial + 0) * self.heightLine, self.heightLine)
+                          (linhaInicial + 0) * self.heightLine, self.heightLine)
         self._verticalLine(self.widthCanhoto - (35 * mm),
-            (linhaInicial + 1) * self.heightLine, self.heightLine)
+                          (linhaInicial + 1) * self.heightLine, self.heightLine)
 
         self.pdfCanvas.setFont('Helvetica-Bold', 6)
         self.pdfCanvas.drawRightString(self.widthCanhoto,
-            0 * self.heightLine + 3,
-            'Recibo do Sacado')
+                                       0 * self.heightLine + 3,
+                                       'Recibo do Sacado')
 
         # Titles
         self.pdfCanvas.setFont('Helvetica', 6)
@@ -168,38 +171,63 @@ class BoletoPDF(object):
 
         # Horizontal Lines
         self.pdfCanvas.setLineWidth(1)
+        # Cedente
         self._horizontalLine(0,
-            linhaInicial * self.heightLine, self.width)
+                             linhaInicial * self.heightLine, self.width)
+        # Endereço
         self._horizontalLine(0,
-            (linhaInicial + 1) * self.heightLine, self.width)
+                            (linhaInicial + 1) * self.heightLine, self.width)
+        # Sacado
+        self._horizontalLine(0,
+                            (linhaInicial - 1) * self.heightLine, self.width)
 
         self.pdfCanvas.setLineWidth(2)
         self._horizontalLine(0,
-            (linhaInicial + 2) * self.heightLine, self.width)
+                            (linhaInicial + 2) * self.heightLine, self.width)
 
         # Vertical Lines
+
+        # Vertical line 1
+        # Linha Sacado
+        self.pdfCanvas.setLineWidth(1)
+        self._verticalLine(
+            self.width - (35 * mm) - (30 * mm) - (40 * mm),
+            (linhaInicial - 1) * self.heightLine,
+            1 * self.heightLine)
+        # Linha Cedente
+        self._verticalLine(
+            self.width - (35 * mm) - (30 * mm) - (40 * mm),
+            (linhaInicial + 1) * self.heightLine,
+            1 * self.heightLine)
+
+        # Vertical line 2
+        # Cedente
+        self.pdfCanvas.setLineWidth(1)
+        self._verticalLine(
+            self.width - (35 * mm) - (30 * mm),
+            (linhaInicial + 1) * self.heightLine,
+            1 * self.heightLine)
+        # Sacado
+        self.pdfCanvas.setLineWidth(1)
+        self._verticalLine(
+            self.width - (35 * mm) - (30 * mm),
+            (linhaInicial - 1) * self.heightLine,
+            1 * self.heightLine)
+
+        # Vertical line 3
+        # Cedente/Endereço/Sacado
         self.pdfCanvas.setLineWidth(1)
         self._verticalLine(
             self.width - (35 * mm),
-            (linhaInicial + 0) * self.heightLine,
-            2 * self.heightLine)
-
-        self._verticalLine(
-            self.width - (35 * mm) - (30 * mm),
-            (linhaInicial + 0) * self.heightLine,
-            2 * self.heightLine)
-
-        self._verticalLine(
-            self.width - (35 * mm) - (30 * mm) - (40 * mm),
-            (linhaInicial + 0) * self.heightLine,
-            2 * self.heightLine)
+            (linhaInicial + -1) * self.heightLine,
+            3 * self.heightLine)
 
         # Head
         self.pdfCanvas.setLineWidth(2)
         self._verticalLine(40 * mm,
-            (linhaInicial + 2) * self.heightLine, self.heightLine)
+                          (linhaInicial + 2) * self.heightLine, self.heightLine)
         self._verticalLine(60 * mm,
-            (linhaInicial + 2) * self.heightLine, self.heightLine)
+                          (linhaInicial + 2) * self.heightLine, self.heightLine)
 
         if boletoDados.logo_image_path:
             self.pdfCanvas.drawImage(
@@ -231,6 +259,7 @@ class BoletoPDF(object):
             self.heightLine,
             'Autenticação Mecânica')
 
+        # Linha Cedente
         self.pdfCanvas.drawString(
             0,
             (((linhaInicial + 1) * self.heightLine)) + self.deltaTitle,
@@ -248,36 +277,48 @@ class BoletoPDF(object):
             (((linhaInicial + 1) * self.heightLine)) + self.deltaTitle,
             'Vencimento')
 
+        # Linha Endereço
         self.pdfCanvas.drawString(
             0,
             (((linhaInicial + 0) * self.heightLine)) + self.deltaTitle,
-            'Sacado')
-        self.pdfCanvas.drawString(
-            self.width - (35 * mm) - (30 * mm) - (40 * mm) + self.space,
-            (((linhaInicial + 0) * self.heightLine)) + self.deltaTitle,
-            'Nosso Número')
-        self.pdfCanvas.drawString(
-            self.width - (35 * mm) - (30 * mm) + self.space,
-            (((linhaInicial + 0) * self.heightLine)) + self.deltaTitle,
-            'N. do documento')
+            'Endereço Cedente')
         self.pdfCanvas.drawString(
             self.width - (35 * mm) + self.space,
             (((linhaInicial + 0) * self.heightLine)) + self.deltaTitle,
+            'CNPJ Cedente')
+
+        # Linha Sacado
+        self.pdfCanvas.drawString(
+            0,
+            (((linhaInicial - 1) * self.heightLine)) + self.deltaTitle,
+            'Sacado')
+        self.pdfCanvas.drawString(
+            self.width - (35 * mm) - (30 * mm) - (40 * mm) + self.space,
+            (((linhaInicial - 1) * self.heightLine)) + self.deltaTitle,
+            'Nosso Número')
+        self.pdfCanvas.drawString(
+            self.width - (35 * mm) - (30 * mm) + self.space,
+            (((linhaInicial - 1) * self.heightLine)) + self.deltaTitle,
+            'N. do documento')
+        self.pdfCanvas.drawString(
+            self.width - (35 * mm) + self.space,
+            (((linhaInicial - 1) * self.heightLine)) + self.deltaTitle,
             'Valor Documento')
 
         self.pdfCanvas.drawString(
             0,
-            (((linhaInicial - 1) * self.heightLine)) + self.deltaTitle,
+            (((linhaInicial - 2) * self.heightLine)) + self.deltaTitle,
             'Demonstrativo')
 
         # Values
         self.pdfCanvas.setFont('Helvetica', 9)
         heighFont = 9 + 1
 
+        # Valores da linha Cedente
         self.pdfCanvas.drawString(
             0 + self.space,
             (((linhaInicial + 1) * self.heightLine)) + self.space,
-            boletoDados.cedente)
+            boletoDados.cedente[0])
         self.pdfCanvas.drawString(
             self.width - (35 * mm) - (30 * mm) - (40 * mm) + self.space,
             (((linhaInicial + 1) * self.heightLine)) + self.space,
@@ -291,31 +332,45 @@ class BoletoPDF(object):
             (((linhaInicial + 1) * self.heightLine)) + self.space,
             boletoDados.data_vencimento.strftime('%d/%m/%Y'))
 
+        # Valores da linha Endereço
+        # Endereço
+        self.pdfCanvas.drawString(
+            0 + self.space,
+            (((linhaInicial + 0) * self.heightLine)) + self.space,
+            '{endereco}, {detalhe_end}'.format(endereco=boletoDados.cedente[1],
+                                               detalhe_end=boletoDados.cedente[2]))
+        # CNPJ
+        self.pdfCanvas.drawString(
+            self.width - (35 * mm) + self.space,
+            (((linhaInicial + 0) * self.heightLine)) + self.space,
+            boletoDados.cedente[3])
+
+        # Valores da linha Sacado
         valorDocumento = self._formataValorParaExibir(
             boletoDados.valor_documento)
 
         self.pdfCanvas.drawString(
             0 + self.space,
-            (((linhaInicial + 0) * self.heightLine)) + self.space,
+            (((linhaInicial - 1) * self.heightLine)) + self.space,
             boletoDados.sacado[0])
         self.pdfCanvas.drawString(
             self.width - (35 * mm) - (30 * mm) - (40 * mm) + self.space,
-            (((linhaInicial + 0) * self.heightLine)) + self.space,
+            (((linhaInicial - 1) * self.heightLine)) + self.space,
             boletoDados.format_nosso_numero())
         self.pdfCanvas.drawString(
             self.width - (35 * mm) - (30 * mm) + self.space,
-            (((linhaInicial + 0) * self.heightLine)) + self.space,
+            (((linhaInicial - 1) * self.heightLine)) + self.space,
             boletoDados.numero_documento)
         self.pdfCanvas.drawString(
             self.width - (35 * mm) + self.space,
-            (((linhaInicial + 0) * self.heightLine)) + self.space,
+            (((linhaInicial - 1) * self.heightLine)) + self.space,
             valorDocumento)
 
         demonstrativo = boletoDados.demonstrativo[0:25]
         for i in range(len(demonstrativo)):
             self.pdfCanvas.drawString(
                 2 * self.space,
-                (((linhaInicial - 1) * self.heightLine)) - (i * heighFont),
+                (((linhaInicial - 2) * self.heightLine)) - (i * heighFont),
                 demonstrativo[i])
 
         self.pdfCanvas.restoreState()
@@ -567,7 +622,7 @@ class BoletoPDF(object):
             'Agência/Código cedente')
 
         self.pdfCanvas.setFont('Helvetica', self.fontSizeValue)
-        self.pdfCanvas.drawString(0, y + self.space, boletoDados.cedente)
+        self.pdfCanvas.drawString(0, y + self.space, boletoDados.cedente[0])
         self.pdfCanvas.drawRightString(
             self.width - 2 * self.space,
             y + self.space,
@@ -602,8 +657,8 @@ class BoletoPDF(object):
         y += self.heightLine
         self._horizontalLine(0, y, self.width)
         self.pdfCanvas.setLineWidth(2)
-        self._verticalLine(40 * mm, y, self.heightLine) # Logo Tipo
-        self._verticalLine(60 * mm, y, self.heightLine) # Numero do Banco
+        self._verticalLine(40 * mm, y, self.heightLine)  # Logo Tipo
+        self._verticalLine(60 * mm, y, self.heightLine)  # Numero do Banco
 
         if boletoDados.logo_image_path:
             self.pdfCanvas.drawImage(
@@ -633,26 +688,30 @@ class BoletoPDF(object):
         return self.width, (y + self.heightLine) / mm
 
     def drawBoletoCarneDuplo(self, boletoDados1, boletoDados2):
-        y = 5
+        if self.format == self.FORMAT_CARNE:
+            y = 25
+        else:
+            y = 5
+
         d = self.drawBoletoCarne(boletoDados1, y)
         y += d[1] + 6
-        #self.drawHorizontalCorteLine(0, y, d[0])
+        # self.drawHorizontalCorteLine(0, y, d[0])
         y += 7
         if boletoDados2:
             self.drawBoletoCarne(boletoDados2, y)
 
     def drawBoletoCarne(self, boletoDados, y):
-        x = 15
+        x = 5
         d = self.drawReciboSacadoCanhoto(boletoDados, x, y)
-        x += d[0] + 8
+        x += d[0] + 6
         self.drawVerticalCorteLine(x, y, d[1])
-        x += 8
+        x += 6
         d = self.drawReciboCaixa(boletoDados, x, y)
         x += d[0]
         return x, d[1]
 
     def drawBoleto(self, boletoDados):
-        x = 10
+        x = 5
         y = 40
         self.drawHorizontalCorteLine(x, y, self.width / mm)
         y += 5
@@ -715,7 +774,7 @@ class BoletoPDF(object):
         altura = 13 * mm
         comprimento = 103 * mm
 
-        tracoFino = 0.254320987654 * mm # Tamanho correto aproximado
+        tracoFino = 0.254320987654 * mm  # Tamanho correto aproximado
 
         bc = I2of5(num,
                    barWidth=tracoFino,
@@ -801,11 +860,14 @@ class BillReport(object):
         format = BoletoPDF.FORMAT_BOLETO
         if len(self._payments) > 1:
             format = BoletoPDF.FORMAT_CARNE
+            # This is a PrintOperationPoppler's workaround to really print
+            # the page in landscape, without cutting the edges
+            self.print_as_landscape = True
         return BoletoPDF(self._filename, format)
 
     def _get_instrucoes(self, payment):
         instructions = []
-        data = sysparam(payment.store).BILL_INSTRUCTIONS
+        data = sysparam.get_string('BILL_INSTRUCTIONS')
         for line in data.split('\n')[:3]:
             line = line.replace('$DATE', payment.due_date.strftime('%d/%m/%Y'))
             instructions.append(line)
@@ -836,8 +898,13 @@ class BillReport(object):
         if parent:
             branch = parent.branch
         else:
-            branch = sysparam(payment.store).MAIN_COMPANY
-        return branch.get_description()
+            branch = sysparam.get_object(payment.store, 'MAIN_COMPANY')
+
+        address = branch.person.get_main_address()
+        return [branch.get_description(),
+                address.get_address_string(),
+                address.get_details_string(),
+                branch.person.company.cnpj]
 
     def _get_account(self, payment):
         if self._account:
@@ -869,8 +936,8 @@ class BillReport(object):
             data_documento=payment.open_date.date(),
             data_processamento=self.today,
             # FIXME: Maybe we should add the branch id to this numbers
-            nosso_numero=str(payment.identifier),
-            numero_documento=str(payment.identifier),
+            nosso_numero=str(int(payment.identifier)),
+            numero_documento=str(int(payment.identifier)),
             sacado=self._get_sacado(),
             cedente=self._get_cedente(),
             demonstrativo=self._get_demonstrativo(),
