@@ -49,7 +49,7 @@ class LabelReport(object):
             for i in range(model.quantity):
                 # XXX: glabels is not working with unicode caracters
                 desc = strip_accents(model.description)
-                self.rows.append([model.code, model.barcode[:-1], desc,
+                self.rows.append([model.code, model.barcode, desc,
                                   model.price])
 
     def save(self):
@@ -60,7 +60,7 @@ class LabelReport(object):
         writer.writerows(self.rows)
         temp_csv.close()
 
-        template_file = sysparam(self.store).LABEL_TEMPLATE_PATH.path
+        template_file = sysparam.get_string('LABEL_TEMPLATE_PATH')
         if not os.path.exists(template_file):
             raise ValueError(_('Template file for printing labels was not found.'))
 
