@@ -67,10 +67,8 @@ class LoanReceipt(HTMLReport):
 
     def get_namespace(self):
         store = self.loan.store
-        sysparam_ = api.sysparam(store)
-
-        order_number = self.loan.get_order_number_str()
-        print_promissory_note = sysparam_.PRINT_PROMISSORY_NOTE_ON_LOAN
+        order_identifier = unicode(self.loan.identifier)
+        print_promissory_note = api.sysparam.get_bool('PRINT_PROMISSORY_NOTE_ON_LOAN')
         branch = api.get_current_branch(store)
         drawer_person = self.loan.branch.person
         drawee_person = self.loan.client.person
@@ -78,10 +76,10 @@ class LoanReceipt(HTMLReport):
         emission_location = emission_address.city_location
 
         promissory_data = Settable(
-            order_number=order_number,
+            order_identifier=order_identifier,
             payment_number=None,
             drawee=drawee_person.name,
-            drawer=drawer_person.name,
+            drawer=branch.get_description(),
             drawee_document=self._get_person_document(drawee_person),
             drawer_document=self._get_person_document(drawer_person),
             drawee_address=self._get_person_address(drawee_person),
@@ -90,14 +88,14 @@ class LoanReceipt(HTMLReport):
             value=self.loan.get_total_amount(),
             emission_city=emission_location.city,
             emission_date=datetime.date.today(),
-            )
+        )
 
         return dict(
-            subtitle=_("Loan number: %s") % order_number,
+            subtitle=_("Loan number: %s") % order_identifier,
             loan=self.loan,
             print_promissory_note=print_promissory_note,
             promissory_data=promissory_data,
-            )
+        )
 
     def adjust_for_test(self):
         # today is mocked on test
@@ -112,7 +110,7 @@ if __name__ == '__main__':  # pragma nocover
     from stoqlib.domain.loan import Loan
     import sys
     creator = api.prepare_test()
-    loan = creator.trans.find(Loan, id=int(sys.argv[-1])).one()
-    r = LoanReceipt('test.pdf', loan)
+    loan_ = creator.trans.find(Loan, id=int(sys.argv[-1])).one()
+    r = LoanReceipt('test.pdf', loan_)
     r.save_html('test.html')
     r.save()
